#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals

"""
拼音库，抓取自汉典网(zdic.net)。包含下列范围的 Unicode 字符：

CJK基本:[4E00-9FFF]       CJK扩展A:[3400-4DBF]
CJK扩展B:[20000-2A6DF]    CJK扩展C:[2A700-2B73F]
CJK扩展D:[2B740-2B81D]    CJK兼容扩展:[2F800-2FA1F]
CJK部首扩展:[2E80-2EFF]    CJK笔画:[31C0-31EF]
CJK康熙部首:[2F00-2FDF]    CJK兼容:[F900-FAFF]

注释掉了没有拼音的字符。
"""

# Unicode 编码作为字典的 key
pinyin_dict = {
    # CJK 部首扩展:[2E80-2EFF]
    # 0x2E80: '',  # ⺀
    # 0x2E81: '',  # ⺁
    # 0x2E82: '',  # ⺂
    # 0x2E83: '',  # ⺃
    # 0x2E84: '',  # ⺄
    # 0x2E85: '',  # ⺅
    # 0x2E86: '',  # ⺆
    # 0x2E87: '',  # ⺇
    # 0x2E88: '',  # ⺈
    # 0x2E89: '',  # ⺉
    # 0x2E8A: '',  # ⺊
    # 0x2E8B: '',  # ⺋
    # 0x2E8C: '',  # ⺌
    # 0x2E8D: '',  # ⺍
    # 0x2E8E: '',  # ⺎
    # 0x2E8F: '',  # ⺏
    # 0x2E90: '',  # ⺐
    # 0x2E91: '',  # ⺑
    # 0x2E92: '',  # ⺒
    # 0x2E93: '',  # ⺓
    # 0x2E94: '',  # ⺔
    # 0x2E95: '',  # ⺕
    # 0x2E96: '',  # ⺖
    # 0x2E97: '',  # ⺗
    # 0x2E98: '',  # ⺘
    # 0x2E99: '',  # ⺙
    # 0x2E9A: '',  # ⺚
    # 0x2E9B: '',  # ⺛
    # 0x2E9C: '',  # ⺜
    # 0x2E9D: '',  # ⺝
    # 0x2E9E: '',  # ⺞
    # 0x2E9F: '',  # ⺟
    # 0x2EA0: '',  # ⺠
    # 0x2EA1: '',  # ⺡
    # 0x2EA2: '',  # ⺢
    # 0x2EA3: '',  # ⺣
    # 0x2EA4: '',  # ⺤
    # 0x2EA5: '',  # ⺥
    # 0x2EA6: '',  # ⺦
    # 0x2EA7: '',  # ⺧
    # 0x2EA8: '',  # ⺨
    # 0x2EA9: '',  # ⺩
    # 0x2EAA: '',  # ⺪
    # 0x2EAB: '',  # ⺫
    # 0x2EAC: '',  # ⺬
    # 0x2EAD: '',  # ⺭
    # 0x2EAE: '',  # ⺮
    # 0x2EAF: '',  # ⺯
    # 0x2EB0: '',  # ⺰
    # 0x2EB1: '',  # ⺱
    # 0x2EB2: '',  # ⺲
    # 0x2EB3: '',  # ⺳
    # 0x2EB4: '',  # ⺴
    # 0x2EB5: '',  # ⺵
    # 0x2EB6: '',  # ⺶
    # 0x2EB7: '',  # ⺷
    # 0x2EB8: '',  # ⺸
    # 0x2EB9: '',  # ⺹
    # 0x2EBA: '',  # ⺺
    # 0x2EBB: '',  # ⺻
    # 0x2EBC: '',  # ⺼
    # 0x2EBD: '',  # ⺽
    # 0x2EBE: '',  # ⺾
    # 0x2EBF: '',  # ⺿
    # 0x2EC0: '',  # ⻀
    # 0x2EC1: '',  # ⻁
    # 0x2EC2: '',  # ⻂
    # 0x2EC3: '',  # ⻃
    # 0x2EC4: '',  # ⻄
    # 0x2EC5: '',  # ⻅
    # 0x2EC6: '',  # ⻆
    # 0x2EC7: '',  # ⻇
    # 0x2EC8: '',  # ⻈
    # 0x2EC9: '',  # ⻉
    # 0x2ECA: '',  # ⻊
    # 0x2ECB: '',  # ⻋
    # 0x2ECC: '',  # ⻌
    # 0x2ECD: '',  # ⻍
    # 0x2ECE: '',  # ⻎
    # 0x2ECF: '',  # ⻏
    # 0x2ED0: '',  # ⻐
    # 0x2ED1: '',  # ⻑
    # 0x2ED2: '',  # ⻒
    # 0x2ED3: '',  # ⻓
    # 0x2ED4: '',  # ⻔
    # 0x2ED5: '',  # ⻕
    # 0x2ED6: '',  # ⻖
    # 0x2ED7: '',  # ⻗
    # 0x2ED8: '',  # ⻘
    # 0x2ED9: '',  # ⻙
    # 0x2EDA: '',  # ⻚
    # 0x2EDB: '',  # ⻛
    # 0x2EDC: '',  # ⻜
    # 0x2EDD: '',  # ⻝
    # 0x2EDE: '',  # ⻞
    # 0x2EDF: '',  # ⻟
    # 0x2EE0: '',  # ⻠
    # 0x2EE1: '',  # ⻡
    # 0x2EE2: '',  # ⻢
    # 0x2EE3: '',  # ⻣
    # 0x2EE4: '',  # ⻤
    # 0x2EE5: '',  # ⻥
    # 0x2EE6: '',  # ⻦
    # 0x2EE7: '',  # ⻧
    # 0x2EE8: '',  # ⻨
    # 0x2EE9: '',  # ⻩
    # 0x2EEA: '',  # ⻪
    # 0x2EEB: '',  # ⻫
    # 0x2EEC: '',  # ⻬
    # 0x2EED: '',  # ⻭
    # 0x2EEE: '',  # ⻮
    # 0x2EEF: '',  # ⻯
    # 0x2EF0: '',  # ⻰
    # 0x2EF1: '',  # ⻱
    # 0x2EF2: '',  # ⻲
    # 0x2EF3: '',  # ⻳
    # 0x2EF4: '',  #
    # 0x2EF5: '',  #
    # 0x2EF6: '',  #
    # 0x2EF7: '',  #
    # 0x2EF8: '',  #
    # 0x2EF9: '',  #
    # 0x2EFA: '',  #
    # 0x2EFB: '',  #
    # 0x2EFC: '',  #
    # 0x2EFD: '',  #
    # 0x2EFE: '',  #
    # 0x2EFF: '',  #

    # CJK 康熙部首:[2F00-2FDF]
    # 0x2F00: '',  # ⼀
    # 0x2F01: '',  # ⼁
    # 0x2F02: '',  # ⼂
    # 0x2F03: '',  # ⼃
    # 0x2F04: '',  # ⼄
    # 0x2F05: '',  # ⼅
    # 0x2F06: '',  # ⼆
    # 0x2F07: '',  # ⼇
    # 0x2F08: '',  # ⼈
    # 0x2F09: '',  # ⼉
    # 0x2F0A: '',  # ⼊
    # 0x2F0B: '',  # ⼋
    # 0x2F0C: '',  # ⼌
    # 0x2F0D: '',  # ⼍
    # 0x2F0E: '',  # ⼎
    # 0x2F0F: '',  # ⼏
    # 0x2F10: '',  # ⼐
    # 0x2F11: '',  # ⼑
    # 0x2F12: '',  # ⼒
    # 0x2F13: '',  # ⼓
    # 0x2F14: '',  # ⼔
    # 0x2F15: '',  # ⼕
    # 0x2F16: '',  # ⼖
    # 0x2F17: '',  # ⼗
    # 0x2F18: '',  # ⼘
    # 0x2F19: '',  # ⼙
    # 0x2F1A: '',  # ⼚
    # 0x2F1B: '',  # ⼛
    # 0x2F1C: '',  # ⼜
    # 0x2F1D: '',  # ⼝
    # 0x2F1E: '',  # ⼞
    # 0x2F1F: '',  # ⼟
    # 0x2F20: '',  # ⼠
    # 0x2F21: '',  # ⼡
    # 0x2F22: '',  # ⼢
    # 0x2F23: '',  # ⼣
    # 0x2F24: '',  # ⼤
    # 0x2F25: '',  # ⼥
    # 0x2F26: '',  # ⼦
    # 0x2F27: '',  # ⼧
    # 0x2F28: '',  # ⼨
    # 0x2F29: '',  # ⼩
    # 0x2F2A: '',  # ⼪
    # 0x2F2B: '',  # ⼫
    # 0x2F2C: '',  # ⼬
    # 0x2F2D: '',  # ⼭
    # 0x2F2E: '',  # ⼮
    # 0x2F2F: '',  # ⼯
    # 0x2F30: '',  # ⼰
    # 0x2F31: '',  # ⼱
    # 0x2F32: '',  # ⼲
    # 0x2F33: '',  # ⼳
    # 0x2F34: '',  # ⼴
    # 0x2F35: '',  # ⼵
    # 0x2F36: '',  # ⼶
    # 0x2F37: '',  # ⼷
    # 0x2F38: '',  # ⼸
    # 0x2F39: '',  # ⼹
    # 0x2F3A: '',  # ⼺
    # 0x2F3B: '',  # ⼻
    # 0x2F3C: '',  # ⼼
    # 0x2F3D: '',  # ⼽
    # 0x2F3E: '',  # ⼾
    # 0x2F3F: '',  # ⼿
    # 0x2F40: '',  # ⽀
    # 0x2F41: '',  # ⽁
    # 0x2F42: '',  # ⽂
    # 0x2F43: '',  # ⽃
    # 0x2F44: '',  # ⽄
    # 0x2F45: '',  # ⽅
    # 0x2F46: '',  # ⽆
    # 0x2F47: '',  # ⽇
    # 0x2F48: '',  # ⽈
    # 0x2F49: '',  # ⽉
    # 0x2F4A: '',  # ⽊
    # 0x2F4B: '',  # ⽋
    # 0x2F4C: '',  # ⽌
    # 0x2F4D: '',  # ⽍
    # 0x2F4E: '',  # ⽎
    # 0x2F4F: '',  # ⽏
    # 0x2F50: '',  # ⽐
    # 0x2F51: '',  # ⽑
    # 0x2F52: '',  # ⽒
    # 0x2F53: '',  # ⽓
    # 0x2F54: '',  # ⽔
    # 0x2F55: '',  # ⽕
    # 0x2F56: '',  # ⽖
    # 0x2F57: '',  # ⽗
    # 0x2F58: '',  # ⽘
    # 0x2F59: '',  # ⽙
    # 0x2F5A: '',  # ⽚
    # 0x2F5B: '',  # ⽛
    # 0x2F5C: '',  # ⽜
    # 0x2F5D: '',  # ⽝
    # 0x2F5E: '',  # ⽞
    # 0x2F5F: '',  # ⽟
    # 0x2F60: '',  # ⽠
    # 0x2F61: '',  # ⽡
    # 0x2F62: '',  # ⽢
    # 0x2F63: '',  # ⽣
    # 0x2F64: '',  # ⽤
    # 0x2F65: '',  # ⽥
    # 0x2F66: '',  # ⽦
    # 0x2F67: '',  # ⽧
    # 0x2F68: '',  # ⽨
    # 0x2F69: '',  # ⽩
    # 0x2F6A: '',  # ⽪
    # 0x2F6B: '',  # ⽫
    # 0x2F6C: '',  # ⽬
    # 0x2F6D: '',  # ⽭
    # 0x2F6E: '',  # ⽮
    # 0x2F6F: '',  # ⽯
    # 0x2F70: '',  # ⽰
    # 0x2F71: '',  # ⽱
    # 0x2F72: '',  # ⽲
    # 0x2F73: '',  # ⽳
    # 0x2F74: '',  # ⽴
    # 0x2F75: '',  # ⽵
    # 0x2F76: '',  # ⽶
    # 0x2F77: '',  # ⽷
    # 0x2F78: '',  # ⽸
    # 0x2F79: '',  # ⽹
    # 0x2F7A: '',  # ⽺
    # 0x2F7B: '',  # ⽻
    # 0x2F7C: '',  # ⽼
    # 0x2F7D: '',  # ⽽
    # 0x2F7E: '',  # ⽾
    # 0x2F7F: '',  # ⽿
    # 0x2F800: '',  # 丽
    # 0x2F810: '',  # 兤
    # 0x2F820: '',  # 刻
    # 0x2F830: '',  # 卽
    # 0x2F840: '',  # 咢
    # 0x2F850: '',  # 切
    # 0x2F860: '',  # 𡚨
    # 0x2F870: '',  # 寳
    # 0x2F880: '',  # 嵼
    # 0x2F890: '',  # 廾
    # 0x2F8A0: '',  # 悁
    # 0x2F8B0: '',  # 懲
    # 0x2F8C0: '',  # 揅
    # 0x2F8D0: '',  # 㬈
    # 0x2F8E0: '',  # 枅
    # 0x2F8F0: '',  # 𣢧
    # 0x2F900: '',  # 派
    # 0x2F910: '',  # 𣽞
    # 0x2F920: '',  # 爨
    # 0x2F930: '',  # 瑱
    # 0x2F940: '',  # 直
    # 0x2F950: '',  # 磌
    # 0x2F960: '',  # 䈂
    # 0x2F970: '',  # 繅
    # 0x2F980: '',  # 𣍟
    # 0x2F990: '',  # 芋
    # 0x2F9A0: '',  # 荓
    # 0x2F9B0: '',  # 𦾱
    # 0x2F9C0: '',  # 蟡
    # 0x2F9D0: '',  # 諭
    # 0x2F9E0: '',  # 𨗒
    # 0x2F9F0: '',  # 閷
    # 0x2FA00: '',  # 頩
    # 0x2FA10: '',  # 𪃎
    # 0x2FA2: '',  # ⾢
    # 0x2FA3: '',  # ⾣
    # 0x2FA4: '',  # ⾤
    # 0x2FA5: '',  # ⾥
    # 0x2FA6: '',  # ⾦
    # 0x2FA7: '',  # ⾧
    # 0x2FA8: '',  # ⾨
    # 0x2FA9: '',  # ⾩
    # 0x2FAA: '',  # ⾪
    # 0x2FAB: '',  # ⾫
    # 0x2FAC: '',  # ⾬
    # 0x2FAD: '',  # ⾭
    # 0x2FAE: '',  # ⾮
    # 0x2FAF: '',  # ⾯
    # 0x2FB0: '',  # ⾰
    # 0x2FB1: '',  # ⾱
    # 0x2FB2: '',  # ⾲
    # 0x2FB3: '',  # ⾳
    # 0x2FB4: '',  # ⾴
    # 0x2FB5: '',  # ⾵
    # 0x2FB6: '',  # ⾶
    # 0x2FB7: '',  # ⾷
    # 0x2FB8: '',  # ⾸
    # 0x2FB9: '',  # ⾹
    # 0x2FBA: '',  # ⾺
    # 0x2FBB: '',  # ⾻
    # 0x2FBC: '',  # ⾼
    # 0x2FBD: '',  # ⾽
    # 0x2FBE: '',  # ⾾
    # 0x2FBF: '',  # ⾿
    # 0x2FC0: '',  # ⿀
    # 0x2FC1: '',  # ⿁
    # 0x2FC2: '',  # ⿂
    # 0x2FC3: '',  # ⿃
    # 0x2FC4: '',  # ⿄
    # 0x2FC5: '',  # ⿅
    # 0x2FC6: '',  # ⿆
    # 0x2FC7: '',  # ⿇
    # 0x2FC8: '',  # ⿈
    # 0x2FC9: '',  # ⿉
    # 0x2FCA: '',  # ⿊
    # 0x2FCB: '',  # ⿋
    # 0x2FCC: '',  # ⿌
    # 0x2FCD: '',  # ⿍
    # 0x2FCE: '',  # ⿎
    # 0x2FCF: '',  # ⿏
    # 0x2FD0: '',  # ⿐
    # 0x2FD1: '',  # ⿑
    # 0x2FD2: '',  # ⿒
    # 0x2FD3: '',  # ⿓
    # 0x2FD4: '',  # ⿔
    # 0x2FD5: '',  # ⿕
    # 0x2FD6: '',  #
    # 0x2FD7: '',  #
    # 0x2FD8: '',  #
    # 0x2FD9: '',  #
    # 0x2FDA: '',  #
    # 0x2FDB: '',  #
    # 0x2FDC: '',  #
    # 0x2FDD: '',  #
    # 0x2FDE: '',  #
    # 0x2FDF: '',  #

    # CJK 笔画:[31C0-31EF]
    # 0x31C0: '',  # ㇀
    # 0x31C1: '',  # ㇁
    # 0x31C2: '',  # ㇂
    # 0x31C3: '',  # ㇃
    # 0x31C4: '',  # ㇄
    # 0x31C5: '',  # ㇅
    # 0x31C6: '',  # ㇆
    # 0x31C7: '',  # ㇇
    # 0x31C8: '',  # ㇈
    # 0x31C9: '',  # ㇉
    # 0x31CA: '',  # ㇊
    # 0x31CB: '',  # ㇋
    # 0x31CC: '',  # ㇌
    # 0x31CD: '',  # ㇍
    # 0x31CE: '',  # ㇎
    # 0x31CF: '',  # ㇏
    # 0x31D0: '',  # ㇐
    # 0x31D1: '',  # ㇑
    # 0x31D2: '',  # ㇒
    # 0x31D3: '',  # ㇓
    # 0x31D4: '',  # ㇔
    # 0x31D5: '',  # ㇕
    # 0x31D6: '',  # ㇖
    # 0x31D7: '',  # ㇗
    # 0x31D8: '',  # ㇘
    # 0x31D9: '',  # ㇙
    # 0x31DA: '',  # ㇚
    # 0x31DB: '',  # ㇛
    # 0x31DC: '',  # ㇜
    # 0x31DD: '',  # ㇝
    # 0x31DE: '',  # ㇞
    # 0x31DF: '',  # ㇟
    # 0x31E0: '',  # ㇠
    # 0x31E1: '',  # ㇡
    # 0x31E2: '',  # ㇢
    # 0x31E3: '',  # ㇣
    # 0x31E4: '',  #
    # 0x31E5: '',  #
    # 0x31E6: '',  #
    # 0x31E7: '',  #
    # 0x31E8: '',  #
    # 0x31E9: '',  #
    # 0x31EA: '',  #
    # 0x31EB: '',  #
    # 0x31EC: '',  #
    # 0x31ED: '',  #
    # 0x31EE: '',  #
    # 0x31EF: '',  #

    # CJK 扩展 A:[3400-4DBF]
    0x3400: 'qiū',  # 㐀
    0x3401: 'tiǎn,tiàn',  # 㐁
    0x3402: 'xǐ',  # 㐂
    # 0x3403: '',  # 㐃
    # 0x3404: '',  # 㐄
    0x3405: 'wǔ',  # 㐅
    0x3406: 'yǐn,yī',  # 㐆
    0x3407: 'jiǔ',  # 㐇
    0x3408: 'rù',  # 㐈
    0x3409: 'dīng',  # 㐉
    0x340A: 'shì',  # 㐊
    0x340B: 'tǔ',  # 㐋
    0x340C: 'sì,yí',  # 㐌
    0x340D: 'zhǎo',  # 㐍
    0x340E: 'wén',  # 㐎
    0x340F: 'wǔ',  # 㐏
    0x3410: 'nú',  # 㐐
    0x3411: 'dōng',  # 㐑
    0x3412: 'zhào',  # 㐒
    0x3413: 'kě',  # 㐓
    0x3414: 'xiǎng',  # 㐔
    # 0x3415: '',  # 㐕
    0x3416: 'yè',  # 㐖
    0x3417: 'lǎo',  # 㐗
    0x3418: 'mǐ',  # 㐘
    0x3419: 'dòu',  # 㐙
    0x341A: 'wú',  # 㐚
    0x341B: 'yòu ㄧ',  # 㐛
    0x341C: 'chóu',  # 㐜
    0x341D: 'jū',  # 㐝
    0x341E: 'qí',  # 㐞
    0x341F: 'fēi',  # 㐟
    # 0x3420: '',  # 㐠
    0x3421: 'nuò',  # 㐡
    0x3422: 'fú',  # 㐢
    0x3423: 'kù',  # 㐣
    0x3424: 'qiú',  # 㐤
    0x3425: 'chú',  # 㐥
    0x3426: 'jǔ',  # 㐦
    # 0x3427: '',  # 㐧
    0x3428: 'xù',  # 㐨
    0x3429: 'xíng',  # 㐩
    # 0x342A: '',  # 㐪
    0x342B: 'xiōng',  # 㐫
    0x342C: 'liú',  # 㐬
    0x342D: 'lǐn',  # 㐭
    # 0x342E: '',  # 㐮
    # 0x342F: '',  # 㐯
    0x3430: 'xìn',  # 㐰
    0x3431: 'zhěn',  # 㐱
    0x3432: 'dài,fú',  # 㐲
    0x3433: 'wù',  # 㐳
    # 0x3434: '',  # 㐴
    # 0x3435: '',  # 㐵
    # 0x3436: '',  # 㐶
    0x3437: 'mǎ,mà,mián',  # 㐷
    0x3438: 'qiàn',  # 㐸
    0x3439: 'yì',  # 㐹
    0x343A: 'zhòng,yín',  # 㐺
    0x343B: 'nèi',  # 㐻
    0x343C: 'chèng,zhěng',  # 㐼
    # 0x343D: '',  # 㐽
    0x343E: 'ruǎn,yuàn',  # 㐾
    # 0x343F: '',  # 㐿
    0x3440: 'tài',  # 㑀
    # 0x3441: '',  # 㑁
    0x3442: 'fǎng,páng',  # 㑂
    0x3443: 'ǎo',  # 㑃
    0x3444: 'wǔ',  # 㑄
    0x3445: 'zuò',  # 㑅
    # 0x3446: '',  # 㑆
    0x3447: 'zhòu',  # 㑇
    0x3448: 'dòng',  # 㑈
    0x3449: 'sù',  # 㑉
    0x344A: 'yì',  # 㑊
    0x344B: 'jiòng,kǒng,qióng',  # 㑋
    # 0x344C: '',  # 㑌
    0x344D: 'lěi,lèi',  # 㑍
    0x344E: 'nǎo',  # 㑎
    0x344F: 'zhù',  # 㑏
    # 0x3450: '',  # 㑐
    0x3451: 'lǎn,jì',  # 㑑
    # 0x3452: '',  # 㑒
    # 0x3453: '',  # 㑓
    0x3454: 'xǔ',  # 㑔
    # 0x3455: '',  # 㑕
    # 0x3456: '',  # 㑖
    0x3457: 'shēn',  # 㑗
    0x3458: 'jiè',  # 㑘
    0x3459: 'dié,yǒng',  # 㑙
    0x345A: 'nuó',  # 㑚
    0x345B: 'sù',  # 㑛
    0x345C: 'yì,chì',  # 㑜
    0x345D: 'lòng',  # 㑝
    0x345E: 'yìng',  # 㑞
    0x345F: 'běng,bó,pěng',  # 㑟
    # 0x3460: '',  # 㑠
    # 0x3461: '',  # 㑡
    # 0x3462: '',  # 㑢
    0x3463: 'lán',  # 㑣
    0x3464: 'miáo',  # 㑤
    0x3465: 'yì',  # 㑥
    0x3466: 'lì',  # 㑦
    0x3467: 'jì',  # 㑧
    0x3468: 'yǔ',  # 㑨
    0x3469: 'luó',  # 㑩
    0x346A: 'chái',  # 㑪
    # 0x346B: '',  # 㑫
    # 0x346C: '',  # 㑬
    # 0x346D: '',  # 㑭
    0x346E: 'hún,wén',  # 㑮
    0x346F: 'xǔ',  # 㑯
    0x3470: 'huì',  # 㑰
    0x3471: 'rǎo',  # 㑱
    # 0x3472: '',  # 㑲
    0x3473: 'zhòu',  # 㑳
    # 0x3474: '',  # 㑴
    0x3475: 'hàn,jí,jié,zhǎ,zí',  # 㑵
    0x3476: 'xì',  # 㑶
    0x3477: 'tài',  # 㑷
    0x3478: 'ǎi,yáo,yóu',  # 㑸
    0x3479: 'huì',  # 㑹
    0x347A: 'jùn',  # 㑺
    0x347B: 'mà',  # 㑻
    # 0x347C: '',  # 㑼
    0x347D: 'táng',  # 㑽
    0x347E: 'xiáo,yáo',  # 㑾
    0x347F: 'zhào',  # 㑿
    0x3480: 'zhǎ',  # 㒀
    0x3481: 'yǔ,yùn',  # 㒁
    0x3482: 'kù,zhuó',  # 㒂
    0x3483: 'èr',  # 㒃
    0x3484: 'nàng,nèn,rǎn',  # 㒄
    0x3485: 'qǐ',  # 㒅
    0x3486: 'chì,kè,xì,xiào,yàn',  # 㒆
    0x3487: 'mù,wǔ',  # 㒇
    0x3488: 'hàn',  # 㒈
    0x3489: 'tǎng',  # 㒉
    0x348A: 'sè',  # 㒊
    # 0x348B: '',  # 㒋
    0x348C: 'qióng',  # 㒌
    0x348D: 'léi,lěi',  # 㒍
    0x348E: 'sǎ,sà,tàn',  # 㒎
    # 0x348F: '',  # 㒏
    0x3490: 'xùn',  # 㒐
    0x3491: 'huì,kuǐ',  # 㒑
    0x3492: 'pú',  # 㒒
    0x3493: 'tà',  # 㒓
    0x3494: 'shǔ',  # 㒔
    # 0x3495: '',  # 㒕
    0x3496: 'ǒu',  # 㒖
    0x3497: 'tái',  # 㒗
    # 0x3498: '',  # 㒘
    0x3499: 'mián',  # 㒙
    0x349A: 'wěn',  # 㒚
    0x349B: 'diào',  # 㒛
    0x349C: 'yú,yǔ',  # 㒜
    0x349D: 'miè,wà',  # 㒝
    0x349E: 'jùn,kě',  # 㒞
    0x349F: 'niǎo',  # 㒟
    0x34A0: 'xiè',  # 㒠
    0x34A1: 'yóu',  # 㒡
    # 0x34A2: '',  # 㒢
    # 0x34A3: '',  # 㒣
    0x34A4: 'shè,chè',  # 㒤
    # 0x34A5: '',  # 㒥
    0x34A6: 'lěi',  # 㒦
    0x34A7: 'lì',  # 㒧
    # 0x34A8: '',  # 㒨
    0x34A9: 'luǒ',  # 㒩
    # 0x34AA: '',  # 㒪
    0x34AB: 'jì',  # 㒫
    # 0x34AC: '',  # 㒬
    # 0x34AD: '',  # 㒭
    # 0x34AE: '',  # 㒮
    # 0x34AF: '',  # 㒯
    0x34B0: 'quán',  # 㒰
    0x34B1: 'mèng',  # 㒱
    0x34B2: 'cái',  # 㒲
    0x34B3: 'liǎng',  # 㒳
    0x34B4: 'gǔ',  # 㒴
    0x34B5: 'mào',  # 㒵
    # 0x34B6: '',  # 㒶
    0x34B7: 'guǎ,xìng,xǔ',  # 㒷
    0x34B8: 'suì,xuán',  # 㒸
    0x34B9: 'diān',  # 㒹
    # 0x34BA: '',  # 㒺
    0x34BB: 'mào',  # 㒻
    0x34BC: 'mán',  # 㒼
    # 0x34BD: '',  # 㒽
    0x34BE: 'shì',  # 㒾
    0x34BF: 'lí',  # 㒿
    # 0x34C0: '',  # 㓀
    0x34C1: 'wǎng',  # 㓁
    0x34C2: 'kòu',  # 㓂
    0x34C3: 'chuí,dù,zhà',  # 㓃
    0x34C4: 'zhèn',  # 㓄
    # 0x34C5: '',  # 㓅
    # 0x34C6: '',  # 㓆
    # 0x34C7: '',  # 㓇
    0x34C8: 'bèi,bìng,fèi,yè',  # 㓈
    0x34C9: 'huàn,huó,huò',  # 㓉
    0x34CA: 'dòng',  # 㓊
    0x34CB: 'gòng',  # 㓋
    # 0x34CC: '',  # 㓌
    # 0x34CD: '',  # 㓍
    0x34CE: 'qīn,qǐn,qìn',  # 㓎
    0x34CF: 'jiǒng',  # 㓏
    0x34D0: 'lù',  # 㓐
    0x34D1: 'xìng',  # 㓑
    # 0x34D2: '',  # 㓒
    0x34D3: 'nán',  # 㓓
    0x34D4: 'xiè',  # 㓔
    # 0x34D5: '',  # 㓕
    0x34D6: 'bì,bié',  # 㓖
    0x34D7: 'jié,qǐ',  # 㓗
    0x34D8: 'sù',  # 㓘
    # 0x34D9: '',  # 㓙
    # 0x34DA: '',  # 㓚
    # 0x34DB: '',  # 㓛
    0x34DC: 'yòu',  # 㓜
    0x34DD: 'xíng',  # 㓝
    0x34DE: 'qì,qià,yáo',  # 㓞
    0x34DF: 'pí',  # 㓟
    0x34E0: 'diàn',  # 㓠
    0x34E1: 'fǔ,fǒu',  # 㓡
    0x34E2: 'luò',  # 㓢
    0x34E3: 'qià',  # 㓣
    0x34E4: 'jié,qià',  # 㓤
    # 0x34E5: '',  # 㓥
    0x34E6: 'bāi',  # 㓦
    0x34E7: 'yǎn',  # 㓧
    0x34E8: 'cí,cì',  # 㓨
    # 0x34E9: '',  # 㓩
    0x34EA: 'lǎng',  # 㓪
    # 0x34EB: '',  # 㓫
    # 0x34EC: '',  # 㓬
    0x34ED: 'hé',  # 㓭
    # 0x34EE: '',  # 㓮
    0x34EF: 'lí',  # 㓯
    0x34F0: 'huà',  # 㓰
    0x34F1: 'tóu',  # 㓱
    0x34F2: 'piàn',  # 㓲
    # 0x34F3: '',  # 㓳
    0x34F4: 'jùn,ruǎn',  # 㓴
    0x34F5: 'è',  # 㓵
    0x34F6: 'qiè',  # 㓶
    0x34F7: 'yì',  # 㓷
    0x34F8: 'jué,zhuó',  # 㓸
    0x34F9: 'ruì',  # 㓹
    0x34FA: 'jiàn',  # 㓺
    # 0x34FB: '',  # 㓻
    0x34FC: 'chì,chòng',  # 㓼
    0x34FD: 'chóng',  # 㓽
    0x34FE: 'chí',  # 㓾
    # 0x34FF: '',  # 㓿
    0x3500: 'lüè,qíng',  # 㔀
    # 0x3501: '',  # 㔁
    0x3502: 'lín',  # 㔂
    0x3503: 'jué,pì',  # 㔃
    0x3504: 'sù',  # 㔄
    0x3505: 'xiào',  # 㔅
    0x3506: 'zàn',  # 㔆
    0x3507: 'pō',  # 㔇
    # 0x3508: '',  # 㔈
    0x3509: 'zhú',  # 㔉
    0x350A: 'dǎn',  # 㔊
    0x350B: 'jiàn,lán,làn',  # 㔋
    0x350C: 'zhòu',  # 㔌
    0x350D: 'duǒ,zhá',  # 㔍
    0x350E: 'xiè,yì',  # 㔎
    0x350F: 'lì',  # 㔏
    # 0x3510: '',  # 㔐
    0x3511: 'chì,dào,qì,shuì',  # 㔑
    0x3512: 'xí',  # 㔒
    0x3513: 'jiǎn,xiàn',  # 㔓
    # 0x3514: '',  # 㔔
    0x3515: 'jí,yì',  # 㔕
    0x3516: 'jiā',  # 㔖
    0x3517: 'fèi',  # 㔗
    0x3518: 'chù',  # 㔘
    0x3519: 'bǎng,péng',  # 㔙
    0x351A: 'kǒu',  # 㔚
    0x351B: 'jié',  # 㔛
    0x351C: 'bá,bó',  # 㔜
    0x351D: 'liǎng',  # 㔝
    0x351E: 'kuài,kuàng,wàng',  # 㔞
    # 0x351F: '',  # 㔟
    0x3520: 'hé,jiá',  # 㔠
    # 0x3521: '',  # 㔡
    0x3522: 'jué',  # 㔢
    0x3523: 'léi,lèi',  # 㔣
    0x3524: 'shěn',  # 㔤
    0x3525: 'pí',  # 㔥
    0x3526: 'yǎng',  # 㔦
    0x3527: 'xuè',  # 㔧
    0x3528: 'bèi',  # 㔨
    0x3529: 'è',  # 㔩
    0x352A: 'lǔ',  # 㔪
    # 0x352B: '',  # 㔫
    # 0x352C: '',  # 㔬
    0x352D: 'chè,chí,yí',  # 㔭
    0x352E: 'nuó',  # 㔮
    0x352F: 'suǎn,xuán',  # 㔯
    0x3530: 'héng',  # 㔰
    0x3531: 'yǔ',  # 㔱
    # 0x3532: '',  # 㔲
    0x3533: 'guǐ,gùn,huán,jué',  # 㔳
    0x3534: 'yì',  # 㔴
    0x3535: 'xiàn,xuǎn',  # 㔵
    0x3536: 'gòng',  # 㔶
    0x3537: 'lòu',  # 㔷
    # 0x3538: '',  # 㔸
    0x3539: 'lè',  # 㔹
    0x353A: 'shì',  # 㔺
    0x353B: 'pī',  # 㔻
    0x353C: 'sǔn',  # 㔼
    0x353D: 'yào,yǒu',  # 㔽
    0x353E: 'jié',  # 㔾
    0x353F: 'zòu',  # 㔿
    # 0x3540: '',  # 㕀
    0x3541: 'què',  # 㕁
    0x3542: 'yín',  # 㕂
    # 0x3543: '',  # 㕃
    0x3544: 'zhì',  # 㕄
    0x3545: 'jiǎ',  # 㕅
    0x3546: 'hù',  # 㕆
    0x3547: 'lá,lā',  # 㕇
    0x3548: 'hòu,yǐ',  # 㕈
    0x3549: 'kè',  # 㕉
    0x354A: 'fū',  # 㕊
    0x354B: 'jìng,qín',  # 㕋
    0x354C: 'ài',  # 㕌
    # 0x354D: '',  # 㕍
    0x354E: 'è,kè,kǔn',  # 㕎
    0x354F: 'chú',  # 㕏
    0x3550: 'xiě',  # 㕐
    0x3551: 'chú',  # 㕑
    0x3552: 'wéi,wěi,wēi',  # 㕒
    # 0x3553: '',  # 㕓
    # 0x3554: '',  # 㕔
    0x3555: 'huàn',  # 㕕
    0x3556: 'sù',  # 㕖
    0x3557: 'yòu',  # 㕗
    0x3558: 'cān',  # 㕘
    0x3559: 'jùn,ruì',  # 㕙
    0x355A: 'zhǎo',  # 㕚
    0x355B: 'xù,yǒu,yòu',  # 㕛
    0x355C: 'shǐ',  # 㕜
    # 0x355D: '',  # 㕝
    0x355E: 'shuā',  # 㕞
    0x355F: 'kuì',  # 㕟
    0x3560: 'shuāng',  # 㕠
    0x3561: 'hé,hè,huò',  # 㕡
    0x3562: 'gài,hài,jù,lǔn,nǒu',  # 㕢
    0x3563: 'yǎn,yàn',  # 㕣
    0x3564: 'qiú',  # 㕤
    0x3565: 'yǐ',  # 㕥
    0x3566: 'huà',  # 㕦
    0x3567: 'xī',  # 㕧
    0x3568: 'fàn',  # 㕨
    0x3569: 'zhàng',  # 㕩
    0x356A: 'dǎn',  # 㕪
    0x356B: 'fǎng',  # 㕫
    0x356C: 'sòng',  # 㕬
    0x356D: 'ào,bì',  # 㕭
    0x356E: 'fǔ,tiào',  # 㕮
    0x356F: 'nè',  # 㕯
    0x3570: 'hè',  # 㕰
    0x3571: 'yóu',  # 㕱
    0x3572: 'huá,yíng',  # 㕲
    # 0x3573: '',  # 㕳
    0x3574: 'chén',  # 㕴
    0x3575: 'guó,hún,luǒ',  # 㕵
    0x3576: 'ň,ňg',  # 㕶
    0x3577: 'huà',  # 㕷
    0x3578: 'lì',  # 㕸
    0x3579: 'fá',  # 㕹
    0x357A: 'háo',  # 㕺
    0x357B: 'tòu',  # 㕻
    # 0x357C: '',  # 㕼
    0x357D: 'sì',  # 㕽
    0x357E: 'xiǎo',  # 㕾
    # 0x357F: '',  # 㕿
    0x3580: 'lè,luò',  # 㖀
    0x3581: 'lìn',  # 㖁
    0x3582: 'yì',  # 㖂
    0x3583: 'hǒu,hòu',  # 㖃
    # 0x3584: '',  # 㖄
    0x3585: 'xù',  # 㖅
    0x3586: 'qú,qǔ',  # 㖆
    0x3587: 'ér',  # 㖇
    # 0x3588: '',  # 㖈
    # 0x3589: '',  # 㖉
    # 0x358A: '',  # 㖊
    # 0x358B: '',  # 㖋
    # 0x358C: '',  # 㖌
    # 0x358D: '',  # 㖍
    # 0x358E: '',  # 㖎
    0x358F: 'nèi',  # 㖏
    0x3590: 'wěi',  # 㖐
    0x3591: 'xiè',  # 㖑
    0x3592: 'tí',  # 㖒
    0x3593: 'hóng',  # 㖓
    0x3594: 'tǔn',  # 㖔
    0x3595: 'bò,niè',  # 㖕
    0x3596: 'niè',  # 㖖
    0x3597: 'yín',  # 㖗
    # 0x3598: '',  # 㖘
    # 0x3599: '',  # 㖙
    # 0x359A: '',  # 㖚
    # 0x359B: '',  # 㖛
    0x359C: 'xiǎng',  # 㖜
    # 0x359D: '',  # 㖝
    0x359E: 'wāi',  # 㖞
    0x359F: 'shòu',  # 㖟
    0x35A0: 'bà,nuò',  # 㖠
    0x35A1: 'yè',  # 㖡
    0x35A2: 'jí,qí',  # 㖢
    0x35A3: 'tòu',  # 㖣
    0x35A4: 'hán',  # 㖤
    0x35A5: 'jiǒng',  # 㖥
    0x35A6: 'dǒng',  # 㖦
    0x35A7: 'wěn',  # 㖧
    0x35A8: 'lù',  # 㖨
    0x35A9: 'sǒu',  # 㖩
    0x35AA: 'guó',  # 㖪
    0x35AB: 'líng',  # 㖫
    # 0x35AC: '',  # 㖬
    0x35AD: 'tiǎn',  # 㖭
    0x35AE: 'lún',  # 㖮
    # 0x35AF: '',  # 㖯
    # 0x35B0: '',  # 㖰
    # 0x35B1: '',  # 㖱
    # 0x35B2: '',  # 㖲
    # 0x35B3: '',  # 㖳
    # 0x35B4: '',  # 㖴
    # 0x35B5: '',  # 㖵
    0x35B6: 'yè',  # 㖶
    0x35B7: 'shí,tí',  # 㖷
    0x35B8: 'xué',  # 㖸
    0x35B9: 'fèn',  # 㖹
    0x35BA: 'chǔn',  # 㖺
    0x35BB: 'róu',  # 㖻
    0x35BC: 'duǒ,lín,móu',  # 㖼
    0x35BD: 'zé,zéi',  # 㖽
    0x35BE: 'è',  # 㖾
    0x35BF: 'xié',  # 㖿
    # 0x35C0: '',  # 㗀
    0x35C1: 'è',  # 㗁
    0x35C2: 'shěng',  # 㗂
    0x35C3: 'wěn,yìn',  # 㗃
    0x35C4: 'mán,màn',  # 㗄
    0x35C5: 'hú',  # 㗅
    0x35C6: 'gé,kài',  # 㗆
    0x35C7: 'xiá,ya',  # 㗇
    0x35C8: 'màn',  # 㗈
    0x35C9: 'bì,è,lüè',  # 㗉
    0x35CA: 'jí,qì,bī,léi',  # 㗊
    0x35CB: 'hóu',  # 㗋
    0x35CC: 'zhì',  # 㗌
    # 0x35CD: '',  # 㗍
    # 0x35CE: '',  # 㗎
    # 0x35CF: '',  # 㗏
    # 0x35D0: '',  # 㗐
    0x35D1: 'bài',  # 㗑
    0x35D2: 'ài',  # 㗒
    # 0x35D3: '',  # 㗓
    # 0x35D4: '',  # 㗔
    0x35D5: 'gòu',  # 㗕
    0x35D6: 'dàn',  # 㗖
    0x35D7: 'bǎi',  # 㗗
    0x35D8: 'bó,fù',  # 㗘
    0x35D9: 'nà,chú,zhōu',  # 㗙
    0x35DA: 'lì',  # 㗚
    0x35DB: 'xiào',  # 㗛
    0x35DC: 'xiù',  # 㗜
    # 0x35DD: '',  # 㗝
    # 0x35DE: '',  # 㗞
    # 0x35DF: '',  # 㗟
    # 0x35E0: '',  # 㗠
    # 0x35E1: '',  # 㗡
    0x35E2: 'dòng,hóng',  # 㗢
    0x35E3: 'tì',  # 㗣
    0x35E4: 'cù',  # 㗤
    0x35E5: 'kuò',  # 㗥
    0x35E6: 'láo',  # 㗦
    0x35E7: 'zhì',  # 㗧
    0x35E8: 'ǎi',  # 㗨
    0x35E9: 'xī',  # 㗩
    # 0x35EA: '',  # 㗪
    0x35EB: 'qiè',  # 㗫
    0x35EC: 'zhā',  # 㗬
    # 0x35ED: '',  # 㗭
    # 0x35EE: '',  # 㗮
    # 0x35EF: '',  # 㗯
    0x35F0: 'chù,cóng',  # 㗰
    0x35F1: 'jí',  # 㗱
    0x35F2: 'huò,xì',  # 㗲
    0x35F3: 'tǎ',  # 㗳
    0x35F4: 'yán',  # 㗴
    0x35F5: 'xù',  # 㗵
    # 0x35F6: '',  # 㗶
    0x35F7: 'sǎi',  # 㗷
    # 0x35F8: '',  # 㗸
    # 0x35F9: '',  # 㗹
    # 0x35FA: '',  # 㗺
    0x35FB: 'guō',  # 㗻
    0x35FC: 'yè',  # 㗼
    0x35FD: 'xiǎng',  # 㗽
    0x35FE: 'xué',  # 㗾
    0x35FF: 'hé,xià,xiā',  # 㗿
    0x3600: 'zuò',  # 㘀
    0x3601: 'yì',  # 㘁
    0x3602: 'cí',  # 㘂
    0x3603: 'ruò',  # 㘃
    0x3604: 'lēng',  # 㘄
    0x3605: 'xián',  # 㘅
    0x3606: 'tái',  # 㘆
    0x3607: 'róng',  # 㘇
    0x3608: 'yī,yì',  # 㘈
    0x3609: 'zhì',  # 㘉
    0x360A: 'yì',  # 㘊
    0x360B: 'xián',  # 㘋
    0x360C: 'jù',  # 㘌
    0x360D: 'jí,qì',  # 㘍
    0x360E: 'hǎn,hàn',  # 㘎
    # 0x360F: '',  # 㘏
    0x3610: 'pào,pěng',  # 㘐
    0x3611: 'lì',  # 㘑
    # 0x3612: '',  # 㘒
    0x3613: 'lán',  # 㘓
    0x3614: 'cǎn,sǎi',  # 㘔
    0x3615: 'hǎn,lán',  # 㘕
    0x3616: 'yán',  # 㘖
    # 0x3617: '',  # 㘗
    # 0x3618: '',  # 㘘
    0x3619: 'yán,yǎn',  # 㘙
    0x361A: 'hǎn',  # 㘚
    # 0x361B: '',  # 㘛
    0x361C: 'chǐ,chóu,chù',  # 㘜
    0x361D: 'niǎn,niè,nà,lǎn',  # 㘝
    0x361E: 'huò',  # 㘞
    # 0x361F: '',  # 㘟
    0x3620: 'bì,mì',  # 㘠
    0x3621: 'xiá',  # 㘡
    0x3622: 'wěng',  # 㘢
    0x3623: 'xuán,yuán',  # 㘣
    # 0x3624: '',  # 㘤
    0x3625: 'yóu',  # 㘥
    0x3626: 'qín',  # 㘦
    0x3627: 'xù',  # 㘧
    0x3628: 'nèi',  # 㘨
    0x3629: 'bì',  # 㘩
    0x362A: 'hào',  # 㘪
    0x362B: 'jǐng',  # 㘫
    0x362C: 'ào',  # 㘬
    0x362D: 'ào',  # 㘭
    # 0x362E: '',  # 㘮
    # 0x362F: '',  # 㘯
    # 0x3630: '',  # 㘰
    # 0x3631: '',  # 㘱
    0x3632: 'jú',  # 㘲
    # 0x3633: '',  # 㘳
    0x3634: 'zuò',  # 㘴
    0x3635: 'bù',  # 㘵
    0x3636: 'jié',  # 㘶
    0x3637: 'ài',  # 㘷
    0x3638: 'zàng',  # 㘸
    0x3639: 'cí',  # 㘹
    0x363A: 'fá',  # 㘺
    # 0x363B: '',  # 㘻
    # 0x363C: '',  # 㘼
    # 0x363D: '',  # 㘽
    # 0x363E: '',  # 㘾
    0x363F: 'niè',  # 㘿
    0x3640: 'liù',  # 㙀
    0x3641: 'mǎng,méi,mèi,mù,nà',  # 㙁
    0x3642: 'duì',  # 㙂
    # 0x3643: '',  # 㙃
    0x3644: 'bì',  # 㙄
    0x3645: 'bǎo',  # 㙅
    # 0x3646: '',  # 㙆
    0x3647: 'chù',  # 㙇
    0x3648: 'hán,xià',  # 㙈
    0x3649: 'tiǎn',  # 㙉
    0x364A: 'cháng,zhàng',  # 㙊
    # 0x364B: '',  # 㙋
    # 0x364C: '',  # 㙌
    0x364D: 'duō',  # 㙍
    # 0x364E: '',  # 㙎
    0x364F: 'fù',  # 㙏
    0x3650: 'duǒ',  # 㙐
    0x3651: 'yǔ',  # 㙑
    0x3652: 'yě',  # 㙒
    0x3653: 'kuí',  # 㙓
    0x3654: 'hán',  # 㙔
    0x3655: 'kuài',  # 㙕
    # 0x3656: '',  # 㙖
    0x3657: 'kuài',  # 㙗
    # 0x3658: '',  # 㙘
    0x3659: 'lǒng',  # 㙙
    0x365A: 'xīng',  # 㙚
    0x365B: 'bǔ',  # 㙛
    0x365C: 'chí,tái',  # 㙜
    0x365D: 'xié',  # 㙝
    0x365E: 'niè',  # 㙞
    0x365F: 'lǎng',  # 㙟
    0x3660: 'yì,yī',  # 㙠
    # 0x3661: '',  # 㙡
    0x3662: 'mán,mén',  # 㙢
    0x3663: 'zhàng',  # 㙣
    0x3664: 'xià',  # 㙤
    0x3665: 'gǔn',  # 㙥
    0x3666: 'xié',  # 㙦
    # 0x3667: '',  # 㙧
    0x3668: 'jì,qí',  # 㙨
    0x3669: 'liáo',  # 㙩
    0x366A: 'yè,yì',  # 㙪
    0x366B: 'jí',  # 㙫
    0x366C: 'yín',  # 㙬
    # 0x366D: '',  # 㙭
    0x366E: 'dā,da',  # 㙮
    0x366F: 'yì',  # 㙯
    0x3670: 'xiè',  # 㙰
    0x3671: 'hào',  # 㙱
    0x3672: 'yǒng',  # 㙲
    0x3673: 'hǎn,hé,kǎn',  # 㙳
    0x3674: 'chàn,zhàn',  # 㙴
    0x3675: 'tái',  # 㙵
    0x3676: 'táng',  # 㙶
    0x3677: 'zhí',  # 㙷
    0x3678: 'bào,bó,pú',  # 㙸
    0x3679: 'méng',  # 㙹
    0x367A: 'guì,kuí',  # 㙺
    0x367B: 'chán,qiè,zàn',  # 㙻
    0x367C: 'lěi',  # 㙼
    # 0x367D: '',  # 㙽
    0x367E: 'xì,xué',  # 㙾
    # 0x367F: '',  # 㙿
    # 0x3680: '',  # 㚀
    0x3681: 'qiáo,qiào,qù',  # 㚁
    0x3682: 'ráng',  # 㚂
    0x3683: 'yún,yùn,yūn',  # 㚃
    # 0x3684: '',  # 㚄
    0x3685: 'lóng',  # 㚅
    0x3686: 'fù',  # 㚆
    0x3687: 'zōng',  # 㚇
    # 0x3688: '',  # 㚈
    0x3689: 'gǔ',  # 㚉
    0x368A: 'kāi',  # 㚊
    # 0x368B: '',  # 㚋
    0x368C: 'huà,huǒ',  # 㚌
    0x368D: 'guó,kuǐ,kuì',  # 㚍
    # 0x368E: '',  # 㚎
    0x368F: 'gǎo',  # 㚏
    0x3690: 'tào',  # 㚐
    # 0x3691: '',  # 㚑
    0x3692: 'shǎn',  # 㚒
    0x3693: 'lái,lǎi',  # 㚓
    0x3694: 'niè',  # 㚔
    0x3695: 'fú,bì',  # 㚕
    0x3696: 'gǎo',  # 㚖
    0x3697: 'qié,xié',  # 㚗
    0x3698: 'bàn',  # 㚘
    # 0x3699: '',  # 㚙
    # 0x369A: '',  # 㚚
    0x369B: 'xì',  # 㚛
    0x369C: 'xù,yù',  # 㚜
    0x369D: 'kuí',  # 㚝
    0x369E: 'měng,shěn,yìng,yùn',  # 㚞
    0x369F: 'chuò',  # 㚟
    # 0x36A0: '',  # 㚠
    0x36A1: 'jǐ',  # 㚡
    0x36A2: 'nú',  # 㚢
    0x36A3: 'jiāo,xiáo',  # 㚣
    0x36A4: 'yì',  # 㚤
    0x36A5: 'yú',  # 㚥
    0x36A6: 'yí',  # 㚦
    0x36A7: 'yǎn',  # 㚧
    # 0x36A8: '',  # 㚨
    0x36A9: 'rǎn',  # 㚩
    0x36AA: 'hào',  # 㚪
    0x36AB: 'shà,zhà',  # 㚫
    # 0x36AC: '',  # 㚬
    0x36AD: 'yóu',  # 㚭
    # 0x36AE: '',  # 㚮
    0x36AF: 'xín,xún',  # 㚯
    0x36B0: 'bǐ',  # 㚰
    # 0x36B1: '',  # 㚱
    0x36B2: 'diǎn,shàn,chān',  # 㚲
    # 0x36B3: '',  # 㚳
    0x36B4: 'bù',  # 㚴
    # 0x36B5: '',  # 㚵
    0x36B6: 'sì',  # 㚶
    0x36B7: 'ěr,nǎi',  # 㚷
    0x36B8: 'sī',  # 㚸
    0x36B9: 'mǎo',  # 㚹
    0x36BA: 'yùn',  # 㚺
    0x36BB: 'jī',  # 㚻
    # 0x36BC: '',  # 㚼
    0x36BD: 'qiǎo',  # 㚽
    # 0x36BE: '',  # 㚾
    0x36BF: 'páo',  # 㚿
    # 0x36C0: '',  # 㛀
    # 0x36C1: '',  # 㛁
    0x36C2: 'nuǒ',  # 㛂
    0x36C3: 'jié',  # 㛃
    0x36C4: 'yī',  # 㛄
    0x36C5: 'èr',  # 㛅
    0x36C6: 'duǒ,duò',  # 㛆
    # 0x36C7: '',  # 㛇
    # 0x36C8: '',  # 㛈
    # 0x36C9: '',  # 㛉
    0x36CA: 'duǒ',  # 㛊
    # 0x36CB: '',  # 㛋
    # 0x36CC: '',  # 㛌
    0x36CD: 'qiè',  # 㛍
    # 0x36CE: '',  # 㛎
    0x36CF: 'òu,qiú',  # 㛏
    0x36D0: 'sǎo',  # 㛐
    0x36D1: 'càn',  # 㛑
    0x36D2: 'dòu',  # 㛒
    # 0x36D3: '',  # 㛓
    0x36D4: 'péng',  # 㛔
    0x36D5: 'yì',  # 㛕
    0x36D6: 'suō',  # 㛖
    0x36D7: 'zuò,qiē',  # 㛗
    0x36D8: 'pò',  # 㛘
    0x36D9: 'qiè,qín,shěn,shèn',  # 㛙
    0x36DA: 'tǒng',  # 㛚
    0x36DB: 'xìn,zhèn',  # 㛛
    0x36DC: 'yóu',  # 㛜
    0x36DD: 'bèi,bèng',  # 㛝
    0x36DE: 'lòng',  # 㛞
    # 0x36DF: '',  # 㛟
    # 0x36E0: '',  # 㛠
    # 0x36E1: '',  # 㛡
    # 0x36E2: '',  # 㛢
    0x36E3: 'yún',  # 㛣
    # 0x36E4: '',  # 㛤
    0x36E5: 'tà',  # 㛥
    0x36E6: 'lǎn',  # 㛦
    0x36E7: 'mǎn',  # 㛧
    0x36E8: 'qiǎng',  # 㛨
    0x36E9: 'zhóu',  # 㛩
    0x36EA: 'yàn,yuán',  # 㛪
    # 0x36EB: '',  # 㛫
    0x36EC: 'lù',  # 㛬
    # 0x36ED: '',  # 㛭
    0x36EE: 'sǎo',  # 㛮
    0x36EF: 'miǎn',  # 㛯
    # 0x36F0: '',  # 㛰
    0x36F1: 'ruì,wěi',  # 㛱
    0x36F2: 'fà',  # 㛲
    0x36F3: 'chà,yì',  # 㛳
    0x36F4: 'nǎo',  # 㛴
    # 0x36F5: '',  # 㛵
    0x36F6: 'chóu,tán,tàn',  # 㛶
    # 0x36F7: '',  # 㛷
    0x36F8: 'shù',  # 㛸
    0x36F9: 'pián',  # 㛹
    # 0x36FA: '',  # 㛺
    0x36FB: 'kuǐ',  # 㛻
    0x36FC: 'shà,chā',  # 㛼
    # 0x36FD: '',  # 㛽
    0x36FE: 'xián',  # 㛾
    0x36FF: 'zhì',  # 㛿
    # 0x3700: '',  # 㜀
    # 0x3701: '',  # 㜁
    # 0x3702: '',  # 㜂
    0x3703: 'liàn,liáo,máng',  # 㜃
    0x3704: 'xún',  # 㜄
    0x3705: 'xù',  # 㜅
    0x3706: 'mì',  # 㜆
    0x3707: 'huì,yè',  # 㜇
    0x3708: 'mù',  # 㜈
    # 0x3709: '',  # 㜉
    0x370A: 'pàng,zhǎn',  # 㜊
    0x370B: 'yì',  # 㜋
    0x370C: 'gòu',  # 㜌
    0x370D: 'táng',  # 㜍
    0x370E: 'xī,xì',  # 㜎
    0x370F: 'yún',  # 㜏
    0x3710: 'shù',  # 㜐
    0x3711: 'fú,pó',  # 㜑
    0x3712: 'yì',  # 㜒
    0x3713: 'dá',  # 㜓
    # 0x3714: '',  # 㜔
    0x3715: 'lián',  # 㜕
    0x3716: 'cáo',  # 㜖
    0x3717: 'cǎn,chú,xuàn',  # 㜗
    0x3718: 'jù',  # 㜘
    0x3719: 'lù',  # 㜙
    0x371A: 'sù',  # 㜚
    0x371B: 'nèn,ruǎn',  # 㜛
    0x371C: 'ào',  # 㜜
    0x371D: 'ǎn,àn',  # 㜝
    0x371E: 'qiàn',  # 㜞
    # 0x371F: '',  # 㜟
    # 0x3720: '',  # 㜠
    # 0x3721: '',  # 㜡
    # 0x3722: '',  # 㜢
    0x3723: 'rán,niàn',  # 㜣
    0x3724: 'shěn,niǎn',  # 㜤
    0x3725: 'mái,mó',  # 㜥
    0x3726: 'hàn,niè,sì,xié,xín',  # 㜦
    0x3727: 'yuè',  # 㜧
    0x3728: 'ér,nái',  # 㜨
    0x3729: 'ào',  # 㜩
    0x372A: 'xiǎn',  # 㜪
    0x372B: 'mà,méi,měi',  # 㜫
    # 0x372C: '',  # 㜬
    0x372D: 'dāng',  # 㜭
    0x372E: 'làn',  # 㜮
    # 0x372F: '',  # 㜯
    0x3730: 'yuè',  # 㜰
    0x3731: 'dòng,zhì',  # 㜱
    0x3732: 'wěng,yíng',  # 㜲
    0x3733: 'huái',  # 㜳
    0x3734: 'mèng',  # 㜴
    0x3735: 'niǎo',  # 㜵
    0x3736: 'fàn',  # 㜶
    0x3737: 'mí,nǎi,xiǎn',  # 㜷
    0x3738: 'niè',  # 㜸
    0x3739: 'qú',  # 㜹
    0x373A: 'zàn',  # 㜺
    0x373B: 'liàn',  # 㜻
    0x373C: 'zhí,zhì',  # 㜼
    0x373D: 'zǐ',  # 㜽
    0x373E: 'hái',  # 㜾
    0x373F: 'xù',  # 㜿
    0x3740: 'hào',  # 㝀
    0x3741: 'xún',  # 㝁
    0x3742: 'zhì',  # 㝂
    0x3743: 'fàn,miǎn,wǎn',  # 㝃
    0x3744: 'chún,qì,rùn',  # 㝄
    0x3745: 'gòu',  # 㝅
    # 0x3746: '',  # 㝆
    0x3747: 'chún',  # 㝇
    0x3748: 'luán',  # 㝈
    0x3749: 'zhù',  # 㝉
    0x374A: 'shǒu',  # 㝊
    0x374B: 'liáo,liǎo,liú',  # 㝋
    0x374C: 'jié,jiù,zhòu',  # 㝌
    0x374D: 'xiě',  # 㝍
    0x374E: 'dìng',  # 㝎
    0x374F: 'jiè',  # 㝏
    0x3750: 'róng',  # 㝐
    0x3751: 'máng,páng',  # 㝑
    # 0x3752: '',  # 㝒
    0x3753: 'gé,kè',  # 㝓
    0x3754: 'yào',  # 㝔
    0x3755: 'níng',  # 㝕
    0x3756: 'yí,yín',  # 㝖
    0x3757: 'láng',  # 㝗
    0x3758: 'yóng',  # 㝘
    0x3759: 'yín',  # 㝙
    # 0x375A: '',  # 㝚
    0x375B: 'sù',  # 㝛
    # 0x375C: '',  # 㝜
    0x375D: 'lín',  # 㝝
    0x375E: 'yā',  # 㝞
    0x375F: 'máo,mào,kuān',  # 㝟
    0x3760: 'míng',  # 㝠
    0x3761: 'zuì',  # 㝡
    0x3762: 'yǔ',  # 㝢
    0x3763: 'yè,yì',  # 㝣
    0x3764: 'gòu',  # 㝤
    0x3765: 'mǐ',  # 㝥
    0x3766: 'jùn,yá',  # 㝦
    0x3767: 'wěn',  # 㝧
    # 0x3768: '',  # 㝨
    0x3769: 'kāng',  # 㝩
    0x376A: 'diàn,dǐng',  # 㝪
    0x376B: 'lóng',  # 㝫
    0x376C: 'hú',  # 㝬
    0x376D: 'xǐng',  # 㝭
    0x376E: 'cuì',  # 㝮
    0x376F: 'qiáo',  # 㝯
    0x3770: 'mián',  # 㝰
    0x3771: 'mèng',  # 㝱
    0x3772: 'qǐn',  # 㝲
    # 0x3773: '',  # 㝳
    0x3774: 'wán',  # 㝴
    0x3775: 'dé',  # 㝵
    0x3776: 'ài,dé',  # 㝶
    # 0x3777: '',  # 㝷
    0x3778: 'biàn',  # 㝸
    0x3779: 'nóu',  # 㝹
    0x377A: 'lián,lín',  # 㝺
    0x377B: 'jǐn',  # 㝻
    0x377C: 'yū',  # 㝼
    0x377D: 'chuí,shuǐ,zhuǐ',  # 㝽
    0x377E: 'zuǒ',  # 㝾
    0x377F: 'bó,bǒ,fù,qiàn',  # 㝿
    # 0x3780: '',  # 㞀
    0x3781: 'yào',  # 㞁
    0x3782: 'tuǐ',  # 㞂
    0x3783: 'jí',  # 㞃
    # 0x3784: '',  # 㞄
    0x3785: 'guǒ',  # 㞅
    0x3786: 'jǐ',  # 㞆
    0x3787: 'wěi',  # 㞇
    # 0x3788: '',  # 㞈
    # 0x3789: '',  # 㞉
    0x378A: 'xù',  # 㞊
    0x378B: 'niǎn',  # 㞋
    0x378C: 'yùn',  # 㞌
    # 0x378D: '',  # 㞍
    0x378E: 'bǎ,fú,pá',  # 㞎
    0x378F: 'zhé',  # 㞏
    0x3790: 'jū',  # 㞐
    0x3791: 'wěi',  # 㞑
    0x3792: 'xì,xiè',  # 㞒
    0x3793: 'qǐ,qì',  # 㞓
    0x3794: 'yí',  # 㞔
    0x3795: 'xiè',  # 㞕
    0x3796: 'cì',  # 㞖
    0x3797: 'qiú',  # 㞗
    0x3798: 'tún',  # 㞘
    0x3799: 'niào',  # 㞙
    0x379A: 'qì,zhǎ',  # 㞚
    0x379B: 'jǐ',  # 㞛
    # 0x379C: '',  # 㞜
    # 0x379D: '',  # 㞝
    0x379E: 'sóng',  # 㞞
    0x379F: 'diàn',  # 㞟
    0x37A0: 'láo,liáo',  # 㞠
    0x37A1: 'zhǎn',  # 㞡
    # 0x37A2: '',  # 㞢
    # 0x37A3: '',  # 㞣
    0x37A4: 'yín',  # 㞤
    0x37A5: 'cén',  # 㞥
    0x37A6: 'jǐ',  # 㞦
    0x37A7: 'huì',  # 㞧
    0x37A8: 'zǎi,zǐ',  # 㞨
    0x37A9: 'lán',  # 㞩
    0x37AA: 'náo',  # 㞪
    0x37AB: 'jù,zǒu',  # 㞫
    0x37AC: 'qìn',  # 㞬
    0x37AD: 'dài',  # 㞭
    # 0x37AE: '',  # 㞮
    0x37AF: 'jié',  # 㞯
    0x37B0: 'xǔ',  # 㞰
    # 0x37B1: '',  # 㞱
    0x37B2: 'yòng',  # 㞲
    0x37B3: 'dǒu',  # 㞳
    0x37B4: 'chí',  # 㞴
    # 0x37B5: '',  # 㞵
    0x37B6: 'mǐn',  # 㞶
    0x37B7: 'huáng',  # 㞷
    0x37B8: 'suì',  # 㞸
    0x37B9: 'kě',  # 㞹
    0x37BA: 'zú',  # 㞺
    0x37BB: 'hào',  # 㞻
    0x37BC: 'chéng,shèng,zhé',  # 㞼
    0x37BD: 'xuè',  # 㞽
    0x37BE: 'ní,yì',  # 㞾
    0x37BF: 'chì,qí',  # 㞿
    0x37C0: 'lián',  # 㟀
    0x37C1: 'àn',  # 㟁
    0x37C2: 'chǐ,mǔ',  # 㟂
    0x37C3: 'sī',  # 㟃
    0x37C4: 'xiáng',  # 㟄
    0x37C5: 'yáng',  # 㟅
    0x37C6: 'huá',  # 㟆
    0x37C7: 'cuó,cuǒ',  # 㟇
    0x37C8: 'qiú',  # 㟈
    0x37C9: 'láo',  # 㟉
    0x37CA: 'fú',  # 㟊
    0x37CB: 'duì',  # 㟋
    0x37CC: 'máng',  # 㟌
    0x37CD: 'láng',  # 㟍
    0x37CE: 'tuǒ',  # 㟎
    0x37CF: 'hán',  # 㟏
    0x37D0: 'mǎng',  # 㟐
    0x37D1: 'bó',  # 㟑
    # 0x37D2: '',  # 㟒
    0x37D3: 'qí',  # 㟓
    0x37D4: 'hán',  # 㟔
    # 0x37D5: '',  # 㟕
    0x37D6: 'lòng',  # 㟖
    # 0x37D7: '',  # 㟗
    0x37D8: 'tiáo',  # 㟘
    0x37D9: 'lǎo,zé,zhái',  # 㟙
    0x37DA: 'qí',  # 㟚
    0x37DB: 'zàn',  # 㟛
    0x37DC: 'mí',  # 㟜
    0x37DD: 'péi,pǒu',  # 㟝
    0x37DE: 'zhàn',  # 㟞
    0x37DF: 'xiàng',  # 㟟
    0x37E0: 'gǎng',  # 㟠
    # 0x37E1: '',  # 㟡
    0x37E2: 'qí',  # 㟢
    # 0x37E3: '',  # 㟣
    0x37E4: 'lù',  # 㟤
    # 0x37E5: '',  # 㟥
    0x37E6: 'yùn',  # 㟦
    0x37E7: 'è,niè,xùn',  # 㟧
    0x37E8: 'quán',  # 㟨
    0x37E9: 'mín,mǐn,wěn',  # 㟩
    0x37EA: 'wěi',  # 㟪
    0x37EB: 'quán',  # 㟫
    0x37EC: 'shǔ,sǒu',  # 㟬
    0x37ED: 'mín',  # 㟭
    0x37EE: 'tū',  # 㟮
    0x37EF: 'è',  # 㟯
    0x37F0: 'mǐng',  # 㟰
    0x37F1: 'yǎo',  # 㟱
    0x37F2: 'jué,yuán',  # 㟲
    0x37F3: 'lì',  # 㟳
    0x37F4: 'kuài,kuǐ,wěi',  # 㟴
    0x37F5: 'gǎng',  # 㟵
    0x37F6: 'yuán',  # 㟶
    0x37F7: 'da',  # 㟷
    # 0x37F8: '',  # 㟸
    0x37F9: 'láo',  # 㟹
    0x37FA: 'lóu',  # 㟺
    0x37FB: 'qiàn',  # 㟻
    0x37FC: 'áo',  # 㟼
    0x37FD: 'biǎo',  # 㟽
    # 0x37FE: '',  # 㟾
    0x37FF: 'máng,mǎng',  # 㟿
    0x3800: 'dǎo',  # 㠀
    # 0x3801: '',  # 㠁
    0x3802: 'áo',  # 㠂
    # 0x3803: '',  # 㠃
    0x3804: 'xí',  # 㠄
    0x3805: 'fú,fù',  # 㠅
    # 0x3806: '',  # 㠆
    0x3807: 'jiù',  # 㠇
    0x3808: 'rùn',  # 㠈
    0x3809: 'tóng',  # 㠉
    # 0x380A: '',  # 㠊
    0x380B: 'è',  # 㠋
    # 0x380C: '',  # 㠌
    0x380D: 'jí,jié,qì',  # 㠍
    0x380E: 'qì',  # 㠎
    0x380F: 'huá',  # 㠏
    0x3810: 'jiào',  # 㠐
    0x3811: 'zuì',  # 㠑
    0x3812: 'biǎo',  # 㠒
    0x3813: 'méng',  # 㠓
    0x3814: 'bài',  # 㠔
    0x3815: 'wěi',  # 㠕
    0x3816: 'jì,yǐ',  # 㠖
    0x3817: 'ào,wò',  # 㠗
    0x3818: 'yǔ',  # 㠘
    0x3819: 'háo',  # 㠙
    0x381A: 'duì,zhuó',  # 㠚
    0x381B: 'wò',  # 㠛
    0x381C: 'nì',  # 㠜
    0x381D: 'cuán',  # 㠝
    # 0x381E: '',  # 㠞
    0x381F: 'lí',  # 㠟
    0x3820: 'lú',  # 㠠
    0x3821: 'niǎo',  # 㠡
    0x3822: 'huái',  # 㠢
    0x3823: 'lài,lì',  # 㠣
    # 0x3824: '',  # 㠤
    0x3825: 'lǜ',  # 㠥
    # 0x3826: '',  # 㠦
    0x3827: 'mí,mǐ',  # 㠧
    0x3828: 'yù',  # 㠨
    # 0x3829: '',  # 㠩
    0x382A: 'jù',  # 㠪
    0x382B: 'gū',  # 㠫
    0x382C: 'gū',  # 㠬
    0x382D: 'zhǎn,zhàn',  # 㠭
    # 0x382E: '',  # 㠮
    0x382F: 'yǐ',  # 㠯
    # 0x3830: '',  # 㠰
    0x3831: 'jì,qǐ',  # 㠱
    0x3832: 'bǐ',  # 㠲
    # 0x3833: '',  # 㠳
    0x3834: 'rèn',  # 㠴
    0x3835: 'huāng',  # 㠵
    0x3836: 'fán',  # 㠶
    0x3837: 'gé',  # 㠷
    0x3838: 'kù',  # 㠸
    0x3839: 'jiè',  # 㠹
    0x383A: 'miáo',  # 㠺
    # 0x383B: '',  # 㠻
    # 0x383C: '',  # 㠼
    0x383D: 'tóng',  # 㠽
    # 0x383E: '',  # 㠾
    0x383F: 'cǐ',  # 㠿
    0x3840: 'bì',  # 㡀
    0x3841: 'kǎi,kuà',  # 㡁
    0x3842: 'lì',  # 㡂
    # 0x3843: '',  # 㡃
    0x3844: 'sǔn,xún',  # 㡄
    0x3845: 'nuǒ',  # 㡅
    0x3846: 'huāng',  # 㡆
    0x3847: 'jí,zhé',  # 㡇
    0x3848: 'mén,wèn',  # 㡈
    0x3849: 'xián,yán',  # 㡉
    0x384A: 'qià,qiǎn',  # 㡊
    0x384B: 'è,yé',  # 㡋
    0x384C: 'mào,mèi',  # 㡌
    # 0x384D: '',  # 㡍
    # 0x384E: '',  # 㡎
    0x384F: 'tóu,shū',  # 㡏
    # 0x3850: '',  # 㡐
    0x3851: 'qiǎo',  # 㡑
    0x3852: 'zhūn',  # 㡒
    # 0x3853: '',  # 㡓
    0x3854: 'wù,mù',  # 㡔
    # 0x3855: '',  # 㡕
    0x3856: 'chuáng',  # 㡖
    0x3857: 'tí',  # 㡗
    0x3858: 'lián',  # 㡘
    0x3859: 'bī,pí',  # 㡙
    # 0x385A: '',  # 㡚
    0x385B: 'máng',  # 㡛
    0x385C: 'xuě',  # 㡜
    0x385D: 'fèng,fú',  # 㡝
    0x385E: 'lěi,lóu',  # 㡞
    # 0x385F: '',  # 㡟
    0x3860: 'zhèng',  # 㡠
    0x3861: 'chú',  # 㡡
    0x3862: 'màn',  # 㡢
    0x3863: 'lóng',  # 㡣
    # 0x3864: '',  # 㡤
    0x3865: 'yǐn',  # 㡥
    # 0x3866: '',  # 㡦
    0x3867: 'zhèng',  # 㡧
    0x3868: 'qiān,jiān',  # 㡨
    0x3869: 'luán',  # 㡩
    0x386A: 'nié',  # 㡪
    0x386B: 'yì',  # 㡫
    # 0x386C: '',  # 㡬
    0x386D: 'jì',  # 㡭
    0x386E: 'jí',  # 㡮
    0x386F: 'zhái,dù',  # 㡯
    0x3870: 'yǔ',  # 㡰
    0x3871: 'jiǔ',  # 㡱
    0x3872: 'huán',  # 㡲
    0x3873: 'dǐ,zhé,zhǐ',  # 㡳
    # 0x3874: '',  # 㡴
    0x3875: 'líng',  # 㡵
    0x3876: 'zhǐ',  # 㡶
    0x3877: 'běn',  # 㡷
    0x3878: 'zhǎ,zhà',  # 㡸
    0x3879: 'cì,jū',  # 㡹
    0x387A: 'dàn',  # 㡺
    0x387B: 'liào',  # 㡻
    0x387C: 'yì',  # 㡼
    0x387D: 'zhào',  # 㡽
    0x387E: 'xiàn',  # 㡾
    0x387F: 'chì',  # 㡿
    0x3880: 'cì,zì',  # 㢀
    0x3881: 'chǐ',  # 㢁
    0x3882: 'yǎn',  # 㢂
    0x3883: 'láng',  # 㢃
    0x3884: 'dòu',  # 㢄
    0x3885: 'lòng',  # 㢅
    0x3886: 'chán',  # 㢆
    # 0x3887: '',  # 㢇
    0x3888: 'tuí',  # 㢈
    0x3889: 'chá',  # 㢉
    0x388A: 'ǎi',  # 㢊
    0x388B: 'chǐ',  # 㢋
    # 0x388C: '',  # 㢌
    0x388D: 'yíng,yǐng',  # 㢍
    0x388E: 'chà,zé,zhái,zhé',  # 㢎
    0x388F: 'tóu',  # 㢏
    # 0x3890: '',  # 㢐
    0x3891: 'tuí',  # 㢑
    0x3892: 'chá',  # 㢒
    0x3893: 'yǎo,zhàng',  # 㢓
    0x3894: 'zǒng',  # 㢔
    # 0x3895: '',  # 㢕
    # 0x3896: '',  # 㢖
    0x3897: 'qiào',  # 㢗
    0x3898: 'lián',  # 㢘
    0x3899: 'qín',  # 㢙
    0x389A: 'lǔ',  # 㢚
    0x389B: 'yàn',  # 㢛
    # 0x389C: '',  # 㢜
    # 0x389D: '',  # 㢝
    0x389E: 'yì',  # 㢞
    0x389F: 'chǎn,chān',  # 㢟
    0x38A0: 'jiǒng,jùn',  # 㢠
    0x38A1: 'jiǎng',  # 㢡
    # 0x38A2: '',  # 㢢
    0x38A3: 'jìng,qíng',  # 㢣
    # 0x38A4: '',  # 㢤
    0x38A5: 'dòng',  # 㢥
    0x38A6: 'gē',  # 㢦
    0x38A7: 'juàn',  # 㢧
    0x38A8: 'hàn',  # 㢨
    0x38A9: 'dì',  # 㢩
    # 0x38AA: '',  # 㢪
    # 0x38AB: '',  # 㢫
    0x38AC: 'hóng',  # 㢬
    # 0x38AD: '',  # 㢭
    0x38AE: 'chí',  # 㢮
    0x38AF: 'mín',  # 㢯
    0x38B0: 'bì,huán',  # 㢰
    # 0x38B1: '',  # 㢱
    0x38B2: 'xùn',  # 㢲
    0x38B3: 'lú',  # 㢳
    # 0x38B4: '',  # 㢴
    0x38B5: 'shè,xié',  # 㢵
    0x38B6: 'bì',  # 㢶
    # 0x38B7: '',  # 㢷
    0x38B8: 'bì',  # 㢸
    # 0x38B9: '',  # 㢹
    0x38BA: 'xián',  # 㢺
    0x38BB: 'wěi',  # 㢻
    0x38BC: 'biè',  # 㢼
    0x38BD: 'ěr',  # 㢽
    0x38BE: 'juàn',  # 㢾
    # 0x38BF: '',  # 㢿
    0x38C0: 'zhèn',  # 㣀
    0x38C1: 'bèi',  # 㣁
    0x38C2: 'yì',  # 㣂
    0x38C3: 'yǔ,yù',  # 㣃
    0x38C4: 'qú',  # 㣄
    0x38C5: 'zàn',  # 㣅
    0x38C6: 'mí,mí,pèi',  # 㣆
    0x38C7: 'nǐ,yì',  # 㣇
    0x38C8: 'sì',  # 㣈
    # 0x38C9: '',  # 㣉
    # 0x38CA: '',  # 㣊
    # 0x38CB: '',  # 㣋
    0x38CC: 'shàn',  # 㣌
    0x38CD: 'tái',  # 㣍
    0x38CE: 'mù',  # 㣎
    0x38CF: 'jìng',  # 㣏
    0x38D0: 'biàn',  # 㣐
    0x38D1: 'róng',  # 㣑
    0x38D2: 'cèng',  # 㣒
    0x38D3: 'càn',  # 㣓
    # 0x38D4: '',  # 㣔
    # 0x38D5: '',  # 㣕
    # 0x38D6: '',  # 㣖
    # 0x38D7: '',  # 㣗
    # 0x38D8: '',  # 㣘
    0x38D9: 'dí',  # 㣙
    0x38DA: 'tóng,tǒng',  # 㣚
    0x38DB: 'tà',  # 㣛
    0x38DC: 'xíng',  # 㣜
    0x38DD: 'sōng',  # 㣝
    0x38DE: 'duó,duò',  # 㣞
    0x38DF: 'xì',  # 㣟
    0x38E0: 'tóng',  # 㣠
    # 0x38E1: '',  # 㣡
    0x38E2: 'tí',  # 㣢
    0x38E3: 'shǎn,shàn',  # 㣣
    0x38E4: 'jiàn',  # 㣤
    0x38E5: 'zhì',  # 㣥
    # 0x38E6: '',  # 㣦
    0x38E7: 'yìn,yǒng',  # 㣧
    # 0x38E8: '',  # 㣨
    # 0x38E9: '',  # 㣩
    0x38EA: 'huǎn,kuò',  # 㣪
    0x38EB: 'zhǒng',  # 㣫
    0x38EC: 'qì',  # 㣬
    # 0x38ED: '',  # 㣭
    # 0x38EE: '',  # 㣮
    0x38EF: 'xiè',  # 㣯
    0x38F0: 'xiè',  # 㣰
    0x38F1: 'zé,zuò',  # 㣱
    0x38F2: 'wéi',  # 㣲
    # 0x38F3: '',  # 㣳
    # 0x38F4: '',  # 㣴
    0x38F5: 'tà',  # 㣵
    0x38F6: 'zhān',  # 㣶
    0x38F7: 'nìng',  # 㣷
    # 0x38F8: '',  # 㣸
    # 0x38F9: '',  # 㣹
    # 0x38FA: '',  # 㣺
    0x38FB: 'yì',  # 㣻
    0x38FC: 'rěn',  # 㣼
    0x38FD: 'shù',  # 㣽
    0x38FE: 'chà',  # 㣾
    0x38FF: 'zhuó',  # 㣿
    # 0x3900: '',  # 㤀
    0x3901: 'miǎn,tiǎn',  # 㤁
    0x3902: 'jí',  # 㤂
    0x3903: 'fáng',  # 㤃
    0x3904: 'pèi',  # 㤄
    0x3905: 'ài',  # 㤅
    0x3906: 'fàn',  # 㤆
    0x3907: 'ǎo,fó,wù',  # 㤇
    0x3908: 'qìn',  # 㤈
    0x3909: 'qiā,yá',  # 㤉
    0x390A: 'xiào,yáo',  # 㤊
    # 0x390B: '',  # 㤋
    # 0x390C: '',  # 㤌
    0x390D: 'qiǎo',  # 㤍
    # 0x390E: '',  # 㤎
    0x390F: 'tóng',  # 㤏
    # 0x3910: '',  # 㤐
    0x3911: 'yōu',  # 㤑
    # 0x3912: '',  # 㤒
    0x3913: 'bèn',  # 㤓
    0x3914: 'fú,fù',  # 㤔
    0x3915: 'chù',  # 㤕
    0x3916: 'zhù',  # 㤖
    # 0x3917: '',  # 㤗
    0x3918: 'chù,cù,zhòu',  # 㤘
    # 0x3919: '',  # 㤙
    0x391A: 'háng',  # 㤚
    0x391B: 'nín,rèn',  # 㤛
    0x391C: 'jué,yù',  # 㤜
    # 0x391D: '',  # 㤝
    0x391E: 'chà',  # 㤞
    0x391F: 'kǒng,tòu',  # 㤟
    0x3920: 'liè',  # 㤠
    0x3921: 'lì',  # 㤡
    0x3922: 'xù,yù',  # 㤢
    # 0x3923: '',  # 㤣
    0x3924: 'yú,yǔ',  # 㤤
    0x3925: 'hài',  # 㤥
    0x3926: 'lì',  # 㤦
    0x3927: 'hóu,hòu',  # 㤧
    0x3928: 'gǒng,qióng',  # 㤨
    0x3929: 'kè',  # 㤩
    0x392A: 'yuàn',  # 㤪
    0x392B: 'dé',  # 㤫
    0x392C: 'huì,kuì',  # 㤬
    # 0x392D: '',  # 㤭
    0x392E: 'kuáng,guàng',  # 㤮
    0x392F: 'jiǒng,jùn',  # 㤯
    0x3930: 'zǎn,zuò',  # 㤰
    0x3931: 'fù',  # 㤱
    0x3932: 'qiè,qù',  # 㤲
    0x3933: 'běi',  # 㤳
    0x3934: 'xí',  # 㤴
    0x3935: 'cí',  # 㤵
    0x3936: 'páng',  # 㤶
    # 0x3937: '',  # 㤷
    0x3938: 'xì',  # 㤸
    0x3939: 'qiú',  # 㤹
    0x393A: 'huǎng',  # 㤺
    0x393B: 'lǔn',  # 㤻
    # 0x393C: '',  # 㤼
    0x393D: 'chóu',  # 㤽
    0x393E: 'sàn',  # 㤾
    # 0x393F: '',  # 㤿
    0x3940: 'dé',  # 㥀
    0x3941: 'dé,zhí,zhòu',  # 㥁
    0x3942: 'tè',  # 㥂
    0x3943: 'mèn',  # 㥃
    0x3944: 'líng',  # 㥄
    0x3945: 'shòu',  # 㥅
    0x3946: 'diàn,tuì',  # 㥆
    0x3947: 'cán,càn',  # 㥇
    0x3948: 'dié',  # 㥈
    0x3949: 'chè,chì',  # 㥉
    0x394A: 'péng',  # 㥊
    0x394B: 'yī',  # 㥋
    0x394C: 'jú',  # 㥌
    0x394D: 'jì',  # 㥍
    0x394E: 'lái,lí',  # 㥎
    0x394F: 'tiǎn',  # 㥏
    0x3950: 'yuàn',  # 㥐
    # 0x3951: '',  # 㥑
    0x3952: 'cǎi',  # 㥒
    0x3953: 'qǐ',  # 㥓
    0x3954: 'yú,yù',  # 㥔
    0x3955: 'lián',  # 㥕
    # 0x3956: '',  # 㥖
    # 0x3957: '',  # 㥗
    # 0x3958: '',  # 㥘
    # 0x3959: '',  # 㥙
    0x395A: 'yú',  # 㥚
    0x395B: 'jí,kè,sù',  # 㥛
    0x395C: 'wèi',  # 㥜
    0x395D: 'mǐ,miǎn',  # 㥝
    0x395E: 'cuì,qiàn,suì',  # 㥞
    0x395F: 'xié',  # 㥟
    0x3960: 'xǔ',  # 㥠
    0x3961: 'xì',  # 㥡
    0x3962: 'qiú',  # 㥢
    0x3963: 'huì',  # 㥣
    # 0x3964: '',  # 㥤
    0x3965: 'yú',  # 㥥
    0x3966: 'qiè,xiá,xiǎn',  # 㥦
    0x3967: 'shùn',  # 㥧
    0x3968: 'chuí,shuì,wěi',  # 㥨
    0x3969: 'duǒ',  # 㥩
    0x396A: 'lóu',  # 㥪
    0x396B: 'dūn',  # 㥫
    0x396C: 'páng',  # 㥬
    0x396D: 'tài',  # 㥭
    0x396E: 'zhòu',  # 㥮
    0x396F: 'yǐn',  # 㥯
    # 0x3970: '',  # 㥰
    0x3971: 'fěi',  # 㥱
    0x3972: 'shèn,yín',  # 㥲
    0x3973: 'yuán',  # 㥳
    0x3974: 'yí,yǐ',  # 㥴
    0x3975: 'hùn',  # 㥵
    0x3976: 'sè',  # 㥶
    0x3977: 'yè,yì',  # 㥷
    0x3978: 'mǐn',  # 㥸
    0x3979: 'fěn',  # 㥹
    0x397A: 'hé,hè',  # 㥺
    # 0x397B: '',  # 㥻
    0x397C: 'yǐn',  # 㥼
    0x397D: 'cè,zé',  # 㥽
    0x397E: 'nì',  # 㥾
    0x397F: 'ào',  # 㥿
    0x3980: 'féng',  # 㦀
    0x3981: 'lián',  # 㦁
    0x3982: 'cháng,tàng',  # 㦂
    0x3983: 'chǎn',  # 㦃
    0x3984: 'má,mì',  # 㦄
    0x3985: 'diē,dì',  # 㦅
    # 0x3986: '',  # 㦆
    0x3987: 'lù',  # 㦇
    # 0x3988: '',  # 㦈
    0x3989: 'yì',  # 㦉
    0x398A: 'huá',  # 㦊
    # 0x398B: '',  # 㦋
    0x398C: 'tuì,xù,hū',  # 㦌
    0x398D: 'è',  # 㦍
    0x398E: 'huà',  # 㦎
    0x398F: 'sǔn,xuàn',  # 㦏
    0x3990: 'nì',  # 㦐
    0x3991: 'liǎn,xiàn',  # 㦑
    0x3992: 'lí',  # 㦒
    0x3993: 'xiàn',  # 㦓
    0x3994: 'yàn',  # 㦔
    0x3995: 'lóng',  # 㦕
    0x3996: 'mèn',  # 㦖
    0x3997: 'jiàn,jìn',  # 㦗
    # 0x3998: '',  # 㦘
    # 0x3999: '',  # 㦙
    0x399A: 'biǎn',  # 㦚
    0x399B: 'yú,yǔ',  # 㦛
    0x399C: 'huò,xuè',  # 㦜
    0x399D: 'miǎo',  # 㦝
    0x399E: 'chóu',  # 㦞
    0x399F: 'hài,mái',  # 㦟
    # 0x39A0: '',  # 㦠
    0x39A1: 'lè',  # 㦡
    0x39A2: 'jié,qì',  # 㦢
    0x39A3: 'wèi',  # 㦣
    0x39A4: 'yì',  # 㦤
    0x39A5: 'huán,xiǎn',  # 㦥
    0x39A6: 'hè',  # 㦦
    0x39A7: 'cǎn',  # 㦧
    0x39A8: 'lán,làn',  # 㦨
    0x39A9: 'yǐn',  # 㦩
    0x39AA: 'xiè',  # 㦪
    # 0x39AB: '',  # 㦫
    0x39AC: 'luǒ',  # 㦬
    0x39AD: 'líng',  # 㦭
    0x39AE: 'qián',  # 㦮
    0x39AF: 'huò',  # 㦯
    0x39B0: 'jiān',  # 㦰
    0x39B1: 'wǒ',  # 㦱
    0x39B2: 'zāi',  # 㦲
    # 0x39B3: '',  # 㦳
    0x39B4: 'gé,qià',  # 㦴
    # 0x39B5: '',  # 㦵
    0x39B6: 'dié',  # 㦶
    0x39B7: 'yǒng',  # 㦷
    0x39B8: 'jǐ',  # 㦸
    0x39B9: 'àng,yáng,yǐng',  # 㦹
    0x39BA: 'rǔ,rù',  # 㦺
    0x39BB: 'xí,zhé',  # 㦻
    0x39BC: 'shuàng',  # 㦼
    0x39BD: 'xù,yù',  # 㦽
    0x39BE: 'yí',  # 㦾
    0x39BF: 'hù',  # 㦿
    0x39C0: 'jí',  # 㧀
    0x39C1: 'qù',  # 㧁
    0x39C2: 'tián',  # 㧂
    # 0x39C3: '',  # 㧃
    0x39C4: 'qiǎn,qiú',  # 㧄
    0x39C5: 'mù,dāo',  # 㧅
    # 0x39C6: '',  # 㧆
    0x39C7: 'mǎo',  # 㧇
    0x39C8: 'yǐn,yìn',  # 㧈
    0x39C9: 'gài,kuì',  # 㧉
    0x39CA: 'bá,pō',  # 㧊
    0x39CB: 'xiǎn,xuǎn',  # 㧋
    0x39CC: 'mào',  # 㧌
    0x39CD: 'fǎng',  # 㧍
    0x39CE: 'yá,yà,qiā',  # 㧎
    0x39CF: 'gāng',  # 㧏
    0x39D0: 'sǒng',  # 㧐
    0x39D1: 'wéi,wěi',  # 㧑
    0x39D2: 'xué,yù,yuè',  # 㧒
    # 0x39D3: '',  # 㧓
    0x39D4: 'guài',  # 㧔
    0x39D5: 'jiù,liǔ,yú',  # 㧕
    0x39D6: 'è',  # 㧖
    0x39D7: 'zǐ,jǐ,zhǐ',  # 㧗
    0x39D8: 'cuì,nǎo,zì',  # 㧘
    0x39D9: 'bì',  # 㧙
    0x39DA: 'wǎ',  # 㧚
    # 0x39DB: '',  # 㧛
    0x39DC: 'liè',  # 㧜
    # 0x39DD: '',  # 㧝
    # 0x39DE: '',  # 㧞
    0x39DF: 'kuǎi',  # 㧟
    # 0x39E0: '',  # 㧠
    0x39E1: 'hài',  # 㧡
    0x39E2: 'yīn',  # 㧢
    0x39E3: 'zhù',  # 㧣
    0x39E4: 'chòng',  # 㧤
    0x39E5: 'xiǎn',  # 㧥
    0x39E6: 'xuàn',  # 㧦
    # 0x39E7: '',  # 㧧
    0x39E8: 'qiú',  # 㧨
    0x39E9: 'pèi',  # 㧩
    0x39EA: 'guǐ',  # 㧪
    0x39EB: 'ér',  # 㧫
    0x39EC: 'gǒng',  # 㧬
    0x39ED: 'qióng',  # 㧭
    # 0x39EE: '',  # 㧮
    0x39EF: 'lǎo',  # 㧯
    0x39F0: 'lì',  # 㧰
    0x39F1: 'chèn,ná,nì,nì,tiàn',  # 㧱
    0x39F2: 'sǎn',  # 㧲
    0x39F3: 'bǎi,bó,zhuò',  # 㧳
    0x39F4: 'wǒ',  # 㧴
    0x39F5: 'póu,pǒu',  # 㧵
    # 0x39F6: '',  # 㧶
    0x39F7: 'duò,tùn',  # 㧷
    # 0x39F8: '',  # 㧸
    0x39F9: 'tè',  # 㧹
    0x39FA: 'tà',  # 㧺
    0x39FB: 'zhǐ,zhuó,zú',  # 㧻
    0x39FC: 'biào',  # 㧼
    0x39FD: 'gù,hú',  # 㧽
    # 0x39FE: '',  # 㧾
    # 0x39FF: '',  # 㧿
    0x3A00: 'bǐng',  # 㨀
    0x3A01: 'zhí,zhì',  # 㨁
    0x3A02: 'dǒng',  # 㨂
    0x3A03: 'chéng,duǐ',  # 㨃
    0x3A04: 'zhào',  # 㨄
    0x3A05: 'nèi,ruì',  # 㨅
    0x3A06: 'lǐn',  # 㨆
    0x3A07: 'pó',  # 㨇
    0x3A08: 'jǐ',  # 㨈
    0x3A09: 'mǐn',  # 㨉
    0x3A0A: 'wěi',  # 㨊
    0x3A0B: 'chě,lè,zhèn',  # 㨋
    0x3A0C: 'gòu,rú,rǔ',  # 㨌
    # 0x3A0D: '',  # 㨍
    0x3A0E: 'rú,ruán',  # 㨎
    # 0x3A0F: '',  # 㨏
    0x3A10: 'bǔ,péi',  # 㨐
    # 0x3A11: '',  # 㨑
    0x3A12: 'kuí,wěi,xié',  # 㨒
    0x3A13: 'láo,liáo',  # 㨓
    0x3A14: 'hàn',  # 㨔
    0x3A15: 'yíng',  # 㨕
    0x3A16: 'zhì',  # 㨖
    0x3A17: 'jié',  # 㨗
    0x3A18: 'xǐng',  # 㨘
    0x3A19: 'xié',  # 㨙
    0x3A1A: 'xún',  # 㨚
    0x3A1B: 'shǎn',  # 㨛
    0x3A1C: 'qián',  # 㨜
    0x3A1D: 'xiè',  # 㨝
    0x3A1E: 'sù',  # 㨞
    0x3A1F: 'hái',  # 㨟
    0x3A20: 'mì',  # 㨠
    0x3A21: 'hún',  # 㨡
    # 0x3A22: '',  # 㨢
    # 0x3A23: '',  # 㨣
    0x3A24: 'huì,kuǎi,wài',  # 㨤
    0x3A25: 'nà',  # 㨥
    0x3A26: 'sǒng',  # 㨦
    0x3A27: 'bèn',  # 㨧
    0x3A28: 'liù',  # 㨨
    0x3A29: 'jié',  # 㨩
    0x3A2A: 'huàng',  # 㨪
    0x3A2B: 'lǎn',  # 㨫
    # 0x3A2C: '',  # 㨬
    0x3A2D: 'hù',  # 㨭
    0x3A2E: 'dōu',  # 㨮
    0x3A2F: 'huò,kuò',  # 㨯
    0x3A30: 'gé,gǔn,hùn,huò,jié',  # 㨰
    0x3A31: 'yáo',  # 㨱
    0x3A32: 'cè',  # 㨲
    0x3A33: 'guǐ',  # 㨳
    0x3A34: 'jiàn',  # 㨴
    0x3A35: 'jiǎn',  # 㨵
    0x3A36: 'chóu,dǎo,zhǒu,zhòu',  # 㨶
    0x3A37: 'jìn',  # 㨷
    0x3A38: 'mà',  # 㨸
    0x3A39: 'huì',  # 㨹
    0x3A3A: 'mén,mì,miǎn',  # 㨺
    0x3A3B: 'cán,shǎn,zàn',  # 㨻
    0x3A3C: 'lüè',  # 㨼
    0x3A3D: 'pǐ,pì,qiǎo',  # 㨽
    0x3A3E: 'yàng',  # 㨾
    0x3A3F: 'jù',  # 㨿
    0x3A40: 'jù',  # 㩀
    0x3A41: 'què',  # 㩁
    # 0x3A42: '',  # 㩂
    0x3A43: 'qiān',  # 㩃
    0x3A44: 'shāi',  # 㩄
    0x3A45: 'chōu',  # 㩅
    0x3A46: 'jiù',  # 㩆
    0x3A47: 'huà,huò',  # 㩇
    0x3A48: 'xiàn,yǔn',  # 㩈
    0x3A49: 'xié',  # 㩉
    # 0x3A4A: '',  # 㩊
    0x3A4B: 'sù,xiāo',  # 㩋
    0x3A4C: 'fèi',  # 㩌
    0x3A4D: 'cè',  # 㩍
    0x3A4E: 'yè',  # 㩎
    # 0x3A4F: '',  # 㩏
    0x3A50: 'dèn',  # 㩐
    # 0x3A51: '',  # 㩑
    0x3A52: 'qín',  # 㩒
    0x3A53: 'huǐ',  # 㩓
    0x3A54: 'tún',  # 㩔
    # 0x3A55: '',  # 㩕
    0x3A56: 'qiáng,tiáo',  # 㩖
    0x3A57: 'xí,xié',  # 㩗
    0x3A58: 'yǐ',  # 㩘
    # 0x3A59: '',  # 㩙
    0x3A5A: 'méng',  # 㩚
    0x3A5B: 'tuán',  # 㩛
    0x3A5C: 'lǎn',  # 㩜
    0x3A5D: 'háo',  # 㩝
    0x3A5E: 'cì',  # 㩞
    0x3A5F: 'zhài',  # 㩟
    0x3A60: 'piǎo',  # 㩠
    0x3A61: 'luǒ',  # 㩡
    0x3A62: 'mí,miè',  # 㩢
    # 0x3A63: '',  # 㩣
    # 0x3A64: '',  # 㩤
    # 0x3A65: '',  # 㩥
    0x3A66: 'xié',  # 㩦
    0x3A67: 'bó',  # 㩧
    0x3A68: 'huì',  # 㩨
    0x3A69: 'qǐ,qǐng',  # 㩩
    0x3A6A: 'xié,xìn,yé',  # 㩪
    # 0x3A6B: '',  # 㩫
    # 0x3A6C: '',  # 㩬
    0x3A6D: 'bó,jiǎo,xiào',  # 㩭
    0x3A6E: 'qián,xián',  # 㩮
    0x3A6F: 'bǎn,pán,pó',  # 㩯
    0x3A70: 'jiǎo,qiáo,xiǔ',  # 㩰
    0x3A71: 'jué',  # 㩱
    0x3A72: 'kǔn,quán',  # 㩲
    0x3A73: 'sǒng',  # 㩳
    0x3A74: 'jú',  # 㩴
    0x3A75: 'è',  # 㩵
    0x3A76: 'niè,nǐng',  # 㩶
    # 0x3A77: '',  # 㩷
    0x3A78: 'dié',  # 㩸
    0x3A79: 'dié,zhá',  # 㩹
    # 0x3A7A: '',  # 㩺
    0x3A7B: 'guǐ,qī',  # 㩻
    0x3A7C: 'zhī',  # 㩼
    0x3A7D: 'qí',  # 㩽
    0x3A7E: 'chuí',  # 㩾
    # 0x3A7F: '',  # 㩿
    0x3A80: 'yú',  # 㪀
    0x3A81: 'qín',  # 㪁
    # 0x3A82: '',  # 㪂
    0x3A83: 'hé',  # 㪃
    0x3A84: 'fú',  # 㪄
    # 0x3A85: '',  # 㪅
    0x3A86: 'dǐ',  # 㪆
    0x3A87: 'xiàn',  # 㪇
    0x3A88: 'guì',  # 㪈
    0x3A89: 'hé',  # 㪉
    0x3A8A: 'qún',  # 㪊
    0x3A8B: 'hàn',  # 㪋
    0x3A8C: 'tǒng,yú,yǔ',  # 㪌
    0x3A8D: 'bó',  # 㪍
    0x3A8E: 'shǎn',  # 㪎
    0x3A8F: 'bǐ',  # 㪏
    0x3A90: 'lù',  # 㪐
    0x3A91: 'yè',  # 㪑
    0x3A92: 'ní',  # 㪒
    0x3A93: 'chuái',  # 㪓
    0x3A94: 'sàn,tán',  # 㪔
    0x3A95: 'diào',  # 㪕
    0x3A96: 'lù',  # 㪖
    0x3A97: 'tǒu',  # 㪗
    0x3A98: 'liǎn',  # 㪘
    0x3A99: 'kě,kè,kuò',  # 㪙
    0x3A9A: 'sàn',  # 㪚
    0x3A9B: 'zhěn',  # 㪛
    0x3A9C: 'chuǎi',  # 㪜
    0x3A9D: 'liàn',  # 㪝
    0x3A9E: 'mào',  # 㪞
    # 0x3A9F: '',  # 㪟
    0x3AA0: 'qiàn',  # 㪠
    0x3AA1: 'kě',  # 㪡
    0x3AA2: 'shǎo',  # 㪢
    0x3AA3: 'qiào',  # 㪣
    0x3AA4: 'bì',  # 㪤
    0x3AA5: 'zhā',  # 㪥
    0x3AA6: 'yìn',  # 㪦
    # 0x3AA7: '',  # 㪧
    0x3AA8: 'shàn',  # 㪨
    0x3AA9: 'sù',  # 㪩
    0x3AAA: 'sà,xǐ',  # 㪪
    0x3AAB: 'ruì',  # 㪫
    0x3AAC: 'zhuó',  # 㪬
    0x3AAD: 'lú',  # 㪭
    0x3AAE: 'líng',  # 㪮
    0x3AAF: 'chá,jǔ,qú',  # 㪯
    # 0x3AB0: '',  # 㪰
    0x3AB1: 'huàn',  # 㪱
    # 0x3AB2: '',  # 㪲
    # 0x3AB3: '',  # 㪳
    0x3AB4: 'jiá',  # 㪴
    0x3AB5: 'bàn',  # 㪵
    0x3AB6: 'hú',  # 㪶
    0x3AB7: 'dǒu',  # 㪷
    # 0x3AB8: '',  # 㪸
    0x3AB9: 'lǒu',  # 㪹
    0x3ABA: 'jū',  # 㪺
    0x3ABB: 'juàn',  # 㪻
    0x3ABC: 'kě',  # 㪼
    0x3ABD: 'suǒ,suò',  # 㪽
    0x3ABE: 'gé,luò',  # 㪾
    0x3ABF: 'zhé,shé',  # 㪿
    0x3AC0: 'dǐng',  # 㫀
    0x3AC1: 'duàn',  # 㫁
    0x3AC2: 'zhù',  # 㫂
    0x3AC3: 'yǎn',  # 㫃
    0x3AC4: 'páng',  # 㫄
    0x3AC5: 'chá,qí,shí',  # 㫅
    # 0x3AC6: '',  # 㫆
    # 0x3AC7: '',  # 㫇
    # 0x3AC8: '',  # 㫈
    # 0x3AC9: '',  # 㫉
    0x3ACA: 'yǐ',  # 㫊
    # 0x3ACB: '',  # 㫋
    # 0x3ACC: '',  # 㫌
    0x3ACD: 'yóu',  # 㫍
    0x3ACE: 'gǔn,kuài',  # 㫎
    0x3ACF: 'yǎo',  # 㫏
    0x3AD0: 'yǎo',  # 㫐
    0x3AD1: 'shí,zhǐ',  # 㫑
    0x3AD2: 'gǒng',  # 㫒
    0x3AD3: 'qǐ,qì',  # 㫓
    0x3AD4: 'gèn',  # 㫔
    # 0x3AD5: '',  # 㫕
    0x3AD6: 'zhǐ',  # 㫖
    0x3AD7: 'hòu',  # 㫗
    0x3AD8: 'mì,miǎn',  # 㫘
    0x3AD9: 'fú',  # 㫙
    0x3ADA: 'hū',  # 㫚
    0x3ADB: 'guàng,kuáng,kuàng,mǔ',  # 㫛
    0x3ADC: 'dàn,tǎn',  # 㫜
    # 0x3ADD: '',  # 㫝
    # 0x3ADE: '',  # 㫞
    0x3ADF: 'yán',  # 㫟
    # 0x3AE0: '',  # 㫠
    # 0x3AE1: '',  # 㫡
    0x3AE2: 'qù',  # 㫢
    # 0x3AE3: '',  # 㫣
    0x3AE4: 'chǎng,zhào',  # 㫤
    0x3AE5: 'mǐng',  # 㫥
    # 0x3AE6: '',  # 㫦
    0x3AE7: 'bào',  # 㫧
    # 0x3AE8: '',  # 㫨
    # 0x3AE9: '',  # 㫩
    # 0x3AEA: '',  # 㫪
    0x3AEB: 'xiǎn',  # 㫫
    # 0x3AEC: '',  # 㫬
    0x3AED: 'shí',  # 㫭
    # 0x3AEE: '',  # 㫮
    0x3AEF: 'mào',  # 㫯
    0x3AF0: 'lǎng',  # 㫰
    0x3AF1: 'nǎn',  # 㫱
    0x3AF2: 'pèi',  # 㫲
    0x3AF3: 'chén',  # 㫳
    # 0x3AF4: '',  # 㫴
    # 0x3AF5: '',  # 㫵
    0x3AF6: 'cǒu,zhǒu',  # 㫶
    # 0x3AF7: '',  # 㫷
    0x3AF8: 'qiè',  # 㫸
    0x3AF9: 'dài,shù,yú',  # 㫹
    # 0x3AFA: '',  # 㫺
    0x3AFB: 'kùn',  # 㫻
    0x3AFC: 'dié,zhé,zhì',  # 㫼
    0x3AFD: 'lù',  # 㫽
    # 0x3AFE: '',  # 㫾
    # 0x3AFF: '',  # 㫿
    # 0x3B00: '',  # 㬀
    # 0x3B01: '',  # 㬁
    0x3B02: 'yú',  # 㬂
    0x3B03: 'tái',  # 㬃
    0x3B04: 'chàn',  # 㬄
    0x3B05: 'màn',  # 㬅
    0x3B06: 'mián,miàn,mǐn',  # 㬆
    0x3B07: 'huàn',  # 㬇
    # 0x3B08: '',  # 㬈
    0x3B09: 'nuǎn,ruò',  # 㬉
    0x3B0A: 'huǎn',  # 㬊
    0x3B0B: 'hóu',  # 㬋
    0x3B0C: 'jìng',  # 㬌
    0x3B0D: 'bó',  # 㬍
    0x3B0E: 'xiǎn',  # 㬎
    0x3B0F: 'lì',  # 㬏
    0x3B10: 'jǐn,jìn,xíng,yǐng',  # 㬐
    # 0x3B11: '',  # 㬑
    0x3B12: 'mǎng,mào',  # 㬒
    0x3B13: 'piào',  # 㬓
    0x3B14: 'háo',  # 㬔
    0x3B15: 'yáng',  # 㬕
    # 0x3B16: '',  # 㬖
    0x3B17: 'xiàn',  # 㬗
    0x3B18: 'sù',  # 㬘
    0x3B19: 'wěi',  # 㬙
    0x3B1A: 'chè',  # 㬚
    # 0x3B1B: '',  # 㬛
    0x3B1C: 'jìn',  # 㬜
    0x3B1D: 'céng',  # 㬝
    0x3B1E: 'hè',  # 㬞
    # 0x3B1F: '',  # 㬟
    0x3B20: 'shài',  # 㬠
    0x3B21: 'líng',  # 㬡
    # 0x3B22: '',  # 㬢
    0x3B23: 'duì',  # 㬣
    # 0x3B24: '',  # 㬤
    0x3B25: 'pù',  # 㬥
    0x3B26: 'yuè',  # 㬦
    0x3B27: 'bó',  # 㬧
    # 0x3B28: '',  # 㬨
    0x3B29: 'huì',  # 㬩
    0x3B2A: 'dié,zhì',  # 㬪
    0x3B2B: 'yàn',  # 㬫
    0x3B2C: 'jù',  # 㬬
    0x3B2D: 'jiào,shǎn,yǎo',  # 㬭
    0x3B2E: 'kuài,nàn',  # 㬮
    0x3B2F: 'liè',  # 㬯
    0x3B30: 'yú',  # 㬰
    0x3B31: 'tì',  # 㬱
    # 0x3B32: '',  # 㬲
    0x3B33: 'wǔ',  # 㬳
    0x3B34: 'hǒng',  # 㬴
    0x3B35: 'xiáo,jiāo',  # 㬵
    0x3B36: 'hào',  # 㬶
    # 0x3B37: '',  # 㬷
    # 0x3B38: '',  # 㬸
    # 0x3B39: '',  # 㬹
    # 0x3B3A: '',  # 㬺
    0x3B3B: 'huǎng',  # 㬻
    0x3B3C: 'fù',  # 㬼
    # 0x3B3D: '',  # 㬽
    # 0x3B3E: '',  # 㬾
    0x3B3F: 'dùn',  # 㬿
    # 0x3B40: '',  # 㭀
    0x3B41: 'réng',  # 㭁
    0x3B42: 'jiǎo',  # 㭂
    # 0x3B43: '',  # 㭃
    0x3B44: 'xìn',  # 㭄
    # 0x3B45: '',  # 㭅
    # 0x3B46: '',  # 㭆
    0x3B47: 'yuàn',  # 㭇
    0x3B48: 'jué,kuài',  # 㭈
    0x3B49: 'huá',  # 㭉
    # 0x3B4A: '',  # 㭊
    0x3B4B: 'bàng',  # 㭋
    0x3B4C: 'móu,yú',  # 㭌
    # 0x3B4D: '',  # 㭍
    0x3B4E: 'gāng',  # 㭎
    0x3B4F: 'wěi',  # 㭏
    # 0x3B50: '',  # 㭐
    0x3B51: 'mèi',  # 㭑
    0x3B52: 'sì',  # 㭒
    0x3B53: 'biàn',  # 㭓
    0x3B54: 'lú',  # 㭔
    0x3B55: 'qū',  # 㭕
    # 0x3B56: '',  # 㭖
    # 0x3B57: '',  # 㭗
    0x3B58: 'hé,gé',  # 㭘
    0x3B59: 'shé,zhé',  # 㭙
    # 0x3B5A: '',  # 㭚
    0x3B5B: 'pài',  # 㭛
    0x3B5C: 'róng',  # 㭜
    0x3B5D: 'qiú',  # 㭝
    0x3B5E: 'liè',  # 㭞
    0x3B5F: 'gǒng',  # 㭟
    0x3B60: 'xiǎn',  # 㭠
    0x3B61: 'xì,xìn',  # 㭡
    # 0x3B62: '',  # 㭢
    # 0x3B63: '',  # 㭣
    0x3B64: 'niǎo',  # 㭤
    # 0x3B65: '',  # 㭥
    # 0x3B66: '',  # 㭦
    # 0x3B67: '',  # 㭧
    0x3B68: 'yé',  # 㭨
    0x3B69: 'lèi,líng,liè',  # 㭩
    # 0x3B6A: '',  # 㭪
    0x3B6B: 'cuán,cuó,zhèn',  # 㭫
    0x3B6C: 'zhuó',  # 㭬
    0x3B6D: 'fèi',  # 㭭
    0x3B6E: 'zuò',  # 㭮
    0x3B6F: 'dié,nà,zhé',  # 㭯
    0x3B70: 'jì,jué,zuǐ',  # 㭰
    0x3B71: 'hé,xiá',  # 㭱
    0x3B72: 'jí',  # 㭲
    # 0x3B73: '',  # 㭳
    # 0x3B74: '',  # 㭴
    # 0x3B75: '',  # 㭵
    # 0x3B76: '',  # 㭶
    # 0x3B77: '',  # 㭷
    0x3B78: 'tú',  # 㭸
    0x3B79: 'xián',  # 㭹
    0x3B7A: 'yǎn',  # 㭺
    0x3B7B: 'táng',  # 㭻
    0x3B7C: 'tà',  # 㭼
    0x3B7D: 'dǐ',  # 㭽
    0x3B7E: 'jué,yuè',  # 㭾
    0x3B7F: 'áng',  # 㭿
    0x3B80: 'hán',  # 㮀
    0x3B81: 'yáo',  # 㮁
    0x3B82: 'jú',  # 㮂
    0x3B83: 'ruí',  # 㮃
    0x3B84: 'bǎng,bì,péng',  # 㮄
    # 0x3B85: '',  # 㮅
    0x3B86: 'niè',  # 㮆
    0x3B87: 'tiàn',  # 㮇
    0x3B88: 'nài',  # 㮈
    # 0x3B89: '',  # 㮉
    # 0x3B8A: '',  # 㮊
    0x3B8B: 'yǒu,yù',  # 㮋
    0x3B8C: 'mián,mǐn',  # 㮌
    # 0x3B8D: '',  # 㮍
    # 0x3B8E: '',  # 㮎
    0x3B8F: 'nài',  # 㮏
    0x3B90: 'xǐng,shěng',  # 㮐
    0x3B91: 'qì',  # 㮑
    # 0x3B92: '',  # 㮒
    0x3B93: 'gèn',  # 㮓
    0x3B94: 'tóng',  # 㮔
    0x3B95: 'ér,ruǎn',  # 㮕
    0x3B96: 'jiá,jiá',  # 㮖
    0x3B97: 'qín',  # 㮗
    0x3B98: 'mào',  # 㮘
    0x3B99: 'è',  # 㮙
    0x3B9A: 'lì',  # 㮚
    0x3B9B: 'chí',  # 㮛
    # 0x3B9C: '',  # 㮜
    0x3B9D: 'hé,luò',  # 㮝
    0x3B9E: 'jié,ní,yá',  # 㮞
    0x3B9F: 'jí,niǎn,pèng,ròu,kā',  # 㮟
    # 0x3BA0: '',  # 㮠
    0x3BA1: 'guàn',  # 㮡
    0x3BA2: 'hóu',  # 㮢
    0x3BA3: 'gài,zé',  # 㮣
    # 0x3BA4: '',  # 㮤
    0x3BA5: 'fèn',  # 㮥
    0x3BA6: 'sè,suǒ',  # 㮦
    # 0x3BA7: '',  # 㮧
    0x3BA8: 'jí,jì',  # 㮨
    0x3BA9: 'xī',  # 㮩
    0x3BAA: 'qióng',  # 㮪
    0x3BAB: 'hé',  # 㮫
    # 0x3BAC: '',  # 㮬
    0x3BAD: 'xián',  # 㮭
    0x3BAE: 'jié',  # 㮮
    0x3BAF: 'huá,hún,kuǎn',  # 㮯
    0x3BB0: 'bí,pí',  # 㮰
    # 0x3BB1: '',  # 㮱
    # 0x3BB2: '',  # 㮲
    0x3BB3: 'zhèn',  # 㮳
    # 0x3BB4: '',  # 㮴
    # 0x3BB5: '',  # 㮵
    0x3BB6: 'shì,shuò',  # 㮶
    # 0x3BB7: '',  # 㮷
    0x3BB8: 'sòng',  # 㮸
    0x3BB9: 'zhǐ',  # 㮹
    0x3BBA: 'běn',  # 㮺
    # 0x3BBB: '',  # 㮻
    # 0x3BBC: '',  # 㮼
    # 0x3BBD: '',  # 㮽
    0x3BBE: 'lǎng',  # 㮾
    0x3BBF: 'bì',  # 㮿
    0x3BC0: 'xiǎn,xuàn',  # 㯀
    0x3BC1: 'bàng',  # 㯁
    0x3BC2: 'dài',  # 㯂
    # 0x3BC3: '',  # 㯃
    # 0x3BC4: '',  # 㯄
    0x3BC5: 'pí',  # 㯅
    0x3BC6: 'chǎn',  # 㯆
    0x3BC7: 'bì',  # 㯇
    0x3BC8: 'sù',  # 㯈
    0x3BC9: 'huò,chū',  # 㯉
    0x3BCA: 'hén',  # 㯊
    0x3BCB: 'yǐng',  # 㯋
    0x3BCC: 'chuán',  # 㯌
    0x3BCD: 'jiǎng',  # 㯍
    0x3BCE: 'nèn',  # 㯎
    0x3BCF: 'gǔ',  # 㯏
    0x3BD0: 'fǎng,tuǒ',  # 㯐
    # 0x3BD1: '',  # 㯑
    # 0x3BD2: '',  # 㯒
    0x3BD3: 'tà',  # 㯓
    0x3BD4: 'cuì',  # 㯔
    0x3BD5: 'xī',  # 㯕
    0x3BD6: 'dé',  # 㯖
    0x3BD7: 'rǎn,shùn,xián,xiàn',  # 㯗
    0x3BD8: 'kuǎn',  # 㯘
    0x3BD9: 'chè',  # 㯙
    0x3BDA: 'dá',  # 㯚
    0x3BDB: 'hú,huò',  # 㯛
    0x3BDC: 'cuì',  # 㯜
    0x3BDD: 'lù',  # 㯝
    0x3BDE: 'juàn,yuè',  # 㯞
    0x3BDF: 'lù',  # 㯟
    0x3BE0: 'qiàn,xiàn,xún',  # 㯠
    0x3BE1: 'pào',  # 㯡
    0x3BE2: 'zhèn',  # 㯢
    # 0x3BE3: '',  # 㯣
    0x3BE4: 'lì',  # 㯤
    0x3BE5: 'cáo,zāo',  # 㯥
    0x3BE6: 'qí',  # 㯦
    # 0x3BE7: '',  # 㯧
    # 0x3BE8: '',  # 㯨
    0x3BE9: 'tì',  # 㯩
    0x3BEA: 'líng',  # 㯪
    0x3BEB: 'qú',  # 㯫
    0x3BEC: 'liǎn',  # 㯬
    0x3BED: 'lǔ',  # 㯭
    0x3BEE: 'shǔ',  # 㯮
    0x3BEF: 'gòng',  # 㯯
    0x3BF0: 'zhé,zhí',  # 㯰
    0x3BF1: 'biǎo,piáo,pāo',  # 㯱
    0x3BF2: 'jìn',  # 㯲
    0x3BF3: 'qíng',  # 㯳
    # 0x3BF4: '',  # 㯴
    # 0x3BF5: '',  # 㯵
    0x3BF6: 'zōng',  # 㯶
    0x3BF7: 'pú',  # 㯷
    0x3BF8: 'jǐn',  # 㯸
    0x3BF9: 'biǎo',  # 㯹
    0x3BFA: 'jiàn',  # 㯺
    0x3BFB: 'gǔn,hùn',  # 㯻
    # 0x3BFC: '',  # 㯼
    # 0x3BFD: '',  # 㯽
    # 0x3BFE: '',  # 㯾
    0x3BFF: 'liè',  # 㯿
    0x3C00: 'lí',  # 㰀
    0x3C01: 'luǒ',  # 㰁
    0x3C02: 'shěn,sǔn',  # 㰂
    0x3C03: 'mián',  # 㰃
    0x3C04: 'jiàn',  # 㰄
    0x3C05: 'dí',  # 㰅
    0x3C06: 'bèi',  # 㰆
    # 0x3C07: '',  # 㰇
    0x3C08: 'liǎn',  # 㰈
    # 0x3C09: '',  # 㰉
    0x3C0A: 'xún',  # 㰊
    0x3C0B: 'pín',  # 㰋
    0x3C0C: 'què',  # 㰌
    0x3C0D: 'lóng',  # 㰍
    0x3C0E: 'zuì',  # 㰎
    # 0x3C0F: '',  # 㰏
    0x3C10: 'jué,kuí,lěi,tuǐ,tuǒ',  # 㰐
    # 0x3C11: '',  # 㰑
    0x3C12: 'shé,xué',  # 㰒
    # 0x3C13: '',  # 㰓
    0x3C14: 'xiè',  # 㰔
    # 0x3C15: '',  # 㰕
    0x3C16: 'lǎn',  # 㰖
    0x3C17: 'cù',  # 㰗
    0x3C18: 'yí',  # 㰘
    0x3C19: 'nuó',  # 㰙
    0x3C1A: 'lí',  # 㰚
    0x3C1B: 'yuè',  # 㰛
    # 0x3C1C: '',  # 㰜
    0x3C1D: 'yǐ',  # 㰝
    # 0x3C1E: '',  # 㰞
    0x3C1F: 'jì,qì',  # 㰟
    0x3C20: 'kàng',  # 㰠
    0x3C21: 'xiè',  # 㰡
    # 0x3C22: '',  # 㰢
    0x3C23: 'zì',  # 㰣
    0x3C24: 'hē,qiè',  # 㰤
    0x3C25: 'huì',  # 㰥
    0x3C26: 'qù',  # 㰦
    # 0x3C27: '',  # 㰧
    # 0x3C28: '',  # 㰨
    # 0x3C29: '',  # 㰩
    0x3C2A: 'wá',  # 㰪
    # 0x3C2B: '',  # 㰫
    0x3C2C: 'xún',  # 㰬
    # 0x3C2D: '',  # 㰭
    0x3C2E: 'shèn',  # 㰮
    0x3C2F: 'tòu,tǒu,hòu',  # 㰯
    0x3C30: 'qiè',  # 㰰
    0x3C31: 'shà',  # 㰱
    0x3C32: 'xù,yù',  # 㰲
    0x3C33: 'yà',  # 㰳
    0x3C34: 'pó,pǒu',  # 㰴
    0x3C35: 'zú',  # 㰵
    0x3C36: 'yǒu',  # 㰶
    0x3C37: 'zì',  # 㰷
    0x3C38: 'liǎn,liàn,luǎn',  # 㰸
    0x3C39: 'jìn',  # 㰹
    0x3C3A: 'xiá,xià',  # 㰺
    0x3C3B: 'yǐ',  # 㰻
    0x3C3C: 'qiè',  # 㰼
    0x3C3D: 'mǐ,yàn',  # 㰽
    0x3C3E: 'jiào',  # 㰾
    # 0x3C3F: '',  # 㰿
    0x3C40: 'chǐ,chuài',  # 㱀
    0x3C41: 'shì',  # 㱁
    0x3C42: 'kāng',  # 㱂
    0x3C43: 'yǐn',  # 㱃
    0x3C44: 'mò',  # 㱄
    0x3C45: 'yì',  # 㱅
    # 0x3C46: '',  # 㱆
    0x3C47: 'sè,xì',  # 㱇
    0x3C48: 'jìn',  # 㱈
    0x3C49: 'yè',  # 㱉
    # 0x3C4A: '',  # 㱊
    0x3C4B: 'què',  # 㱋
    0x3C4C: 'chè,yǎn,yé',  # 㱌
    0x3C4D: 'luán',  # 㱍
    # 0x3C4E: '',  # 㱎
    0x3C4F: 'zhèng',  # 㱏
    # 0x3C50: '',  # 㱐
    # 0x3C51: '',  # 㱑
    # 0x3C52: '',  # 㱒
    # 0x3C53: '',  # 㱓
    0x3C54: 'xiē,suò',  # 㱔
    # 0x3C55: '',  # 㱕
    0x3C56: 'cuì',  # 㱖
    # 0x3C57: '',  # 㱗
    0x3C58: 'àn,yǎn',  # 㱘
    0x3C59: 'xiǔ',  # 㱙
    0x3C5A: 'cán,hài,shàn',  # 㱚
    0x3C5B: 'chuǎn',  # 㱛
    0x3C5C: 'zhá',  # 㱜
    # 0x3C5D: '',  # 㱝
    0x3C5E: 'jí',  # 㱞
    0x3C5F: 'bó,pí,pǐ',  # 㱟
    0x3C60: 'kū',  # 㱠
    # 0x3C61: '',  # 㱡
    0x3C62: 'láng',  # 㱢
    0x3C63: 'tuǐ',  # 㱣
    # 0x3C64: '',  # 㱤
    0x3C65: 'líng',  # 㱥
    0x3C66: 'è,guì,jǐ,qī',  # 㱦
    0x3C67: 'wò',  # 㱧
    0x3C68: 'liàn',  # 㱨
    0x3C69: 'dú',  # 㱩
    0x3C6A: 'mèn,hūn',  # 㱪
    0x3C6B: 'làn',  # 㱫
    0x3C6C: 'wěi',  # 㱬
    0x3C6D: 'duàn',  # 㱭
    0x3C6E: 'kuài,kuì',  # 㱮
    0x3C6F: 'ái',  # 㱯
    0x3C70: 'zǎi',  # 㱰
    0x3C71: 'huì,wù,xì',  # 㱱
    0x3C72: 'yì',  # 㱲
    0x3C73: 'mò',  # 㱳
    0x3C74: 'zì',  # 㱴
    0x3C75: 'bèn,fèn',  # 㱵
    0x3C76: 'bèng,jiào,péng,qiǎo,rù',  # 㱶
    # 0x3C77: '',  # 㱷
    0x3C78: 'bì,bié',  # 㱸
    0x3C79: 'lì,suàn,xiàn',  # 㱹
    0x3C7A: 'lú',  # 㱺
    0x3C7B: 'luǒ,luò',  # 㱻
    # 0x3C7C: '',  # 㱼
    0x3C7D: 'dàn,qín,zhěn',  # 㱽
    0x3C7E: 'gāi,kāi',  # 㱾
    0x3C7F: 'què',  # 㱿
    0x3C80: 'chén',  # 㲀
    # 0x3C81: '',  # 㲁
    0x3C82: 'chéng',  # 㲂
    0x3C83: 'jiù',  # 㲃
    0x3C84: 'kòu,kū',  # 㲄
    0x3C85: 'jì',  # 㲅
    0x3C86: 'líng',  # 㲆
    # 0x3C87: '',  # 㲇
    0x3C88: 'sháo',  # 㲈
    0x3C89: 'què',  # 㲉
    0x3C8A: 'ruì',  # 㲊
    0x3C8B: 'chuò,zhuó,zú',  # 㲋
    0x3C8C: 'nèng',  # 㲌
    # 0x3C8D: '',  # 㲍
    0x3C8E: 'lóu',  # 㲎
    0x3C8F: 'bǎo,piǎo,pín,pìng',  # 㲏
    # 0x3C90: '',  # 㲐
    # 0x3C91: '',  # 㲑
    0x3C92: 'bào',  # 㲒
    0x3C93: 'róng',  # 㲓
    # 0x3C94: '',  # 㲔
    0x3C95: 'lèi',  # 㲕
    # 0x3C96: '',  # 㲖
    # 0x3C97: '',  # 㲗
    0x3C98: 'qú',  # 㲘
    # 0x3C99: '',  # 㲙
    0x3C9A: 'shā',  # 㲚
    0x3C9B: 'zhǐ',  # 㲛
    0x3C9C: 'tán,tǎn',  # 㲜
    0x3C9D: 'rǒng',  # 㲝
    0x3C9E: 'zú',  # 㲞
    0x3C9F: 'yǐng',  # 㲟
    0x3CA0: 'máo',  # 㲠
    0x3CA1: 'nài,nì',  # 㲡
    0x3CA2: 'biàn,bié',  # 㲢
    # 0x3CA3: '',  # 㲣
    # 0x3CA4: '',  # 㲤
    0x3CA5: 'táng',  # 㲥
    0x3CA6: 'hàn,hě',  # 㲦
    0x3CA7: 'zào',  # 㲧
    0x3CA8: 'róng',  # 㲨
    # 0x3CA9: '',  # 㲩
    0x3CAA: 'dēng',  # 㲪
    0x3CAB: 'pú',  # 㲫
    # 0x3CAC: '',  # 㲬
    0x3CAD: 'tǎn',  # 㲭
    # 0x3CAE: '',  # 㲮
    0x3CAF: 'rán',  # 㲯
    0x3CB0: 'níng',  # 㲰
    0x3CB1: 'liè',  # 㲱
    0x3CB2: 'dié,yì',  # 㲲
    0x3CB3: 'dié',  # 㲳
    0x3CB4: 'zhòng,zhòu',  # 㲴
    # 0x3CB5: '',  # 㲵
    0x3CB6: 'lǜ',  # 㲶
    0x3CB7: 'dàn',  # 㲷
    # 0x3CB8: '',  # 㲸
    0x3CB9: 'guǐ,qiú',  # 㲹
    0x3CBA: 'jí,kè,léi',  # 㲺
    0x3CBB: 'nì',  # 㲻
    0x3CBC: 'yì',  # 㲼
    0x3CBD: 'niàn,rěn,xiàn',  # 㲽
    0x3CBE: 'yǔ,yù',  # 㲾
    0x3CBF: 'wǎng',  # 㲿
    0x3CC0: 'guò,kǎi,xì',  # 㳀
    0x3CC1: 'zè',  # 㳁
    0x3CC2: 'yán',  # 㳂
    0x3CC3: 'cuì',  # 㳃
    0x3CC4: 'xián',  # 㳄
    0x3CC5: 'jiǎo,liú',  # 㳅
    0x3CC6: 'shǔ,tǒu',  # 㳆
    0x3CC7: 'fù',  # 㳇
    0x3CC8: 'pèi',  # 㳈
    # 0x3CC9: '',  # 㳉
    # 0x3CCA: '',  # 㳊
    # 0x3CCB: '',  # 㳋
    # 0x3CCC: '',  # 㳌
    0x3CCD: 'bù',  # 㳍
    0x3CCE: 'biàn,fàn',  # 㳎
    0x3CCF: 'chǐ,shì',  # 㳏
    0x3CD0: 'sà,zhá,zhǎ',  # 㳐
    0x3CD1: 'yì',  # 㳑
    0x3CD2: 'fǎ',  # 㳒
    # 0x3CD3: '',  # 㳓
    0x3CD4: 'duì',  # 㳔
    0x3CD5: 'lán',  # 㳕
    # 0x3CD6: '',  # 㳖
    0x3CD7: 'chài',  # 㳗
    0x3CD8: 'chōng',  # 㳘
    0x3CD9: 'xuàn',  # 㳙
    0x3CDA: 'yù',  # 㳚
    0x3CDB: 'yú',  # 㳛
    # 0x3CDC: '',  # 㳜
    # 0x3CDD: '',  # 㳝
    # 0x3CDE: '',  # 㳞
    # 0x3CDF: '',  # 㳟
    0x3CE0: 'tà',  # 㳠
    # 0x3CE1: '',  # 㳡
    # 0x3CE2: '',  # 㳢
    # 0x3CE3: '',  # 㳣
    # 0x3CE4: '',  # 㳤
    0x3CE5: 'jù,lòng',  # 㳥
    0x3CE6: 'xiè',  # 㳦
    0x3CE7: 'xí',  # 㳧
    0x3CE8: 'jiǎn,zá,zǎn',  # 㳨
    # 0x3CE9: '',  # 㳩
    0x3CEA: 'pàn,pì',  # 㳪
    0x3CEB: 'tà',  # 㳫
    0x3CEC: 'xuán',  # 㳬
    0x3CED: 'xián',  # 㳭
    0x3CEE: 'niào',  # 㳮
    # 0x3CEF: '',  # 㳯
    # 0x3CF0: '',  # 㳰
    # 0x3CF1: '',  # 㳱
    # 0x3CF2: '',  # 㳲
    # 0x3CF3: '',  # 㳳
    0x3CF4: 'mì',  # 㳴
    0x3CF5: 'jì',  # 㳵
    0x3CF6: 'gòu,nǒu',  # 㳶
    0x3CF7: 'wěn,hū',  # 㳷
    # 0x3CF8: '',  # 㳸
    0x3CF9: 'wǎng',  # 㳹
    0x3CFA: 'yóu',  # 㳺
    0x3CFB: 'zé',  # 㳻
    0x3CFC: 'bì',  # 㳼
    0x3CFD: 'mǐ',  # 㳽
    # 0x3CFE: '',  # 㳾
    0x3CFF: 'xiè',  # 㳿
    0x3D00: 'fàn',  # 㴀
    0x3D01: 'yì',  # 㴁
    # 0x3D02: '',  # 㴂
    0x3D03: 'lèi,lì',  # 㴃
    0x3D04: 'yíng',  # 㴄
    # 0x3D05: '',  # 㴅
    0x3D06: 'jìn,xìng',  # 㴆
    0x3D07: 'shè',  # 㴇
    0x3D08: 'yìn',  # 㴈
    0x3D09: 'jǐ',  # 㴉
    # 0x3D0A: '',  # 㴊
    0x3D0B: 'sù',  # 㴋
    # 0x3D0C: '',  # 㴌
    # 0x3D0D: '',  # 㴍
    # 0x3D0E: '',  # 㴎
    0x3D0F: 'wǎng',  # 㴏
    0x3D10: 'miàn',  # 㴐
    0x3D11: 'sù',  # 㴑
    0x3D12: 'yì',  # 㴒
    0x3D13: 'zǎi',  # 㴓
    0x3D14: 'sè,yì',  # 㴔
    0x3D15: 'jí',  # 㴕
    0x3D16: 'luò',  # 㴖
    # 0x3D17: '',  # 㴗
    0x3D18: 'mào',  # 㴘
    0x3D19: 'zhá',  # 㴙
    0x3D1A: 'suì',  # 㴚
    0x3D1B: 'zhì',  # 㴛
    0x3D1C: 'biàn',  # 㴜
    0x3D1D: 'lí',  # 㴝
    0x3D1E: 'tāo',  # 㴞
    # 0x3D1F: '',  # 㴟
    # 0x3D20: '',  # 㴠
    # 0x3D21: '',  # 㴡
    # 0x3D22: '',  # 㴢
    # 0x3D23: '',  # 㴣
    # 0x3D24: '',  # 㴤
    0x3D25: 'qiào',  # 㴥
    0x3D26: 'guàn',  # 㴦
    # 0x3D27: '',  # 㴧
    0x3D28: 'zhèn',  # 㴨
    0x3D29: 'yōng',  # 㴩
    0x3D2A: 'niè',  # 㴪
    0x3D2B: 'jùn',  # 㴫
    0x3D2C: 'xiè',  # 㴬
    0x3D2D: 'yǎo',  # 㴭
    0x3D2E: 'xiè',  # 㴮
    # 0x3D2F: '',  # 㴯
    0x3D30: 'néng',  # 㴰
    # 0x3D31: '',  # 㴱
    0x3D32: 'sī',  # 㴲
    0x3D33: 'lǒng',  # 㴳
    0x3D34: 'chén',  # 㴴
    0x3D35: 'mì',  # 㴵
    0x3D36: 'què',  # 㴶
    0x3D37: 'dān',  # 㴷
    0x3D38: 'nà,shǎn,yè',  # 㴸
    # 0x3D39: '',  # 㴹
    # 0x3D3A: '',  # 㴺
    # 0x3D3B: '',  # 㴻
    0x3D3C: 'sù',  # 㴼
    0x3D3D: 'xiè,yìn',  # 㴽
    0x3D3E: 'bó',  # 㴾
    0x3D3F: 'dǐng',  # 㴿
    0x3D40: 'cuàn,zú',  # 㵀
    # 0x3D41: '',  # 㵁
    0x3D42: 'chuǎng,shù',  # 㵂
    0x3D43: 'shé',  # 㵃
    0x3D44: 'hàn,qià,yù',  # 㵄
    0x3D45: 'dàn,tàn',  # 㵅
    0x3D46: 'hào',  # 㵆
    # 0x3D47: '',  # 㵇
    # 0x3D48: '',  # 㵈
    # 0x3D49: '',  # 㵉
    0x3D4A: 'shěn,zhé',  # 㵊
    0x3D4B: 'mì',  # 㵋
    0x3D4C: 'chàn,qióng,xún',  # 㵌
    0x3D4D: 'mèn',  # 㵍
    0x3D4E: 'hǎn,jiàn,kǎn',  # 㵎
    0x3D4F: 'cuǐ',  # 㵏
    0x3D50: 'jué',  # 㵐
    0x3D51: 'hè',  # 㵑
    0x3D52: 'fèi',  # 㵒
    0x3D53: 'shí',  # 㵓
    0x3D54: 'chě,chè',  # 㵔
    0x3D55: 'shèn',  # 㵕
    # 0x3D56: '',  # 㵖
    0x3D57: 'fù,pán,píng',  # 㵗
    0x3D58: 'màn',  # 㵘
    # 0x3D59: '',  # 㵙
    # 0x3D5A: '',  # 㵚
    # 0x3D5B: '',  # 㵛
    # 0x3D5C: '',  # 㵜
    0x3D5D: 'yì',  # 㵝
    0x3D5E: 'chóu',  # 㵞
    # 0x3D5F: '',  # 㵟
    # 0x3D60: '',  # 㵠
    0x3D61: 'báo',  # 㵡
    0x3D62: 'léi,lěi',  # 㵢
    0x3D63: 'kě,luǒ',  # 㵣
    0x3D64: 'diàn,shà,xiá',  # 㵤
    0x3D65: 'bì,mì',  # 㵥
    0x3D66: 'suí',  # 㵦
    0x3D67: 'gé',  # 㵧
    0x3D68: 'bì,pì',  # 㵨
    0x3D69: 'yì',  # 㵩
    0x3D6A: 'xián',  # 㵪
    0x3D6B: 'nǐ,yì',  # 㵫
    0x3D6C: 'yíng',  # 㵬
    0x3D6D: 'zhǔ',  # 㵭
    0x3D6E: 'chún,wěn',  # 㵮
    0x3D6F: 'féng',  # 㵯
    0x3D70: 'xù',  # 㵰
    0x3D71: 'piǎo',  # 㵱
    0x3D72: 'wǔ',  # 㵲
    0x3D73: 'liáo,liú',  # 㵳
    0x3D74: 'cáng',  # 㵴
    0x3D75: 'zòu',  # 㵵
    # 0x3D76: '',  # 㵶
    0x3D77: 'biàn',  # 㵷
    0x3D78: 'yào,yuè',  # 㵸
    0x3D79: 'huán',  # 㵹
    0x3D7A: 'pái,pài',  # 㵺
    0x3D7B: 'sòu',  # 㵻
    0x3D7C: 'xiè',  # 㵼
    0x3D7D: 'duì,lěi',  # 㵽
    0x3D7E: 'jìng,qìng',  # 㵾
    0x3D7F: 'xí',  # 㵿
    # 0x3D80: '',  # 㶀
    0x3D81: 'guó',  # 㶁
    # 0x3D82: '',  # 㶂
    # 0x3D83: '',  # 㶃
    0x3D84: 'yán',  # 㶄
    0x3D85: 'xué',  # 㶅
    0x3D86: 'chú,zhū',  # 㶆
    0x3D87: 'héng',  # 㶇
    0x3D88: 'yíng,yìng',  # 㶈
    # 0x3D89: '',  # 㶉
    # 0x3D8A: '',  # 㶊
    # 0x3D8B: '',  # 㶋
    0x3D8C: 'lián',  # 㶌
    0x3D8D: 'xiǎn',  # 㶍
    0x3D8E: 'huán',  # 㶎
    # 0x3D8F: '',  # 㶏
    # 0x3D90: '',  # 㶐
    0x3D91: 'liàn',  # 㶑
    0x3D92: 'shǎn,shěn,tàn',  # 㶒
    0x3D93: 'cáng',  # 㶓
    0x3D94: 'bèi',  # 㶔
    0x3D95: 'jiǎn',  # 㶕
    0x3D96: 'shù',  # 㶖
    0x3D97: 'fàn',  # 㶗
    0x3D98: 'diàn',  # 㶘
    # 0x3D99: '',  # 㶙
    0x3D9A: 'bà',  # 㶚
    0x3D9B: 'yú',  # 㶛
    # 0x3D9C: '',  # 㶜
    # 0x3D9D: '',  # 㶝
    0x3D9E: 'nǎng',  # 㶞
    0x3D9F: 'lěi',  # 㶟
    0x3DA0: 'yì',  # 㶠
    0x3DA1: 'dài,huǒ,zuó',  # 㶡
    # 0x3DA2: '',  # 㶢
    0x3DA3: 'chán',  # 㶣
    0x3DA4: 'chǎo',  # 㶤
    # 0x3DA5: '',  # 㶥
    0x3DA6: 'jìn',  # 㶦
    0x3DA7: 'nèn',  # 㶧
    # 0x3DA8: '',  # 㶨
    # 0x3DA9: '',  # 㶩
    # 0x3DAA: '',  # 㶪
    0x3DAB: 'liǎo,liào',  # 㶫
    0x3DAC: 'méi,mò',  # 㶬
    0x3DAD: 'jiù,yǒu',  # 㶭
    # 0x3DAE: '',  # 㶮
    0x3DAF: 'liù',  # 㶯
    0x3DB0: 'hán',  # 㶰
    # 0x3DB1: '',  # 㶱
    0x3DB2: 'yòng',  # 㶲
    0x3DB3: 'jìn',  # 㶳
    0x3DB4: 'chǐ,shǐ',  # 㶴
    0x3DB5: 'rèn',  # 㶵
    0x3DB6: 'nóng',  # 㶶
    # 0x3DB7: '',  # 㶷
    # 0x3DB8: '',  # 㶸
    0x3DB9: 'hòng',  # 㶹
    0x3DBA: 'tiàn',  # 㶺
    # 0x3DBB: '',  # 㶻
    # 0x3DBC: '',  # 㶼
    # 0x3DBD: '',  # 㶽
    # 0x3DBE: '',  # 㶾
    0x3DBF: 'bó',  # 㶿
    0x3DC0: 'qióng',  # 㷀
    # 0x3DC1: '',  # 㷁
    0x3DC2: 'shù',  # 㷂
    0x3DC3: 'cuǐ',  # 㷃
    0x3DC4: 'huì',  # 㷄
    0x3DC5: 'chǎo,miǎo',  # 㷅
    0x3DC6: 'dòu,fù',  # 㷆
    0x3DC7: 'guài,kuí',  # 㷇
    0x3DC8: 'è',  # 㷈
    0x3DC9: 'wèi,yù,yùn',  # 㷉
    0x3DCA: 'fén',  # 㷊
    0x3DCB: 'tán,tǎn',  # 㷋
    # 0x3DCC: '',  # 㷌
    0x3DCD: 'lún',  # 㷍
    0x3DCE: 'hè,hóng,xié',  # 㷎
    0x3DCF: 'yǒng',  # 㷏
    0x3DD0: 'huǐ',  # 㷐
    # 0x3DD1: '',  # 㷑
    0x3DD2: 'yú',  # 㷒
    0x3DD3: 'zǒng',  # 㷓
    0x3DD4: 'yàn',  # 㷔
    0x3DD5: 'qiú',  # 㷕
    0x3DD6: 'zhào',  # 㷖
    0x3DD7: 'jiǒng',  # 㷗
    0x3DD8: 'tái',  # 㷘
    # 0x3DD9: '',  # 㷙
    # 0x3DDA: '',  # 㷚
    # 0x3DDB: '',  # 㷛
    # 0x3DDC: '',  # 㷜
    # 0x3DDD: '',  # 㷝
    # 0x3DDE: '',  # 㷞
    0x3DDF: 'tuì',  # 㷟
    0x3DE0: 'lín',  # 㷠
    0x3DE1: 'jiǒng',  # 㷡
    0x3DE2: 'zhǎ',  # 㷢
    # 0x3DE3: '',  # 㷣
    0x3DE4: 'hè,hù,xuè',  # 㷤
    # 0x3DE5: '',  # 㷥
    0x3DE6: 'xù',  # 㷦
    # 0x3DE7: '',  # 㷧
    # 0x3DE8: '',  # 㷨
    0x3DE9: 'xī',  # 㷩
    0x3DEA: 'cuì,zuǎn',  # 㷪
    0x3DEB: 'qǐng',  # 㷫
    0x3DEC: 'mò',  # 㷬
    0x3DED: 'fēng',  # 㷭
    0x3DEE: 'zāo',  # 㷮
    0x3DEF: 'bèng',  # 㷯
    0x3DF0: 'lí',  # 㷰
    # 0x3DF1: '',  # 㷱
    # 0x3DF2: '',  # 㷲
    0x3DF3: 'yàn',  # 㷳
    0x3DF4: 'gé,lì',  # 㷴
    0x3DF5: 'mò',  # 㷵
    0x3DF6: 'bèi,bì',  # 㷶
    0x3DF7: 'juǎn',  # 㷷
    0x3DF8: 'dié,yè',  # 㷸
    0x3DF9: 'shào',  # 㷹
    # 0x3DFA: '',  # 㷺
    0x3DFB: 'wú',  # 㷻
    0x3DFC: 'yàn',  # 㷼
    # 0x3DFD: '',  # 㷽
    0x3DFE: 'jué',  # 㷾
    # 0x3DFF: '',  # 㷿
    0x3E00: 'tái',  # 㸀
    0x3E01: 'hǎn,hàn',  # 㸁
    # 0x3E02: '',  # 㸂
    0x3E03: 'diǎn',  # 㸃
    0x3E04: 'jì,jié',  # 㸄
    0x3E05: 'jié',  # 㸅
    0x3E06: 'kào',  # 㸆
    # 0x3E07: '',  # 㸇
    # 0x3E08: '',  # 㸈
    0x3E09: 'xiè',  # 㸉
    0x3E0A: 'là,lài,liè',  # 㸊
    0x3E0B: 'fán',  # 㸋
    0x3E0C: 'huò',  # 㸌
    0x3E0D: 'xì',  # 㸍
    0x3E0E: 'niè',  # 㸎
    0x3E0F: 'mí',  # 㸏
    0x3E10: 'rán',  # 㸐
    0x3E11: 'cuàn',  # 㸑
    0x3E12: 'yín',  # 㸒
    0x3E13: 'mì',  # 㸓
    0x3E14: 'kàn',  # 㸔
    0x3E15: 'jué',  # 㸕
    # 0x3E16: '',  # 㸖
    0x3E17: 'tóng',  # 㸗
    0x3E18: 'wàn',  # 㸘
    # 0x3E19: '',  # 㸙
    0x3E1A: 'lǐ',  # 㸚
    0x3E1B: 'sháo,shuò',  # 㸛
    0x3E1C: 'kòng',  # 㸜
    0x3E1D: 'kǎn',  # 㸝
    0x3E1E: 'bǎn',  # 㸞
    # 0x3E1F: '',  # 㸟
    0x3E20: 'tiǎo',  # 㸠
    # 0x3E21: '',  # 㸡
    0x3E22: 'bèi',  # 㸢
    0x3E23: 'yè,yì',  # 㸣
    0x3E24: 'piàn',  # 㸤
    0x3E25: 'chán',  # 㸥
    0x3E26: 'hù',  # 㸦
    0x3E27: 'kèn,yín',  # 㸧
    # 0x3E28: '',  # 㸨
    0x3E29: 'àn',  # 㸩
    0x3E2A: 'chún',  # 㸪
    0x3E2B: 'qián',  # 㸫
    0x3E2C: 'bèi,fèi,pèi',  # 㸬
    # 0x3E2D: '',  # 㸭
    0x3E2E: 'fén',  # 㸮
    # 0x3E2F: '',  # 㸯
    0x3E30: 'tuó',  # 㸰
    0x3E31: 'tuó',  # 㸱
    0x3E32: 'zuó,zuò',  # 㸲
    0x3E33: 'líng',  # 㸳
    # 0x3E34: '',  # 㸴
    0x3E35: 'guǐ,wěi',  # 㸵
    # 0x3E36: '',  # 㸶
    0x3E37: 'shì',  # 㸷
    0x3E38: 'hǒu,ǒu,kǒu',  # 㸸
    0x3E39: 'liè',  # 㸹
    0x3E3A: 'shā',  # 㸺
    0x3E3B: 'sì',  # 㸻
    # 0x3E3C: '',  # 㸼
    0x3E3D: 'bèi',  # 㸽
    0x3E3E: 'rèn',  # 㸾
    0x3E3F: 'dú',  # 㸿
    0x3E40: 'bó',  # 㹀
    0x3E41: 'liáng',  # 㹁
    0x3E42: 'cì,qiǎn',  # 㹂
    0x3E43: 'bì,fèi',  # 㹃
    0x3E44: 'jì,qì',  # 㹄
    0x3E45: 'zǒng',  # 㹅
    # 0x3E46: '',  # 㹆
    0x3E47: 'hé',  # 㹇
    0x3E48: 'lí,máo',  # 㹈
    0x3E49: 'yuán',  # 㹉
    0x3E4A: 'yuè',  # 㹊
    # 0x3E4B: '',  # 㹋
    0x3E4C: 'chǎn,shèng',  # 㹌
    0x3E4D: 'dí,dú',  # 㹍
    0x3E4E: 'léi',  # 㹎
    0x3E4F: 'jǐn',  # 㹏
    0x3E50: 'chóng,zhòu',  # 㹐
    0x3E51: 'sì,yí',  # 㹑
    0x3E52: 'pǔ',  # 㹒
    0x3E53: 'yì',  # 㹓
    0x3E54: 'jiāng',  # 㹔
    # 0x3E55: '',  # 㹕
    0x3E56: 'huàn',  # 㹖
    0x3E57: 'táo,tāo',  # 㹗
    0x3E58: 'rú,rù,ruí',  # 㹘
    0x3E59: 'wěng',  # 㹙
    0x3E5A: 'wěng',  # 㹚
    0x3E5B: 'ráo,rǎo',  # 㹛
    0x3E5C: 'yín',  # 㹜
    0x3E5D: 'shì',  # 㹝
    0x3E5E: 'yín,yǐn',  # 㹞
    0x3E5F: 'jué',  # 㹟
    0x3E60: 'tún',  # 㹠
    0x3E61: 'xuán,xuàn',  # 㹡
    # 0x3E62: '',  # 㹢
    0x3E63: 'zhōng',  # 㹣
    0x3E64: 'qiè,què',  # 㹤
    0x3E65: 'zhù',  # 㹥
    # 0x3E66: '',  # 㹦
    # 0x3E67: '',  # 㹧
    0x3E68: 'yòu',  # 㹨
    # 0x3E69: '',  # 㹩
    # 0x3E6A: '',  # 㹪
    0x3E6B: 'xì,yí',  # 㹫
    0x3E6C: 'shǐ',  # 㹬
    0x3E6D: 'yì',  # 㹭
    0x3E6E: 'mò',  # 㹮
    # 0x3E6F: '',  # 㹯
    # 0x3E70: '',  # 㹰
    0x3E71: 'hú,què,rǎn',  # 㹱
    0x3E72: 'xiào',  # 㹲
    0x3E73: 'wú',  # 㹳
    # 0x3E74: '',  # 㹴
    0x3E75: 'jìng',  # 㹵
    0x3E76: 'tíng',  # 㹶
    0x3E77: 'shǐ,xìn',  # 㹷
    0x3E78: 'ní',  # 㹸
    # 0x3E79: '',  # 㹹
    0x3E7A: 'tà',  # 㹺
    # 0x3E7B: '',  # 㹻
    0x3E7C: 'chǔ,jú,yù',  # 㹼
    0x3E7D: 'chǎn,shàn',  # 㹽
    0x3E7E: 'piǎo',  # 㹾
    0x3E7F: 'diǎo,zhào,zhuó',  # 㹿
    0x3E80: 'náo',  # 㺀
    0x3E81: 'nǎo',  # 㺁
    0x3E82: 'gǎn,jiàn,yán',  # 㺂
    0x3E83: 'gǒu',  # 㺃
    0x3E84: 'yǔ',  # 㺄
    0x3E85: 'hóu',  # 㺅
    # 0x3E86: '',  # 㺆
    0x3E87: 'sī',  # 㺇
    0x3E88: 'chī',  # 㺈
    0x3E89: 'hù',  # 㺉
    0x3E8A: 'yàng',  # 㺊
    # 0x3E8B: '',  # 㺋
    0x3E8C: 'xiàn',  # 㺌
    # 0x3E8D: '',  # 㺍
    0x3E8E: 'róng',  # 㺎
    0x3E8F: 'lóu',  # 㺏
    0x3E90: 'zhǎo',  # 㺐
    0x3E91: 'cán,shǎn',  # 㺑
    0x3E92: 'liào,yáo,xiāo',  # 㺒
    0x3E93: 'piào',  # 㺓
    0x3E94: 'hài,wèi',  # 㺔
    0x3E95: 'fán',  # 㺕
    0x3E96: 'hǎn',  # 㺖
    0x3E97: 'dàn,yán',  # 㺗
    0x3E98: 'zhàn',  # 㺘
    # 0x3E99: '',  # 㺙
    0x3E9A: 'tǎ',  # 㺚
    0x3E9B: 'zhù',  # 㺛
    0x3E9C: 'nóng',  # 㺜
    0x3E9D: 'jiàn',  # 㺝
    0x3E9E: 'yú',  # 㺞
    0x3E9F: 'zhuó',  # 㺟
    0x3EA0: 'yòu,yù',  # 㺠
    0x3EA1: 'lì',  # 㺡
    # 0x3EA2: '',  # 㺢
    0x3EA3: 'xī',  # 㺣
    # 0x3EA4: '',  # 㺤
    0x3EA5: 'chán,tán',  # 㺥
    0x3EA6: 'lián',  # 㺦
    # 0x3EA7: '',  # 㺧
    0x3EA8: 'sī',  # 㺨
    0x3EA9: 'jiù,sè',  # 㺩
    0x3EAA: 'pú',  # 㺪
    0x3EAB: 'qiú',  # 㺫
    0x3EAC: 'gǒng',  # 㺬
    0x3EAD: 'zǐ',  # 㺭
    0x3EAE: 'yú',  # 㺮
    # 0x3EAF: '',  # 㺯
    # 0x3EB0: '',  # 㺰
    0x3EB1: 'réng',  # 㺱
    0x3EB2: 'niǔ',  # 㺲
    0x3EB3: 'méi',  # 㺳
    # 0x3EB4: '',  # 㺴
    0x3EB5: 'jiú',  # 㺵
    # 0x3EB6: '',  # 㺶
    0x3EB7: 'xù',  # 㺷
    0x3EB8: 'píng',  # 㺸
    0x3EB9: 'biàn',  # 㺹
    0x3EBA: 'mào',  # 㺺
    # 0x3EBB: '',  # 㺻
    # 0x3EBC: '',  # 㺼
    # 0x3EBD: '',  # 㺽
    # 0x3EBE: '',  # 㺾
    0x3EBF: 'yí',  # 㺿
    0x3EC0: 'yóu,yú',  # 㻀
    # 0x3EC1: '',  # 㻁
    0x3EC2: 'píng',  # 㻂
    0x3EC3: 'qū',  # 㻃
    0x3EC4: 'bǎo',  # 㻄
    0x3EC5: 'huì,kuài',  # 㻅
    # 0x3EC6: '',  # 㻆
    # 0x3EC7: '',  # 㻇
    # 0x3EC8: '',  # 㻈
    0x3EC9: 'bù',  # 㻉
    0x3ECA: 'máng,mén,mèng',  # 㻊
    0x3ECB: 'là,lèi',  # 㻋
    0x3ECC: 'tú',  # 㻌
    0x3ECD: 'wú',  # 㻍
    0x3ECE: 'lì,sè',  # 㻎
    0x3ECF: 'líng,lǐng',  # 㻏
    # 0x3ED0: '',  # 㻐
    0x3ED1: 'jì',  # 㻑
    0x3ED2: 'jùn',  # 㻒
    # 0x3ED3: '',  # 㻓
    0x3ED4: 'duǒ,ruì',  # 㻔
    0x3ED5: 'jué',  # 㻕
    0x3ED6: 'dài',  # 㻖
    0x3ED7: 'bèi',  # 㻗
    # 0x3ED8: '',  # 㻘
    # 0x3ED9: '',  # 㻙
    # 0x3EDA: '',  # 㻚
    # 0x3EDB: '',  # 㻛
    # 0x3EDC: '',  # 㻜
    0x3EDD: 'là',  # 㻝
    0x3EDE: 'biàn,fèn,pìn',  # 㻞
    0x3EDF: 'suí',  # 㻟
    0x3EE0: 'tú',  # 㻠
    0x3EE1: 'dié,jué',  # 㻡
    # 0x3EE2: '',  # 㻢
    # 0x3EE3: '',  # 㻣
    # 0x3EE4: '',  # 㻤
    # 0x3EE5: '',  # 㻥
    # 0x3EE6: '',  # 㻦
    0x3EE7: 'duò,hé',  # 㻧
    # 0x3EE8: '',  # 㻨
    # 0x3EE9: '',  # 㻩
    0x3EEA: 'suì',  # 㻪
    0x3EEB: 'bì',  # 㻫
    0x3EEC: 'tú',  # 㻬
    0x3EED: 'sè,zé',  # 㻭
    0x3EEE: 'càn',  # 㻮
    0x3EEF: 'tú',  # 㻯
    0x3EF0: 'miǎn,rè,wèi,yù',  # 㻰
    # 0x3EF1: '',  # 㻱
    # 0x3EF2: '',  # 㻲
    # 0x3EF3: '',  # 㻳
    # 0x3EF4: '',  # 㻴
    0x3EF5: 'zhàn',  # 㻵
    0x3EF6: 'bǐ,bì',  # 㻶
    0x3EF7: 'jí',  # 㻷
    0x3EF8: 'cén,jìn,xín,zēn',  # 㻸
    # 0x3EF9: '',  # 㻹
    0x3EFA: 'lì,liè',  # 㻺
    # 0x3EFB: '',  # 㻻
    # 0x3EFC: '',  # 㻼
    0x3EFD: 'suì',  # 㻽
    # 0x3EFE: '',  # 㻾
    0x3EFF: 'shǔ',  # 㻿
    # 0x3F00: '',  # 㼀
    # 0x3F01: '',  # 㼁
    0x3F02: 'é,wèn,yuǎn',  # 㼂
    # 0x3F03: '',  # 㼃
    # 0x3F04: '',  # 㼄
    # 0x3F05: '',  # 㼅
    0x3F06: 'yíng',  # 㼆
    0x3F07: 'qióng',  # 㼇
    0x3F08: 'luó',  # 㼈
    0x3F09: 'yìn,zhèn',  # 㼉
    0x3F0A: 'tún',  # 㼊
    0x3F0B: 'gǔ,jiǔ,móu,rǔ',  # 㼋
    0x3F0C: 'yǔ',  # 㼌
    0x3F0D: 'lěi',  # 㼍
    0x3F0E: 'bèi,bó,kě',  # 㼎
    0x3F0F: 'něi',  # 㼏
    0x3F10: 'pián',  # 㼐
    0x3F11: 'liàn,luán',  # 㼑
    0x3F12: 'qiǔ,tǎng',  # 㼒
    0x3F13: 'lián,liǎn',  # 㼓
    # 0x3F14: '',  # 㼔
    # 0x3F15: '',  # 㼕
    0x3F16: 'lì',  # 㼖
    0x3F17: 'dǐng,tíng',  # 㼗
    0x3F18: 'wǎ',  # 㼘
    0x3F19: 'zhòu',  # 㼙
    # 0x3F1A: '',  # 㼚
    0x3F1B: 'xíng',  # 㼛
    0x3F1C: 'àng,póu',  # 㼜
    0x3F1D: 'fàn,wǎn',  # 㼝
    0x3F1E: 'pèng',  # 㼞
    0x3F1F: 'bái',  # 㼟
    0x3F20: 'tuó',  # 㼠
    # 0x3F21: '',  # 㼡
    0x3F22: 'ě,yí',  # 㼢
    0x3F23: 'bǎi,bó',  # 㼣
    0x3F24: 'qì,qiè,yà',  # 㼤
    0x3F25: 'chú,kǎo,tǒu',  # 㼥
    0x3F26: 'gǒng',  # 㼦
    0x3F27: 'tóng',  # 㼧
    0x3F28: 'hán',  # 㼨
    0x3F29: 'chéng',  # 㼩
    0x3F2A: 'jiá',  # 㼪
    0x3F2B: 'huàn',  # 㼫
    0x3F2C: 'xìng',  # 㼬
    0x3F2D: 'diàn,niǎo',  # 㼭
    0x3F2E: 'chāi,qì',  # 㼮
    0x3F2F: 'dòng',  # 㼯
    0x3F30: 'é,pí',  # 㼰
    0x3F31: 'ruǎn',  # 㼱
    0x3F32: 'liè',  # 㼲
    0x3F33: 'shěng',  # 㼳
    0x3F34: 'ǒu',  # 㼴
    0x3F35: 'dì',  # 㼵
    0x3F36: 'yú',  # 㼶
    0x3F37: 'chuán',  # 㼷
    0x3F38: 'róng',  # 㼸
    # 0x3F39: '',  # 㼹
    0x3F3A: 'táng',  # 㼺
    0x3F3B: 'cóng',  # 㼻
    0x3F3C: 'piáo',  # 㼼
    0x3F3D: 'shuǎng,chuǎng',  # 㼽
    0x3F3E: 'lù',  # 㼾
    0x3F3F: 'tóng',  # 㼿
    0x3F40: 'zhèng',  # 㽀
    0x3F41: 'lì',  # 㽁
    0x3F42: 'sà',  # 㽂
    # 0x3F43: '',  # 㽃
    # 0x3F44: '',  # 㽄
    # 0x3F45: '',  # 㽅
    # 0x3F46: '',  # 㽆
    0x3F47: 'guài,hú,huí,méng,sè',  # 㽇
    0x3F48: 'yì',  # 㽈
    0x3F49: 'hǎn,jiàn,xiàn',  # 㽉
    0x3F4A: 'xiè',  # 㽊
    0x3F4B: 'luó,luò',  # 㽋
    0x3F4C: 'liù',  # 㽌
    # 0x3F4D: '',  # 㽍
    0x3F4E: 'dǎn,tán',  # 㽎
    0x3F4F: 'gàn',  # 㽏
    # 0x3F50: '',  # 㽐
    0x3F51: 'tán',  # 㽑
    # 0x3F52: '',  # 㽒
    # 0x3F53: '',  # 㽓
    # 0x3F54: '',  # 㽔
    0x3F55: 'yóu',  # 㽕
    0x3F56: 'nán',  # 㽖
    # 0x3F57: '',  # 㽗
    0x3F58: 'gǎng',  # 㽘
    0x3F59: 'jùn',  # 㽙
    0x3F5A: 'chì',  # 㽚
    0x3F5B: 'gōu,qú',  # 㽛
    0x3F5C: 'wǎn',  # 㽜
    0x3F5D: 'lì',  # 㽝
    0x3F5E: 'liú',  # 㽞
    0x3F5F: 'liè',  # 㽟
    0x3F60: 'xiá',  # 㽠
    0x3F61: 'bēi',  # 㽡
    0x3F62: 'ǎn,yè',  # 㽢
    0x3F63: 'yù',  # 㽣
    0x3F64: 'jú',  # 㽤
    0x3F65: 'róu',  # 㽥
    0x3F66: 'xún',  # 㽦
    # 0x3F67: '',  # 㽧
    0x3F68: 'cuó',  # 㽨
    0x3F69: 'càn,cào',  # 㽩
    0x3F6A: 'zěng,zhǎ',  # 㽪
    0x3F6B: 'yǒng',  # 㽫
    0x3F6C: 'fù',  # 㽬
    0x3F6D: 'ruǎn',  # 㽭
    # 0x3F6E: '',  # 㽮
    0x3F6F: 'xí',  # 㽯
    0x3F70: 'shù',  # 㽰
    0x3F71: 'jiǎo,jiū,niú',  # 㽱
    0x3F72: 'jiǎo',  # 㽲
    0x3F73: 'hàn,xiè,xǔ,yú',  # 㽳
    0x3F74: 'zhàng',  # 㽴
    # 0x3F75: '',  # 㽵
    # 0x3F76: '',  # 㽶
    0x3F77: 'shuì',  # 㽷
    0x3F78: 'chén',  # 㽸
    0x3F79: 'fàn,wǎn',  # 㽹
    0x3F7A: 'jí',  # 㽺
    # 0x3F7B: '',  # 㽻
    # 0x3F7C: '',  # 㽼
    0x3F7D: 'gù',  # 㽽
    0x3F7E: 'wù',  # 㽾
    # 0x3F7F: '',  # 㽿
    0x3F80: 'qiè',  # 㾀
    0x3F81: 'shù',  # 㾁
    # 0x3F82: '',  # 㾂
    0x3F83: 'tuó',  # 㾃
    0x3F84: 'dú',  # 㾄
    0x3F85: 'zǐ',  # 㾅
    0x3F86: 'rán,shǎn',  # 㾆
    0x3F87: 'mù',  # 㾇
    0x3F88: 'fù',  # 㾈
    0x3F89: 'líng',  # 㾉
    0x3F8A: 'jí',  # 㾊
    0x3F8B: 'xiù',  # 㾋
    0x3F8C: 'xuǎn',  # 㾌
    0x3F8D: 'nái',  # 㾍
    # 0x3F8E: '',  # 㾎
    0x3F8F: 'jiè',  # 㾏
    0x3F90: 'lì',  # 㾐
    0x3F91: 'dá',  # 㾑
    0x3F92: 'jì,rú,rù',  # 㾒
    0x3F93: 'yùn',  # 㾓
    # 0x3F94: '',  # 㾔
    0x3F95: 'shěn',  # 㾕
    0x3F96: 'lǐ,luó',  # 㾖
    0x3F97: 'lǎng,liàng',  # 㾗
    0x3F98: 'gěng',  # 㾘
    0x3F99: 'yǐn',  # 㾙
    # 0x3F9A: '',  # 㾚
    0x3F9B: 'qǐn',  # 㾛
    0x3F9C: 'qiè',  # 㾜
    0x3F9D: 'chè',  # 㾝
    0x3F9E: 'yǒu',  # 㾞
    0x3F9F: 'bù',  # 㾟
    0x3FA0: 'huáng,kuáng,kuì',  # 㾠
    0x3FA1: 'què',  # 㾡
    0x3FA2: 'lài',  # 㾢
    # 0x3FA3: '',  # 㾣
    # 0x3FA4: '',  # 㾤
    0x3FA5: 'xù',  # 㾥
    0x3FA6: 'bàng,pèi,pén',  # 㾦
    0x3FA7: 'kè',  # 㾧
    0x3FA8: 'qǐ,yǐ',  # 㾨
    # 0x3FA9: '',  # 㾩
    0x3FAA: 'shěng',  # 㾪
    0x3FAB: 'piān',  # 㾫
    # 0x3FAC: '',  # 㾬
    0x3FAD: 'zhòu',  # 㾭
    0x3FAE: 'huáng',  # 㾮
    0x3FAF: 'tuí,wěi',  # 㾯
    0x3FB0: 'hú',  # 㾰
    0x3FB1: 'bèi,fàn,fèi,fú',  # 㾱
    # 0x3FB2: '',  # 㾲
    # 0x3FB3: '',  # 㾳
    # 0x3FB4: '',  # 㾴
    0x3FB5: 'jì',  # 㾵
    0x3FB6: 'gǔ',  # 㾶
    # 0x3FB7: '',  # 㾷
    0x3FB8: 'gǎo',  # 㾸
    0x3FB9: 'chái',  # 㾹
    0x3FBA: 'mà,mò',  # 㾺
    0x3FBB: 'zhù',  # 㾻
    0x3FBC: 'tuǐ',  # 㾼
    0x3FBD: 'tuí,zhuì',  # 㾽
    0x3FBE: 'lián',  # 㾾
    0x3FBF: 'láng,lǎng',  # 㾿
    # 0x3FC0: '',  # 㿀
    # 0x3FC1: '',  # 㿁
    # 0x3FC2: '',  # 㿂
    0x3FC3: 'dài,zhì',  # 㿃
    0x3FC4: 'ài',  # 㿄
    0x3FC5: 'xiǎn,xuǎn',  # 㿅
    # 0x3FC6: '',  # 㿆
    0x3FC7: 'xí,xì',  # 㿇
    # 0x3FC8: '',  # 㿈
    0x3FC9: 'tuí',  # 㿉
    0x3FCA: 'cǎn',  # 㿊
    0x3FCB: 'sào',  # 㿋
    # 0x3FCC: '',  # 㿌
    0x3FCD: 'jiè',  # 㿍
    0x3FCE: 'fèn',  # 㿎
    0x3FCF: 'qún',  # 㿏
    # 0x3FD0: '',  # 㿐
    0x3FD1: 'yào',  # 㿑
    0x3FD2: 'dǎo',  # 㿒
    0x3FD3: 'jiá',  # 㿓
    0x3FD4: 'lěi',  # 㿔
    0x3FD5: 'yán',  # 㿕
    0x3FD6: 'lú',  # 㿖
    0x3FD7: 'tuí',  # 㿗
    0x3FD8: 'yíng',  # 㿘
    0x3FD9: 'pì',  # 㿙
    0x3FDA: 'luò',  # 㿚
    0x3FDB: 'lí,lì',  # 㿛
    0x3FDC: 'biě',  # 㿜
    # 0x3FDD: '',  # 㿝
    0x3FDE: 'mào',  # 㿞
    0x3FDF: 'bái,jiǎo',  # 㿟
    0x3FE0: 'huàng',  # 㿠
    # 0x3FE1: '',  # 㿡
    0x3FE2: 'yào,zhuì',  # 㿢
    0x3FE3: 'hé,xiá',  # 㿣
    0x3FE4: 'chǔn',  # 㿤
    0x3FE5: 'hú,hé',  # 㿥
    0x3FE6: 'nìng',  # 㿦
    0x3FE7: 'chóu',  # 㿧
    0x3FE8: 'lì',  # 㿨
    0x3FE9: 'tǎng',  # 㿩
    0x3FEA: 'huán',  # 㿪
    0x3FEB: 'bì',  # 㿫
    # 0x3FEC: '',  # 㿬
    0x3FED: 'chè',  # 㿭
    0x3FEE: 'yàng',  # 㿮
    0x3FEF: 'dá',  # 㿯
    0x3FF0: 'áo',  # 㿰
    0x3FF1: 'xué',  # 㿱
    # 0x3FF2: '',  # 㿲
    # 0x3FF3: '',  # 㿳
    # 0x3FF4: '',  # 㿴
    0x3FF5: 'rǎn',  # 㿵
    # 0x3FF6: '',  # 㿶
    0x3FF7: 'cuó,cāo',  # 㿷
    0x3FF8: 'wǎn,mán',  # 㿸
    0x3FF9: 'tà',  # 㿹
    0x3FFA: 'báo',  # 㿺
    # 0x3FFB: '',  # 㿻
    0x3FFC: 'yán',  # 㿼
    # 0x3FFD: '',  # 㿽
    0x3FFE: 'zhù',  # 㿾
    0x3FFF: 'yǎ',  # 㿿
    0x4000: 'fán',  # 䀀
    0x4001: 'yòu',  # 䀁
    # 0x4002: '',  # 䀂
    0x4003: 'tuí',  # 䀃
    0x4004: 'méng',  # 䀄
    0x4005: 'shè,zhé',  # 䀅
    0x4006: 'jìn',  # 䀆
    0x4007: 'gǔ,què',  # 䀇
    0x4008: 'qì',  # 䀈
    0x4009: 'qiáo,shà',  # 䀉
    0x400A: 'jiǎo',  # 䀊
    0x400B: 'yán',  # 䀋
    # 0x400C: '',  # 䀌
    0x400D: 'kàn',  # 䀍
    0x400E: 'miǎn',  # 䀎
    0x400F: 'xiàn,xuàn',  # 䀏
    0x4010: 'sǎn',  # 䀐
    0x4011: 'nà,nì,wò',  # 䀑
    # 0x4012: '',  # 䀒
    0x4013: 'huàn',  # 䀓
    0x4014: 'niú,rèn',  # 䀔
    0x4015: 'chèng,zhèn',  # 䀕
    # 0x4016: '',  # 䀖
    0x4017: 'jué',  # 䀗
    0x4018: 'xí,xié',  # 䀘
    0x4019: 'qì',  # 䀙
    0x401A: 'áng',  # 䀚
    0x401B: 'mèi,wù',  # 䀛
    0x401C: 'gǔ,mèi,xué',  # 䀜
    # 0x401D: '',  # 䀝
    # 0x401E: '',  # 䀞
    0x401F: 'fán,fèi,fèn',  # 䀟
    0x4020: 'qú,jù',  # 䀠
    0x4021: 'chàn,tàn',  # 䀡
    0x4022: 'shùn',  # 䀢
    0x4023: 'bì,mà',  # 䀣
    0x4024: 'mào',  # 䀤
    0x4025: 'shuò',  # 䀥
    0x4026: 'gǔ',  # 䀦
    0x4027: 'hǒng',  # 䀧
    0x4028: 'huàn',  # 䀨
    0x4029: 'luò',  # 䀩
    0x402A: 'háng',  # 䀪
    0x402B: 'jiá',  # 䀫
    0x402C: 'quán',  # 䀬
    0x402D: 'gāi',  # 䀭
    0x402E: 'máng',  # 䀮
    0x402F: 'bǔ',  # 䀯
    0x4030: 'gǔ,yíng',  # 䀰
    # 0x4031: '',  # 䀱
    0x4032: 'mù',  # 䀲
    0x4033: 'ài,là,lài',  # 䀳
    0x4034: 'yǐng',  # 䀴
    0x4035: 'shùn',  # 䀵
    0x4036: 'lǎng,liàng',  # 䀶
    0x4037: 'jié',  # 䀷
    0x4038: 'dì,zhì',  # 䀸
    0x4039: 'jiá,shè,jié',  # 䀹
    0x403A: 'chōu',  # 䀺
    0x403B: 'pìn',  # 䀻
    0x403C: 'rèn,zhěn',  # 䀼
    0x403D: 'yán',  # 䀽
    0x403E: 'dǔ',  # 䀾
    0x403F: 'dì',  # 䀿
    # 0x4040: '',  # 䁀
    0x4041: 'lǎng,liàng',  # 䁁
    0x4042: 'xiàn',  # 䁂
    # 0x4043: '',  # 䁃
    0x4044: 'xìng',  # 䁄
    0x4045: 'bèi,bì,měng,mèng',  # 䁅
    0x4046: 'ǎn,yì',  # 䁆
    0x4047: 'mì',  # 䁇
    0x4048: 'qì',  # 䁈
    0x4049: 'qì',  # 䁉
    0x404A: 'wò',  # 䁊
    0x404B: 'shé',  # 䁋
    0x404C: 'yù',  # 䁌
    0x404D: 'jià,kè,qià',  # 䁍
    0x404E: 'chéng',  # 䁎
    0x404F: 'yǎo',  # 䁏
    0x4050: 'yìng',  # 䁐
    0x4051: 'yáng',  # 䁑
    0x4052: 'jí',  # 䁒
    0x4053: 'jiè,zǒng',  # 䁓
    0x4054: 'hàn,huǎn,xuān',  # 䁔
    0x4055: 'mín',  # 䁕
    0x4056: 'lōu',  # 䁖
    0x4057: 'kǎi',  # 䁗
    0x4058: 'yǎo',  # 䁘
    0x4059: 'yǎn,yàn',  # 䁙
    0x405A: 'sǔn',  # 䁚
    0x405B: 'guǐ,guì,kuì',  # 䁛
    0x405C: 'huǎng,huàng',  # 䁜
    0x405D: 'yíng',  # 䁝
    0x405E: 'shěng',  # 䁞
    0x405F: 'chá,duó',  # 䁟
    0x4060: 'lián',  # 䁠
    # 0x4061: '',  # 䁡
    0x4062: 'xuán',  # 䁢
    0x4063: 'chuán',  # 䁣
    0x4064: 'chè,chèng',  # 䁤
    0x4065: 'nì',  # 䁥
    0x4066: 'qù',  # 䁦
    0x4067: 'miáo',  # 䁧
    0x4068: 'huò',  # 䁨
    0x4069: 'yú',  # 䁩
    0x406A: 'nǎn,zhǎn',  # 䁪
    0x406B: 'hú',  # 䁫
    0x406C: 'céng',  # 䁬
    # 0x406D: '',  # 䁭
    0x406E: 'qián',  # 䁮
    0x406F: 'shè,xié',  # 䁯
    0x4070: 'jiǎng',  # 䁰
    0x4071: 'ào',  # 䁱
    0x4072: 'mái',  # 䁲
    0x4073: 'mǎng',  # 䁳
    0x4074: 'zhǎn',  # 䁴
    0x4075: 'biǎn',  # 䁵
    0x4076: 'jiǎo',  # 䁶
    0x4077: 'jué,wò',  # 䁷
    0x4078: 'nóng',  # 䁸
    0x4079: 'bì',  # 䁹
    0x407A: 'shì',  # 䁺
    0x407B: 'lì,shuò',  # 䁻
    0x407C: 'mò,mù',  # 䁼
    0x407D: 'liè',  # 䁽
    0x407E: 'miè',  # 䁾
    0x407F: 'mò',  # 䁿
    # 0x4080: '',  # 䂀
    0x4081: 'chán',  # 䂁
    0x4082: 'qú',  # 䂂
    0x4083: 'jiào,jié',  # 䂃
    0x4084: 'huò,kuàng',  # 䂄
    # 0x4085: '',  # 䂅
    0x4086: 'xù',  # 䂆
    0x4087: 'náng,niǔ,nǒng,páng',  # 䂇
    0x4088: 'tóng',  # 䂈
    0x4089: 'hóu',  # 䂉
    0x408A: 'yù',  # 䂊
    # 0x408B: '',  # 䂋
    # 0x408C: '',  # 䂌
    0x408D: 'bó',  # 䂍
    0x408E: 'zuǎn',  # 䂎
    # 0x408F: '',  # 䂏
    0x4090: 'chuò',  # 䂐
    # 0x4091: '',  # 䂑
    0x4092: 'jié,qià,yà',  # 䂒
    # 0x4093: '',  # 䂓
    0x4094: 'xìng',  # 䂔
    0x4095: 'huì',  # 䂕
    0x4096: 'shí,sì',  # 䂖
    # 0x4097: '',  # 䂗
    # 0x4098: '',  # 䂘
    # 0x4099: '',  # 䂙
    0x409A: 'yáo,yóu',  # 䂚
    0x409B: 'yú',  # 䂛
    0x409C: 'bàng,péi',  # 䂜
    0x409D: 'jié,zé,zhé',  # 䂝
    0x409E: 'zhè',  # 䂞
    # 0x409F: '',  # 䂟
    0x40A0: 'shé,shǐ',  # 䂠
    0x40A1: 'dǐ,zhǐ',  # 䂡
    0x40A2: 'dǒng',  # 䂢
    0x40A3: 'cí',  # 䂣
    0x40A4: 'fù,hái',  # 䂤
    0x40A5: 'mín',  # 䂥
    0x40A6: 'zhěn',  # 䂦
    0x40A7: 'zhěn',  # 䂧
    # 0x40A8: '',  # 䂨
    0x40A9: 'yàn',  # 䂩
    0x40AA: 'diào,tiǎo',  # 䂪
    0x40AB: 'hóng',  # 䂫
    0x40AC: 'gǒng',  # 䂬
    0x40AD: 'qiāo',  # 䂭
    # 0x40AE: '',  # 䂮
    0x40AF: 'guài,guàn',  # 䂯
    0x40B0: 'là',  # 䂰
    0x40B1: 'cuì,ruì',  # 䂱
    0x40B2: 'fǎ',  # 䂲
    0x40B3: 'cuǒ',  # 䂳
    0x40B4: 'yán',  # 䂴
    # 0x40B5: '',  # 䂵
    0x40B6: 'jié',  # 䂶
    # 0x40B7: '',  # 䂷
    0x40B8: 'guó,xù',  # 䂸
    0x40B9: 'suǒ',  # 䂹
    0x40BA: 'wǎn,wǒ',  # 䂺
    0x40BB: 'zhèng',  # 䂻
    0x40BC: 'niè',  # 䂼
    0x40BD: 'diào,yì',  # 䂽
    0x40BE: 'lǎi',  # 䂾
    0x40BF: 'tà,tiè',  # 䂿
    0x40C0: 'cuì,xùn',  # 䃀
    0x40C1: 'yā',  # 䃁
    0x40C2: 'gǔn,gùn',  # 䃂
    # 0x40C3: '',  # 䃃
    # 0x40C4: '',  # 䃄
    # 0x40C5: '',  # 䃅
    # 0x40C6: '',  # 䃆
    0x40C7: 'mián',  # 䃇
    0x40C8: 'jiē',  # 䃈
    0x40C9: 'mín',  # 䃉
    0x40CA: 'jǔ',  # 䃊
    0x40CB: 'yú',  # 䃋
    # 0x40CC: '',  # 䃌
    0x40CD: 'zhào,zhuì',  # 䃍
    0x40CE: 'zhǎ',  # 䃎
    # 0x40CF: '',  # 䃏
    # 0x40D0: '',  # 䃐
    0x40D1: 'pán',  # 䃑
    0x40D2: 'hé',  # 䃒
    0x40D3: 'gòu',  # 䃓
    0x40D4: 'hóng',  # 䃔
    0x40D5: 'láo,luò',  # 䃕
    0x40D6: 'wù',  # 䃖
    0x40D7: 'chuò',  # 䃗
    # 0x40D8: '',  # 䃘
    0x40D9: 'lù',  # 䃙
    0x40DA: 'cù',  # 䃚
    0x40DB: 'lián,qiàn',  # 䃛
    # 0x40DC: '',  # 䃜
    0x40DD: 'qiào',  # 䃝
    0x40DE: 'shú,yì',  # 䃞
    # 0x40DF: '',  # 䃟
    # 0x40E0: '',  # 䃠
    0x40E1: 'cén',  # 䃡
    # 0x40E2: '',  # 䃢
    0x40E3: 'huǐ',  # 䃣
    0x40E4: 'sù',  # 䃤
    0x40E5: 'chuáng',  # 䃥
    # 0x40E6: '',  # 䃦
    0x40E7: 'lóng',  # 䃧
    # 0x40E8: '',  # 䃨
    0x40E9: 'náo',  # 䃩
    0x40EA: 'tán',  # 䃪
    0x40EB: 'dǎn',  # 䃫
    0x40EC: 'wěi',  # 䃬
    0x40ED: 'gǎn',  # 䃭
    0x40EE: 'dá',  # 䃮
    0x40EF: 'lì',  # 䃯
    # 0x40F0: '',  # 䃰
    0x40F1: 'xiàn',  # 䃱
    0x40F2: 'pán,pàn',  # 䃲
    0x40F3: 'là',  # 䃳
    # 0x40F4: '',  # 䃴
    0x40F5: 'niǎo',  # 䃵
    0x40F6: 'huái',  # 䃶
    0x40F7: 'yíng',  # 䃷
    0x40F8: 'xiàn',  # 䃸
    0x40F9: 'làn,lǎng',  # 䃹
    0x40FA: 'mó,mò',  # 䃺
    0x40FB: 'bà,pái',  # 䃻
    # 0x40FC: '',  # 䃼
    0x40FD: 'fú,guǐ,sì',  # 䃽
    0x40FE: 'bǐ',  # 䃾
    # 0x40FF: '',  # 䃿
    0x4100: 'huò',  # 䄀
    0x4101: 'yì',  # 䄁
    0x4102: 'liù',  # 䄂
    # 0x4103: '',  # 䄃
    # 0x4104: '',  # 䄄
    0x4105: 'juàn',  # 䄅
    0x4106: 'huó,kuò',  # 䄆
    0x4107: 'chéng',  # 䄇
    0x4108: 'dòu',  # 䄈
    0x4109: 'é',  # 䄉
    # 0x410A: '',  # 䄊
    0x410B: 'yǎn',  # 䄋
    0x410C: 'zhuì',  # 䄌
    0x410D: 'dù,duó,zhà',  # 䄍
    0x410E: 'qǐ',  # 䄎
    0x410F: 'yú,yāo',  # 䄏
    0x4110: 'quàn',  # 䄐
    0x4111: 'huó,kuò',  # 䄑
    0x4112: 'niè,rěn',  # 䄒
    0x4113: 'héng,huáng',  # 䄓
    0x4114: 'jǔ',  # 䄔
    0x4115: 'shè,shèn,tiǎn',  # 䄕
    # 0x4116: '',  # 䄖
    # 0x4117: '',  # 䄗
    0x4118: 'péng',  # 䄘
    0x4119: 'míng',  # 䄙
    0x411A: 'cáo',  # 䄚
    0x411B: 'lóu',  # 䄛
    0x411C: 'lí,chī ',  # 䄜
    0x411D: 'chǔn',  # 䄝
    # 0x411E: '',  # 䄞
    0x411F: 'cuì',  # 䄟
    0x4120: 'shàn',  # 䄠
    # 0x4121: '',  # 䄡
    0x4122: 'qí',  # 䄢
    # 0x4123: '',  # 䄣
    0x4124: 'lài,lán',  # 䄤
    0x4125: 'líng',  # 䄥
    0x4126: 'liǎo',  # 䄦
    0x4127: 'réng,rǒng',  # 䄧
    0x4128: 'yú,yǔ',  # 䄨
    0x4129: 'náo,yì',  # 䄩
    0x412A: 'chuò,diǎo',  # 䄪
    0x412B: 'qǐ',  # 䄫
    0x412C: 'yí',  # 䄬
    0x412D: 'nián',  # 䄭
    # 0x412E: '',  # 䄮
    0x412F: 'jiǎn,xiàn',  # 䄯
    0x4130: 'yá,zhá',  # 䄰
    # 0x4131: '',  # 䄱
    0x4132: 'chuí',  # 䄲
    # 0x4133: '',  # 䄳
    # 0x4134: '',  # 䄴
    # 0x4135: '',  # 䄵
    0x4136: 'bì',  # 䄶
    0x4137: 'dàn,diǎo,shí',  # 䄷
    0x4138: 'pò',  # 䄸
    0x4139: 'nián,tiǎn',  # 䄹
    0x413A: 'zhì',  # 䄺
    0x413B: 'cháo,táo,zhào',  # 䄻
    0x413C: 'tiǎn',  # 䄼
    0x413D: 'tiǎn',  # 䄽
    0x413E: 'ròu',  # 䄾
    0x413F: 'yì',  # 䄿
    0x4140: 'liè',  # 䅀
    0x4141: 'àn',  # 䅁
    0x4142: 'hé',  # 䅂
    0x4143: 'qióng',  # 䅃
    0x4144: 'lì',  # 䅄
    # 0x4145: '',  # 䅅
    0x4146: 'zì',  # 䅆
    0x4147: 'sù',  # 䅇
    0x4148: 'yuàn',  # 䅈
    0x4149: 'yà',  # 䅉
    0x414A: 'dù',  # 䅊
    0x414B: 'wǎn',  # 䅋
    0x414C: 'juān',  # 䅌
    0x414D: 'dòng,tǐng',  # 䅍
    0x414E: 'yǒu',  # 䅎
    0x414F: 'huì,wèi',  # 䅏
    0x4150: 'jiǎn,qián',  # 䅐
    0x4151: 'ruí,suí',  # 䅑
    0x4152: 'máng',  # 䅒
    0x4153: 'jǔ,qù',  # 䅓
    # 0x4154: '',  # 䅔
    # 0x4155: '',  # 䅕
    0x4156: 'ǎn',  # 䅖
    0x4157: 'suì',  # 䅗
    0x4158: 'lái',  # 䅘
    0x4159: 'hùn',  # 䅙
    0x415A: 'qiǎng,quǎn,zé',  # 䅚
    # 0x415B: '',  # 䅛
    0x415C: 'duò',  # 䅜
    # 0x415D: '',  # 䅝
    0x415E: 'nà,nài,nè',  # 䅞
    0x415F: 'cǎn',  # 䅟
    0x4160: 'tí',  # 䅠
    0x4161: 'xǔ',  # 䅡
    0x4162: 'jiù',  # 䅢
    0x4163: 'huáng',  # 䅣
    0x4164: 'qì',  # 䅤
    0x4165: 'jié',  # 䅥
    0x4166: 'máo',  # 䅦
    0x4167: 'yàn',  # 䅧
    # 0x4168: '',  # 䅨
    0x4169: 'zhǐ',  # 䅩
    0x416A: 'tuí',  # 䅪
    # 0x416B: '',  # 䅫
    0x416C: 'ài,yǎn,yè',  # 䅬
    0x416D: 'páng',  # 䅭
    0x416E: 'càng',  # 䅮
    0x416F: 'táng',  # 䅯
    0x4170: 'ěn',  # 䅰
    0x4171: 'hùn',  # 䅱
    0x4172: 'qí',  # 䅲
    0x4173: 'chú',  # 䅳
    0x4174: 'suǒ',  # 䅴
    0x4175: 'zhuó',  # 䅵
    0x4176: 'nòu,wǔ',  # 䅶
    0x4177: 'tú',  # 䅷
    0x4178: 'zú',  # 䅸
    0x4179: 'lóu,lǒu',  # 䅹
    0x417A: 'miǎo',  # 䅺
    0x417B: 'lí',  # 䅻
    0x417C: 'mán',  # 䅼
    0x417D: 'gǔ',  # 䅽
    0x417E: 'cén,qián,qín',  # 䅾
    0x417F: 'huá',  # 䅿
    0x4180: 'měi',  # 䆀
    # 0x4181: '',  # 䆁
    0x4182: 'lián,qiàn',  # 䆂
    0x4183: 'dǎo,dào',  # 䆃
    0x4184: 'shàn',  # 䆄
    0x4185: 'cí,jǐ,zī',  # 䆅
    # 0x4186: '',  # 䆆
    # 0x4187: '',  # 䆇
    0x4188: 'zhì',  # 䆈
    0x4189: 'bà',  # 䆉
    0x418A: 'cuì',  # 䆊
    # 0x418B: '',  # 䆋
    # 0x418C: '',  # 䆌
    0x418D: 'lóng',  # 䆍
    # 0x418E: '',  # 䆎
    0x418F: 'fèi',  # 䆏
    0x4190: 'guó',  # 䆐
    0x4191: 'chéng',  # 䆑
    0x4192: 'jiù',  # 䆒
    0x4193: 'è,ruǎn',  # 䆓
    # 0x4194: '',  # 䆔
    0x4195: 'jué,yuè',  # 䆕
    0x4196: 'hóng',  # 䆖
    0x4197: 'jiào',  # 䆗
    0x4198: 'cuán,yā',  # 䆘
    0x4199: 'yáo',  # 䆙
    0x419A: 'tóng',  # 䆚
    0x419B: 'chá,zhà,zhé',  # 䆛
    0x419C: 'yòu',  # 䆜
    0x419D: 'shù',  # 䆝
    0x419E: 'yǎo',  # 䆞
    0x419F: 'gé',  # 䆟
    0x41A0: 'huàn',  # 䆠
    0x41A1: 'láng,làng',  # 䆡
    0x41A2: 'jué,yuè',  # 䆢
    0x41A3: 'chén',  # 䆣
    # 0x41A4: '',  # 䆤
    # 0x41A5: '',  # 䆥
    0x41A6: 'shèn',  # 䆦
    # 0x41A7: '',  # 䆧
    0x41A8: 'míng',  # 䆨
    0x41A9: 'míng',  # 䆩
    # 0x41AA: '',  # 䆪
    # 0x41AB: '',  # 䆫
    0x41AC: 'yǔn',  # 䆬
    # 0x41AD: '',  # 䆭
    0x41AE: 'jìn',  # 䆮
    0x41AF: 'chuò,zhuó',  # 䆯
    # 0x41B0: '',  # 䆰
    0x41B1: 'tǎn',  # 䆱
    # 0x41B2: '',  # 䆲
    0x41B3: 'qióng,suì',  # 䆳
    # 0x41B4: '',  # 䆴
    0x41B5: 'chéng',  # 䆵
    # 0x41B6: '',  # 䆶
    0x41B7: 'yù,xuè',  # 䆷
    0x41B8: 'chéng',  # 䆸
    0x41B9: 'tǒng',  # 䆹
    # 0x41BA: '',  # 䆺
    0x41BB: 'qiào',  # 䆻
    # 0x41BC: '',  # 䆼
    0x41BD: 'jù,qú,qún',  # 䆽
    0x41BE: 'lán',  # 䆾
    0x41BF: 'yì',  # 䆿
    0x41C0: 'róng,rǒng',  # 䇀
    0x41C1: 'sī',  # 䇁
    0x41C2: 'qiān',  # 䇂
    0x41C3: 'sì,xiào',  # 䇃
    # 0x41C4: '',  # 䇄
    0x41C5: 'fá',  # 䇅
    # 0x41C6: '',  # 䇆
    0x41C7: 'méng',  # 䇇
    0x41C8: 'guì,huà',  # 䇈
    # 0x41C9: '',  # 䇉
    # 0x41CA: '',  # 䇊
    0x41CB: 'hài,rǎn,xiè',  # 䇋
    0x41CC: 'qiào',  # 䇌
    0x41CD: 'chuò',  # 䇍
    0x41CE: 'què',  # 䇎
    0x41CF: 'duì',  # 䇏
    0x41D0: 'lì',  # 䇐
    0x41D1: 'bà',  # 䇑
    0x41D2: 'jiè,qín,xiàn',  # 䇒
    # 0x41D3: '',  # 䇓
    0x41D4: 'luò,nuò',  # 䇔
    # 0x41D5: '',  # 䇕
    0x41D6: 'yǔn',  # 䇖
    # 0x41D7: '',  # 䇗
    0x41D8: 'hù',  # 䇘
    0x41D9: 'yǐn',  # 䇙
    # 0x41DA: '',  # 䇚
    0x41DB: 'zhǐ',  # 䇛
    0x41DC: 'liǎn',  # 䇜
    # 0x41DD: '',  # 䇝
    0x41DE: 'gǎn',  # 䇞
    0x41DF: 'jiàn',  # 䇟
    0x41E0: 'zhòu,zhù',  # 䇠
    0x41E1: 'zhù',  # 䇡
    0x41E2: 'kǔ',  # 䇢
    0x41E3: 'nà,nèi,yǐ',  # 䇣
    0x41E4: 'duì,ruì,sù',  # 䇤
    0x41E5: 'zé,zuó',  # 䇥
    0x41E6: 'yǎng',  # 䇦
    0x41E7: 'zhù',  # 䇧
    0x41E8: 'gòng,xiáng',  # 䇨
    0x41E9: 'yì',  # 䇩
    0x41EA: 'chī',  # 䇪
    0x41EB: 'jī',  # 䇫
    0x41EC: 'chuǎng,zhū',  # 䇬
    0x41ED: 'lǎo',  # 䇭
    0x41EE: 'rèn',  # 䇮
    0x41EF: 'róng',  # 䇯
    # 0x41F0: '',  # 䇰
    0x41F1: 'nà',  # 䇱
    0x41F2: 'cè,jiā',  # 䇲
    # 0x41F3: '',  # 䇳
    # 0x41F4: '',  # 䇴
    0x41F5: 'yí',  # 䇵
    0x41F6: 'jué',  # 䇶
    0x41F7: 'bǐ,bié',  # 䇷
    0x41F8: 'chéng,shèng,zèng',  # 䇸
    0x41F9: 'jùn',  # 䇹
    0x41FA: 'chóu,dòu',  # 䇺
    0x41FB: 'huì,kuì,wěi',  # 䇻
    0x41FC: 'chì,yì',  # 䇼
    0x41FD: 'zhì',  # 䇽
    0x41FE: 'yán',  # 䇾
    # 0x41FF: '',  # 䇿
    # 0x4200: '',  # 䈀
    0x4201: 'lún,luò',  # 䈁
    0x4202: 'bìng,píng',  # 䈂
    0x4203: 'zhǎo',  # 䈃
    0x4204: 'hán',  # 䈄
    0x4205: 'yù',  # 䈅
    0x4206: 'dài',  # 䈆
    0x4207: 'zhào',  # 䈇
    0x4208: 'féi',  # 䈈
    0x4209: 'shà',  # 䈉
    0x420A: 'líng',  # 䈊
    0x420B: 'tà',  # 䈋
    # 0x420C: '',  # 䈌
    0x420D: 'máng',  # 䈍
    0x420E: 'yè',  # 䈎
    0x420F: 'báo',  # 䈏
    0x4210: 'kuì',  # 䈐
    0x4211: 'guǎ,jué',  # 䈑
    0x4212: 'nǎn',  # 䈒
    0x4213: 'gé',  # 䈓
    # 0x4214: '',  # 䈔
    0x4215: 'chí,shi,tí,shí',  # 䈕
    # 0x4216: '',  # 䈖
    0x4217: 'suǒ',  # 䈗
    0x4218: 'cí',  # 䈘
    0x4219: 'zhòu',  # 䈙
    0x421A: 'tái',  # 䈚
    0x421B: 'kuài',  # 䈛
    0x421C: 'qìn',  # 䈜
    # 0x421D: '',  # 䈝
    0x421E: 'dǔ',  # 䈞
    0x421F: 'cè',  # 䈟
    0x4220: 'huǎn',  # 䈠
    # 0x4221: '',  # 䈡
    0x4222: 'sǎi',  # 䈢
    0x4223: 'zhèng',  # 䈣
    0x4224: 'qián',  # 䈤
    # 0x4225: '',  # 䈥
    # 0x4226: '',  # 䈦
    0x4227: 'wěi',  # 䈧
    # 0x4228: '',  # 䈨
    # 0x4229: '',  # 䈩
    0x422A: 'xì',  # 䈪
    0x422B: 'nà',  # 䈫
    0x422C: 'pú',  # 䈬
    0x422D: 'huái',  # 䈭
    0x422E: 'jǔ,jù,wǎn',  # 䈮
    # 0x422F: '',  # 䈯
    0x4230: 'shāo',  # 䈰
    # 0x4231: '',  # 䈱
    0x4232: 'pán',  # 䈲
    0x4233: 'tà',  # 䈳
    0x4234: 'qiàn,zhǎn',  # 䈴
    0x4235: 'wēng',  # 䈵
    0x4236: 'róng',  # 䈶
    0x4237: 'luò',  # 䈷
    0x4238: 'hú',  # 䈸
    0x4239: 'sǒu',  # 䈹
    # 0x423A: '',  # 䈺
    0x423B: 'pú',  # 䈻
    0x423C: 'miè,mì',  # 䈼
    # 0x423D: '',  # 䈽
    0x423E: 'shāo,shuò',  # 䈾
    0x423F: 'mài,mì',  # 䈿
    0x4240: 'shù',  # 䉀
    0x4241: 'líng',  # 䉁
    0x4242: 'lěi',  # 䉂
    0x4243: 'jiǎng',  # 䉃
    0x4244: 'léng',  # 䉄
    0x4245: 'zhì',  # 䉅
    0x4246: 'diǎo',  # 䉆
    # 0x4247: '',  # 䉇
    0x4248: 'sǎn',  # 䉈
    0x4249: 'hú',  # 䉉
    0x424A: 'fàn,fáng',  # 䉊
    0x424B: 'mèi',  # 䉋
    0x424C: 'suì',  # 䉌
    0x424D: 'jiǎn',  # 䉍
    0x424E: 'táng',  # 䉎
    0x424F: 'xiè',  # 䉏
    # 0x4250: '',  # 䉐
    0x4251: 'mó,wú',  # 䉑
    0x4252: 'fán',  # 䉒
    0x4253: 'léi,luò',  # 䉓
    # 0x4254: '',  # 䉔
    0x4255: 'céng',  # 䉕
    0x4256: 'líng',  # 䉖
    # 0x4257: '',  # 䉗
    0x4258: 'cóng',  # 䉘
    0x4259: 'yún',  # 䉙
    0x425A: 'méng',  # 䉚
    0x425B: 'yù',  # 䉛
    0x425C: 'zhì',  # 䉜
    0x425D: 'qǐ',  # 䉝
    0x425E: 'dǎn',  # 䉞
    0x425F: 'huò',  # 䉟
    0x4260: 'wéi',  # 䉠
    0x4261: 'tán',  # 䉡
    0x4262: 'sè',  # 䉢
    0x4263: 'xiè',  # 䉣
    0x4264: 'sǒu',  # 䉤
    0x4265: 'sǒng',  # 䉥
    # 0x4266: '',  # 䉦
    0x4267: 'liú,liǔ',  # 䉧
    0x4268: 'yì',  # 䉨
    # 0x4269: '',  # 䉩
    0x426A: 'lèi',  # 䉪
    0x426B: 'lí',  # 䉫
    0x426C: 'fèi',  # 䉬
    0x426D: 'liè',  # 䉭
    0x426E: 'lìn',  # 䉮
    0x426F: 'xiàn',  # 䉯
    0x4270: 'yáo',  # 䉰
    # 0x4271: '',  # 䉱
    0x4272: 'biè,mí',  # 䉲
    0x4273: 'xiǎn',  # 䉳
    0x4274: 'ráng,rǎng',  # 䉴
    0x4275: 'zhuàn',  # 䉵
    # 0x4276: '',  # 䉶
    0x4277: 'dàn,jìn,yán',  # 䉷
    0x4278: 'biàn',  # 䉸
    0x4279: 'líng,liǔ',  # 䉹
    0x427A: 'hóng',  # 䉺
    0x427B: 'qí',  # 䉻
    0x427C: 'liào',  # 䉼
    0x427D: 'bǎn',  # 䉽
    0x427E: 'mì,bì',  # 䉾
    0x427F: 'hú,luò',  # 䉿
    0x4280: 'hú',  # 䊀
    # 0x4281: '',  # 䊁
    0x4282: 'cè,sè',  # 䊂
    0x4283: 'pèi',  # 䊃
    0x4284: 'qióng',  # 䊄
    0x4285: 'míng',  # 䊅
    0x4286: 'jiù,qiǔ',  # 䊆
    0x4287: 'bù',  # 䊇
    0x4288: 'méi',  # 䊈
    0x4289: 'sǎn',  # 䊉
    0x428A: 'mèi',  # 䊊
    # 0x428B: '',  # 䊋
    # 0x428C: '',  # 䊌
    0x428D: 'lí',  # 䊍
    0x428E: 'quǎn',  # 䊎
    # 0x428F: '',  # 䊏
    0x4290: 'èn,huá,huàn,hún',  # 䊐
    0x4291: 'xiǎng',  # 䊑
    # 0x4292: '',  # 䊒
    0x4293: 'shì',  # 䊓
    # 0x4294: '',  # 䊔
    # 0x4295: '',  # 䊕
    0x4296: 'lǎn,nǎn',  # 䊖
    0x4297: 'huáng,huǎng',  # 䊗
    0x4298: 'jiù',  # 䊘
    0x4299: 'yán',  # 䊙
    0x429A: 'duī',  # 䊚
    0x429B: 'sǎ',  # 䊛
    0x429C: 'tuán',  # 䊜
    0x429D: 'xiè',  # 䊝
    0x429E: 'zhé',  # 䊞
    0x429F: 'mén',  # 䊟
    0x42A0: 'xì',  # 䊠
    0x42A1: 'mán',  # 䊡
    # 0x42A2: '',  # 䊢
    0x42A3: 'huáng',  # 䊣
    0x42A4: 'tán',  # 䊤
    0x42A5: 'xiào',  # 䊥
    0x42A6: 'yá,yè',  # 䊦
    0x42A7: 'bì',  # 䊧
    0x42A8: 'luó',  # 䊨
    0x42A9: 'fán,fàn',  # 䊩
    0x42AA: 'lì',  # 䊪
    0x42AB: 'cuǐ,mí',  # 䊫
    0x42AC: 'chà',  # 䊬
    0x42AD: 'chóu,dào',  # 䊭
    0x42AE: 'dí,zhé,zhè',  # 䊮
    0x42AF: 'kuàng',  # 䊯
    0x42B0: 'chǔ',  # 䊰
    # 0x42B1: '',  # 䊱
    0x42B2: 'chǎn',  # 䊲
    0x42B3: 'mí',  # 䊳
    0x42B4: 'qiàn',  # 䊴
    0x42B5: 'qiú',  # 䊵
    0x42B6: 'zhèn',  # 䊶
    # 0x42B7: '',  # 䊷
    # 0x42B8: '',  # 䊸
    # 0x42B9: '',  # 䊹
    0x42BA: 'gǔ,hù',  # 䊺
    0x42BB: 'yǎn',  # 䊻
    0x42BC: 'chǐ',  # 䊼
    0x42BD: 'guài',  # 䊽
    0x42BE: 'mù',  # 䊾
    0x42BF: 'bó,kù',  # 䊿
    0x42C0: 'kuà,huà',  # 䋀
    0x42C1: 'gěng',  # 䋁
    0x42C2: 'yáo',  # 䋂
    0x42C3: 'mào',  # 䋃
    0x42C4: 'wǎng',  # 䋄
    # 0x42C5: '',  # 䋅
    # 0x42C6: '',  # 䋆
    # 0x42C7: '',  # 䋇
    0x42C8: 'rú',  # 䋈
    0x42C9: 'jué,kě,xué',  # 䋉
    0x42CA: 'zhēng',  # 䋊
    0x42CB: 'mín',  # 䋋
    0x42CC: 'jiǎng',  # 䋌
    # 0x42CD: '',  # 䋍
    0x42CE: 'zhàn',  # 䋎
    0x42CF: 'zuò',  # 䋏
    0x42D0: 'yuè',  # 䋐
    0x42D1: 'bǐng',  # 䋑
    # 0x42D2: '',  # 䋒
    0x42D3: 'zhòu',  # 䋓
    0x42D4: 'bì',  # 䋔
    0x42D5: 'rèn',  # 䋕
    0x42D6: 'yù',  # 䋖
    # 0x42D7: '',  # 䋗
    0x42D8: 'chuò,zhuì',  # 䋘
    0x42D9: 'ěr',  # 䋙
    0x42DA: 'yì',  # 䋚
    0x42DB: 'mí,mǐ',  # 䋛
    0x42DC: 'qìng',  # 䋜
    # 0x42DD: '',  # 䋝
    0x42DE: 'wǎng',  # 䋞
    0x42DF: 'jì',  # 䋟
    0x42E0: 'bǔ',  # 䋠
    # 0x42E1: '',  # 䋡
    0x42E2: 'biè,biē',  # 䋢
    0x42E3: 'fán,pán',  # 䋣
    0x42E4: 'yào,yuè',  # 䋤
    0x42E5: 'lí',  # 䋥
    0x42E6: 'fán',  # 䋦
    0x42E7: 'qú',  # 䋧
    0x42E8: 'fǔ',  # 䋨
    0x42E9: 'ér',  # 䋩
    # 0x42EA: '',  # 䋪
    0x42EB: 'zhēng',  # 䋫
    # 0x42EC: '',  # 䋬
    0x42ED: 'huò,yù',  # 䋭
    0x42EE: 'jìn,qián',  # 䋮
    0x42EF: 'qǐ,qìng',  # 䋯
    0x42F0: 'jú',  # 䋰
    0x42F1: 'lái',  # 䋱
    0x42F2: 'chě,shéng,xǐng,zhè',  # 䋲
    0x42F3: 'bèi,mì',  # 䋳
    0x42F4: 'niù,rǒng,róu,rǔ',  # 䋴
    0x42F5: 'yì',  # 䋵
    0x42F6: 'xù',  # 䋶
    0x42F7: 'liú,móu',  # 䋷
    0x42F8: 'xún',  # 䋸
    0x42F9: 'fú,fù',  # 䋹
    # 0x42FA: '',  # 䋺
    0x42FB: 'nín',  # 䋻
    0x42FC: 'tǐng,yíng,tīng',  # 䋼
    0x42FD: 'běng,pěng',  # 䋽
    0x42FE: 'zhǎ',  # 䋾
    # 0x42FF: '',  # 䋿
    # 0x4300: '',  # 䌀
    # 0x4301: '',  # 䌁
    0x4302: 'òu',  # 䌂
    0x4303: 'shuò',  # 䌃
    0x4304: 'gěng',  # 䌄
    0x4305: 'táng',  # 䌅
    0x4306: 'guì',  # 䌆
    0x4307: 'suǒ',  # 䌇
    0x4308: 'tà',  # 䌈
    # 0x4309: '',  # 䌉
    0x430A: 'yáo,yóu',  # 䌊
    # 0x430B: '',  # 䌋
    0x430C: 'qì,qiè,qǔ',  # 䌌
    0x430D: 'hàn,jǐn',  # 䌍
    # 0x430E: '',  # 䌎
    0x430F: 'mì,miàn',  # 䌏
    0x4310: 'mì',  # 䌐
    # 0x4311: '',  # 䌑
    0x4312: 'lù',  # 䌒
    0x4313: 'fán',  # 䌓
    0x4314: 'òu',  # 䌔
    0x4315: 'mí,mó',  # 䌕
    0x4316: 'jié',  # 䌖
    0x4317: 'fǔ',  # 䌗
    0x4318: 'mí',  # 䌘
    0x4319: 'huǎng',  # 䌙
    0x431A: 'sù',  # 䌚
    0x431B: 'yáo',  # 䌛
    0x431C: 'niè',  # 䌜
    0x431D: 'jìn',  # 䌝
    0x431E: 'liǎn',  # 䌞
    0x431F: 'bì',  # 䌟
    0x4320: 'qìng,yǎn,yìn',  # 䌠
    0x4321: 'tǐ',  # 䌡
    0x4322: 'líng',  # 䌢
    0x4323: 'zuǎn',  # 䌣
    0x4324: 'zhǐ',  # 䌤
    0x4325: 'yǐn',  # 䌥
    0x4326: 'dǎo',  # 䌦
    0x4327: 'chóu',  # 䌧
    0x4328: 'cài',  # 䌨
    0x4329: 'mì,miè',  # 䌩
    0x432A: 'yán',  # 䌪
    0x432B: 'lǎn',  # 䌫
    0x432C: 'chóng',  # 䌬
    # 0x432D: '',  # 䌭
    # 0x432E: '',  # 䌮
    0x432F: 'guàn,quán',  # 䌯
    0x4330: 'shè',  # 䌰
    0x4331: 'luò',  # 䌱
    # 0x4332: '',  # 䌲
    0x4333: 'shī',  # 䌳
    0x4334: 'luò',  # 䌴
    0x4335: 'zhú,zhǔ',  # 䌵
    # 0x4336: '',  # 䌶
    0x4337: 'chōu,chóu',  # 䌷
    0x4338: 'juàn',  # 䌸
    0x4339: 'jiǒng',  # 䌹
    0x433A: 'ěr',  # 䌺
    0x433B: 'yì',  # 䌻
    0x433C: 'ruì',  # 䌼
    0x433D: 'cǎi',  # 䌽
    0x433E: 'rén',  # 䌾
    0x433F: 'fú',  # 䌿
    0x4340: 'lán',  # 䍀
    0x4341: 'suì',  # 䍁
    0x4342: 'yú',  # 䍂
    0x4343: 'yáo,yóu',  # 䍃
    0x4344: 'diǎn',  # 䍄
    0x4345: 'líng',  # 䍅
    0x4346: 'zhù',  # 䍆
    0x4347: 'tà',  # 䍇
    0x4348: 'píng',  # 䍈
    0x4349: 'qián,zhǎi',  # 䍉
    0x434A: 'jué',  # 䍊
    0x434B: 'chuí',  # 䍋
    0x434C: 'bù,fú',  # 䍌
    0x434D: 'gǔ,gù,guàng,kòu',  # 䍍
    0x434E: 'cùn',  # 䍎
    # 0x434F: '',  # 䍏
    0x4350: 'hǎn,hàn',  # 䍐
    0x4351: 'hǎn',  # 䍑
    0x4352: 'mǒu',  # 䍒
    0x4353: 'hù,yá',  # 䍓
    0x4354: 'hóng',  # 䍔
    0x4355: 'dǐ',  # 䍕
    0x4356: 'fú,fù,hài,xiè',  # 䍖
    0x4357: 'xuàn',  # 䍗
    0x4358: 'mí',  # 䍘
    0x4359: 'méi',  # 䍙
    0x435A: 'làng',  # 䍚
    0x435B: 'gù',  # 䍛
    0x435C: 'zhào',  # 䍜
    0x435D: 'tà,zǎn',  # 䍝
    0x435E: 'yù',  # 䍞
    0x435F: 'zòng',  # 䍟
    0x4360: 'lí',  # 䍠
    0x4361: 'liào,lù',  # 䍡
    0x4362: 'wú,wǔ',  # 䍢
    0x4363: 'léi',  # 䍣
    0x4364: 'jǐ',  # 䍤
    0x4365: 'lèi,lì',  # 䍥
    0x4366: 'lí',  # 䍦
    # 0x4367: '',  # 䍧
    0x4368: 'bó,fèi',  # 䍨
    0x4369: 'ǎng,yǎng',  # 䍩
    0x436A: 'kuì,wà',  # 䍪
    0x436B: 'tuó',  # 䍫
    # 0x436C: '',  # 䍬
    # 0x436D: '',  # 䍭
    0x436E: 'zhào',  # 䍮
    0x436F: 'guǐ,jì',  # 䍯
    # 0x4370: '',  # 䍰
    0x4371: 'xú',  # 䍱
    0x4372: 'nái,ní,nì',  # 䍲
    0x4373: 'chuò,jué,què',  # 䍳
    0x4374: 'duò,ruí,wěi,wèi',  # 䍴
    # 0x4375: '',  # 䍵
    0x4376: 'dòng',  # 䍶
    0x4377: 'guì,huì,wěi',  # 䍷
    0x4378: 'bó',  # 䍸
    # 0x4379: '',  # 䍹
    0x437A: 'huán',  # 䍺
    0x437B: 'xuǎn',  # 䍻
    0x437C: 'cán',  # 䍼
    0x437D: 'lì',  # 䍽
    0x437E: 'tuí,yǎn',  # 䍾
    0x437F: 'huáng',  # 䍿
    0x4380: 'xuè,yuè',  # 䎀
    0x4381: 'hú',  # 䎁
    0x4382: 'bǎo',  # 䎂
    0x4383: 'rǎn',  # 䎃
    0x4384: 'tiáo',  # 䎄
    0x4385: 'fù,luò,pò',  # 䎅
    0x4386: 'liào',  # 䎆
    # 0x4387: '',  # 䎇
    0x4388: 'yì',  # 䎈
    0x4389: 'shù,yù',  # 䎉
    0x438A: 'pò',  # 䎊
    0x438B: 'hè,kào',  # 䎋
    0x438C: 'cù',  # 䎌
    # 0x438D: '',  # 䎍
    0x438E: 'nà',  # 䎎
    0x438F: 'àn,hán',  # 䎏
    0x4390: 'chǎo',  # 䎐
    0x4391: 'lù',  # 䎑
    0x4392: 'zhǎn',  # 䎒
    0x4393: 'tà',  # 䎓
    # 0x4394: '',  # 䎔
    # 0x4395: '',  # 䎕
    # 0x4396: '',  # 䎖
    0x4397: 'qiáo',  # 䎗
    0x4398: 'sù',  # 䎘
    # 0x4399: '',  # 䎙
    0x439A: 'guàn,huì',  # 䎚
    # 0x439B: '',  # 䎛
    # 0x439C: '',  # 䎜
    0x439D: 'chú,zhù',  # 䎝
    # 0x439E: '',  # 䎞
    0x439F: 'ér,nuò',  # 䎟
    0x43A0: 'ér,nuó',  # 䎠
    0x43A1: 'nuǎn,ruǎn',  # 䎡
    0x43A2: 'qǐ',  # 䎢
    0x43A3: 'sì,xìn',  # 䎣
    0x43A4: 'chú,jú',  # 䎤
    # 0x43A5: '',  # 䎥
    0x43A6: 'yǎn',  # 䎦
    0x43A7: 'bàng,póu',  # 䎧
    0x43A8: 'àn,yè',  # 䎨
    # 0x43A9: '',  # 䎩
    0x43AA: 'nè',  # 䎪
    0x43AB: 'chuàng,zǒng',  # 䎫
    0x43AC: 'bēi,bà',  # 䎬
    0x43AD: 'cāo',  # 䎭
    0x43AE: 'tì',  # 䎮
    0x43AF: 'hàn',  # 䎯
    0x43B0: 'zuó',  # 䎰
    0x43B1: 'bēi,bà',  # 䎱
    0x43B2: 'zhé',  # 䎲
    0x43B3: 'wà,yuè',  # 䎳
    0x43B4: 'shèng',  # 䎴
    0x43B5: 'bì',  # 䎵
    0x43B6: 'èr',  # 䎶
    0x43B7: 'zhù',  # 䎷
    0x43B8: 'wù',  # 䎸
    0x43B9: 'wén',  # 䎹
    0x43BA: 'zhǐ,zhì',  # 䎺
    0x43BB: 'zhǒu',  # 䎻
    0x43BC: 'lù',  # 䎼
    0x43BD: 'wén,wèn',  # 䎽
    0x43BE: 'gǔn',  # 䎾
    0x43BF: 'qiú,xiòng',  # 䎿
    0x43C0: 'là',  # 䏀
    0x43C1: 'zǎi',  # 䏁
    0x43C2: 'sǒu',  # 䏂
    0x43C3: 'mián',  # 䏃
    0x43C4: 'zhì',  # 䏄
    0x43C5: 'qì',  # 䏅
    0x43C6: 'cáo',  # 䏆
    0x43C7: 'piào',  # 䏇
    0x43C8: 'lián',  # 䏈
    # 0x43C9: '',  # 䏉
    0x43CA: 'lóng',  # 䏊
    0x43CB: 'sù',  # 䏋
    0x43CC: 'qì,yì',  # 䏌
    0x43CD: 'yuàn',  # 䏍
    0x43CE: 'féng,hàn',  # 䏎
    # 0x43CF: '',  # 䏏
    0x43D0: 'jué,zhuò',  # 䏐
    0x43D1: 'dì,zhì',  # 䏑
    0x43D2: 'piàn',  # 䏒
    0x43D3: 'guǎn',  # 䏓
    0x43D4: 'niǔ',  # 䏔
    0x43D5: 'rěn,rùn',  # 䏕
    0x43D6: 'zhèn',  # 䏖
    0x43D7: 'gài,kuì',  # 䏗
    0x43D8: 'pǐ,pì',  # 䏘
    0x43D9: 'tǎn',  # 䏙
    0x43DA: 'chǎo,miǎo',  # 䏚
    0x43DB: 'chǔn',  # 䏛
    # 0x43DC: '',  # 䏜
    0x43DD: 'chún,zhuǎn',  # 䏝
    0x43DE: 'mò',  # 䏞
    0x43DF: 'biè,bié',  # 䏟
    0x43E0: 'qì',  # 䏠
    0x43E1: 'shì',  # 䏡
    0x43E2: 'bǐ',  # 䏢
    0x43E3: 'jué,qù,qū',  # 䏣
    0x43E4: 'sì',  # 䏤
    # 0x43E5: '',  # 䏥
    0x43E6: 'huá,tián,wǎn',  # 䏦
    0x43E7: 'ná',  # 䏧
    0x43E8: 'huǐ',  # 䏨
    # 0x43E9: '',  # 䏩
    0x43EA: 'èr',  # 䏪
    # 0x43EB: '',  # 䏫
    0x43EC: 'móu',  # 䏬
    # 0x43ED: '',  # 䏭
    0x43EE: 'xí,xié',  # 䏮
    0x43EF: 'zhì',  # 䏯
    0x43F0: 'rěn,chǔn',  # 䏰
    0x43F1: 'jú',  # 䏱
    0x43F2: 'dié',  # 䏲
    0x43F3: 'zhè',  # 䏳
    0x43F4: 'shào,shè',  # 䏴
    0x43F5: 'měng',  # 䏵
    0x43F6: 'bì',  # 䏶
    0x43F7: 'hàn',  # 䏷
    0x43F8: 'yú',  # 䏸
    0x43F9: 'xiàn',  # 䏹
    # 0x43FA: '',  # 䏺
    0x43FB: 'néng',  # 䏻
    0x43FC: 'cán',  # 䏼
    0x43FD: 'bù',  # 䏽
    # 0x43FE: '',  # 䏾
    0x43FF: 'qǐ',  # 䏿
    0x4400: 'jì',  # 䐀
    0x4401: 'niǎo,zhuó',  # 䐁
    0x4402: 'lù',  # 䐂
    0x4403: 'jiǒng',  # 䐃
    0x4404: 'hàn,liǎn,xiàn',  # 䐄
    0x4405: 'yí',  # 䐅
    0x4406: 'cǎi,cài',  # 䐆
    0x4407: 'chún',  # 䐇
    0x4408: 'zhí',  # 䐈
    0x4409: 'zì',  # 䐉
    0x440A: 'dá,hún,hùn',  # 䐊
    # 0x440B: '',  # 䐋
    0x440C: 'tiǎn,zhòu',  # 䐌
    0x440D: 'zhòu',  # 䐍
    # 0x440E: '',  # 䐎
    0x440F: 'chǔn',  # 䐏
    # 0x4410: '',  # 䐐
    0x4411: 'zhé',  # 䐑
    # 0x4412: '',  # 䐒
    0x4413: 'róu,rù',  # 䐓
    0x4414: 'bìn',  # 䐔
    0x4415: 'jí',  # 䐕
    0x4416: 'yí',  # 䐖
    0x4417: 'dǔ',  # 䐗
    0x4418: 'jué',  # 䐘
    0x4419: 'gé,yì',  # 䐙
    0x441A: 'jí,jì',  # 䐚
    0x441B: 'dā',  # 䐛
    0x441C: 'chēn',  # 䐜
    0x441D: 'suǒ,suò',  # 䐝
    0x441E: 'ruò',  # 䐞
    0x441F: 'xiàng',  # 䐟
    0x4420: 'huǎng',  # 䐠
    0x4421: 'qí',  # 䐡
    0x4422: 'zhù',  # 䐢
    0x4423: 'cuò,sǔn',  # 䐣
    0x4424: 'chí,cuó,qì,zhàn',  # 䐤
    0x4425: 'wěng',  # 䐥
    # 0x4426: '',  # 䐦
    0x4427: 'kào',  # 䐧
    0x4428: 'gǔ',  # 䐨
    0x4429: 'kǎi',  # 䐩
    0x442A: 'fàn,juǎn',  # 䐪
    # 0x442B: '',  # 䐫
    0x442C: 'cáo',  # 䐬
    0x442D: 'zhì',  # 䐭
    0x442E: 'chǎn',  # 䐮
    0x442F: 'léi',  # 䐯
    # 0x4430: '',  # 䐰
    # 0x4431: '',  # 䐱
    0x4432: 'zhé',  # 䐲
    0x4433: 'yú',  # 䐳
    0x4434: 'guì',  # 䐴
    0x4435: 'huáng',  # 䐵
    0x4436: 'jǐn',  # 䐶
    # 0x4437: '',  # 䐷
    0x4438: 'guó,huò',  # 䐸
    0x4439: 'sào,sōu',  # 䐹
    0x443A: 'tàn',  # 䐺
    # 0x443B: '',  # 䐻
    0x443C: 'xì',  # 䐼
    0x443D: 'mán',  # 䐽
    0x443E: 'duó',  # 䐾
    0x443F: 'áo,ǎo',  # 䐿
    0x4440: 'pì',  # 䑀
    0x4441: 'wù',  # 䑁
    0x4442: 'ǎi,xì',  # 䑂
    0x4443: 'méng',  # 䑃
    0x4444: 'pì,yì',  # 䑄
    0x4445: 'méng',  # 䑅
    0x4446: 'yǎng',  # 䑆
    0x4447: 'zhì',  # 䑇
    0x4448: 'bó',  # 䑈
    0x4449: 'yíng',  # 䑉
    0x444A: 'wéi,wèi',  # 䑊
    0x444B: 'náo,rǎng',  # 䑋
    0x444C: 'lán',  # 䑌
    0x444D: 'yàn,yǐng',  # 䑍
    0x444E: 'chǎn',  # 䑎
    0x444F: 'quán',  # 䑏
    0x4450: 'zhěn',  # 䑐
    0x4451: 'pú',  # 䑑
    # 0x4452: '',  # 䑒
    0x4453: 'tái,tǎi',  # 䑓
    0x4454: 'fèi',  # 䑔
    0x4455: 'shǔ',  # 䑕
    # 0x4456: '',  # 䑖
    0x4457: 'dàng',  # 䑗
    0x4458: 'chá,cuó',  # 䑘
    0x4459: 'rán',  # 䑙
    0x445A: 'tián',  # 䑚
    0x445B: 'chǐ,shì,yì',  # 䑛
    0x445C: 'tà',  # 䑜
    0x445D: 'jiǎ',  # 䑝
    0x445E: 'shùn',  # 䑞
    0x445F: 'huáng',  # 䑟
    0x4460: 'liǎo',  # 䑠
    0x4461: 'chā',  # 䑡
    # 0x4462: '',  # 䑢
    0x4463: 'chēn',  # 䑣
    0x4464: 'jìn,jìng',  # 䑤
    0x4465: 'è,sà',  # 䑥
    0x4466: 'gōu',  # 䑦
    0x4467: 'fú',  # 䑧
    0x4468: 'duò',  # 䑨
    # 0x4469: '',  # 䑩
    0x446A: 'è',  # 䑪
    # 0x446B: '',  # 䑫
    0x446C: 'yào',  # 䑬
    0x446D: 'dì,zhì',  # 䑭
    # 0x446E: '',  # 䑮
    0x446F: 'dì',  # 䑯
    0x4470: 'bù',  # 䑰
    0x4471: 'mán,wǎn',  # 䑱
    0x4472: 'chè,zhái,zhào',  # 䑲
    0x4473: 'lún',  # 䑳
    0x4474: 'qí',  # 䑴
    0x4475: 'mù',  # 䑵
    0x4476: 'cán,qiàn',  # 䑶
    # 0x4477: '',  # 䑷
    # 0x4478: '',  # 䑸
    # 0x4479: '',  # 䑹
    # 0x447A: '',  # 䑺
    0x447B: 'yóu',  # 䑻
    # 0x447C: '',  # 䑼
    0x447D: 'dá,tà',  # 䑽
    # 0x447E: '',  # 䑾
    0x447F: 'sù',  # 䑿
    0x4480: 'fú',  # 䒀
    0x4481: 'jì,xí,xiào,yà',  # 䒁
    0x4482: 'jiǎng,xiǎng',  # 䒂
    0x4483: 'zào',  # 䒃
    0x4484: 'bó,fù',  # 䒄
    0x4485: 'téng',  # 䒅
    0x4486: 'chè',  # 䒆
    0x4487: 'fù',  # 䒇
    0x4488: 'bǔ,fèi',  # 䒈
    0x4489: 'wǔ',  # 䒉
    # 0x448A: '',  # 䒊
    0x448B: 'yǎng',  # 䒋
    0x448C: 'mìng',  # 䒌
    0x448D: 'pǎng',  # 䒍
    0x448E: 'mǎng',  # 䒎
    # 0x448F: '',  # 䒏
    0x4490: 'méng',  # 䒐
    0x4491: 'cǎo',  # 䒑
    0x4492: 'tiáo,yǎo,yóu',  # 䒒
    0x4493: 'kǎi',  # 䒓
    0x4494: 'bài',  # 䒔
    0x4495: 'xiǎo',  # 䒕
    0x4496: 'xìn',  # 䒖
    0x4497: 'qì',  # 䒗
    # 0x4498: '',  # 䒘
    # 0x4499: '',  # 䒙
    0x449A: 'shǎo',  # 䒚
    0x449B: 'héng,huàn',  # 䒛
    0x449C: 'niú',  # 䒜
    0x449D: 'xiáo',  # 䒝
    0x449E: 'chén',  # 䒞
    # 0x449F: '',  # 䒟
    0x44A0: 'fēng,xiá',  # 䒠
    0x44A1: 'yǐn',  # 䒡
    0x44A2: 'áng,yìng',  # 䒢
    0x44A3: 'rǎn',  # 䒣
    0x44A4: 'rì',  # 䒤
    0x44A5: 'fà,liǔ,mán',  # 䒥
    0x44A6: 'fàn',  # 䒦
    0x44A7: 'qù',  # 䒧
    0x44A8: 'shǐ',  # 䒨
    0x44A9: 'hé,xiá',  # 䒩
    0x44AA: 'biàn',  # 䒪
    0x44AB: 'dài',  # 䒫
    0x44AC: 'mò',  # 䒬
    0x44AD: 'děng',  # 䒭
    # 0x44AE: '',  # 䒮
    # 0x44AF: '',  # 䒯
    # 0x44B0: '',  # 䒰
    # 0x44B1: '',  # 䒱
    0x44B2: 'chà',  # 䒲
    0x44B3: 'duǒ',  # 䒳
    0x44B4: 'yǒu',  # 䒴
    0x44B5: 'hào',  # 䒵
    # 0x44B6: '',  # 䒶
    0x44B7: 'guā',  # 䒷
    0x44B8: 'xián,xuè,yuè',  # 䒸
    0x44B9: 'lèi',  # 䒹
    0x44BA: 'jǐn',  # 䒺
    0x44BB: 'qǐ',  # 䒻
    0x44BC: 'qū',  # 䒼
    0x44BD: 'méi,wǎng',  # 䒽
    # 0x44BE: '',  # 䒾
    0x44BF: 'liáo',  # 䒿
    # 0x44C0: '',  # 䓀
    # 0x44C1: '',  # 䓁
    0x44C2: 'yán',  # 䓂
    0x44C3: 'yì',  # 䓃
    0x44C4: 'yín',  # 䓄
    0x44C5: 'qí',  # 䓅
    0x44C6: 'zhé',  # 䓆
    0x44C7: 'xì',  # 䓇
    0x44C8: 'yì',  # 䓈
    0x44C9: 'yé',  # 䓉
    0x44CA: 'è,wú,yú',  # 䓊
    # 0x44CB: '',  # 䓋
    0x44CC: 'zhì',  # 䓌
    0x44CD: 'hǎn',  # 䓍
    0x44CE: 'chuò',  # 䓎
    # 0x44CF: '',  # 䓏
    0x44D0: 'chún',  # 䓐
    0x44D1: 'bǐng,píng',  # 䓑
    0x44D2: 'kuǎi',  # 䓒
    0x44D3: 'chóu',  # 䓓
    # 0x44D4: '',  # 䓔
    0x44D5: 'tuǒ,wěi',  # 䓕
    0x44D6: 'qióng',  # 䓖
    # 0x44D7: '',  # 䓗
    0x44D8: 'jiù',  # 䓘
    # 0x44D9: '',  # 䓙
    0x44DA: 'cú',  # 䓚
    0x44DB: 'fǔ,gǔ,qū',  # 䓛
    0x44DC: 'zhī',  # 䓜
    0x44DD: 'méng,mèng',  # 䓝
    0x44DE: 'lì',  # 䓞
    0x44DF: 'liè',  # 䓟
    0x44E0: 'tà',  # 䓠
    0x44E1: 'zhī',  # 䓡
    0x44E2: 'gù',  # 䓢
    0x44E3: 'liǎng',  # 䓣
    # 0x44E4: '',  # 䓤
    0x44E5: 'là',  # 䓥
    0x44E6: 'diǎn',  # 䓦
    0x44E7: 'cì,jí',  # 䓧
    # 0x44E8: '',  # 䓨
    # 0x44E9: '',  # 䓩
    # 0x44EA: '',  # 䓪
    0x44EB: 'jì,qí',  # 䓫
    # 0x44EC: '',  # 䓬
    0x44ED: 'chà',  # 䓭
    0x44EE: 'mào',  # 䓮
    0x44EF: 'dú',  # 䓯
    # 0x44F0: '',  # 䓰
    0x44F1: 'chái,zhài',  # 䓱
    0x44F2: 'ruì,sà',  # 䓲
    0x44F3: 'hěn',  # 䓳
    0x44F4: 'ruán,ruǎn',  # 䓴
    # 0x44F5: '',  # 䓵
    0x44F6: 'lài',  # 䓶
    0x44F7: 'xìng',  # 䓷
    # 0x44F8: '',  # 䓸
    0x44F9: 'yì',  # 䓹
    0x44FA: 'měi,wèi',  # 䓺
    # 0x44FB: '',  # 䓻
    0x44FC: 'hè,máng',  # 䓼
    0x44FD: 'jì',  # 䓽
    0x44FE: 'suō',  # 䓾
    0x44FF: 'hǎn,hàn',  # 䓿
    # 0x4500: '',  # 䔀
    0x4501: 'lì',  # 䔁
    0x4502: 'zǐ',  # 䔂
    0x4503: 'zǔ',  # 䔃
    0x4504: 'yáo',  # 䔄
    # 0x4505: '',  # 䔅
    0x4506: 'lí',  # 䔆
    0x4507: 'qǐ,yǐ',  # 䔇
    0x4508: 'gǎn,gòng,nǒu',  # 䔈
    0x4509: 'lì',  # 䔉
    # 0x450A: '',  # 䔊
    # 0x450B: '',  # 䔋
    0x450C: 'gāo',  # 䔌
    # 0x450D: '',  # 䔍
    0x450E: 'sù',  # 䔎
    0x450F: 'chòu',  # 䔏
    # 0x4510: '',  # 䔐
    0x4511: 'xié,yé',  # 䔑
    0x4512: 'bèi',  # 䔒
    0x4513: 'xǔ',  # 䔓
    0x4514: 'jìng,qiǎn,qiú,yǐng',  # 䔔
    0x4515: 'pú',  # 䔕
    0x4516: 'líng',  # 䔖
    0x4517: 'xiáng',  # 䔗
    0x4518: 'zuò',  # 䔘
    0x4519: 'diào',  # 䔙
    0x451A: 'chún',  # 䔚
    0x451B: 'qǐng',  # 䔛
    0x451C: 'nán',  # 䔜
    # 0x451D: '',  # 䔝
    # 0x451E: '',  # 䔞
    0x451F: 'chí,chǐ,yí',  # 䔟
    0x4520: 'shǎo',  # 䔠
    0x4521: 'yú',  # 䔡
    0x4522: 'huá,huà',  # 䔢
    0x4523: 'lí',  # 䔣
    0x4524: 'pā',  # 䔤
    # 0x4525: '',  # 䔥
    # 0x4526: '',  # 䔦
    0x4527: 'lí,lì',  # 䔧
    # 0x4528: '',  # 䔨
    # 0x4529: '',  # 䔩
    0x452A: 'duì,shuǎng',  # 䔪
    0x452B: 'shū',  # 䔫
    0x452C: 'yì',  # 䔬
    0x452D: 'nìng,zhǒu',  # 䔭
    0x452E: 'sī',  # 䔮
    0x452F: 'hú,huà,kù',  # 䔯
    0x4530: 'fú,fù',  # 䔰
    # 0x4531: '',  # 䔱
    0x4532: 'chéng,zhuó',  # 䔲
    0x4533: 'nǎn,rán',  # 䔳
    0x4534: 'cè,cuì',  # 䔴
    # 0x4535: '',  # 䔵
    0x4536: 'tí',  # 䔶
    0x4537: 'qín',  # 䔷
    0x4538: 'biǎo',  # 䔸
    0x4539: 'suì',  # 䔹
    0x453A: 'wéi',  # 䔺
    # 0x453B: '',  # 䔻
    0x453C: 'sè',  # 䔼
    0x453D: 'ài',  # 䔽
    0x453E: 'è,qì,zè',  # 䔾
    0x453F: 'jiè,zǔn',  # 䔿
    0x4540: 'kuǎn',  # 䕀
    0x4541: 'fěi',  # 䕁
    # 0x4542: '',  # 䕂
    0x4543: 'yìn',  # 䕃
    # 0x4544: '',  # 䕄
    0x4545: 'sǎo',  # 䕅
    0x4546: 'dòu',  # 䕆
    0x4547: 'huì',  # 䕇
    0x4548: 'xiè',  # 䕈
    0x4549: 'zé',  # 䕉
    0x454A: 'tán',  # 䕊
    0x454B: 'chǎng,táng',  # 䕋
    0x454C: 'zhì',  # 䕌
    0x454D: 'yì',  # 䕍
    0x454E: 'fú',  # 䕎
    0x454F: 'é',  # 䕏
    # 0x4550: '',  # 䕐
    0x4551: 'jùn',  # 䕑
    # 0x4552: '',  # 䕒
    0x4553: 'chá,chuì',  # 䕓
    0x4554: 'xián',  # 䕔
    0x4555: 'màn',  # 䕕
    # 0x4556: '',  # 䕖
    0x4557: 'bì,pèi',  # 䕗
    0x4558: 'líng',  # 䕘
    0x4559: 'jié',  # 䕙
    0x455A: 'kuì',  # 䕚
    0x455B: 'jiá',  # 䕛
    # 0x455C: '',  # 䕜
    # 0x455D: '',  # 䕝
    0x455E: 'làng,liáo',  # 䕞
    # 0x455F: '',  # 䕟
    0x4560: 'fèi',  # 䕠
    0x4561: 'lǘ',  # 䕡
    0x4562: 'zhǎ',  # 䕢
    0x4563: 'hé,kě,shé',  # 䕣
    0x4564: 'qí,jī',  # 䕤
    0x4565: 'nǐ,yí',  # 䕥
    0x4566: 'yíng',  # 䕦
    0x4567: 'xiào',  # 䕧
    0x4568: 'téng',  # 䕨
    0x4569: 'lǎo',  # 䕩
    0x456A: 'zé',  # 䕪
    0x456B: 'kuí',  # 䕫
    0x456C: 'jiāng',  # 䕬
    0x456D: 'qián',  # 䕭
    0x456E: 'jú',  # 䕮
    0x456F: 'piáo',  # 䕯
    0x4570: 'bàn,fán,fàn',  # 䕰
    0x4571: 'dǒu,dòu,tóu',  # 䕱
    0x4572: 'lǐn',  # 䕲
    0x4573: 'mí',  # 䕳
    0x4574: 'zhuó',  # 䕴
    0x4575: 'xié,xiè',  # 䕵
    0x4576: 'hù',  # 䕶
    0x4577: 'mí',  # 䕷
    # 0x4578: '',  # 䕸
    0x4579: 'zá',  # 䕹
    0x457A: 'cóng',  # 䕺
    0x457B: 'gé,lì,lí',  # 䕻
    0x457C: 'nán,nàn,rán',  # 䕼
    0x457D: 'zhú',  # 䕽
    0x457E: 'yán,yín',  # 䕾
    0x457F: 'hàn',  # 䕿
    # 0x4580: '',  # 䖀
    0x4581: 'yì',  # 䖁
    0x4582: 'luán',  # 䖂
    0x4583: 'yuè',  # 䖃
    0x4584: 'rán',  # 䖄
    0x4585: 'líng',  # 䖅
    0x4586: 'niàng',  # 䖆
    0x4587: 'yù',  # 䖇
    0x4588: 'nüè',  # 䖈
    # 0x4589: '',  # 䖉
    0x458A: 'yí,yì',  # 䖊
    0x458B: 'nüè',  # 䖋
    0x458C: 'qín,yá,yì',  # 䖌
    0x458D: 'qián',  # 䖍
    0x458E: 'xiá',  # 䖎
    0x458F: 'chǔ',  # 䖏
    0x4590: 'jìn,yín',  # 䖐
    0x4591: 'mì',  # 䖑
    0x4592: 'xī',  # 䖒
    0x4593: 'nà',  # 䖓
    0x4594: 'hàn,kǎn',  # 䖔
    0x4595: 'zǔ',  # 䖕
    0x4596: 'xiá',  # 䖖
    0x4597: 'yán,yàn',  # 䖗
    0x4598: 'tú',  # 䖘
    # 0x4599: '',  # 䖙
    # 0x459A: '',  # 䖚
    0x459B: 'suǒ',  # 䖛
    0x459C: 'yín,yìn',  # 䖜
    0x459D: 'chóng',  # 䖝
    0x459E: 'zhǒu',  # 䖞
    0x459F: 'mǎng,méng',  # 䖟
    0x45A0: 'yuán',  # 䖠
    # 0x45A1: '',  # 䖡
    0x45A2: 'miáo',  # 䖢
    0x45A3: 'zǎo',  # 䖣
    0x45A4: 'wǎn,yuán',  # 䖤
    0x45A5: 'máo',  # 䖥
    0x45A6: 'qū,zhuō',  # 䖦
    0x45A7: 'nà',  # 䖧
    0x45A8: 'shí',  # 䖨
    0x45A9: 'bì,pì',  # 䖩
    0x45AA: 'cí',  # 䖪
    0x45AB: 'bàng',  # 䖫
    0x45AC: 'jiǎ',  # 䖬
    0x45AD: 'juàn',  # 䖭
    0x45AE: 'xiǎng',  # 䖮
    0x45AF: 'kuí,wā',  # 䖯
    0x45B0: 'pài',  # 䖰
    # 0x45B1: '',  # 䖱
    0x45B2: 'xún',  # 䖲
    0x45B3: 'zhà',  # 䖳
    0x45B4: 'yáo',  # 䖴
    0x45B5: 'kūn',  # 䖵
    # 0x45B6: '',  # 䖶
    # 0x45B7: '',  # 䖷
    0x45B8: 'é',  # 䖸
    0x45B9: 'yáng',  # 䖹
    0x45BA: 'tiáo,zhào',  # 䖺
    0x45BB: 'yóu',  # 䖻
    0x45BC: 'jué,xuè',  # 䖼
    0x45BD: 'lí',  # 䖽
    # 0x45BE: '',  # 䖾
    0x45BF: 'lí',  # 䖿
    # 0x45C0: '',  # 䗀
    0x45C1: 'jì,qī',  # 䗁
    0x45C2: 'hǔ',  # 䗂
    0x45C3: 'zhàn',  # 䗃
    0x45C4: 'fǔ,pì',  # 䗄
    0x45C5: 'cháng',  # 䗅
    0x45C6: 'guǎn,wěi',  # 䗆
    0x45C7: 'jú,qú',  # 䗇
    0x45C8: 'méng',  # 䗈
    # 0x45C9: '',  # 䗉
    0x45CA: 'chéng,tàn',  # 䗊
    0x45CB: 'móu',  # 䗋
    # 0x45CC: '',  # 䗌
    0x45CD: 'lǐ',  # 䗍
    # 0x45CE: '',  # 䗎
    # 0x45CF: '',  # 䗏
    0x45D0: 'shī',  # 䗐
    0x45D1: 'yì',  # 䗑
    0x45D2: 'bìng',  # 䗒
    # 0x45D3: '',  # 䗓
    0x45D4: 'hóu',  # 䗔
    0x45D5: 'wǎn',  # 䗕
    0x45D6: 'dì',  # 䗖
    # 0x45D7: '',  # 䗗
    0x45D8: 'gé,kè',  # 䗘
    0x45D9: 'hán',  # 䗙
    0x45DA: 'bó',  # 䗚
    # 0x45DB: '',  # 䗛
    0x45DC: 'liú',  # 䗜
    0x45DD: 'cán',  # 䗝
    0x45DE: 'cán,chěn,shǎn,yǐn,zàn,zhàn',  # 䗞
    0x45DF: 'yì',  # 䗟
    0x45E0: 'xuán',  # 䗠
    0x45E1: 'yán',  # 䗡
    0x45E2: 'zǎo',  # 䗢
    0x45E3: 'gǎo,hàn',  # 䗣
    0x45E4: 'yóng',  # 䗤
    0x45E5: 'zōng',  # 䗥
    # 0x45E6: '',  # 䗦
    # 0x45E7: '',  # 䗧
    0x45E8: 'yú',  # 䗨
    # 0x45E9: '',  # 䗩
    0x45EA: 'zhè',  # 䗪
    0x45EB: 'má',  # 䗫
    # 0x45EC: '',  # 䗬
    # 0x45ED: '',  # 䗭
    0x45EE: 'shuǎng',  # 䗮
    0x45EF: 'jìn',  # 䗯
    0x45F0: 'guàn',  # 䗰
    0x45F1: 'pú',  # 䗱
    0x45F2: 'lìn',  # 䗲
    # 0x45F3: '',  # 䗳
    0x45F4: 'tíng',  # 䗴
    # 0x45F5: '',  # 䗵
    0x45F6: 'là,lì',  # 䗶
    0x45F7: 'yì',  # 䗷
    # 0x45F8: '',  # 䗸
    0x45F9: 'cì',  # 䗹
    0x45FA: 'yǎn',  # 䗺
    0x45FB: 'jié',  # 䗻
    # 0x45FC: '',  # 䗼
    0x45FD: 'wèi',  # 䗽
    0x45FE: 'xiǎn',  # 䗾
    0x45FF: 'níng',  # 䗿
    0x4600: 'fù',  # 䘀
    0x4601: 'gé,jié,kě',  # 䘁
    # 0x4602: '',  # 䘂
    0x4603: 'mò',  # 䘃
    0x4604: 'fù,zhù',  # 䘄
    0x4605: 'nái,nài,něng',  # 䘅
    0x4606: 'xiǎn',  # 䘆
    0x4607: 'wén,wèn',  # 䘇
    0x4608: 'lì',  # 䘈
    0x4609: 'cán',  # 䘉
    0x460A: 'miè',  # 䘊
    # 0x460B: '',  # 䘋
    0x460C: 'nì',  # 䘌
    0x460D: 'chài',  # 䘍
    # 0x460E: '',  # 䘎
    0x460F: 'xù',  # 䘏
    # 0x4610: '',  # 䘐
    0x4611: 'mài,mò',  # 䘑
    0x4612: 'zuī',  # 䘒
    0x4613: 'kàn,kào',  # 䘓
    0x4614: 'kā',  # 䘔
    0x4615: 'háng',  # 䘕
    # 0x4616: '',  # 䘖
    # 0x4617: '',  # 䘗
    0x4618: 'yù',  # 䘘
    0x4619: 'wèi',  # 䘙
    0x461A: 'zú',  # 䘚
    # 0x461B: '',  # 䘛
    # 0x461C: '',  # 䘜
    0x461D: 'yì',  # 䘝
    # 0x461E: '',  # 䘞
    0x461F: 'diāo',  # 䘟
    0x4620: 'fú,pò',  # 䘠
    0x4621: 'bǐ',  # 䘡
    0x4622: 'zhǔ',  # 䘢
    0x4623: 'zǐ',  # 䘣
    0x4624: 'shù',  # 䘤
    0x4625: 'xiá,jiá',  # 䘥
    0x4626: 'ní,nǐ',  # 䘦
    # 0x4627: '',  # 䘧
    0x4628: 'jiǎo',  # 䘨
    0x4629: 'xuàn,xún',  # 䘩
    # 0x462A: '',  # 䘪
    0x462B: 'nòu,rú',  # 䘫
    0x462C: 'róng',  # 䘬
    0x462D: 'dié,zhì',  # 䘭
    0x462E: 'sà,sàng,xì',  # 䘮
    0x462F: 'shāo',  # 䘯
    0x4630: 'shān',  # 䘰
    0x4631: 'yù',  # 䘱
    # 0x4632: '',  # 䘲
    0x4633: 'jīn',  # 䘳
    # 0x4634: '',  # 䘴
    0x4635: 'lù',  # 䘵
    0x4636: 'hàn,yǎn',  # 䘶
    # 0x4637: '',  # 䘷
    0x4638: 'yì',  # 䘸
    0x4639: 'zuì',  # 䘹
    0x463A: 'zhàn',  # 䘺
    0x463B: 'sù,yù',  # 䘻
    0x463C: 'wǎn',  # 䘼
    0x463D: 'ní,nǐ,nì',  # 䘽
    0x463E: 'guǎn',  # 䘾
    0x463F: 'jué',  # 䘿
    0x4640: 'běng',  # 䙀
    0x4641: 'cán',  # 䙁
    # 0x4642: '',  # 䙂
    0x4643: 'duò,kuò,pán,ruán',  # 䙃
    0x4644: 'qì,zhǎ',  # 䙄
    0x4645: 'yào',  # 䙅
    0x4646: 'guì,kuì',  # 䙆
    0x4647: 'nuǎn,ruán',  # 䙇
    0x4648: 'hóu',  # 䙈
    0x4649: 'xún,zǎn',  # 䙉
    0x464A: 'xiè',  # 䙊
    # 0x464B: '',  # 䙋
    0x464C: 'huì,kuì',  # 䙌
    # 0x464D: '',  # 䙍
    0x464E: 'xié',  # 䙎
    0x464F: 'bó',  # 䙏
    0x4650: 'kè',  # 䙐
    # 0x4651: '',  # 䙑
    0x4652: 'xù',  # 䙒
    0x4653: 'bǎi',  # 䙓
    0x4654: 'yǔ',  # 䙔
    0x4655: 'chù,zǒng',  # 䙕
    # 0x4656: '',  # 䙖
    0x4657: 'tì',  # 䙗
    0x4658: 'chǔ,zú',  # 䙘
    0x4659: 'chí',  # 䙙
    0x465A: 'niǎo',  # 䙚
    0x465B: 'guàn,gǔn',  # 䙛
    0x465C: 'féng',  # 䙜
    0x465D: 'xiè,dié',  # 䙝
    # 0x465E: '',  # 䙞
    0x465F: 'duò,wéi',  # 䙟
    0x4660: 'jué,wò',  # 䙠
    0x4661: 'huì,kuì',  # 䙡
    0x4662: 'zèng',  # 䙢
    0x4663: 'sà',  # 䙣
    0x4664: 'duǒ,duò',  # 䙤
    0x4665: 'líng',  # 䙥
    0x4666: 'méng',  # 䙦
    # 0x4667: '',  # 䙧
    0x4668: 'guǒ,luǒ',  # 䙨
    0x4669: 'méng',  # 䙩
    0x466A: 'lóng,màng,pàn',  # 䙪
    # 0x466B: '',  # 䙫
    0x466C: 'yìng',  # 䙬
    # 0x466D: '',  # 䙭
    0x466E: 'guàn',  # 䙮
    0x466F: 'cù,zhuó',  # 䙯
    0x4670: 'lí',  # 䙰
    0x4671: 'dú,shǔ',  # 䙱
    # 0x4672: '',  # 䙲
    0x4673: 'è',  # 䙳
    # 0x4674: '',  # 䙴
    0x4675: 'xī',  # 䙵
    # 0x4676: '',  # 䙶
    0x4677: 'dé,zhé',  # 䙷
    0x4678: 'dé,de',  # 䙸
    0x4679: 'jiǎng,nǎo,xiàn,xiǎng',  # 䙹
    0x467A: 'lián,liǎn,qiǎn',  # 䙺
    # 0x467B: '',  # 䙻
    0x467C: 'shào',  # 䙼
    0x467D: 'xì,xié',  # 䙽
    0x467E: 'shī',  # 䙾
    0x467F: 'wèi',  # 䙿
    # 0x4680: '',  # 䚀
    # 0x4681: '',  # 䚁
    0x4682: 'hè,xì',  # 䚂
    0x4683: 'yóu',  # 䚃
    0x4684: 'lù',  # 䚄
    0x4685: 'lái,lài',  # 䚅
    0x4686: 'ǒu,yǎo,yǐng',  # 䚆
    0x4687: 'shěng,zhì',  # 䚇
    0x4688: 'juàn,wù,zhuàn',  # 䚈
    0x4689: 'qì,xì',  # 䚉
    # 0x468A: '',  # 䚊
    0x468B: 'yùn',  # 䚋
    # 0x468C: '',  # 䚌
    0x468D: 'qì',  # 䚍
    0x468E: 'chuāng',  # 䚎
    0x468F: 'lèng,lì,lìn',  # 䚏
    0x4690: 'jí',  # 䚐
    0x4691: 'mái',  # 䚑
    0x4692: 'chuáng,zhuàng',  # 䚒
    0x4693: 'niǎn,shěn',  # 䚓
    0x4694: 'bìn',  # 䚔
    0x4695: 'lì,luán',  # 䚕
    0x4696: 'líng',  # 䚖
    0x4697: 'gāng',  # 䚗
    0x4698: 'chén,chéng',  # 䚘
    0x4699: 'xuān',  # 䚙
    0x469A: 'xiǎn',  # 䚚
    0x469B: 'hú',  # 䚛
    # 0x469C: '',  # 䚜
    0x469D: 'zú',  # 䚝
    0x469E: 'dǎi',  # 䚞
    0x469F: 'dǎi',  # 䚟
    0x46A0: 'hùn',  # 䚠
    0x46A1: 'sāi',  # 䚡
    0x46A2: 'chè',  # 䚢
    0x46A3: 'tí,tì',  # 䚣
    # 0x46A4: '',  # 䚤
    0x46A5: 'nuò',  # 䚥
    0x46A6: 'zhì',  # 䚦
    0x46A7: 'liú',  # 䚧
    0x46A8: 'fèi',  # 䚨
    0x46A9: 'jiǎo,jiào',  # 䚩
    # 0x46AA: '',  # 䚪
    0x46AB: 'áo,xí',  # 䚫
    0x46AC: 'lín',  # 䚬
    0x46AD: 'xuān',  # 䚭
    0x46AE: 'réng',  # 䚮
    0x46AF: 'tǎo,zhèn',  # 䚯
    0x46B0: 'pǐ',  # 䚰
    0x46B1: 'xìn',  # 䚱
    0x46B2: 'shàn',  # 䚲
    0x46B3: 'xiè,zhì',  # 䚳
    0x46B4: 'wà',  # 䚴
    0x46B5: 'tǒu',  # 䚵
    # 0x46B6: '',  # 䚶
    0x46B7: 'xì,yǐ,yì',  # 䚷
    0x46B8: 'xiè',  # 䚸
    0x46B9: 'pǐ',  # 䚹
    0x46BA: 'yáo',  # 䚺
    0x46BB: 'yáo',  # 䚻
    # 0x46BC: '',  # 䚼
    0x46BD: 'hào',  # 䚽
    0x46BE: 'nín,rén',  # 䚾
    0x46BF: 'yìn',  # 䚿
    0x46C0: 'fǎn',  # 䛀
    0x46C1: 'nán',  # 䛁
    0x46C2: 'chí,chǐ',  # 䛂
    0x46C3: 'wàng',  # 䛃
    0x46C4: 'yuǎn',  # 䛄
    0x46C5: 'xiá',  # 䛅
    0x46C6: 'zhòu',  # 䛆
    0x46C7: 'yuǎn',  # 䛇
    0x46C8: 'shì',  # 䛈
    0x46C9: 'mì,miàn',  # 䛉
    # 0x46CA: '',  # 䛊
    0x46CB: 'gé,jì',  # 䛋
    0x46CC: 'páo,táo',  # 䛌
    0x46CD: 'fèi',  # 䛍
    0x46CE: 'hù,xuè,yù',  # 䛎
    0x46CF: 'ní',  # 䛏
    0x46D0: 'cí',  # 䛐
    0x46D1: 'mì',  # 䛑
    0x46D2: 'biàn',  # 䛒
    # 0x46D3: '',  # 䛓
    0x46D4: 'ná',  # 䛔
    0x46D5: 'yù',  # 䛕
    0x46D6: 'è,yì',  # 䛖
    0x46D7: 'zhǐ',  # 䛗
    0x46D8: 'nín,rén',  # 䛘
    0x46D9: 'xù',  # 䛙
    # 0x46DA: '',  # 䛚
    0x46DB: 'huì,qì',  # 䛛
    0x46DC: 'xùn',  # 䛜
    0x46DD: 'náo',  # 䛝
    0x46DE: 'hǎn,hàn',  # 䛞
    0x46DF: 'jiá',  # 䛟
    0x46E0: 'dòu,xiáng',  # 䛠
    0x46E1: 'huà',  # 䛡
    # 0x46E2: '',  # 䛢
    # 0x46E3: '',  # 䛣
    0x46E4: 'cù',  # 䛤
    0x46E5: 'xì',  # 䛥
    0x46E6: 'sòng',  # 䛦
    0x46E7: 'mí',  # 䛧
    0x46E8: 'xìn',  # 䛨
    0x46E9: 'wù',  # 䛩
    0x46EA: 'qióng,wěi',  # 䛪
    0x46EB: 'zhèng',  # 䛫
    0x46EC: 'táo',  # 䛬
    0x46ED: 'xìng',  # 䛭
    0x46EE: 'jiù',  # 䛮
    0x46EF: 'jù',  # 䛯
    0x46F0: 'hún,hùn',  # 䛰
    0x46F1: 'tí',  # 䛱
    0x46F2: 'mán,màn',  # 䛲
    0x46F3: 'jiǎn,yàn',  # 䛳
    0x46F4: 'qǐ',  # 䛴
    0x46F5: 'shòu',  # 䛵
    0x46F6: 'lěi',  # 䛶
    0x46F7: 'wǎn',  # 䛷
    0x46F8: 'chè,shǎn',  # 䛸
    0x46F9: 'càn',  # 䛹
    0x46FA: 'jiè',  # 䛺
    0x46FB: 'yòu',  # 䛻
    0x46FC: 'huǐ',  # 䛼
    0x46FD: 'zhǎ',  # 䛽
    0x46FE: 'sù',  # 䛾
    0x46FF: 'gé',  # 䛿
    0x4700: 'nǎo',  # 䜀
    0x4701: 'xì',  # 䜁
    # 0x4702: '',  # 䜂
    # 0x4703: '',  # 䜃
    0x4704: 'chí',  # 䜄
    0x4705: 'wéi',  # 䜅
    0x4706: 'mò,nèi,shé,suì,zhé',  # 䜆
    0x4707: 'gǔn,gùn',  # 䜇
    0x4708: 'jiǎo',  # 䜈
    # 0x4709: '',  # 䜉
    0x470A: 'zāo,zào',  # 䜊
    0x470B: 'huì',  # 䜋
    0x470C: 'luán',  # 䜌
    0x470D: 'liáo',  # 䜍
    0x470E: 'láo,lào',  # 䜎
    # 0x470F: '',  # 䜏
    0x4710: 'huī',  # 䜐
    0x4711: 'qià,wù',  # 䜑
    0x4712: 'ào',  # 䜒
    0x4713: 'niè,shè',  # 䜓
    0x4714: 'suí',  # 䜔
    0x4715: 'mài',  # 䜕
    0x4716: 'tàn',  # 䜖
    0x4717: 'xìn',  # 䜗
    0x4718: 'jǐng',  # 䜘
    0x4719: 'án',  # 䜙
    0x471A: 'tà',  # 䜚
    0x471B: 'chán,chàn',  # 䜛
    0x471C: 'wèi',  # 䜜
    0x471D: 'tuǎn',  # 䜝
    0x471E: 'jì',  # 䜞
    0x471F: 'chén,chèn',  # 䜟
    0x4720: 'chè,zhì',  # 䜠
    0x4721: 'xù,xuè,yù',  # 䜡
    0x4722: 'xiǎn',  # 䜢
    0x4723: 'xī,xīn,yín',  # 䜣
    # 0x4724: '',  # 䜤
    # 0x4725: '',  # 䜥
    # 0x4726: '',  # 䜦
    0x4727: 'nǎo',  # 䜧
    # 0x4728: '',  # 䜨
    0x4729: 'yàn',  # 䜩
    0x472A: 'qiú',  # 䜪
    0x472B: 'hóng',  # 䜫
    0x472C: 'sǒng,xiù',  # 䜬
    0x472D: 'jùn',  # 䜭
    0x472E: 'liáo',  # 䜮
    0x472F: 'jú',  # 䜯
    0x4730: 'hāo',  # 䜰
    0x4731: 'mǎn',  # 䜱
    0x4732: 'liè',  # 䜲
    # 0x4733: '',  # 䜳
    0x4734: 'chù,shì',  # 䜴
    0x4735: 'chǐ,shì',  # 䜵
    0x4736: 'xiáng',  # 䜶
    # 0x4737: '',  # 䜷
    0x4738: 'měi',  # 䜸
    0x4739: 'shù',  # 䜹
    0x473A: 'cè',  # 䜺
    0x473B: 'chǐ,shì',  # 䜻
    0x473C: 'gú',  # 䜼
    0x473D: 'yú',  # 䜽
    # 0x473E: '',  # 䜾
    0x473F: 'shù',  # 䜿
    0x4740: 'liáo,liú',  # 䝀
    0x4741: 'láo',  # 䝁
    0x4742: 'shù',  # 䝂
    0x4743: 'zhé',  # 䝃
    # 0x4744: '',  # 䝄
    # 0x4745: '',  # 䝅
    # 0x4746: '',  # 䝆
    # 0x4747: '',  # 䝇
    0x4748: 'è',  # 䝈
    # 0x4749: '',  # 䝉
    0x474A: 'shà',  # 䝊
    0x474B: 'zòng',  # 䝋
    0x474C: 'jué,jùn',  # 䝌
    0x474D: 'jùn',  # 䝍
    # 0x474E: '',  # 䝎
    0x474F: 'lóu,lǒu',  # 䝏
    0x4750: 'wéi',  # 䝐
    # 0x4751: '',  # 䝑
    0x4752: 'zhù',  # 䝒
    0x4753: 'là,liè',  # 䝓
    # 0x4754: '',  # 䝔
    0x4755: 'zhé',  # 䝕
    0x4756: 'zhǎo',  # 䝖
    # 0x4757: '',  # 䝗
    0x4758: 'yì',  # 䝘
    # 0x4759: '',  # 䝙
    0x475A: 'ní',  # 䝚
    # 0x475B: '',  # 䝛
    # 0x475C: '',  # 䝜
    0x475D: 'yǐ',  # 䝝
    0x475E: 'hào',  # 䝞
    0x475F: 'yà,yè',  # 䝟
    0x4760: 'huán,yuán',  # 䝠
    0x4761: 'màn',  # 䝡
    0x4762: 'màn,méng',  # 䝢
    0x4763: 'qú',  # 䝣
    0x4764: 'lǎo,liáo',  # 䝤
    0x4765: 'háo',  # 䝥
    # 0x4766: '',  # 䝦
    0x4767: 'mén,mín',  # 䝧
    0x4768: 'xián',  # 䝨
    0x4769: 'zhèn',  # 䝩
    0x476A: 'shú,shǔ',  # 䝪
    0x476B: 'zuó',  # 䝫
    0x476C: 'zhù',  # 䝬
    0x476D: 'gòu',  # 䝭
    0x476E: 'xuàn',  # 䝮
    0x476F: 'yì',  # 䝯
    0x4770: 'tí,zhì',  # 䝰
    # 0x4771: '',  # 䝱
    0x4772: 'jìn',  # 䝲
    0x4773: 'cán',  # 䝳
    # 0x4774: '',  # 䝴
    0x4775: 'bù',  # 䝵
    0x4776: 'liáng',  # 䝶
    0x4777: 'zhì',  # 䝷
    0x4778: 'jì',  # 䝸
    0x4779: 'wǎn,yuàn',  # 䝹
    0x477A: 'guàn',  # 䝺
    # 0x477B: '',  # 䝻
    0x477C: 'qíng',  # 䝼
    0x477D: 'ài',  # 䝽
    0x477E: 'fù',  # 䝾
    0x477F: 'guì',  # 䝿
    0x4780: 'gòu,hòu,mǐn',  # 䞀
    0x4781: 'xiàn,yàn,yǎng,yàng',  # 䞁
    0x4782: 'ruǎn',  # 䞂
    0x4783: 'zhì',  # 䞃
    0x4784: 'biào',  # 䞄
    0x4785: 'yí',  # 䞅
    0x4786: 'suǒ',  # 䞆
    0x4787: 'dié,zhì',  # 䞇
    0x4788: 'guǐ,guì',  # 䞈
    0x4789: 'shèng',  # 䞉
    0x478A: 'xùn',  # 䞊
    0x478B: 'chèn',  # 䞋
    0x478C: 'shé',  # 䞌
    0x478D: 'qíng',  # 䞍
    # 0x478E: '',  # 䞎
    # 0x478F: '',  # 䞏
    0x4790: 'chǔn,shǔn',  # 䞐
    0x4791: 'hóng',  # 䞑
    0x4792: 'dòng',  # 䞒
    0x4793: 'chēng',  # 䞓
    0x4794: 'wěi',  # 䞔
    0x4795: 'dié,nǎ,niè,rú,xiè,yú',  # 䞕
    0x4796: 'shǔ',  # 䞖
    0x4797: 'cāi',  # 䞗
    0x4798: 'jí',  # 䞘
    0x4799: 'zá',  # 䞙
    0x479A: 'qí',  # 䞚
    # 0x479B: '',  # 䞛
    0x479C: 'fù',  # 䞜
    0x479D: 'ǎo,yù',  # 䞝
    0x479E: 'fú',  # 䞞
    0x479F: 'pò',  # 䞟
    # 0x47A0: '',  # 䞠
    0x47A1: 'tǎn',  # 䞡
    0x47A2: 'zhà,zuó',  # 䞢
    0x47A3: 'chě,chè,qiè',  # 䞣
    0x47A4: 'qú',  # 䞤
    0x47A5: 'yòu',  # 䞥
    0x47A6: 'hé,jié',  # 䞦
    0x47A7: 'hòu',  # 䞧
    0x47A8: 'guǐ,kuǐ',  # 䞨
    0x47A9: 'è,ruí',  # 䞩
    0x47AA: 'jiàng',  # 䞪
    0x47AB: 'yǔn',  # 䞫
    0x47AC: 'tòu',  # 䞬
    0x47AD: 'qiǔ,qūn',  # 䞭
    # 0x47AE: '',  # 䞮
    0x47AF: 'fù',  # 䞯
    0x47B0: 'zuó',  # 䞰
    0x47B1: 'hú',  # 䞱
    # 0x47B2: '',  # 䞲
    0x47B3: 'bó,fèi',  # 䞳
    # 0x47B4: '',  # 䞴
    0x47B5: 'juě',  # 䞵
    0x47B6: 'dì,tì',  # 䞶
    0x47B7: 'jué',  # 䞷
    0x47B8: 'fù',  # 䞸
    0x47B9: 'huáng',  # 䞹
    # 0x47BA: '',  # 䞺
    0x47BB: 'yǒng',  # 䞻
    0x47BC: 'chuǐ,cuàn,jiàn,mèi',  # 䞼
    0x47BD: 'suǒ',  # 䞽
    0x47BE: 'chí',  # 䞾
    0x47BF: 'qiān',  # 䞿
    # 0x47C0: '',  # 䟀
    # 0x47C1: '',  # 䟁
    0x47C2: 'mán',  # 䟂
    0x47C3: 'cà,zàn',  # 䟃
    0x47C4: 'qì,zuó',  # 䟄
    0x47C5: 'jiàn,zàn',  # 䟅
    0x47C6: 'bì,bó',  # 䟆
    0x47C7: 'jī',  # 䟇
    0x47C8: 'zhí',  # 䟈
    0x47C9: 'zhú',  # 䟉
    0x47CA: 'qú',  # 䟊
    0x47CB: 'zhǎn,zhàn',  # 䟋
    0x47CC: 'jí,jié',  # 䟌
    0x47CD: 'dián',  # 䟍
    # 0x47CE: '',  # 䟎
    0x47CF: 'lì',  # 䟏
    0x47D0: 'lì',  # 䟐
    0x47D1: 'lǎ,yuè',  # 䟑
    0x47D2: 'quán',  # 䟒
    # 0x47D3: '',  # 䟓
    0x47D4: 'fù',  # 䟔
    0x47D5: 'chà',  # 䟕
    0x47D6: 'tàng',  # 䟖
    0x47D7: 'shì',  # 䟗
    0x47D8: 'hàng',  # 䟘
    0x47D9: 'qiè',  # 䟙
    0x47DA: 'qí',  # 䟚
    0x47DB: 'bó',  # 䟛
    0x47DC: 'nà',  # 䟜
    0x47DD: 'tòu',  # 䟝
    0x47DE: 'chú',  # 䟞
    0x47DF: 'cù',  # 䟟
    0x47E0: 'yuè',  # 䟠
    0x47E1: 'dì',  # 䟡
    0x47E2: 'chén,jiàn,niǎn',  # 䟢
    0x47E3: 'chù',  # 䟣
    0x47E4: 'bì',  # 䟤
    0x47E5: 'máng,méng',  # 䟥
    0x47E6: 'bá,bó,yuán',  # 䟦
    0x47E7: 'tián',  # 䟧
    0x47E8: 'mín',  # 䟨
    0x47E9: 'liě',  # 䟩
    0x47EA: 'fěng',  # 䟪
    # 0x47EB: '',  # 䟫
    0x47EC: 'qiù',  # 䟬
    0x47ED: 'tiáo',  # 䟭
    0x47EE: 'fú',  # 䟮
    0x47EF: 'kuò',  # 䟯
    0x47F0: 'jiǎn',  # 䟰
    # 0x47F1: '',  # 䟱
    0x47F2: 'còng',  # 䟲
    # 0x47F3: '',  # 䟳
    0x47F4: 'zhèn',  # 䟴
    0x47F5: 'qiú',  # 䟵
    0x47F6: 'cuò,zuò',  # 䟶
    0x47F7: 'chì,qì',  # 䟷
    0x47F8: 'kuí',  # 䟸
    0x47F9: 'liè,lìn',  # 䟹
    0x47FA: 'bǎng,bèi,pèi',  # 䟺
    0x47FB: 'dù',  # 䟻
    0x47FC: 'wǔ',  # 䟼
    0x47FD: 'shū',  # 䟽
    0x47FE: 'juě,zhuó',  # 䟾
    0x47FF: 'lù',  # 䟿
    0x4800: 'chǎng',  # 䠀
    # 0x4801: '',  # 䠁
    0x4802: 'chú,chǔ',  # 䠂
    0x4803: 'liǎng',  # 䠃
    0x4804: 'tiǎn',  # 䠄
    0x4805: 'kǔn,tà',  # 䠅
    0x4806: 'cháng',  # 䠆
    0x4807: 'jué',  # 䠇
    0x4808: 'tú',  # 䠈
    0x4809: 'huà,huàn,huǐ',  # 䠉
    0x480A: 'fèi',  # 䠊
    0x480B: 'bǐ,bì,mà',  # 䠋
    # 0x480C: '',  # 䠌
    0x480D: 'qiá,xiā',  # 䠍
    0x480E: 'wò',  # 䠎
    0x480F: 'jì',  # 䠏
    0x4810: 'qù',  # 䠐
    0x4811: 'kuǐ',  # 䠑
    0x4812: 'hú',  # 䠒
    0x4813: 'cù,jiù,qù',  # 䠓
    0x4814: 'suì',  # 䠔
    # 0x4815: '',  # 䠕
    # 0x4816: '',  # 䠖
    0x4817: 'qiù',  # 䠗
    0x4818: 'pì',  # 䠘
    0x4819: 'bèi,páng,páo',  # 䠙
    0x481A: 'wà',  # 䠚
    0x481B: 'jiǎo,xiào,yáo',  # 䠛
    0x481C: 'róng',  # 䠜
    # 0x481D: '',  # 䠝
    0x481E: 'cù,qí',  # 䠞
    0x481F: 'dié,shè',  # 䠟
    0x4820: 'chì',  # 䠠
    0x4821: 'cuó',  # 䠡
    0x4822: 'mèng',  # 䠢
    0x4823: 'xuǎn,xuàn',  # 䠣
    0x4824: 'duǒ,duò',  # 䠤
    0x4825: 'bié',  # 䠥
    0x4826: 'zhè,zhì',  # 䠦
    0x4827: 'chú',  # 䠧
    0x4828: 'chàn,mà',  # 䠨
    0x4829: 'guì',  # 䠩
    0x482A: 'duàn',  # 䠪
    0x482B: 'zòu',  # 䠫
    0x482C: 'dèng',  # 䠬
    0x482D: 'lái,lài',  # 䠭
    0x482E: 'téng',  # 䠮
    0x482F: 'yuè',  # 䠯
    0x4830: 'quán',  # 䠰
    0x4831: 'shǔ,zhú',  # 䠱
    0x4832: 'líng',  # 䠲
    # 0x4833: '',  # 䠳
    0x4834: 'qǐn,yǐn,zhěn',  # 䠴
    0x4835: 'fù',  # 䠵
    0x4836: 'shè',  # 䠶
    0x4837: 'tiǎo',  # 䠷
    # 0x4838: '',  # 䠸
    0x4839: 'hái',  # 䠹
    # 0x483A: '',  # 䠺
    0x483B: 'qióng',  # 䠻
    0x483C: 'diào,shù,xuè,zhú',  # 䠼
    0x483D: 'hái',  # 䠽
    0x483E: 'shǎn,shàn',  # 䠾
    0x483F: 'wài',  # 䠿
    0x4840: 'zhǎn',  # 䡀
    0x4841: 'lǒng',  # 䡁
    0x4842: 'jiù',  # 䡂
    0x4843: 'lì',  # 䡃
    # 0x4844: '',  # 䡄
    0x4845: 'mǐn,xiǎn,xún,zhèn,zuǎn,chūn',  # 䡅
    0x4846: 'róng,rǒng',  # 䡆
    0x4847: 'yuè',  # 䡇
    0x4848: 'jué',  # 䡈
    0x4849: 'kǎng',  # 䡉
    0x484A: 'fán,fǎn,pèi',  # 䡊
    0x484B: 'qí',  # 䡋
    0x484C: 'hóng',  # 䡌
    0x484D: 'fú,fǔ',  # 䡍
    0x484E: 'lú',  # 䡎
    0x484F: 'hóng',  # 䡏
    0x4850: 'tuó',  # 䡐
    0x4851: 'mín',  # 䡑
    0x4852: 'tián',  # 䡒
    0x4853: 'juàn',  # 䡓
    0x4854: 'qǐ',  # 䡔
    0x4855: 'zhěng',  # 䡕
    0x4856: 'jìng',  # 䡖
    0x4857: 'gǒng',  # 䡗
    0x4858: 'tián',  # 䡘
    0x4859: 'láng',  # 䡙
    0x485A: 'mào',  # 䡚
    0x485B: 'yìn',  # 䡛
    0x485C: 'lù',  # 䡜
    0x485D: 'yǔn,yuān',  # 䡝
    0x485E: 'jú',  # 䡞
    0x485F: 'pì',  # 䡟
    # 0x4860: '',  # 䡠
    0x4861: 'xié',  # 䡡
    0x4862: 'biàn',  # 䡢
    0x4863: 'hún',  # 䡣
    # 0x4864: '',  # 䡤
    0x4865: 'róng',  # 䡥
    0x4866: 'sǎng',  # 䡦
    0x4867: 'wǔ',  # 䡧
    0x4868: 'chà,chái,yín',  # 䡨
    0x4869: 'gǔ,hòu,tǒu,zhěn,kēng',  # 䡩
    0x486A: 'chán,shàn',  # 䡪
    0x486B: 'péng',  # 䡫
    0x486C: 'màn',  # 䡬
    # 0x486D: '',  # 䡭
    # 0x486E: '',  # 䡮
    0x486F: 'shuàng,zǒng',  # 䡯
    0x4870: 'kěng,kēng',  # 䡰
    0x4871: 'zhuǎn',  # 䡱
    0x4872: 'chán',  # 䡲
    # 0x4873: '',  # 䡳
    0x4874: 'chuáng,chōng',  # 䡴
    0x4875: 'suì',  # 䡵
    0x4876: 'bèi,pì',  # 䡶
    0x4877: 'kài',  # 䡷
    # 0x4878: '',  # 䡸
    0x4879: 'zhì',  # 䡹
    0x487A: 'wèi',  # 䡺
    0x487B: 'mín',  # 䡻
    0x487C: 'líng',  # 䡼
    # 0x487D: '',  # 䡽
    0x487E: 'nèi,niè',  # 䡾
    0x487F: 'líng',  # 䡿
    0x4880: 'qì',  # 䢀
    0x4881: 'yuè',  # 䢁
    # 0x4882: '',  # 䢂
    0x4883: 'yì',  # 䢃
    0x4884: 'xǐ,xǐ',  # 䢄
    0x4885: 'chén',  # 䢅
    # 0x4886: '',  # 䢆
    0x4887: 'rǒng,rǒu',  # 䢇
    0x4888: 'chén,qín',  # 䢈
    0x4889: 'nóng',  # 䢉
    0x488A: 'yóu',  # 䢊
    0x488B: 'jì',  # 䢋
    0x488C: 'bó',  # 䢌
    0x488D: 'fǎng,fèn',  # 䢍
    # 0x488E: '',  # 䢎
    # 0x488F: '',  # 䢏
    0x4890: 'cú',  # 䢐
    0x4891: 'dǐ',  # 䢑
    0x4892: 'jiāo',  # 䢒
    0x4893: 'yú',  # 䢓
    0x4894: 'gé,hé,jiá',  # 䢔
    0x4895: 'xù',  # 䢕
    0x4896: 'yù',  # 䢖
    0x4897: 'hé,qǔ',  # 䢗
    # 0x4898: '',  # 䢘
    0x4899: 'bài',  # 䢙
    0x489A: 'gòng,háng',  # 䢚
    0x489B: 'jiǒng',  # 䢛
    # 0x489C: '',  # 䢜
    0x489D: 'yà',  # 䢝
    0x489E: 'nù,shù',  # 䢞
    0x489F: 'yóu',  # 䢟
    0x48A0: 'sòng',  # 䢠
    0x48A1: 'xiè',  # 䢡
    0x48A2: 'càng',  # 䢢
    0x48A3: 'yáo',  # 䢣
    0x48A4: 'shù',  # 䢤
    0x48A5: 'yán,yàn',  # 䢥
    0x48A6: 'shuài',  # 䢦
    0x48A7: 'liào,lǐn,què',  # 䢧
    # 0x48A8: '',  # 䢨
    0x48A9: 'yù',  # 䢩
    0x48AA: 'bó,cuì,jiǎo,nǔ,qián',  # 䢪
    0x48AB: 'suí',  # 䢫
    # 0x48AC: '',  # 䢬
    0x48AD: 'yàn',  # 䢭
    0x48AE: 'lèi',  # 䢮
    0x48AF: 'lín',  # 䢯
    0x48B0: 'tái,tì',  # 䢰
    0x48B1: 'dú,zhà',  # 䢱
    0x48B2: 'yuè',  # 䢲
    0x48B3: 'jǐ,jì',  # 䢳
    # 0x48B4: '',  # 䢴
    0x48B5: 'yún',  # 䢵
    # 0x48B6: '',  # 䢶
    # 0x48B7: '',  # 䢷
    0x48B8: 'jū',  # 䢸
    0x48B9: 'jǔ',  # 䢹
    0x48BA: 'chū',  # 䢺
    0x48BB: 'chén,jìn,tán',  # 䢻
    0x48BC: 'gōng',  # 䢼
    0x48BD: 'xiàng',  # 䢽
    0x48BE: 'xiǎn',  # 䢾
    # 0x48BF: '',  # 䢿
    0x48C0: 'guǐ,wéi',  # 䣀
    0x48C1: 'yǔ',  # 䣁
    0x48C2: 'lěi,lèi',  # 䣂
    # 0x48C3: '',  # 䣃
    0x48C4: 'tú',  # 䣄
    0x48C5: 'chén',  # 䣅
    0x48C6: 'xíng',  # 䣆
    0x48C7: 'qiú',  # 䣇
    0x48C8: 'hàng,liáo,xiàng',  # 䣈
    # 0x48C9: '',  # 䣉
    0x48CA: 'dǎng',  # 䣊
    0x48CB: 'cǎi',  # 䣋
    0x48CC: 'dǐ',  # 䣌
    0x48CD: 'yǎn',  # 䣍
    # 0x48CE: '',  # 䣎
    # 0x48CF: '',  # 䣏
    # 0x48D0: '',  # 䣐
    0x48D1: 'chán',  # 䣑
    # 0x48D2: '',  # 䣒
    0x48D3: 'lí',  # 䣓
    0x48D4: 'suǒ,suò',  # 䣔
    0x48D5: 'mǎ,mà',  # 䣕
    0x48D6: 'mǎ',  # 䣖
    # 0x48D7: '',  # 䣗
    0x48D8: 'táng',  # 䣘
    0x48D9: 'péi',  # 䣙
    0x48DA: 'lóu,lú',  # 䣚
    0x48DB: 'qī',  # 䣛
    0x48DC: 'cuó',  # 䣜
    0x48DD: 'tú',  # 䣝
    0x48DE: 'è',  # 䣞
    0x48DF: 'cán',  # 䣟
    0x48E0: 'jié,tì',  # 䣠
    0x48E1: 'tí,yí',  # 䣡
    0x48E2: 'jí',  # 䣢
    0x48E3: 'dǎng,dào',  # 䣣
    0x48E4: 'jiào,jué',  # 䣤
    0x48E5: 'bǐ,mì',  # 䣥
    0x48E6: 'lèi',  # 䣦
    0x48E7: 'yì',  # 䣧
    0x48E8: 'chún',  # 䣨
    0x48E9: 'chún',  # 䣩
    0x48EA: 'pò',  # 䣪
    0x48EB: 'lí',  # 䣫
    0x48EC: 'zǎi',  # 䣬
    0x48ED: 'tài',  # 䣭
    0x48EE: 'pò',  # 䣮
    0x48EF: 'tiǎn',  # 䣯
    0x48F0: 'jù,yuàn',  # 䣰
    0x48F1: 'xù,yì',  # 䣱
    0x48F2: 'fàn',  # 䣲
    # 0x48F3: '',  # 䣳
    0x48F4: 'xù',  # 䣴
    0x48F5: 'èr',  # 䣵
    0x48F6: 'huó,tián',  # 䣶
    # 0x48F7: '',  # 䣷
    0x48F8: 'rǎn',  # 䣸
    0x48F9: 'fá',  # 䣹
    0x48FA: 'juān',  # 䣺
    # 0x48FB: '',  # 䣻
    0x48FC: 'liáng',  # 䣼
    0x48FD: 'tǐ',  # 䣽
    0x48FE: 'mì',  # 䣾
    # 0x48FF: '',  # 䣿
    # 0x4900: '',  # 䤀
    0x4901: 'cén,chè,shè,yín',  # 䤁
    0x4902: 'méi',  # 䤂
    0x4903: 'yìn',  # 䤃
    0x4904: 'miǎn,zhuàn',  # 䤄
    0x4905: 'tú',  # 䤅
    0x4906: 'kuí',  # 䤆
    # 0x4907: '',  # 䤇
    # 0x4908: '',  # 䤈
    0x4909: 'mì,míng,mò,rú',  # 䤉
    0x490A: 'róng',  # 䤊
    0x490B: 'guó,yù',  # 䤋
    # 0x490C: '',  # 䤌
    0x490D: 'mí',  # 䤍
    0x490E: 'jú',  # 䤎
    0x490F: 'pǐ',  # 䤏
    0x4910: 'jǐn',  # 䤐
    0x4911: 'wàng',  # 䤑
    0x4912: 'jǐ,jì',  # 䤒
    0x4913: 'méng',  # 䤓
    0x4914: 'jiàn,niú,xiàng',  # 䤔
    0x4915: 'xuè',  # 䤕
    0x4916: 'bào',  # 䤖
    0x4917: 'gǎn',  # 䤗
    0x4918: 'chǎn,qiǎn',  # 䤘
    0x4919: 'lì',  # 䤙
    0x491A: 'lǐ,lüè',  # 䤚
    0x491B: 'qiú',  # 䤛
    0x491C: 'dùn',  # 䤜
    0x491D: 'yìng',  # 䤝
    0x491E: 'yǔn',  # 䤞
    0x491F: 'chén',  # 䤟
    0x4920: 'jī,zhǐ',  # 䤠
    0x4921: 'rǎn',  # 䤡
    # 0x4922: '',  # 䤢
    # 0x4923: '',  # 䤣
    # 0x4924: '',  # 䤤
    0x4925: 'guǐ',  # 䤥
    0x4926: 'yuè',  # 䤦
    0x4927: 'huì',  # 䤧
    0x4928: 'pì',  # 䤨
    0x4929: 'chá',  # 䤩
    0x492A: 'duǒ',  # 䤪
    0x492B: 'chán',  # 䤫
    # 0x492C: '',  # 䤬
    0x492D: 'kuàn,shì,suì,yí',  # 䤭
    0x492E: 'shè',  # 䤮
    0x492F: 'xíng',  # 䤯
    0x4930: 'wěng,yíng',  # 䤰
    0x4931: 'shì',  # 䤱
    0x4932: 'chì',  # 䤲
    0x4933: 'yè',  # 䤳
    0x4934: 'hán',  # 䤴
    0x4935: 'fèi',  # 䤵
    0x4936: 'yè',  # 䤶
    0x4937: 'yán,yǎn',  # 䤷
    0x4938: 'zuàn',  # 䤸
    # 0x4939: '',  # 䤹
    0x493A: 'yǐn',  # 䤺
    0x493B: 'duò',  # 䤻
    0x493C: 'xiàn',  # 䤼
    # 0x493D: '',  # 䤽
    # 0x493E: '',  # 䤾
    0x493F: 'qiè',  # 䤿
    0x4940: 'chǎn',  # 䥀
    0x4941: 'hán',  # 䥁
    0x4942: 'mèng',  # 䥂
    0x4943: 'yuè',  # 䥃
    0x4944: 'cù,zǎn,zàn',  # 䥄
    0x4945: 'qiàn,qín',  # 䥅
    0x4946: 'jǐn,qín,ròu,wèi',  # 䥆
    0x4947: 'shàn',  # 䥇
    0x4948: 'mǔ',  # 䥈
    # 0x4949: '',  # 䥉
    # 0x494A: '',  # 䥊
    # 0x494B: '',  # 䥋
    0x494C: 'zhèng',  # 䥌
    0x494D: 'zhì',  # 䥍
    0x494E: 'chún',  # 䥎
    0x494F: 'yǔ',  # 䥏
    0x4950: 'móu',  # 䥐
    0x4951: 'wàn',  # 䥑
    0x4952: 'jiàng',  # 䥒
    # 0x4953: '',  # 䥓
    0x4954: 'sù',  # 䥔
    0x4955: 'piě',  # 䥕
    0x4956: 'tián',  # 䥖
    0x4957: 'kuǎn',  # 䥗
    0x4958: 'cù,cuò',  # 䥘
    0x4959: 'suì',  # 䥙
    # 0x495A: '',  # 䥚
    0x495B: 'jié',  # 䥛
    0x495C: 'jiàn',  # 䥜
    0x495D: 'áo,āo',  # 䥝
    0x495E: 'jiǎo',  # 䥞
    0x495F: 'yè',  # 䥟
    # 0x4960: '',  # 䥠
    0x4961: 'yè',  # 䥡
    0x4962: 'lóng',  # 䥢
    0x4963: 'záo',  # 䥣
    0x4964: 'báo,fú',  # 䥤
    0x4965: 'lián',  # 䥥
    # 0x4966: '',  # 䥦
    0x4967: 'huán,xuán',  # 䥧
    # 0x4968: '',  # 䥨
    0x4969: 'wéi',  # 䥩
    0x496A: 'xiǎn',  # 䥪
    0x496B: 'tiě',  # 䥫
    0x496C: 'bó',  # 䥬
    0x496D: 'zhèng',  # 䥭
    0x496E: 'zhú',  # 䥮
    0x496F: 'bà,bài,bēi',  # 䥯
    0x4970: 'mèng',  # 䥰
    0x4971: 'xiě',  # 䥱
    # 0x4972: '',  # 䥲
    # 0x4973: '',  # 䥳
    0x4974: 'juān',  # 䥴
    0x4975: 'xiǎo',  # 䥵
    0x4976: 'lì',  # 䥶
    0x4977: 'zhá',  # 䥷
    0x4978: 'mí',  # 䥸
    # 0x4979: '',  # 䥹
    0x497A: 'yé',  # 䥺
    # 0x497B: '',  # 䥻
    # 0x497C: '',  # 䥼
    # 0x497D: '',  # 䥽
    0x497E: 'xiě',  # 䥾
    # 0x497F: '',  # 䥿
    # 0x4980: '',  # 䦀
    # 0x4981: '',  # 䦁
    0x4982: 'shàn',  # 䦂
    # 0x4983: '',  # 䦃
    # 0x4984: '',  # 䦄
    0x4985: 'shàn,zhǎn',  # 䦅
    0x4986: 'jué',  # 䦆
    0x4987: 'jì',  # 䦇
    0x4988: 'fǎng,hǎn,jí,mǒu,zá,zuǒ',  # 䦈
    # 0x4989: '',  # 䦉
    0x498A: 'niǎo',  # 䦊
    0x498B: 'áo',  # 䦋
    0x498C: 'chù,pò,ruì',  # 䦌
    0x498D: 'wù',  # 䦍
    0x498E: 'guǎn',  # 䦎
    0x498F: 'xiè',  # 䦏
    0x4990: 'tǐng',  # 䦐
    0x4991: 'xiè',  # 䦑
    0x4992: 'dàng',  # 䦒
    # 0x4993: '',  # 䦓
    0x4994: 'tǎn',  # 䦔
    # 0x4995: '',  # 䦕
    0x4996: 'xiá,xié',  # 䦖
    0x4997: 'xù',  # 䦗
    0x4998: 'bì,xiǎn,xiàn',  # 䦘
    0x4999: 'sì',  # 䦙
    0x499A: 'huò,kuǎ,kuà',  # 䦚
    0x499B: 'zhèng,zhì',  # 䦛
    0x499C: 'wú,wù',  # 䦜
    # 0x499D: '',  # 䦝
    0x499E: 'rùn',  # 䦞
    0x499F: 'chuài',  # 䦟
    0x49A0: 'shǐ',  # 䦠
    0x49A1: 'huán',  # 䦡
    0x49A2: 'kuò',  # 䦢
    0x49A3: 'fù',  # 䦣
    0x49A4: 'chuài,wěn',  # 䦤
    0x49A5: 'xián',  # 䦥
    0x49A6: 'qín',  # 䦦
    0x49A7: 'qié,xì,yǎn',  # 䦧
    0x49A8: 'lán',  # 䦨
    0x49A9: 'wén',  # 䦩
    0x49AA: 'yà',  # 䦪
    # 0x49AB: '',  # 䦫
    0x49AC: 'què',  # 䦬
    # 0x49AD: '',  # 䦭
    0x49AE: 'chǔn',  # 䦮
    0x49AF: 'zhì',  # 䦯
    # 0x49B0: '',  # 䦰
    0x49B1: 'kuǐ,wěi',  # 䦱
    0x49B2: 'qiàn,yán',  # 䦲
    0x49B3: 'hàng,xiàng',  # 䦳
    0x49B4: 'yì',  # 䦴
    0x49B5: 'nǐ',  # 䦵
    0x49B6: 'zhèng',  # 䦶
    0x49B7: 'chuài,wěn',  # 䦷
    # 0x49B8: '',  # 䦸
    0x49B9: 'shí',  # 䦹
    0x49BA: 'dīng',  # 䦺
    0x49BB: 'cì,zǐ',  # 䦻
    0x49BC: 'jué',  # 䦼
    0x49BD: 'xù',  # 䦽
    0x49BE: 'yǔn',  # 䦾
    # 0x49BF: '',  # 䦿
    # 0x49C0: '',  # 䧀
    0x49C1: 'chù,xǔ',  # 䧁
    0x49C2: 'dào,tiǎo,zhào',  # 䧂
    0x49C3: 'diàn,tián',  # 䧃
    0x49C4: 'gè',  # 䧄
    0x49C5: 'tì,yà,yí',  # 䧅
    0x49C6: 'hóng,kǒu,qióng',  # 䧆
    0x49C7: 'nǐ,yǐ,yī',  # 䧇
    # 0x49C8: '',  # 䧈
    0x49C9: 'lǐ',  # 䧉
    0x49CA: 'kū',  # 䧊
    0x49CB: 'xiǎn',  # 䧋
    # 0x49CC: '',  # 䧌
    0x49CD: 'xì',  # 䧍
    0x49CE: 'xuàn',  # 䧎
    # 0x49CF: '',  # 䧏
    # 0x49D0: '',  # 䧐
    # 0x49D1: '',  # 䧑
    0x49D2: 'lái,lǎn',  # 䧒
    # 0x49D3: '',  # 䧓
    0x49D4: 'mù,niàn',  # 䧔
    0x49D5: 'chéng,yù',  # 䧕
    0x49D6: 'jiàn',  # 䧖
    0x49D7: 'bì',  # 䧗
    0x49D8: 'qí,zhuàn',  # 䧘
    0x49D9: 'líng',  # 䧙
    0x49DA: 'hào',  # 䧚
    0x49DB: 'bàng',  # 䧛
    0x49DC: 'táng',  # 䧜
    0x49DD: 'chī,zhì',  # 䧝
    0x49DE: 'fù,mà',  # 䧞
    0x49DF: 'xiàn,xuàn',  # 䧟
    0x49E0: 'shuàn',  # 䧠
    # 0x49E1: '',  # 䧡
    0x49E2: 'qū',  # 䧢
    # 0x49E3: '',  # 䧣
    0x49E4: 'pú',  # 䧤
    0x49E5: 'huì',  # 䧥
    0x49E6: 'wéi,huī',  # 䧦
    0x49E7: 'yǐ',  # 䧧
    0x49E8: 'yè',  # 䧨
    # 0x49E9: '',  # 䧩
    0x49EA: 'chè,zhé',  # 䧪
    0x49EB: 'háo',  # 䧫
    # 0x49EC: '',  # 䧬
    # 0x49ED: '',  # 䧭
    0x49EE: 'xiǎn,xiàn',  # 䧮
    0x49EF: 'chán,zhàn',  # 䧯
    0x49F0: 'hùn',  # 䧰
    # 0x49F1: '',  # 䧱
    0x49F2: 'hàn',  # 䧲
    0x49F3: 'cí,cǐ',  # 䧳
    0x49F4: 'zhī',  # 䧴
    0x49F5: 'qí,shěn,zhèn',  # 䧵
    0x49F6: 'kuí',  # 䧶
    0x49F7: 'róu',  # 䧷
    # 0x49F8: '',  # 䧸
    # 0x49F9: '',  # 䧹
    0x49FA: 'xióng',  # 䧺
    # 0x49FB: '',  # 䧻
    0x49FC: 'hú',  # 䧼
    0x49FD: 'cuǐ',  # 䧽
    # 0x49FE: '',  # 䧾
    0x49FF: 'què',  # 䧿
    0x4A00: 'dí,dì',  # 䨀
    0x4A01: 'chè,wù,yù',  # 䨁
    # 0x4A02: '',  # 䨂
    # 0x4A03: '',  # 䨃
    0x4A04: 'yàn,ān',  # 䨄
    0x4A05: 'liáo',  # 䨅
    0x4A06: 'bí,bì,xù',  # 䨆
    # 0x4A07: '',  # 䨇
    # 0x4A08: '',  # 䨈
    # 0x4A09: '',  # 䨉
    0x4A0A: 'yuān',  # 䨊
    # 0x4A0B: '',  # 䨋
    0x4A0C: 'báo,bó',  # 䨌
    0x4A0D: 'yǐng',  # 䨍
    0x4A0E: 'hóng',  # 䨎
    0x4A0F: 'cí',  # 䨏
    0x4A10: 'qià,xiá',  # 䨐
    0x4A11: 'tí',  # 䨑
    0x4A12: 'yù',  # 䨒
    0x4A13: 'léi,lèi',  # 䨓
    0x4A14: 'báo',  # 䨔
    # 0x4A15: '',  # 䨕
    0x4A16: 'jì',  # 䨖
    0x4A17: 'fú',  # 䨗
    0x4A18: 'xiàn',  # 䨘
    0x4A19: 'cén,yà,yín',  # 䨙
    # 0x4A1A: '',  # 䨚
    0x4A1B: 'sè',  # 䨛
    # 0x4A1C: '',  # 䨜
    # 0x4A1D: '',  # 䨝
    0x4A1E: 'yǔ,yù',  # 䨞
    # 0x4A1F: '',  # 䨟
    0x4A20: 'ǎi',  # 䨠
    0x4A21: 'hán',  # 䨡
    0x4A22: 'dàn,dí,gào,tán',  # 䨢
    0x4A23: 'gé,gèng',  # 䨣
    0x4A24: 'dí',  # 䨤
    0x4A25: 'hù,huò',  # 䨥
    0x4A26: 'páng',  # 䨦
    # 0x4A27: '',  # 䨧
    # 0x4A28: '',  # 䨨
    0x4A29: 'líng',  # 䨩
    0x4A2A: 'mái',  # 䨪
    0x4A2B: 'mài,màn',  # 䨫
    0x4A2C: 'lián',  # 䨬
    # 0x4A2D: '',  # 䨭
    0x4A2E: 'xuě',  # 䨮
    0x4A2F: 'zhèn',  # 䨯
    0x4A30: 'pò',  # 䨰
    0x4A31: 'fù',  # 䨱
    0x4A32: 'nóu',  # 䨲
    0x4A33: 'xì',  # 䨳
    0x4A34: 'duì,wèng',  # 䨴
    0x4A35: 'dàn',  # 䨵
    0x4A36: 'yǔn',  # 䨶
    0x4A37: 'xiàn',  # 䨷
    0x4A38: 'yǐn',  # 䨸
    # 0x4A39: '',  # 䨹
    0x4A3A: 'duì',  # 䨺
    0x4A3B: 'bèng',  # 䨻
    0x4A3C: 'hù',  # 䨼
    0x4A3D: 'fěi',  # 䨽
    0x4A3E: 'fěi',  # 䨾
    0x4A3F: 'qián,zá',  # 䨿
    0x4A40: 'bèi',  # 䩀
    0x4A41: 'fēi',  # 䩁
    # 0x4A42: '',  # 䩂
    0x4A43: 'shì',  # 䩃
    0x4A44: 'tiǎn',  # 䩄
    0x4A45: 'zhǎn',  # 䩅
    0x4A46: 'jiǎn,zhǎn',  # 䩆
    # 0x4A47: '',  # 䩇
    0x4A48: 'huì,wèi,xuě',  # 䩈
    0x4A49: 'fǔ',  # 䩉
    0x4A4A: 'wǎn,wò',  # 䩊
    0x4A4B: 'mǒ',  # 䩋
    0x4A4C: 'qiáo,jiāo',  # 䩌
    0x4A4D: 'liǎo',  # 䩍
    # 0x4A4E: '',  # 䩎
    0x4A4F: 'miè',  # 䩏
    0x4A50: 'gé,jí',  # 䩐
    0x4A51: 'hóng',  # 䩑
    0x4A52: 'yú',  # 䩒
    0x4A53: 'qí',  # 䩓
    0x4A54: 'duò',  # 䩔
    0x4A55: 'áng',  # 䩕
    # 0x4A56: '',  # 䩖
    0x4A57: 'bà',  # 䩗
    0x4A58: 'dì',  # 䩘
    0x4A59: 'xuàn',  # 䩙
    0x4A5A: 'dì,diàn',  # 䩚
    0x4A5B: 'bì',  # 䩛
    0x4A5C: 'zhòu',  # 䩜
    0x4A5D: 'páo',  # 䩝
    0x4A5E: 'nián,tiǎn,tié,wěi',  # 䩞
    0x4A5F: 'yí,tì',  # 䩟
    # 0x4A60: '',  # 䩠
    0x4A61: 'jiá',  # 䩡
    0x4A62: 'dá,zhì',  # 䩢
    0x4A63: 'duǒ,tú,tuì',  # 䩣
    0x4A64: 'xì,xié',  # 䩤
    0x4A65: 'dàn',  # 䩥
    0x4A66: 'tiáo,zuò',  # 䩦
    0x4A67: 'xiè',  # 䩧
    0x4A68: 'chàng',  # 䩨
    0x4A69: 'yuǎn',  # 䩩
    0x4A6A: 'guǎn',  # 䩪
    0x4A6B: 'liǎng',  # 䩫
    0x4A6C: 'běng,fěng',  # 䩬
    # 0x4A6D: '',  # 䩭
    0x4A6E: 'lù',  # 䩮
    0x4A6F: 'jí',  # 䩯
    0x4A70: 'xuàn',  # 䩰
    0x4A71: 'shù',  # 䩱
    # 0x4A72: '',  # 䩲
    0x4A73: 'shǔ,sù',  # 䩳
    0x4A74: 'hú',  # 䩴
    0x4A75: 'yùn',  # 䩵
    0x4A76: 'chǎn,chěng',  # 䩶
    # 0x4A77: '',  # 䩷
    0x4A78: 'róng,rǒng',  # 䩸
    0x4A79: 'é',  # 䩹
    # 0x4A7A: '',  # 䩺
    0x4A7B: 'bà',  # 䩻
    0x4A7C: 'féng',  # 䩼
    # 0x4A7D: '',  # 䩽
    0x4A7E: 'zhè',  # 䩾
    0x4A7F: 'fén',  # 䩿
    0x4A80: 'guǎn,ruǎn',  # 䪀
    0x4A81: 'bǔ',  # 䪁
    0x4A82: 'gé',  # 䪂
    # 0x4A83: '',  # 䪃
    0x4A84: 'huáng',  # 䪄
    0x4A85: 'dú',  # 䪅
    0x4A86: 'tǐ',  # 䪆
    0x4A87: 'bó',  # 䪇
    0x4A88: 'qiǎn,qiàn',  # 䪈
    0x4A89: 'là,liè',  # 䪉
    0x4A8A: 'lóng',  # 䪊
    0x4A8B: 'wèi',  # 䪋
    0x4A8C: 'zhàn',  # 䪌
    0x4A8D: 'lán,làn',  # 䪍
    0x4A8E: 'suī',  # 䪎
    0x4A8F: 'nà,dā',  # 䪏
    0x4A90: 'bì,pì',  # 䪐
    0x4A91: 'tuó',  # 䪑
    0x4A92: 'jiào,zhì,zhù',  # 䪒
    # 0x4A93: '',  # 䪓
    0x4A94: 'bǔ',  # 䪔
    0x4A95: 'jú',  # 䪕
    0x4A96: 'pò',  # 䪖
    0x4A97: 'xiá',  # 䪗
    0x4A98: 'wěi',  # 䪘
    0x4A99: 'fú,pò',  # 䪙
    0x4A9A: 'hè,tà',  # 䪚
    0x4A9B: 'fán',  # 䪛
    0x4A9C: 'chàn',  # 䪜
    0x4A9D: 'hù',  # 䪝
    0x4A9E: 'zá',  # 䪞
    # 0x4A9F: '',  # 䪟
    # 0x4AA0: '',  # 䪠
    # 0x4AA1: '',  # 䪡
    0x4AA2: 'jī',  # 䪢
    # 0x4AA3: '',  # 䪣
    0x4AA4: 'fán',  # 䪤
    0x4AA5: 'xiè',  # 䪥
    0x4AA6: 'hóng',  # 䪦
    0x4AA7: 'chí',  # 䪧
    0x4AA8: 'báo,qú',  # 䪨
    0x4AA9: 'yín',  # 䪩
    # 0x4AAA: '',  # 䪪
    # 0x4AAB: '',  # 䪫
    0x4AAC: 'bó,pú',  # 䪬
    0x4AAD: 'ruǎn',  # 䪭
    0x4AAE: 'chǒu',  # 䪮
    0x4AAF: 'yíng',  # 䪯
    # 0x4AB0: '',  # 䪰
    0x4AB1: 'gǎi',  # 䪱
    # 0x4AB2: '',  # 䪲
    0x4AB3: 'yǔn',  # 䪳
    0x4AB4: 'zhěn',  # 䪴
    0x4AB5: 'yǎ',  # 䪵
    # 0x4AB6: '',  # 䪶
    0x4AB7: 'hòu',  # 䪷
    0x4AB8: 'mín',  # 䪸
    0x4AB9: 'péi',  # 䪹
    0x4ABA: 'gé',  # 䪺
    0x4ABB: 'biàn',  # 䪻
    0x4ABC: 'zhuō',  # 䪼
    0x4ABD: 'hào',  # 䪽
    0x4ABE: 'mí,zhěn',  # 䪾
    0x4ABF: 'shěng,xìn',  # 䪿
    0x4AC0: 'gěn',  # 䫀
    0x4AC1: 'bì',  # 䫁
    0x4AC2: 'duǒ',  # 䫂
    0x4AC3: 'chún',  # 䫃
    0x4AC4: 'chuà',  # 䫄
    0x4AC5: 'sàn',  # 䫅
    0x4AC6: 'chéng,zhèng',  # 䫆
    0x4AC7: 'rán',  # 䫇
    0x4AC8: 'zèn,cén',  # 䫈
    0x4AC9: 'mào',  # 䫉
    0x4ACA: 'bó,péi',  # 䫊
    0x4ACB: 'tuí',  # 䫋
    0x4ACC: 'pǐ',  # 䫌
    0x4ACD: 'fǔ',  # 䫍
    # 0x4ACE: '',  # 䫎
    0x4ACF: 'qī',  # 䫏
    0x4AD0: 'lín',  # 䫐
    # 0x4AD1: '',  # 䫑
    0x4AD2: 'mén',  # 䫒
    0x4AD3: 'wú',  # 䫓
    0x4AD4: 'qì,qiè,xì',  # 䫔
    0x4AD5: 'zhì',  # 䫕
    0x4AD6: 'chěn,huǐ,nòu,shèn,tíng,yà,zhù',  # 䫖
    0x4AD7: 'xiá,xià',  # 䫗
    0x4AD8: 'hé',  # 䫘
    0x4AD9: 'sǎng',  # 䫙
    # 0x4ADA: '',  # 䫚
    0x4ADB: 'hóu',  # 䫛
    # 0x4ADC: '',  # 䫜
    0x4ADD: 'fǔ,fù',  # 䫝
    0x4ADE: 'ráo,qiāo',  # 䫞
    0x4ADF: 'hùn',  # 䫟
    0x4AE0: 'péi,pī',  # 䫠
    0x4AE1: 'qiàn,yán',  # 䫡
    # 0x4AE2: '',  # 䫢
    0x4AE3: 'xí',  # 䫣
    0x4AE4: 'míng',  # 䫤
    0x4AE5: 'kuǐ,wěi',  # 䫥
    0x4AE6: 'gé,kài',  # 䫦
    # 0x4AE7: '',  # 䫧
    0x4AE8: 'ào',  # 䫨
    0x4AE9: 'sǎn',  # 䫩
    0x4AEA: 'shuǎng',  # 䫪
    0x4AEB: 'lóu,lòu',  # 䫫
    0x4AEC: 'zhěn',  # 䫬
    0x4AED: 'huì',  # 䫭
    0x4AEE: 'cán,cǎn,tì',  # 䫮
    # 0x4AEF: '',  # 䫯
    0x4AF0: 'lìn,lǐn',  # 䫰
    0x4AF1: 'ná,rú',  # 䫱
    0x4AF2: 'hàn,kǎn',  # 䫲
    0x4AF3: 'dú',  # 䫳
    0x4AF4: 'jìn',  # 䫴
    0x4AF5: 'mián',  # 䫵
    0x4AF6: 'fán',  # 䫶
    0x4AF7: 'è',  # 䫷
    0x4AF8: 'náo',  # 䫸
    0x4AF9: 'hóng',  # 䫹
    0x4AFA: 'hóng,hòu',  # 䫺
    0x4AFB: 'xué,yù',  # 䫻
    0x4AFC: 'xuè',  # 䫼
    # 0x4AFD: '',  # 䫽
    0x4AFE: 'bī,bì',  # 䫾
    # 0x4AFF: '',  # 䫿
    0x4B00: 'yǒu',  # 䬀
    0x4B01: 'yí',  # 䬁
    0x4B02: 'xuè,yuè',  # 䬂
    0x4B03: 'sà',  # 䬃
    0x4B04: 'yù',  # 䬄
    0x4B05: 'lì,liè,xié',  # 䬅
    0x4B06: 'lì',  # 䬆
    0x4B07: 'yuàn',  # 䬇
    0x4B08: 'duì',  # 䬈
    0x4B09: 'hào',  # 䬉
    0x4B0A: 'qiè,shà',  # 䬊
    0x4B0B: 'léng',  # 䬋
    # 0x4B0C: '',  # 䬌
    0x4B0D: 'hū',  # 䬍
    0x4B0E: 'guó',  # 䬎
    0x4B0F: 'bù,fǒu',  # 䬏
    0x4B10: 'wěi',  # 䬐
    0x4B11: 'wèi',  # 䬑
    0x4B12: 'sōu',  # 䬒
    0x4B13: 'àn,ǎng',  # 䬓
    0x4B14: 'xù,yú',  # 䬔
    0x4B15: 'shǎng',  # 䬕
    0x4B16: 'héng',  # 䬖
    0x4B17: 'yáng',  # 䬗
    # 0x4B18: '',  # 䬘
    0x4B19: 'yáo',  # 䬙
    # 0x4B1A: '',  # 䬚
    0x4B1B: 'bì,yù',  # 䬛
    0x4B1C: 'chī',  # 䬜
    0x4B1D: 'héng,hòng',  # 䬝
    0x4B1E: 'táo',  # 䬞
    0x4B1F: 'liú',  # 䬟
    # 0x4B20: '',  # 䬠
    0x4B21: 'zhù',  # 䬡
    0x4B22: 'tāo',  # 䬢
    0x4B23: 'qì',  # 䬣
    0x4B24: 'cháo,zàn,zuò',  # 䬤
    0x4B25: 'yì',  # 䬥
    0x4B26: 'dòu',  # 䬦
    0x4B27: 'yuán',  # 䬧
    0x4B28: 'cù,jiù,zú',  # 䬨
    # 0x4B29: '',  # 䬩
    0x4B2A: 'bó,fù',  # 䬪
    0x4B2B: 'cǎn,tí',  # 䬫
    0x4B2C: 'yǎng',  # 䬬
    # 0x4B2D: '',  # 䬭
    0x4B2E: 'yí',  # 䬮
    0x4B2F: 'nián',  # 䬯
    0x4B30: 'shào',  # 䬰
    0x4B31: 'bèn',  # 䬱
    # 0x4B32: '',  # 䬲
    0x4B33: 'bǎn',  # 䬳
    0x4B34: 'mò',  # 䬴
    0x4B35: 'ài',  # 䬵
    0x4B36: 'èn',  # 䬶
    0x4B37: 'shě',  # 䬷
    # 0x4B38: '',  # 䬸
    0x4B39: 'zhì',  # 䬹
    0x4B3A: 'yàng',  # 䬺
    0x4B3B: 'jiàn,kǎn',  # 䬻
    0x4B3C: 'yuàn',  # 䬼
    0x4B3D: 'duì,shuì',  # 䬽
    0x4B3E: 'tí',  # 䬾
    0x4B3F: 'wěi,wèi',  # 䬿
    0x4B40: 'xùn',  # 䭀
    0x4B41: 'zhì',  # 䭁
    0x4B42: 'yì',  # 䭂
    0x4B43: 'rěn',  # 䭃
    0x4B44: 'shì',  # 䭄
    0x4B45: 'hú',  # 䭅
    0x4B46: 'nè',  # 䭆
    0x4B47: 'yì',  # 䭇
    0x4B48: 'jiàn',  # 䭈
    0x4B49: 'suǐ',  # 䭉
    0x4B4A: 'yǐng',  # 䭊
    0x4B4B: 'bǎo',  # 䭋
    0x4B4C: 'hú',  # 䭌
    0x4B4D: 'hú',  # 䭍
    0x4B4E: 'xié,yè',  # 䭎
    # 0x4B4F: '',  # 䭏
    0x4B50: 'yàng',  # 䭐
    0x4B51: 'lián,qiàn,xiàn',  # 䭑
    # 0x4B52: '',  # 䭒
    0x4B53: 'èn,wèn',  # 䭓
    # 0x4B54: '',  # 䭔
    0x4B55: 'jiàn,zǎn',  # 䭕
    0x4B56: 'zhù',  # 䭖
    0x4B57: 'yǐng',  # 䭗
    0x4B58: 'yàn,yǐng',  # 䭘
    0x4B59: 'jǐn',  # 䭙
    0x4B5A: 'chuáng,nè',  # 䭚
    0x4B5B: 'dàn',  # 䭛
    # 0x4B5C: '',  # 䭜
    0x4B5D: 'kuài',  # 䭝
    0x4B5E: 'yì',  # 䭞
    0x4B5F: 'yè',  # 䭟
    0x4B60: 'jiǎn,qiàn',  # 䭠
    0x4B61: 'èn,wèn',  # 䭡
    0x4B62: 'níng',  # 䭢
    0x4B63: 'cí',  # 䭣
    0x4B64: 'qiǎn',  # 䭤
    0x4B65: 'xuè,yàng,yào,zhòu',  # 䭥
    0x4B66: 'bó',  # 䭦
    0x4B67: 'mǐ',  # 䭧
    0x4B68: 'shuì',  # 䭨
    0x4B69: 'mì,mó',  # 䭩
    0x4B6A: 'liáng',  # 䭪
    0x4B6B: 'qǐ',  # 䭫
    0x4B6C: 'qǐ',  # 䭬
    0x4B6D: 'shǒu,shú,shù,tù',  # 䭭
    0x4B6E: 'bì,fú',  # 䭮
    0x4B6F: 'bó',  # 䭯
    0x4B70: 'běng,bèng',  # 䭰
    0x4B71: 'bié',  # 䭱
    0x4B72: 'nǐ,yǐ',  # 䭲
    0x4B73: 'wèi',  # 䭳
    0x4B74: 'huán,yuàn',  # 䭴
    0x4B75: 'fán',  # 䭵
    0x4B76: 'qí',  # 䭶
    0x4B77: 'liú,máo',  # 䭷
    0x4B78: 'fù',  # 䭸
    0x4B79: 'áng,àng',  # 䭹
    0x4B7A: 'áng',  # 䭺
    # 0x4B7B: '',  # 䭻
    0x4B7C: 'qí',  # 䭼
    0x4B7D: 'qún',  # 䭽
    0x4B7E: 'tuó',  # 䭾
    0x4B7F: 'yì',  # 䭿
    0x4B80: 'bó',  # 䮀
    0x4B81: 'pián',  # 䮁
    0x4B82: 'bó',  # 䮂
    # 0x4B83: '',  # 䮃
    0x4B84: 'xuán',  # 䮄
    # 0x4B85: '',  # 䮅
    # 0x4B86: '',  # 䮆
    0x4B87: 'yù',  # 䮇
    0x4B88: 'chí',  # 䮈
    0x4B89: 'lú',  # 䮉
    0x4B8A: 'yí',  # 䮊
    0x4B8B: 'lì,liè',  # 䮋
    # 0x4B8C: '',  # 䮌
    0x4B8D: 'niǎo,xìng',  # 䮍
    0x4B8E: 'xì',  # 䮎
    0x4B8F: 'wú',  # 䮏
    # 0x4B90: '',  # 䮐
    0x4B91: 'lèi',  # 䮑
    # 0x4B92: '',  # 䮒
    0x4B93: 'zhào',  # 䮓
    0x4B94: 'zuǐ,zuī',  # 䮔
    0x4B95: 'chuò',  # 䮕
    # 0x4B96: '',  # 䮖
    0x4B97: 'àn,niù,yàn',  # 䮗
    0x4B98: 'ér,ní,pài,pó',  # 䮘
    0x4B99: 'yù',  # 䮙
    0x4B9A: 'lèng',  # 䮚
    0x4B9B: 'fù',  # 䮛
    0x4B9C: 'shà,zhá',  # 䮜
    0x4B9D: 'huán,huǎn,hún',  # 䮝
    0x4B9E: 'chù,chǔn',  # 䮞
    0x4B9F: 'sǒu',  # 䮟
    # 0x4BA0: '',  # 䮠
    0x4BA1: 'bì',  # 䮡
    0x4BA2: 'dié',  # 䮢
    # 0x4BA3: '',  # 䮣
    0x4BA4: 'dí,hè,hé',  # 䮤
    0x4BA5: 'lì',  # 䮥
    # 0x4BA6: '',  # 䮦
    0x4BA7: 'hán,hàn',  # 䮧
    0x4BA8: 'zǎi',  # 䮨
    0x4BA9: 'gú,gǔ',  # 䮩
    0x4BAA: 'chéng',  # 䮪
    0x4BAB: 'lóu',  # 䮫
    0x4BAC: 'mò',  # 䮬
    0x4BAD: 'mì',  # 䮭
    0x4BAE: 'mài',  # 䮮
    0x4BAF: 'ào',  # 䮯
    0x4BB0: 'zhé',  # 䮰
    0x4BB1: 'zhú',  # 䮱
    0x4BB2: 'huáng',  # 䮲
    0x4BB3: 'fán',  # 䮳
    0x4BB4: 'dèng',  # 䮴
    0x4BB5: 'tóng,yǒng',  # 䮵
    # 0x4BB6: '',  # 䮶
    0x4BB7: 'dú',  # 䮷
    0x4BB8: 'hú,mú,wò',  # 䮸
    0x4BB9: 'wèi',  # 䮹
    0x4BBA: 'jì',  # 䮺
    0x4BBB: 'chì,dǎo,dào,děi',  # 䮻
    0x4BBC: 'lín',  # 䮼
    # 0x4BBD: '',  # 䮽
    0x4BBE: 'páng',  # 䮾
    0x4BBF: 'jiǎn',  # 䮿
    0x4BC0: 'niè',  # 䯀
    0x4BC1: 'luó',  # 䯁
    0x4BC2: 'jí,shēn',  # 䯂
    # 0x4BC3: '',  # 䯃
    # 0x4BC4: '',  # 䯄
    0x4BC5: 'niè',  # 䯅
    0x4BC6: 'yì',  # 䯆
    # 0x4BC7: '',  # 䯇
    0x4BC8: 'wán',  # 䯈
    0x4BC9: 'yà,wā',  # 䯉
    0x4BCA: 'qià',  # 䯊
    0x4BCB: 'bó',  # 䯋
    0x4BCC: 'kāo',  # 䯌
    0x4BCD: 'líng',  # 䯍
    0x4BCE: 'gàn',  # 䯎
    0x4BCF: 'huó,guā',  # 䯏
    0x4BD0: 'hái',  # 䯐
    # 0x4BD1: '',  # 䯑
    0x4BD2: 'héng',  # 䯒
    0x4BD3: 'kuí',  # 䯓
    0x4BD4: 'cén,zé',  # 䯔
    # 0x4BD5: '',  # 䯕
    0x4BD6: 'láng',  # 䯖
    0x4BD7: 'bì',  # 䯗
    0x4BD8: 'huàn',  # 䯘
    0x4BD9: 'pò',  # 䯙
    0x4BDA: 'ǒu,yǎo',  # 䯚
    0x4BDB: 'jiǎn,wàn',  # 䯛
    0x4BDC: 'tì',  # 䯜
    0x4BDD: 'suǐ',  # 䯝
    0x4BDE: 'kuā',  # 䯞
    0x4BDF: 'duì,xiá',  # 䯟
    0x4BE0: 'ǎo,ào',  # 䯠
    0x4BE1: 'jiǎn,jiàn,qiàn',  # 䯡
    0x4BE2: 'mó,mǒ',  # 䯢
    0x4BE3: 'guì,kuì',  # 䯣
    0x4BE4: 'kuài',  # 䯤
    0x4BE5: 'àn,qì',  # 䯥
    0x4BE6: 'mà',  # 䯦
    0x4BE7: 'qǐng',  # 䯧
    0x4BE8: 'fén,hè',  # 䯨
    # 0x4BE9: '',  # 䯩
    0x4BEA: 'kǎo',  # 䯪
    0x4BEB: 'hào,shà',  # 䯫
    0x4BEC: 'duǒ',  # 䯬
    # 0x4BED: '',  # 䯭
    0x4BEE: 'nái',  # 䯮
    # 0x4BEF: '',  # 䯯
    0x4BF0: 'jiè',  # 䯰
    0x4BF1: 'fù,pēi,pī',  # 䯱
    0x4BF2: 'pá',  # 䯲
    # 0x4BF3: '',  # 䯳
    0x4BF4: 'cháng',  # 䯴
    0x4BF5: 'niè',  # 䯵
    0x4BF6: 'mán',  # 䯶
    # 0x4BF7: '',  # 䯷
    0x4BF8: 'cì',  # 䯸
    # 0x4BF9: '',  # 䯹
    0x4BFA: 'kuò',  # 䯺
    # 0x4BFB: '',  # 䯻
    0x4BFC: 'dí',  # 䯼
    0x4BFD: 'fǔ,póu',  # 䯽
    0x4BFE: 'tiáo',  # 䯾
    0x4BFF: 'zú,zuó',  # 䯿
    0x4C00: 'wǒ',  # 䰀
    0x4C01: 'fèi',  # 䰁
    0x4C02: 'cài',  # 䰂
    0x4C03: 'péng',  # 䰃
    0x4C04: 'shì',  # 䰄
    # 0x4C05: '',  # 䰅
    0x4C06: 'róu',  # 䰆
    0x4C07: 'qí',  # 䰇
    0x4C08: 'chǎ,cuó,cuǒ',  # 䰈
    0x4C09: 'pán,pàn',  # 䰉
    0x4C0A: 'bó',  # 䰊
    0x4C0B: 'mán',  # 䰋
    0x4C0C: 'zǒng',  # 䰌
    0x4C0D: 'cì,qī,xiū',  # 䰍
    0x4C0E: 'guì,huǐ,kuì',  # 䰎
    0x4C0F: 'jì',  # 䰏
    0x4C10: 'lán',  # 䰐
    # 0x4C11: '',  # 䰑
    0x4C12: 'méng',  # 䰒
    0x4C13: 'mián',  # 䰓
    0x4C14: 'pán',  # 䰔
    0x4C15: 'lú',  # 䰕
    0x4C16: 'cuán',  # 䰖
    0x4C17: 'jiū',  # 䰗
    0x4C18: 'liú',  # 䰘
    0x4C19: 'yǐ',  # 䰙
    0x4C1A: 'wén',  # 䰚
    0x4C1B: 'lì',  # 䰛
    0x4C1C: 'lì',  # 䰜
    0x4C1D: 'zèng',  # 䰝
    0x4C1E: 'zhǔ',  # 䰞
    0x4C1F: 'hún',  # 䰟
    0x4C20: 'shén,shēn',  # 䰠
    0x4C21: 'chì',  # 䰡
    0x4C22: 'xìng',  # 䰢
    0x4C23: 'wǎng',  # 䰣
    # 0x4C24: '',  # 䰤
    0x4C25: 'huò,jì,shè,yù',  # 䰥
    0x4C26: 'pǐ,pì',  # 䰦
    0x4C27: 'hū',  # 䰧
    0x4C28: 'mèi',  # 䰨
    0x4C29: 'chě,chǐ',  # 䰩
    0x4C2A: 'mèi',  # 䰪
    0x4C2B: 'cháo',  # 䰫
    0x4C2C: 'jú',  # 䰬
    0x4C2D: 'nòu,rú',  # 䰭
    # 0x4C2E: '',  # 䰮
    0x4C2F: 'nǐ,rán,yì',  # 䰯
    0x4C30: 'rú',  # 䰰
    0x4C31: 'líng',  # 䰱
    0x4C32: 'yà',  # 䰲
    # 0x4C33: '',  # 䰳
    0x4C34: 'qì,zhì',  # 䰴
    # 0x4C35: '',  # 䰵
    # 0x4C36: '',  # 䰶
    0x4C37: 'bàng,bó',  # 䰷
    # 0x4C38: '',  # 䰸
    0x4C39: 'zé',  # 䰹
    0x4C3A: 'jiè',  # 䰺
    0x4C3B: 'yú',  # 䰻
    0x4C3C: 'xín,qín',  # 䰼
    0x4C3D: 'bèi',  # 䰽
    0x4C3E: 'bā',  # 䰾
    0x4C3F: 'tuó',  # 䰿
    # 0x4C40: '',  # 䱀
    0x4C41: 'qiáo',  # 䱁
    0x4C42: 'yǒu',  # 䱂
    0x4C43: 'dǐ,zhì',  # 䱃
    0x4C44: 'jiè',  # 䱄
    0x4C45: 'mò',  # 䱅
    0x4C46: 'shéng',  # 䱆
    0x4C47: 'shàn,táo',  # 䱇
    0x4C48: 'qí,yì',  # 䱈
    0x4C49: 'shàn',  # 䱉
    0x4C4A: 'mǐ',  # 䱊
    0x4C4B: 'dǎn,gǒng',  # 䱋
    0x4C4C: 'yí',  # 䱌
    0x4C4D: 'gèng',  # 䱍
    0x4C4E: 'gèng',  # 䱎
    0x4C4F: 'tǒu',  # 䱏
    # 0x4C50: '',  # 䱐
    0x4C51: 'xué',  # 䱑
    0x4C52: 'yì',  # 䱒
    0x4C53: 'tíng',  # 䱓
    0x4C54: 'tiáo',  # 䱔
    0x4C55: 'móu',  # 䱕
    0x4C56: 'liú,liǔ',  # 䱖
    # 0x4C57: '',  # 䱗
    0x4C58: 'lí',  # 䱘
    # 0x4C59: '',  # 䱙
    0x4C5A: 'lù',  # 䱚
    0x4C5B: 'huò',  # 䱛
    0x4C5C: 'cuò,què',  # 䱜
    0x4C5D: 'bà,pái',  # 䱝
    0x4C5E: 'liú,nài,wěi',  # 䱞
    0x4C5F: 'jù',  # 䱟
    0x4C60: 'zhàn',  # 䱠
    0x4C61: 'jú',  # 䱡
    # 0x4C62: '',  # 䱢
    0x4C63: 'zú',  # 䱣
    0x4C64: 'xiàn',  # 䱤
    0x4C65: 'zhì,jì',  # 䱥
    # 0x4C66: '',  # 䱦
    # 0x4C67: '',  # 䱧
    0x4C68: 'zhì',  # 䱨
    # 0x4C69: '',  # 䱩
    # 0x4C6A: '',  # 䱪
    0x4C6B: 'là',  # 䱫
    0x4C6C: 'xū',  # 䱬
    0x4C6D: 'gèng',  # 䱭
    0x4C6E: 'é',  # 䱮
    0x4C6F: 'mú',  # 䱯
    0x4C70: 'zhòng',  # 䱰
    0x4C71: 'dì,tí',  # 䱱
    0x4C72: 'yán',  # 䱲
    # 0x4C73: '',  # 䱳
    0x4C74: 'gèng',  # 䱴
    0x4C75: 'wēng',  # 䱵
    0x4C76: 'láng',  # 䱶
    0x4C77: 'yú',  # 䱷
    0x4C78: 'qiū,sōu',  # 䱸
    0x4C79: 'nà,zhǎ',  # 䱹
    0x4C7A: 'hái',  # 䱺
    0x4C7B: 'huá',  # 䱻
    0x4C7C: 'zhǎn',  # 䱼
    # 0x4C7D: '',  # 䱽
    0x4C7E: 'lóu,yú',  # 䱾
    0x4C7F: 'chàn',  # 䱿
    0x4C80: 'dié,suì,zhì,zòu',  # 䲀
    0x4C81: 'wèi',  # 䲁
    0x4C82: 'xuán',  # 䲂
    0x4C83: 'zǎo',  # 䲃
    0x4C84: 'mín,mǐn',  # 䲄
    0x4C85: 'guī',  # 䲅
    # 0x4C86: '',  # 䲆
    # 0x4C87: '',  # 䲇
    # 0x4C88: '',  # 䲈
    # 0x4C89: '',  # 䲉
    0x4C8A: 'tuǒ,duò',  # 䲊
    0x4C8B: 'cén',  # 䲋
    0x4C8C: 'kuǎn',  # 䲌
    0x4C8D: 'téng',  # 䲍
    0x4C8E: 'něi',  # 䲎
    0x4C8F: 'láo',  # 䲏
    0x4C90: 'lǔ',  # 䲐
    0x4C91: 'yí',  # 䲑
    0x4C92: 'xiè',  # 䲒
    0x4C93: 'yǎn',  # 䲓
    0x4C94: 'qíng,qìng,jīng',  # 䲔
    0x4C95: 'pǔ,pù',  # 䲕
    0x4C96: 'chóu',  # 䲖
    0x4C97: 'xián',  # 䲗
    0x4C98: 'guǎn,kàng,wéi',  # 䲘
    0x4C99: 'jié',  # 䲙
    0x4C9A: 'lài,làn',  # 䲚
    0x4C9B: 'méng',  # 䲛
    0x4C9C: 'yè',  # 䲜
    # 0x4C9D: '',  # 䲝
    0x4C9E: 'lì,luǒ',  # 䲞
    0x4C9F: 'yìn',  # 䲟
    # 0x4CA0: '',  # 䲠
    0x4CA1: 'qiū',  # 䲡
    0x4CA2: 'téng',  # 䲢
    0x4CA3: 'yú',  # 䲣
    # 0x4CA4: '',  # 䲤
    # 0x4CA5: '',  # 䲥
    0x4CA6: 'chá,dài,dì,tuǒ',  # 䲦
    0x4CA7: 'dù,shuì',  # 䲧
    0x4CA8: 'hóng',  # 䲨
    0x4CA9: 'shī',  # 䲩
    0x4CAA: 'xì',  # 䲪
    # 0x4CAB: '',  # 䲫
    0x4CAC: 'qí',  # 䲬
    # 0x4CAD: '',  # 䲭
    0x4CAE: 'yuán',  # 䲮
    0x4CAF: 'jí',  # 䲯
    0x4CB0: 'yùn',  # 䲰
    0x4CB1: 'fǎng',  # 䲱
    # 0x4CB2: '',  # 䲲
    0x4CB3: 'háng',  # 䲳
    0x4CB4: 'zhèn',  # 䲴
    0x4CB5: 'hù,què',  # 䲵
    # 0x4CB6: '',  # 䲶
    # 0x4CB7: '',  # 䲷
    0x4CB8: 'jiè',  # 䲸
    0x4CB9: 'péi',  # 䲹
    0x4CBA: 'gàn',  # 䲺
    0x4CBB: 'xuán,yuán',  # 䲻
    # 0x4CBC: '',  # 䲼
    0x4CBD: 'dǎo,shí',  # 䲽
    0x4CBE: 'qiǎo',  # 䲾
    0x4CBF: 'cí',  # 䲿
    0x4CC0: 'dié',  # 䳀
    0x4CC1: 'bá,bǐn,bó,yuán',  # 䳁
    0x4CC2: 'tiáo',  # 䳂
    0x4CC3: 'wǎn',  # 䳃
    0x4CC4: 'cí',  # 䳄
    0x4CC5: 'zhǐ',  # 䳅
    0x4CC6: 'bái',  # 䳆
    0x4CC7: 'wǔ',  # 䳇
    0x4CC8: 'bǎo',  # 䳈
    0x4CC9: 'dōng,dàn',  # 䳉
    0x4CCA: 'bá',  # 䳊
    0x4CCB: 'tóng,zhòng',  # 䳋
    # 0x4CCC: '',  # 䳌
    # 0x4CCD: '',  # 䳍
    0x4CCE: 'jiù',  # 䳎
    0x4CCF: 'guì',  # 䳏
    0x4CD0: 'cì',  # 䳐
    0x4CD1: 'yǒu,yù',  # 䳑
    0x4CD2: 'yuán',  # 䳒
    0x4CD3: 'lǎo',  # 䳓
    0x4CD4: 'jiù,jú',  # 䳔
    0x4CD5: 'fóu',  # 䳕
    0x4CD6: 'nèi,yè',  # 䳖
    0x4CD7: 'é',  # 䳗
    0x4CD8: 'é',  # 䳘
    0x4CD9: 'xǐng',  # 䳙
    0x4CDA: 'hé,kǎn',  # 䳚
    0x4CDB: 'yàn',  # 䳛
    0x4CDC: 'tú',  # 䳜
    0x4CDD: 'bù,diào,fǔ,pǒu',  # 䳝
    0x4CDE: 'běng',  # 䳞
    0x4CDF: 'kòu,míng,mǒ',  # 䳟
    0x4CE0: 'chuí,ruì,zhù',  # 䳠
    # 0x4CE1: '',  # 䳡
    0x4CE2: 'qí',  # 䳢
    0x4CE3: 'yuán',  # 䳣
    # 0x4CE4: '',  # 䳤
    # 0x4CE5: '',  # 䳥
    # 0x4CE6: '',  # 䳦
    0x4CE7: 'hóu',  # 䳧
    0x4CE8: 'huáng',  # 䳨
    # 0x4CE9: '',  # 䳩
    0x4CEA: 'juàn,tuán',  # 䳪
    0x4CEB: 'kuí',  # 䳫
    0x4CEC: 'è,yǎo,yì',  # 䳬
    0x4CED: 'jí',  # 䳭
    0x4CEE: 'mò',  # 䳮
    0x4CEF: 'chóng,chǒng',  # 䳯
    0x4CF0: 'bǎo',  # 䳰
    0x4CF1: 'wù',  # 䳱
    0x4CF2: 'zhèn',  # 䳲
    0x4CF3: 'xù',  # 䳳
    0x4CF4: 'dá,tà',  # 䳴
    0x4CF5: 'chì',  # 䳵
    # 0x4CF6: '',  # 䳶
    0x4CF7: 'cóng',  # 䳷
    0x4CF8: 'má,mái',  # 䳸
    0x4CF9: 'kòu',  # 䳹
    0x4CFA: 'yàn',  # 䳺
    0x4CFB: 'cán,chán,dié,zhàn',  # 䳻
    0x4CFC: 'ōu',  # 䳼
    0x4CFD: 'hè',  # 䳽
    # 0x4CFE: '',  # 䳾
    0x4CFF: 'lán,rán',  # 䳿
    0x4D00: 'tóng',  # 䴀
    0x4D01: 'yù',  # 䴁
    0x4D02: 'hàng,xiàng',  # 䴂
    0x4D03: 'náo',  # 䴃
    0x4D04: 'lì,shùn',  # 䴄
    0x4D05: 'fén',  # 䴅
    0x4D06: 'pú',  # 䴆
    0x4D07: 'líng',  # 䴇
    0x4D08: 'ǎo',  # 䴈
    0x4D09: 'xuán',  # 䴉
    0x4D0A: 'yí',  # 䴊
    0x4D0B: 'xuán',  # 䴋
    0x4D0C: 'méng',  # 䴌
    # 0x4D0D: '',  # 䴍
    0x4D0E: 'lěi',  # 䴎
    0x4D0F: 'yàn',  # 䴏
    0x4D10: 'bǎo',  # 䴐
    0x4D11: 'dié',  # 䴑
    0x4D12: 'líng',  # 䴒
    0x4D13: 'shī',  # 䴓
    0x4D14: 'jiāo',  # 䴔
    0x4D15: 'liè',  # 䴕
    0x4D16: 'jīng',  # 䴖
    0x4D17: 'jú',  # 䴗
    0x4D18: 'tī',  # 䴘
    0x4D19: 'pì',  # 䴙
    0x4D1A: 'gǎng',  # 䴚
    0x4D1B: 'jiǎo,tú,xì,xiào,yín',  # 䴛
    0x4D1C: 'huái',  # 䴜
    0x4D1D: 'bù,chuài',  # 䴝
    0x4D1E: 'dí',  # 䴞
    0x4D1F: 'huán,huàn',  # 䴟
    0x4D20: 'yǎo',  # 䴠
    0x4D21: 'lì',  # 䴡
    0x4D22: 'mí',  # 䴢
    # 0x4D23: '',  # 䴣
    # 0x4D24: '',  # 䴤
    0x4D25: 'jiā',  # 䴥
    0x4D26: 'rén,yín',  # 䴦
    # 0x4D27: '',  # 䴧
    # 0x4D28: '',  # 䴨
    0x4D29: 'piáo',  # 䴩
    0x4D2A: 'lù',  # 䴪
    0x4D2B: 'líng',  # 䴫
    0x4D2C: 'yì',  # 䴬
    0x4D2D: 'cái',  # 䴭
    0x4D2E: 'shàn',  # 䴮
    # 0x4D2F: '',  # 䴯
    0x4D30: 'shú',  # 䴰
    0x4D31: 'tuō',  # 䴱
    0x4D32: 'mò',  # 䴲
    0x4D33: 'hè,huá',  # 䴳
    0x4D34: 'tiè,nián',  # 䴴
    0x4D35: 'bǐng,zhuó',  # 䴵
    0x4D36: 'péng',  # 䴶
    0x4D37: 'hún',  # 䴷
    # 0x4D38: '',  # 䴸
    0x4D39: 'guǒ',  # 䴹
    0x4D3A: 'bù,cǎi,chàn',  # 䴺
    0x4D3B: 'lí',  # 䴻
    0x4D3C: 'chǎn,chàn',  # 䴼
    0x4D3D: 'bài,pí',  # 䴽
    0x4D3E: 'cuó,cuò,yè,zhěn,zǐ',  # 䴾
    0x4D3F: 'méng',  # 䴿
    0x4D40: 'suǒ',  # 䵀
    0x4D41: 'qiàng',  # 䵁
    0x4D42: 'zhí',  # 䵂
    0x4D43: 'kuàng',  # 䵃
    0x4D44: 'bí,bó,fèng,pěng',  # 䵄
    0x4D45: 'áo',  # 䵅
    0x4D46: 'méng',  # 䵆
    0x4D47: 'xiàn',  # 䵇
    0x4D48: 'kù',  # 䵈
    0x4D49: 'tóu',  # 䵉
    # 0x4D4A: '',  # 䵊
    0x4D4B: 'wěi',  # 䵋
    0x4D4C: 'xiān',  # 䵌
    # 0x4D4D: '',  # 䵍
    0x4D4E: 'tuān',  # 䵎
    0x4D4F: 'lǎo',  # 䵏
    0x4D50: 'chǎn,chàn',  # 䵐
    0x4D51: 'nì',  # 䵑
    0x4D52: 'nì',  # 䵒
    0x4D53: 'lí',  # 䵓
    0x4D54: 'dǒng',  # 䵔
    0x4D55: 'jù',  # 䵕
    0x4D56: 'jiàn,qiàn,xiàn',  # 䵖
    0x4D57: 'fú,bó',  # 䵗
    0x4D58: 'shà,shài',  # 䵘
    0x4D59: 'zhǎ',  # 䵙
    0x4D5A: 'tǎo',  # 䵚
    0x4D5B: 'jiàn,xiàn',  # 䵛
    0x4D5C: 'nǒng',  # 䵜
    0x4D5D: 'yà,yì',  # 䵝
    0x4D5E: 'jìng,qíng',  # 䵞
    0x4D5F: 'gǎn',  # 䵟
    0x4D60: 'dí',  # 䵠
    0x4D61: 'jiǎn',  # 䵡
    0x4D62: 'mèi,wèi',  # 䵢
    0x4D63: 'dá,zhǎn',  # 䵣
    0x4D64: 'jiǎn',  # 䵤
    0x4D65: 'shè,wán,yìng,yù',  # 䵥
    0x4D66: 'xiè',  # 䵦
    0x4D67: 'zài',  # 䵧
    0x4D68: 'máng',  # 䵨
    0x4D69: 'lí',  # 䵩
    0x4D6A: 'gùn',  # 䵪
    0x4D6B: 'yù',  # 䵫
    0x4D6C: 'tà',  # 䵬
    0x4D6D: 'zhè',  # 䵭
    0x4D6E: 'yàng',  # 䵮
    0x4D6F: 'tuǎn',  # 䵯
    # 0x4D70: '',  # 䵰
    0x4D71: 'hè,xì',  # 䵱
    0x4D72: 'diào',  # 䵲
    0x4D73: 'wèi',  # 䵳
    0x4D74: 'yùn,zèng',  # 䵴
    0x4D75: 'zhá,zhuó,chuā',  # 䵵
    0x4D76: 'qú',  # 䵶
    0x4D77: 'wā',  # 䵷
    # 0x4D78: '',  # 䵸
    0x4D79: 'zhī',  # 䵹
    0x4D7A: 'tǐng',  # 䵺
    0x4D7B: 'gǔ,hú,huì',  # 䵻
    # 0x4D7C: '',  # 䵼
    0x4D7D: 'cà',  # 䵽
    0x4D7E: 'fú',  # 䵾
    0x4D7F: 'tiè',  # 䵿
    0x4D80: 'tà',  # 䶀
    0x4D81: 'tà',  # 䶁
    0x4D82: 'zhuó',  # 䶂
    0x4D83: 'hán',  # 䶃
    0x4D84: 'píng',  # 䶄
    0x4D85: 'hé',  # 䶅
    # 0x4D86: '',  # 䶆
    0x4D87: 'zhòu',  # 䶇
    0x4D88: 'bó',  # 䶈
    0x4D89: 'liú',  # 䶉
    # 0x4D8A: '',  # 䶊
    # 0x4D8B: '',  # 䶋
    0x4D8C: 'pào',  # 䶌
    0x4D8D: 'dì,tì',  # 䶍
    0x4D8E: 'shà',  # 䶎
    0x4D8F: 'tǐ,tì',  # 䶏
    0x4D90: 'wài,huì',  # 䶐
    0x4D91: 'tì',  # 䶑
    0x4D92: 'qí',  # 䶒
    0x4D93: 'jì,qì',  # 䶓
    0x4D94: 'chí,mín',  # 䶔
    0x4D95: 'pá',  # 䶕
    0x4D96: 'jìn,qín',  # 䶖
    0x4D97: 'qiā,qiǎ,kè',  # 䶗
    0x4D98: 'lì',  # 䶘
    0x4D99: 'jù',  # 䶙
    0x4D9A: 'qǔ',  # 䶚
    0x4D9B: 'là,liè',  # 䶛
    0x4D9C: 'gù',  # 䶜
    0x4D9D: 'qià,xiá',  # 䶝
    0x4D9E: 'qí',  # 䶞
    0x4D9F: 'xiàn',  # 䶟
    0x4DA0: 'jiǎn,xián',  # 䶠
    0x4DA1: 'shí,zé,zhì',  # 䶡
    0x4DA2: 'xián,jiān',  # 䶢
    0x4DA3: 'ái',  # 䶣
    0x4DA4: 'huá',  # 䶤
    0x4DA5: 'jǔ,zhā',  # 䶥
    0x4DA6: 'zé',  # 䶦
    0x4DA7: 'yǎo',  # 䶧
    # 0x4DA8: '',  # 䶨
    0x4DA9: 'jì',  # 䶩
    0x4DAA: 'chá',  # 䶪
    0x4DAB: 'kǎn,yán,yàn',  # 䶫
    0x4DAC: 'jiān',  # 䶬
    # 0x4DAD: '',  # 䶭
    0x4DAE: 'yǎn',  # 䶮
    # 0x4DAF: '',  # 䶯
    # 0x4DB0: '',  # 䶰
    0x4DB1: 'tóng',  # 䶱
    0x4DB2: 'nán,nàn,rán',  # 䶲
    0x4DB3: 'yuè',  # 䶳
    0x4DB4: 'chuī',  # 䶴
    0x4DB5: 'chí,shǐ',  # 䶵
    # 0x4DB6: '',  #
    # 0x4DB7: '',  #
    # 0x4DB8: '',  #
    # 0x4DB9: '',  #
    # 0x4DBA: '',  #
    # 0x4DBB: '',  #
    # 0x4DBC: '',  #
    # 0x4DBD: '',  #
    # 0x4DBE: '',  #
    # 0x4DBF: '',  #

    # CJK 基本:[4E00-9FFF]
    0x4E00: 'yī',  # 一
    0x4E01: 'dīng,zhēng',  # 丁
    0x4E02: 'kǎo,qiǎo,yú',  # 丂
    0x4E03: 'qī',  # 七
    0x4E04: 'shàng',  # 丄
    0x4E05: 'xià',  # 丅
    0x4E06: 'hǎn',  # 丆
    0x4E07: 'wàn,mò',  # 万
    0x4E08: 'zhàng',  # 丈
    0x4E09: 'sān',  # 三
    0x4E0A: 'shàng,shǎng',  # 上
    0x4E0B: 'xià',  # 下
    0x4E0C: 'qí,jī',  # 丌
    0x4E0D: 'bù,fǒu',  # 不
    0x4E0E: 'yǔ,yù,yú',  # 与
    0x4E0F: 'miǎn',  # 丏
    0x4E10: 'gài',  # 丐
    0x4E11: 'chǒu',  # 丑
    0x4E12: 'chǒu',  # 丒
    0x4E13: 'zhuān',  # 专
    0x4E14: 'qiě,jū',  # 且
    0x4E15: 'pī',  # 丕
    0x4E16: 'shì',  # 世
    0x4E17: 'shì',  # 丗
    0x4E18: 'qiū',  # 丘
    0x4E19: 'bǐng',  # 丙
    0x4E1A: 'yè',  # 业
    0x4E1B: 'cóng',  # 丛
    0x4E1C: 'dōng',  # 东
    0x4E1D: 'sī',  # 丝
    0x4E1E: 'chéng',  # 丞
    0x4E1F: 'diū',  # 丟
    0x4E20: 'qiū',  # 丠
    0x4E21: 'liǎng',  # 両
    0x4E22: 'diū',  # 丢
    0x4E23: 'yǒu',  # 丣
    0x4E24: 'liǎng',  # 两
    0x4E25: 'yán',  # 严
    0x4E26: 'bìng',  # 並
    0x4E27: 'sāng,sàng',  # 丧
    0x4E28: 'gǔn',  # 丨
    0x4E29: 'jiū',  # 丩
    0x4E2A: 'gè,gě',  # 个
    0x4E2B: 'yā',  # 丫
    0x4E2C: 'pán',  # 丬
    0x4E2D: 'zhōng,zhòng',  # 中
    0x4E2E: 'jǐ',  # 丮
    0x4E2F: 'jiè',  # 丯
    0x4E30: 'fēng',  # 丰
    0x4E31: 'guàn,kuàng',  # 丱
    0x4E32: 'chuàn',  # 串
    0x4E33: 'chǎn',  # 丳
    0x4E34: 'lín',  # 临
    0x4E35: 'zhuó',  # 丵
    0x4E36: 'zhǔ',  # 丶
    0x4E37: 'bā',  # 丷
    0x4E38: 'wán',  # 丸
    0x4E39: 'dān',  # 丹
    0x4E3A: 'wéi,wèi',  # 为
    0x4E3B: 'zhǔ',  # 主
    0x4E3C: 'jǐng',  # 丼
    0x4E3D: 'lì,lí',  # 丽
    0x4E3E: 'jǔ',  # 举
    0x4E3F: 'piě',  # 丿
    0x4E40: 'fú',  # 乀
    0x4E41: 'yí,jí',  # 乁
    0x4E42: 'yì',  # 乂
    0x4E43: 'nǎi',  # 乃
    0x4E44: 'wǔ',  # 乄
    0x4E45: 'jiǔ',  # 久
    0x4E46: 'jiǔ',  # 乆
    0x4E47: 'tuō,zhé',  # 乇
    0x4E48: 'mó,ma,me,yāo',  # 么
    0x4E49: 'yì',  # 义
    0x4E4A: 'yī',  # 乊
    0x4E4B: 'zhī',  # 之
    0x4E4C: 'wū',  # 乌
    0x4E4D: 'zhà',  # 乍
    0x4E4E: 'hū',  # 乎
    0x4E4F: 'fá',  # 乏
    0x4E50: 'lè,yuè,yào,lào',  # 乐
    0x4E51: 'yín',  # 乑
    0x4E52: 'pīng',  # 乒
    0x4E53: 'pāng',  # 乓
    0x4E54: 'qiáo',  # 乔
    0x4E55: 'hǔ',  # 乕
    0x4E56: 'guāi',  # 乖
    0x4E57: 'chéng,shèng',  # 乗
    0x4E58: 'chéng,shèng',  # 乘
    0x4E59: 'yǐ',  # 乙
    0x4E5A: 'háo,yǐ',  # 乚
    0x4E5B: 'yǐ',  # 乛
    0x4E5C: 'miē,niè',  # 乜
    0x4E5D: 'jiǔ',  # 九
    0x4E5E: 'qǐ',  # 乞
    0x4E5F: 'yě',  # 也
    0x4E60: 'xí',  # 习
    0x4E61: 'xiāng',  # 乡
    0x4E62: 'gài',  # 乢
    0x4E63: 'jiǔ',  # 乣
    0x4E64: 'xià',  # 乤
    0x4E65: 'hol',  # 乥
    0x4E66: 'shū',  # 书
    0x4E67: 'dǒu',  # 乧
    0x4E68: 'shǐ',  # 乨
    0x4E69: 'jī',  # 乩
    0x4E6A: 'náng',  # 乪
    0x4E6B: 'jiā',  # 乫
    0x4E6C: 'jù',  # 乬
    0x4E6D: 'shí',  # 乭
    0x4E6E: 'mǎo',  # 乮
    0x4E6F: 'hū',  # 乯
    0x4E70: 'mǎi',  # 买
    0x4E71: 'luàn',  # 乱
    0x4E72: 'cal',  # 乲
    0x4E73: 'rǔ',  # 乳
    0x4E74: 'xué',  # 乴
    0x4E75: 'yǎn',  # 乵
    0x4E76: 'fǔ',  # 乶
    0x4E77: 'shā',  # 乷
    0x4E78: 'nǎ',  # 乸
    0x4E79: 'qián',  # 乹
    0x4E7A: 'suǒ',  # 乺
    0x4E7B: 'yú',  # 乻
    0x4E7C: 'zhù',  # 乼
    0x4E7D: 'zhě',  # 乽
    0x4E7E: 'qián,gān',  # 乾
    0x4E7F: 'zhì,luàn',  # 乿
    0x4E80: 'guī',  # 亀
    0x4E81: 'qián',  # 亁
    0x4E82: 'luàn',  # 亂
    0x4E83: 'lǐn,lìn',  # 亃
    0x4E84: 'yì',  # 亄
    0x4E85: 'jué',  # 亅
    0x4E86: 'liǎo,le',  # 了
    0x4E87: 'gè,mā',  # 亇
    0x4E88: 'yú,yǔ',  # 予
    0x4E89: 'zhēng',  # 争
    0x4E8A: 'shì',  # 亊
    0x4E8B: 'shì',  # 事
    0x4E8C: 'èr',  # 二
    0x4E8D: 'chù',  # 亍
    0x4E8E: 'yú',  # 于
    0x4E8F: 'kuī',  # 亏
    0x4E90: 'yú',  # 亐
    0x4E91: 'yún',  # 云
    0x4E92: 'hù',  # 互
    0x4E93: 'qí',  # 亓
    0x4E94: 'wǔ',  # 五
    0x4E95: 'jǐng',  # 井
    0x4E96: 'sì',  # 亖
    0x4E97: 'suì',  # 亗
    0x4E98: 'gèn',  # 亘
    0x4E99: 'gèn',  # 亙
    0x4E9A: 'yà',  # 亚
    0x4E9B: 'xiē,suò',  # 些
    0x4E9C: 'yà',  # 亜
    0x4E9D: 'qí,zhāi',  # 亝
    0x4E9E: 'yā,yà',  # 亞
    0x4E9F: 'jí,qì',  # 亟
    0x4EA0: 'tóu',  # 亠
    0x4EA1: 'wáng,wú',  # 亡
    0x4EA2: 'kàng',  # 亢
    0x4EA3: 'dà',  # 亣
    0x4EA4: 'jiāo',  # 交
    0x4EA5: 'hài',  # 亥
    0x4EA6: 'yì',  # 亦
    0x4EA7: 'chǎn',  # 产
    0x4EA8: 'hēng,pēng',  # 亨
    0x4EA9: 'mǔ',  # 亩
    0x4EAA: 'ye',  # 亪
    0x4EAB: 'xiǎng',  # 享
    0x4EAC: 'jīng',  # 京
    0x4EAD: 'tíng',  # 亭
    0x4EAE: 'liàng',  # 亮
    0x4EAF: 'xiǎng',  # 亯
    0x4EB0: 'jīng',  # 亰
    0x4EB1: 'yè',  # 亱
    0x4EB2: 'qīn,qìng',  # 亲
    0x4EB3: 'bó',  # 亳
    0x4EB4: 'yòu',  # 亴
    0x4EB5: 'xiè',  # 亵
    0x4EB6: 'dǎn,dàn',  # 亶
    0x4EB7: 'lián',  # 亷
    0x4EB8: 'duǒ',  # 亸
    0x4EB9: 'wěi,mén',  # 亹
    0x4EBA: 'rén',  # 人
    0x4EBB: 'rén',  # 亻
    0x4EBC: 'jí',  # 亼
    0x4EBD: 'jí',  # 亽
    0x4EBE: 'wáng',  # 亾
    0x4EBF: 'yì',  # 亿
    0x4EC0: 'shí,shén',  # 什
    0x4EC1: 'rén',  # 仁
    0x4EC2: 'lè',  # 仂
    0x4EC3: 'dīng',  # 仃
    0x4EC4: 'zè',  # 仄
    0x4EC5: 'jǐn,jìn',  # 仅
    0x4EC6: 'pū,pú',  # 仆
    0x4EC7: 'chóu,qiú',  # 仇
    0x4EC8: 'bā',  # 仈
    0x4EC9: 'zhǎng',  # 仉
    0x4ECA: 'jīn',  # 今
    0x4ECB: 'jiè',  # 介
    0x4ECC: 'bīng',  # 仌
    0x4ECD: 'réng',  # 仍
    0x4ECE: 'cóng,zòng',  # 从
    0x4ECF: 'fó',  # 仏
    0x4ED0: 'jīn,sǎn',  # 仐
    0x4ED1: 'lún',  # 仑
    0x4ED2: 'bīng,eo',  # 仒
    0x4ED3: 'cāng',  # 仓
    0x4ED4: 'zī,zǐ,zǎi',  # 仔
    0x4ED5: 'shì',  # 仕
    0x4ED6: 'tā',  # 他
    0x4ED7: 'zhàng',  # 仗
    0x4ED8: 'fù',  # 付
    0x4ED9: 'xiān',  # 仙
    0x4EDA: 'xiān',  # 仚
    0x4EDB: 'tuō,chà,duó',  # 仛
    0x4EDC: 'hóng',  # 仜
    0x4EDD: 'tóng',  # 仝
    0x4EDE: 'rèn',  # 仞
    0x4EDF: 'qiān',  # 仟
    0x4EE0: 'gǎn,hàn',  # 仠
    0x4EE1: 'yì,gē',  # 仡
    0x4EE2: 'bó',  # 仢
    0x4EE3: 'dài',  # 代
    0x4EE4: 'líng,lǐng,lìng',  # 令
    0x4EE5: 'yǐ',  # 以
    0x4EE6: 'chào',  # 仦
    0x4EE7: 'cháng,zhǎng',  # 仧
    0x4EE8: 'sā',  # 仨
    0x4EE9: 'cháng',  # 仩
    0x4EEA: 'yí',  # 仪
    0x4EEB: 'mù',  # 仫
    0x4EEC: 'mén',  # 们
    0x4EED: 'rèn',  # 仭
    0x4EEE: 'fǎn',  # 仮
    0x4EEF: 'chào,miǎo',  # 仯
    0x4EF0: 'yǎng,áng',  # 仰
    0x4EF1: 'qián',  # 仱
    0x4EF2: 'zhòng',  # 仲
    0x4EF3: 'pǐ,pí',  # 仳
    0x4EF4: 'wò',  # 仴
    0x4EF5: 'wǔ',  # 仵
    0x4EF6: 'jiàn',  # 件
    0x4EF7: 'jià,jiè,jie',  # 价
    0x4EF8: 'yǎo,fó',  # 仸
    0x4EF9: 'fēng',  # 仹
    0x4EFA: 'cāng',  # 仺
    0x4EFB: 'rèn,rén',  # 任
    0x4EFC: 'wáng',  # 仼
    0x4EFD: 'fèn,bīn',  # 份
    0x4EFE: 'dī',  # 仾
    0x4EFF: 'fǎng',  # 仿
    0x4F00: 'zhōng',  # 伀
    0x4F01: 'qǐ',  # 企
    0x4F02: 'pèi',  # 伂
    0x4F03: 'yú',  # 伃
    0x4F04: 'diào',  # 伄
    0x4F05: 'dùn',  # 伅
    0x4F06: 'wěn',  # 伆
    0x4F07: 'yì',  # 伇
    0x4F08: 'xǐn',  # 伈
    0x4F09: 'kàng',  # 伉
    0x4F0A: 'yī',  # 伊
    0x4F0B: 'jí',  # 伋
    0x4F0C: 'ài',  # 伌
    0x4F0D: 'wǔ',  # 伍
    0x4F0E: 'jì,qí',  # 伎
    0x4F0F: 'fú',  # 伏
    0x4F10: 'fá',  # 伐
    0x4F11: 'xiū,xǔ',  # 休
    0x4F12: 'jìn,yín',  # 伒
    0x4F13: 'pī',  # 伓
    0x4F14: 'dǎn',  # 伔
    0x4F15: 'fū',  # 伕
    0x4F16: 'tǎng',  # 伖
    0x4F17: 'zhòng',  # 众
    0x4F18: 'yōu',  # 优
    0x4F19: 'huǒ',  # 伙
    0x4F1A: 'huì,kuài',  # 会
    0x4F1B: 'yǔ',  # 伛
    0x4F1C: 'cuì',  # 伜
    0x4F1D: 'yún',  # 伝
    0x4F1E: 'sǎn',  # 伞
    0x4F1F: 'wěi',  # 伟
    0x4F20: 'chuán,zhuàn',  # 传
    0x4F21: 'chē,jū',  # 伡
    0x4F22: 'yá',  # 伢
    0x4F23: 'qiàn',  # 伣
    0x4F24: 'shāng',  # 伤
    0x4F25: 'chāng',  # 伥
    0x4F26: 'lún',  # 伦
    0x4F27: 'cāng,chen',  # 伧
    0x4F28: 'xùn',  # 伨
    0x4F29: 'xìn',  # 伩
    0x4F2A: 'wěi',  # 伪
    0x4F2B: 'zhù',  # 伫
    0x4F2C: 'chǐ',  # 伬
    0x4F2D: 'xián,xuán',  # 伭
    0x4F2E: 'nú,nǔ',  # 伮
    0x4F2F: 'bó,bǎi,bà',  # 伯
    0x4F30: 'gū,gù',  # 估
    0x4F31: 'nǐ',  # 伱
    0x4F32: 'nǐ,nì',  # 伲
    0x4F33: 'xiè',  # 伳
    0x4F34: 'bàn',  # 伴
    0x4F35: 'xù',  # 伵
    0x4F36: 'líng',  # 伶
    0x4F37: 'zhòu',  # 伷
    0x4F38: 'shēn',  # 伸
    0x4F39: 'qū',  # 伹
    0x4F3A: 'sì,cì',  # 伺
    0x4F3B: 'bēng',  # 伻
    0x4F3C: 'sì,shì',  # 似
    0x4F3D: 'qié,jiā,gā',  # 伽
    0x4F3E: 'pī',  # 伾
    0x4F3F: 'yì',  # 伿
    0x4F40: 'sì',  # 佀
    0x4F41: 'yǐ,chì',  # 佁
    0x4F42: 'zhēng',  # 佂
    0x4F43: 'diàn,tián',  # 佃
    0x4F44: 'hān,gàn',  # 佄
    0x4F45: 'mài',  # 佅
    0x4F46: 'dàn',  # 但
    0x4F47: 'zhù',  # 佇
    0x4F48: 'bù',  # 佈
    0x4F49: 'qū',  # 佉
    0x4F4A: 'bǐ',  # 佊
    0x4F4B: 'zhāo,shào',  # 佋
    0x4F4C: 'cǐ',  # 佌
    0x4F4D: 'wèi',  # 位
    0x4F4E: 'dī',  # 低
    0x4F4F: 'zhù',  # 住
    0x4F50: 'zuǒ',  # 佐
    0x4F51: 'yòu',  # 佑
    0x4F52: 'yǎng',  # 佒
    0x4F53: 'tǐ,tī',  # 体
    0x4F54: 'zhàn,diān',  # 佔
    0x4F55: 'hé,hē,hè',  # 何
    0x4F56: 'bì',  # 佖
    0x4F57: 'tuó',  # 佗
    0x4F58: 'shé',  # 佘
    0x4F59: 'yú',  # 余
    0x4F5A: 'yì,dié',  # 佚
    0x4F5B: 'fó,fú,bì,bó',  # 佛
    0x4F5C: 'zuò',  # 作
    0x4F5D: 'gōu,kòu',  # 佝
    0x4F5E: 'nìng',  # 佞
    0x4F5F: 'tóng',  # 佟
    0x4F60: 'nǐ',  # 你
    0x4F61: 'xiān',  # 佡
    0x4F62: 'qú',  # 佢
    0x4F63: 'yōng,yòng',  # 佣
    0x4F64: 'wǎ',  # 佤
    0x4F65: 'qiān',  # 佥
    0x4F66: 'yòu',  # 佦
    0x4F67: 'kǎ',  # 佧
    0x4F68: 'bāo',  # 佨
    0x4F69: 'pèi',  # 佩
    0x4F6A: 'huí,huái',  # 佪
    0x4F6B: 'gé',  # 佫
    0x4F6C: 'lǎo',  # 佬
    0x4F6D: 'xiáng',  # 佭
    0x4F6E: 'gé',  # 佮
    0x4F6F: 'yáng',  # 佯
    0x4F70: 'bǎi',  # 佰
    0x4F71: 'fǎ',  # 佱
    0x4F72: 'mǐng',  # 佲
    0x4F73: 'jiā',  # 佳
    0x4F74: 'èr,nài',  # 佴
    0x4F75: 'bìng',  # 併
    0x4F76: 'jí',  # 佶
    0x4F77: 'hěn',  # 佷
    0x4F78: 'huó',  # 佸
    0x4F79: 'guǐ',  # 佹
    0x4F7A: 'quán',  # 佺
    0x4F7B: 'tiāo',  # 佻
    0x4F7C: 'jiǎo',  # 佼
    0x4F7D: 'cì',  # 佽
    0x4F7E: 'yì',  # 佾
    0x4F7F: 'shǐ',  # 使
    0x4F80: 'xíng',  # 侀
    0x4F81: 'shēn',  # 侁
    0x4F82: 'tuō',  # 侂
    0x4F83: 'kǎn',  # 侃
    0x4F84: 'zhí',  # 侄
    0x4F85: 'gāi',  # 侅
    0x4F86: 'lái',  # 來
    0x4F87: 'yí',  # 侇
    0x4F88: 'chǐ',  # 侈
    0x4F89: 'kuǎ',  # 侉
    0x4F8A: 'gōng',  # 侊
    0x4F8B: 'lì',  # 例
    0x4F8C: 'yīn',  # 侌
    0x4F8D: 'shì',  # 侍
    0x4F8E: 'mǐ',  # 侎
    0x4F8F: 'zhū',  # 侏
    0x4F90: 'xù',  # 侐
    0x4F91: 'yòu',  # 侑
    0x4F92: 'ān',  # 侒
    0x4F93: 'lù',  # 侓
    0x4F94: 'móu',  # 侔
    0x4F95: 'ér',  # 侕
    0x4F96: 'lún',  # 侖
    0x4F97: 'dòng,tóng,tǒng',  # 侗
    0x4F98: 'chà',  # 侘
    0x4F99: 'chì',  # 侙
    0x4F9A: 'xùn',  # 侚
    0x4F9B: 'gōng,gòng',  # 供
    0x4F9C: 'zhōu',  # 侜
    0x4F9D: 'yī',  # 依
    0x4F9E: 'rú',  # 侞
    0x4F9F: 'cún,jiàn',  # 侟
    0x4FA0: 'xiá',  # 侠
    0x4FA1: 'sì',  # 価
    0x4FA2: 'dài',  # 侢
    0x4FA3: 'lǚ',  # 侣
    0x4FA4: 'ta',  # 侤
    0x4FA5: 'jiǎo,yáo',  # 侥
    0x4FA6: 'zhēn',  # 侦
    0x4FA7: 'cè,zè,zhāi',  # 侧
    0x4FA8: 'qiáo',  # 侨
    0x4FA9: 'kuài',  # 侩
    0x4FAA: 'chái',  # 侪
    0x4FAB: 'nìng',  # 侫
    0x4FAC: 'nóng',  # 侬
    0x4FAD: 'jǐn',  # 侭
    0x4FAE: 'wǔ',  # 侮
    0x4FAF: 'hóu,hòu',  # 侯
    0x4FB0: 'jiǒng',  # 侰
    0x4FB1: 'chěng,tǐng',  # 侱
    0x4FB2: 'zhèn,zhēn',  # 侲
    0x4FB3: 'zuò',  # 侳
    0x4FB4: 'hào',  # 侴
    0x4FB5: 'qīn',  # 侵
    0x4FB6: 'lǚ',  # 侶
    0x4FB7: 'jú',  # 侷
    0x4FB8: 'shù,dōu',  # 侸
    0x4FB9: 'tǐng',  # 侹
    0x4FBA: 'shèn',  # 侺
    0x4FBB: 'tuó,tuì',  # 侻
    0x4FBC: 'bó',  # 侼
    0x4FBD: 'nán',  # 侽
    0x4FBE: 'xiāo',  # 侾
    0x4FBF: 'biàn,pián',  # 便
    0x4FC0: 'tuǐ',  # 俀
    0x4FC1: 'yǔ',  # 俁
    0x4FC2: 'xì',  # 係
    0x4FC3: 'cù',  # 促
    0x4FC4: 'é',  # 俄
    0x4FC5: 'qiú',  # 俅
    0x4FC6: 'xú',  # 俆
    0x4FC7: 'guàng',  # 俇
    0x4FC8: 'kù',  # 俈
    0x4FC9: 'wù',  # 俉
    0x4FCA: 'jùn',  # 俊
    0x4FCB: 'yì',  # 俋
    0x4FCC: 'fǔ',  # 俌
    0x4FCD: 'liáng',  # 俍
    0x4FCE: 'zǔ',  # 俎
    0x4FCF: 'qiào,xiào',  # 俏
    0x4FD0: 'lì',  # 俐
    0x4FD1: 'yǒng',  # 俑
    0x4FD2: 'hùn',  # 俒
    0x4FD3: 'jìng',  # 俓
    0x4FD4: 'qiàn',  # 俔
    0x4FD5: 'sàn',  # 俕
    0x4FD6: 'pěi',  # 俖
    0x4FD7: 'sú',  # 俗
    0x4FD8: 'fú',  # 俘
    0x4FD9: 'xī',  # 俙
    0x4FDA: 'lǐ',  # 俚
    0x4FDB: 'fǔ',  # 俛
    0x4FDC: 'pīng',  # 俜
    0x4FDD: 'bǎo',  # 保
    0x4FDE: 'yú,yù,shù',  # 俞
    0x4FDF: 'sì,qí',  # 俟
    0x4FE0: 'xiá',  # 俠
    0x4FE1: 'xìn,shēn',  # 信
    0x4FE2: 'xiū',  # 俢
    0x4FE3: 'yǔ',  # 俣
    0x4FE4: 'dì',  # 俤
    0x4FE5: 'chē,jū',  # 俥
    0x4FE6: 'chóu',  # 俦
    0x4FE7: 'zhì',  # 俧
    0x4FE8: 'yǎn',  # 俨
    0x4FE9: 'liǎng,liǎ',  # 俩
    0x4FEA: 'lì',  # 俪
    0x4FEB: 'lái',  # 俫
    0x4FEC: 'sī',  # 俬
    0x4FED: 'jiǎn',  # 俭
    0x4FEE: 'xiū',  # 修
    0x4FEF: 'fǔ',  # 俯
    0x4FF0: 'huò',  # 俰
    0x4FF1: 'jù',  # 俱
    0x4FF2: 'xiào',  # 俲
    0x4FF3: 'pái',  # 俳
    0x4FF4: 'jiàn',  # 俴
    0x4FF5: 'biào',  # 俵
    0x4FF6: 'chù,tì',  # 俶
    0x4FF7: 'fèi',  # 俷
    0x4FF8: 'fèng',  # 俸
    0x4FF9: 'yà',  # 俹
    0x4FFA: 'ǎn',  # 俺
    0x4FFB: 'bèi',  # 俻
    0x4FFC: 'yù',  # 俼
    0x4FFD: 'xīn',  # 俽
    0x4FFE: 'bǐ',  # 俾
    0x4FFF: 'hǔ,chí',  # 俿
    0x5000: 'chāng',  # 倀
    0x5001: 'zhī',  # 倁
    0x5002: 'bìng',  # 倂
    0x5003: 'jiù',  # 倃
    0x5004: 'yáo',  # 倄
    0x5005: 'cuì,zú',  # 倅
    0x5006: 'liǎng,liǎ',  # 倆
    0x5007: 'wǎn',  # 倇
    0x5008: 'lái',  # 倈
    0x5009: 'cāng',  # 倉
    0x500A: 'zǒng',  # 倊
    0x500B: 'gè,gě',  # 個
    0x500C: 'guān',  # 倌
    0x500D: 'bèi',  # 倍
    0x500E: 'tiǎn',  # 倎
    0x500F: 'shū',  # 倏
    0x5010: 'shū',  # 倐
    0x5011: 'mén',  # 們
    0x5012: 'dǎo,dào',  # 倒
    0x5013: 'tán,tàn',  # 倓
    0x5014: 'jué,juè',  # 倔
    0x5015: 'chuí',  # 倕
    0x5016: 'xìng',  # 倖
    0x5017: 'péng',  # 倗
    0x5018: 'tǎng,cháng',  # 倘
    0x5019: 'hòu',  # 候
    0x501A: 'yǐ',  # 倚
    0x501B: 'qī',  # 倛
    0x501C: 'tì',  # 倜
    0x501D: 'gàn',  # 倝
    0x501E: 'liàng,jìng',  # 倞
    0x501F: 'jiè',  # 借
    0x5020: 'suī',  # 倠
    0x5021: 'chàng,chāng',  # 倡
    0x5022: 'jié',  # 倢
    0x5023: 'fǎng',  # 倣
    0x5024: 'zhí',  # 値
    0x5025: 'kōng,kǒng',  # 倥
    0x5026: 'juàn',  # 倦
    0x5027: 'zōng',  # 倧
    0x5028: 'jù',  # 倨
    0x5029: 'qiàn',  # 倩
    0x502A: 'ní',  # 倪
    0x502B: 'lún',  # 倫
    0x502C: 'zhuō',  # 倬
    0x502D: 'wō,wēi',  # 倭
    0x502E: 'luǒ',  # 倮
    0x502F: 'sōng',  # 倯
    0x5030: 'lèng',  # 倰
    0x5031: 'hùn',  # 倱
    0x5032: 'dōng',  # 倲
    0x5033: 'zì',  # 倳
    0x5034: 'bèn',  # 倴
    0x5035: 'wǔ',  # 倵
    0x5036: 'jù',  # 倶
    0x5037: 'nǎi',  # 倷
    0x5038: 'cǎi',  # 倸
    0x5039: 'jiǎn',  # 倹
    0x503A: 'zhài',  # 债
    0x503B: 'yē',  # 倻
    0x503C: 'zhí',  # 值
    0x503D: 'shà',  # 倽
    0x503E: 'qīng',  # 倾
    0x503F: 'nìng',  # 倿
    0x5040: 'yīng',  # 偀
    0x5041: 'chēng,chèn',  # 偁
    0x5042: 'qián',  # 偂
    0x5043: 'yǎn',  # 偃
    0x5044: 'ruǎn',  # 偄
    0x5045: 'zhòng,tóng',  # 偅
    0x5046: 'chǔn',  # 偆
    0x5047: 'jiǎ,jià',  # 假
    0x5048: 'jì,jié',  # 偈
    0x5049: 'wěi',  # 偉
    0x504A: 'yǔ',  # 偊
    0x504B: 'bǐng,bìng',  # 偋
    0x504C: 'ruò',  # 偌
    0x504D: 'tí',  # 偍
    0x504E: 'wēi',  # 偎
    0x504F: 'piān',  # 偏
    0x5050: 'yàn',  # 偐
    0x5051: 'fēng',  # 偑
    0x5052: 'tǎng,dàng',  # 偒
    0x5053: 'wò',  # 偓
    0x5054: 'è',  # 偔
    0x5055: 'xié',  # 偕
    0x5056: 'chě',  # 偖
    0x5057: 'shěng',  # 偗
    0x5058: 'kǎn',  # 偘
    0x5059: 'dì',  # 偙
    0x505A: 'zuò',  # 做
    0x505B: 'chā',  # 偛
    0x505C: 'tíng',  # 停
    0x505D: 'bèi',  # 偝
    0x505E: 'xiè',  # 偞
    0x505F: 'huáng',  # 偟
    0x5060: 'yǎo',  # 偠
    0x5061: 'zhàn',  # 偡
    0x5062: 'chǒu,qiào',  # 偢
    0x5063: 'ān',  # 偣
    0x5064: 'yóu',  # 偤
    0x5065: 'jiàn',  # 健
    0x5066: 'xū',  # 偦
    0x5067: 'zhā',  # 偧
    0x5068: 'cī',  # 偨
    0x5069: 'fù',  # 偩
    0x506A: 'bī',  # 偪
    0x506B: 'zhì',  # 偫
    0x506C: 'zǒng',  # 偬
    0x506D: 'miǎn',  # 偭
    0x506E: 'jí',  # 偮
    0x506F: 'yǐ',  # 偯
    0x5070: 'xiè',  # 偰
    0x5071: 'xún',  # 偱
    0x5072: 'cāi,sī',  # 偲
    0x5073: 'duān',  # 偳
    0x5074: 'cè,zè,zhāi',  # 側
    0x5075: 'zhēn',  # 偵
    0x5076: 'ǒu',  # 偶
    0x5077: 'tōu',  # 偷
    0x5078: 'tōu',  # 偸
    0x5079: 'bèi',  # 偹
    0x507A: 'zán,zá,zǎ',  # 偺
    0x507B: 'lǚ,lóu',  # 偻
    0x507C: 'jié',  # 偼
    0x507D: 'wěi',  # 偽
    0x507E: 'fèn',  # 偾
    0x507F: 'cháng',  # 偿
    0x5080: 'kuǐ,guī',  # 傀
    0x5081: 'sǒu',  # 傁
    0x5082: 'zhì,sī',  # 傂
    0x5083: 'sù',  # 傃
    0x5084: 'xiā',  # 傄
    0x5085: 'fù',  # 傅
    0x5086: 'yuàn,yuán',  # 傆
    0x5087: 'rǒng',  # 傇
    0x5088: 'lì',  # 傈
    0x5089: 'nù',  # 傉
    0x508A: 'yùn',  # 傊
    0x508B: 'jiǎng,gòu',  # 傋
    0x508C: 'mà',  # 傌
    0x508D: 'bàng',  # 傍
    0x508E: 'diān',  # 傎
    0x508F: 'táng',  # 傏
    0x5090: 'hào',  # 傐
    0x5091: 'jié',  # 傑
    0x5092: 'xī,xì',  # 傒
    0x5093: 'shān',  # 傓
    0x5094: 'qiàn,jiān',  # 傔
    0x5095: 'què,jué',  # 傕
    0x5096: 'cāng,chen',  # 傖
    0x5097: 'chù',  # 傗
    0x5098: 'sǎn',  # 傘
    0x5099: 'bèi',  # 備
    0x509A: 'xiào',  # 傚
    0x509B: 'róng',  # 傛
    0x509C: 'yáo',  # 傜
    0x509D: 'tà,tàn',  # 傝
    0x509E: 'suō',  # 傞
    0x509F: 'yǎng',  # 傟
    0x50A0: 'fá',  # 傠
    0x50A1: 'bìng',  # 傡
    0x50A2: 'jiā',  # 傢
    0x50A3: 'dǎi',  # 傣
    0x50A4: 'zài',  # 傤
    0x50A5: 'tǎng',  # 傥
    0x50A6: 'gǔ',  # 傦
    0x50A7: 'bīn',  # 傧
    0x50A8: 'chǔ',  # 储
    0x50A9: 'nuó',  # 傩
    0x50AA: 'cān,càn',  # 傪
    0x50AB: 'lěi',  # 傫
    0x50AC: 'cuī',  # 催
    0x50AD: 'yōng',  # 傭
    0x50AE: 'zāo,cáo',  # 傮
    0x50AF: 'zǒng',  # 傯
    0x50B0: 'péng',  # 傰
    0x50B1: 'sǒng',  # 傱
    0x50B2: 'ào',  # 傲
    0x50B3: 'chuán,zhuàn',  # 傳
    0x50B4: 'yǔ',  # 傴
    0x50B5: 'zhài',  # 債
    0x50B6: 'qī,còu',  # 傶
    0x50B7: 'shāng',  # 傷
    0x50B8: 'chuǎng',  # 傸
    0x50B9: 'jìng',  # 傹
    0x50BA: 'chì',  # 傺
    0x50BB: 'shǎ',  # 傻
    0x50BC: 'hàn',  # 傼
    0x50BD: 'zhāng',  # 傽
    0x50BE: 'qīng',  # 傾
    0x50BF: 'yān,yàn',  # 傿
    0x50C0: 'dì',  # 僀
    0x50C1: 'xiè',  # 僁
    0x50C2: 'lǚ,lóu',  # 僂
    0x50C3: 'bèi',  # 僃
    0x50C4: 'piào,biāo',  # 僄
    0x50C5: 'jǐn,jìn',  # 僅
    0x50C6: 'liàn',  # 僆
    0x50C7: 'lù',  # 僇
    0x50C8: 'màn',  # 僈
    0x50C9: 'qiān',  # 僉
    0x50CA: 'xiān',  # 僊
    0x50CB: 'tǎn,tàn',  # 僋
    0x50CC: 'yíng',  # 僌
    0x50CD: 'dòng',  # 働
    0x50CE: 'zhuàn',  # 僎
    0x50CF: 'xiàng',  # 像
    0x50D0: 'shàn',  # 僐
    0x50D1: 'qiáo',  # 僑
    0x50D2: 'jiǒng',  # 僒
    0x50D3: 'tuǐ,tuí',  # 僓
    0x50D4: 'zǔn',  # 僔
    0x50D5: 'pú',  # 僕
    0x50D6: 'xī',  # 僖
    0x50D7: 'láo',  # 僗
    0x50D8: 'chǎng',  # 僘
    0x50D9: 'guāng',  # 僙
    0x50DA: 'liáo',  # 僚
    0x50DB: 'qī',  # 僛
    0x50DC: 'chēng,dēng',  # 僜
    0x50DD: 'zhàn,zhuàn,chán',  # 僝
    0x50DE: 'wěi',  # 僞
    0x50DF: 'jī',  # 僟
    0x50E0: 'bō',  # 僠
    0x50E1: 'huì',  # 僡
    0x50E2: 'chuǎn',  # 僢
    0x50E3: 'tiě,jiàn',  # 僣
    0x50E4: 'dàn',  # 僤
    0x50E5: 'jiǎo,yáo',  # 僥
    0x50E6: 'jiù',  # 僦
    0x50E7: 'sēng',  # 僧
    0x50E8: 'fèn',  # 僨
    0x50E9: 'xiàn',  # 僩
    0x50EA: 'yù,jú',  # 僪
    0x50EB: 'è,wù,wū',  # 僫
    0x50EC: 'jiāo',  # 僬
    0x50ED: 'jiàn',  # 僭
    0x50EE: 'tóng,zhuàng',  # 僮
    0x50EF: 'lǐn',  # 僯
    0x50F0: 'bó',  # 僰
    0x50F1: 'gù',  # 僱
    0x50F2: 'xiān',  # 僲
    0x50F3: 'sù',  # 僳
    0x50F4: 'xiàn',  # 僴
    0x50F5: 'jiāng',  # 僵
    0x50F6: 'mǐn',  # 僶
    0x50F7: 'yè',  # 僷
    0x50F8: 'jìn',  # 僸
    0x50F9: 'jià,jie',  # 價
    0x50FA: 'qiào',  # 僺
    0x50FB: 'pì',  # 僻
    0x50FC: 'fēng',  # 僼
    0x50FD: 'zhòu',  # 僽
    0x50FE: 'ài',  # 僾
    0x50FF: 'sài',  # 僿
    0x5100: 'yí',  # 儀
    0x5101: 'jùn',  # 儁
    0x5102: 'nóng',  # 儂
    0x5103: 'chán,tǎn,shàn',  # 儃
    0x5104: 'yì',  # 億
    0x5105: 'dāng,dàng',  # 儅
    0x5106: 'jǐng',  # 儆
    0x5107: 'xuān',  # 儇
    0x5108: 'kuài',  # 儈
    0x5109: 'jiǎn',  # 儉
    0x510A: 'chù',  # 儊
    0x510B: 'dān,dàn',  # 儋
    0x510C: 'jiǎo',  # 儌
    0x510D: 'shǎ',  # 儍
    0x510E: 'zài',  # 儎
    0x510F: 'càn',  # 儏
    0x5110: 'bīn,bìn',  # 儐
    0x5111: 'án,àn',  # 儑
    0x5112: 'rú',  # 儒
    0x5113: 'tái',  # 儓
    0x5114: 'chóu',  # 儔
    0x5115: 'chái',  # 儕
    0x5116: 'lán',  # 儖
    0x5117: 'nǐ,yì',  # 儗
    0x5118: 'jǐn',  # 儘
    0x5119: 'qiàn',  # 儙
    0x511A: 'méng',  # 儚
    0x511B: 'wǔ',  # 儛
    0x511C: 'níng',  # 儜
    0x511D: 'qióng',  # 儝
    0x511E: 'nǐ',  # 儞
    0x511F: 'cháng',  # 償
    0x5120: 'liè',  # 儠
    0x5121: 'lěi',  # 儡
    0x5122: 'lǚ',  # 儢
    0x5123: 'kuǎng',  # 儣
    0x5124: 'bào',  # 儤
    0x5125: 'yù',  # 儥
    0x5126: 'biāo',  # 儦
    0x5127: 'zǎn',  # 儧
    0x5128: 'zhì',  # 儨
    0x5129: 'sì',  # 儩
    0x512A: 'yōu',  # 優
    0x512B: 'háo',  # 儫
    0x512C: 'qìng',  # 儬
    0x512D: 'chèn',  # 儭
    0x512E: 'lì',  # 儮
    0x512F: 'téng',  # 儯
    0x5130: 'wěi',  # 儰
    0x5131: 'lǒng,lóng,lòng',  # 儱
    0x5132: 'chǔ',  # 儲
    0x5133: 'chán,chàn',  # 儳
    0x5134: 'ráng,xiāng',  # 儴
    0x5135: 'shū',  # 儵
    0x5136: 'huì,xié',  # 儶
    0x5137: 'lì',  # 儷
    0x5138: 'luó',  # 儸
    0x5139: 'zǎn',  # 儹
    0x513A: 'nuó',  # 儺
    0x513B: 'tǎng',  # 儻
    0x513C: 'yǎn',  # 儼
    0x513D: 'léi',  # 儽
    0x513E: 'nàng,nāng',  # 儾
    0x513F: 'ér',  # 儿
    0x5140: 'wù',  # 兀
    0x5141: 'yǔn',  # 允
    0x5142: 'zān',  # 兂
    0x5143: 'yuán',  # 元
    0x5144: 'xiōng',  # 兄
    0x5145: 'chōng',  # 充
    0x5146: 'zhào',  # 兆
    0x5147: 'xiōng',  # 兇
    0x5148: 'xiān',  # 先
    0x5149: 'guāng',  # 光
    0x514A: 'duì,ruì,yuè',  # 兊
    0x514B: 'kè',  # 克
    0x514C: 'duì,ruì,yuè',  # 兌
    0x514D: 'miǎn',  # 免
    0x514E: 'tù',  # 兎
    0x514F: 'cháng,zhǎng',  # 兏
    0x5150: 'ér',  # 児
    0x5151: 'duì,ruì,yuè',  # 兑
    0x5152: 'ér',  # 兒
    0x5153: 'qīn',  # 兓
    0x5154: 'tù',  # 兔
    0x5155: 'sì',  # 兕
    0x5156: 'yǎn',  # 兖
    0x5157: 'yǎn',  # 兗
    0x5158: 'shǐ',  # 兘
    0x5159: 'shíkě',  # 兙
    0x515A: 'dǎng',  # 党
    0x515B: 'qiānkè',  # 兛
    0x515C: 'dōu',  # 兜
    0x515D: 'gōngfēn',  # 兝
    0x515E: 'háokè',  # 兞
    0x515F: 'shēn',  # 兟
    0x5160: 'dōu',  # 兠
    0x5161: 'bǎikè',  # 兡
    0x5162: 'jīng',  # 兢
    0x5163: 'gōnglǐ',  # 兣
    0x5164: 'huǎng',  # 兤
    0x5165: 'rù',  # 入
    0x5166: 'wáng',  # 兦
    0x5167: 'nèi',  # 內
    0x5168: 'quán',  # 全
    0x5169: 'liǎng',  # 兩
    0x516A: 'yú,shù',  # 兪
    0x516B: 'bā',  # 八
    0x516C: 'gōng',  # 公
    0x516D: 'liù,lù',  # 六
    0x516E: 'xī',  # 兮
    0x516F: 'han',  # 兯
    0x5170: 'lán',  # 兰
    0x5171: 'gòng,gōng',  # 共
    0x5172: 'tiān',  # 兲
    0x5173: 'guān',  # 关
    0x5174: 'xīng,xìng',  # 兴
    0x5175: 'bīng',  # 兵
    0x5176: 'qí,jī',  # 其
    0x5177: 'jù',  # 具
    0x5178: 'diǎn',  # 典
    0x5179: 'zī,cí',  # 兹
    0x517A: 'būn',  # 兺
    0x517B: 'yǎng',  # 养
    0x517C: 'jiān',  # 兼
    0x517D: 'shòu',  # 兽
    0x517E: 'jì',  # 兾
    0x517F: 'yì',  # 兿
    0x5180: 'jì',  # 冀
    0x5181: 'chǎn',  # 冁
    0x5182: 'jiōng',  # 冂
    0x5183: 'mào',  # 冃
    0x5184: 'rǎn',  # 冄
    0x5185: 'nèi,nà',  # 内
    0x5186: 'yuán',  # 円
    0x5187: 'mǎo',  # 冇
    0x5188: 'gāng',  # 冈
    0x5189: 'rǎn',  # 冉
    0x518A: 'cè',  # 冊
    0x518B: 'jiōng',  # 冋
    0x518C: 'cè',  # 册
    0x518D: 'zài',  # 再
    0x518E: 'guǎ',  # 冎
    0x518F: 'jiǒng',  # 冏
    0x5190: 'mào',  # 冐
    0x5191: 'zhòu',  # 冑
    0x5192: 'mào,mò',  # 冒
    0x5193: 'gòu',  # 冓
    0x5194: 'xú',  # 冔
    0x5195: 'miǎn',  # 冕
    0x5196: 'mì',  # 冖
    0x5197: 'rǒng',  # 冗
    0x5198: 'yín,yóu',  # 冘
    0x5199: 'xiě',  # 写
    0x519A: 'kǎn',  # 冚
    0x519B: 'jūn',  # 军
    0x519C: 'nóng',  # 农
    0x519D: 'yí',  # 冝
    0x519E: 'mí',  # 冞
    0x519F: 'shì',  # 冟
    0x51A0: 'guān,guàn',  # 冠
    0x51A1: 'měng',  # 冡
    0x51A2: 'zhǒng',  # 冢
    0x51A3: 'zuì',  # 冣
    0x51A4: 'yuān',  # 冤
    0x51A5: 'míng',  # 冥
    0x51A6: 'kòu',  # 冦
    0x51A7: 'lín',  # 冧
    0x51A8: 'fù',  # 冨
    0x51A9: 'xiě',  # 冩
    0x51AA: 'mì',  # 冪
    0x51AB: 'bīng',  # 冫
    0x51AC: 'dōng',  # 冬
    0x51AD: 'tài',  # 冭
    0x51AE: 'gāng',  # 冮
    0x51AF: 'féng,píng',  # 冯
    0x51B0: 'bīng',  # 冰
    0x51B1: 'hù',  # 冱
    0x51B2: 'chōng,chòng',  # 冲
    0x51B3: 'jué',  # 决
    0x51B4: 'yà',  # 冴
    0x51B5: 'kuàng',  # 况
    0x51B6: 'yě',  # 冶
    0x51B7: 'lěng',  # 冷
    0x51B8: 'pàn',  # 冸
    0x51B9: 'fā',  # 冹
    0x51BA: 'mǐn',  # 冺
    0x51BB: 'dòng',  # 冻
    0x51BC: 'xiǎn',  # 冼
    0x51BD: 'liè',  # 冽
    0x51BE: 'qià',  # 冾
    0x51BF: 'jiān',  # 冿
    0x51C0: 'jìng,chēng',  # 净
    0x51C1: 'sōu',  # 凁
    0x51C2: 'měi',  # 凂
    0x51C3: 'tú',  # 凃
    0x51C4: 'qī',  # 凄
    0x51C5: 'gù',  # 凅
    0x51C6: 'zhǔn',  # 准
    0x51C7: 'sōng',  # 凇
    0x51C8: 'jìng,chēng',  # 凈
    0x51C9: 'liáng,liàng',  # 凉
    0x51CA: 'qìng',  # 凊
    0x51CB: 'diāo',  # 凋
    0x51CC: 'líng',  # 凌
    0x51CD: 'dòng',  # 凍
    0x51CE: 'gàn',  # 凎
    0x51CF: 'jiǎn',  # 减
    0x51D0: 'yīn',  # 凐
    0x51D1: 'còu',  # 凑
    0x51D2: 'ái',  # 凒
    0x51D3: 'lì',  # 凓
    0x51D4: 'cāng',  # 凔
    0x51D5: 'mǐng',  # 凕
    0x51D6: 'zhǔn',  # 凖
    0x51D7: 'cuī',  # 凗
    0x51D8: 'sī',  # 凘
    0x51D9: 'duó',  # 凙
    0x51DA: 'jìn',  # 凚
    0x51DB: 'lǐn',  # 凛
    0x51DC: 'lǐn',  # 凜
    0x51DD: 'níng',  # 凝
    0x51DE: 'xī',  # 凞
    0x51DF: 'dú',  # 凟
    0x51E0: 'jī,jǐ',  # 几
    0x51E1: 'fán',  # 凡
    0x51E2: 'fán',  # 凢
    0x51E3: 'fán',  # 凣
    0x51E4: 'fèng',  # 凤
    0x51E5: 'jū',  # 凥
    0x51E6: 'chù,chǔ',  # 処
    0x51E7: 'zhēng',  # 凧
    0x51E8: 'fēng',  # 凨
    0x51E9: 'mù',  # 凩
    0x51EA: 'zhǐ',  # 凪
    0x51EB: 'fú',  # 凫
    0x51EC: 'fēng',  # 凬
    0x51ED: 'píng',  # 凭
    0x51EE: 'fēng',  # 凮
    0x51EF: 'kǎi',  # 凯
    0x51F0: 'huáng',  # 凰
    0x51F1: 'kǎi',  # 凱
    0x51F2: 'gān',  # 凲
    0x51F3: 'dèng',  # 凳
    0x51F4: 'píng',  # 凴
    0x51F5: 'kǎn,qiǎn',  # 凵
    0x51F6: 'xiōng',  # 凶
    0x51F7: 'kuài',  # 凷
    0x51F8: 'tū',  # 凸
    0x51F9: 'āo,wā',  # 凹
    0x51FA: 'chū',  # 出
    0x51FB: 'jī',  # 击
    0x51FC: 'dàng',  # 凼
    0x51FD: 'hán',  # 函
    0x51FE: 'hán',  # 凾
    0x51FF: 'záo',  # 凿
    0x5200: 'dāo',  # 刀
    0x5201: 'diāo',  # 刁
    0x5202: 'dāo',  # 刂
    0x5203: 'rèn',  # 刃
    0x5204: 'rèn',  # 刄
    0x5205: 'chuāng',  # 刅
    0x5206: 'fēn,fèn',  # 分
    0x5207: 'qiē,qiè',  # 切
    0x5208: 'yì',  # 刈
    0x5209: 'jī',  # 刉
    0x520A: 'kān',  # 刊
    0x520B: 'qiàn',  # 刋
    0x520C: 'cǔn',  # 刌
    0x520D: 'chú',  # 刍
    0x520E: 'wěn',  # 刎
    0x520F: 'jī',  # 刏
    0x5210: 'dǎn',  # 刐
    0x5211: 'xíng',  # 刑
    0x5212: 'huá,huà',  # 划
    0x5213: 'wán',  # 刓
    0x5214: 'jué',  # 刔
    0x5215: 'lí',  # 刕
    0x5216: 'yuè',  # 刖
    0x5217: 'liè',  # 列
    0x5218: 'liú',  # 刘
    0x5219: 'zé',  # 则
    0x521A: 'gāng',  # 刚
    0x521B: 'chuàng,chuāng',  # 创
    0x521C: 'fú',  # 刜
    0x521D: 'chū',  # 初
    0x521E: 'qù',  # 刞
    0x521F: 'diāo',  # 刟
    0x5220: 'shān',  # 删
    0x5221: 'mǐn',  # 刡
    0x5222: 'líng',  # 刢
    0x5223: 'zhōng',  # 刣
    0x5224: 'pàn',  # 判
    0x5225: 'bié,biè',  # 別
    0x5226: 'jié',  # 刦
    0x5227: 'jié',  # 刧
    0x5228: 'páo,bào',  # 刨
    0x5229: 'lì',  # 利
    0x522A: 'shān',  # 刪
    0x522B: 'bié,biè',  # 别
    0x522C: 'chǎn,chàn',  # 刬
    0x522D: 'jǐng',  # 刭
    0x522E: 'guā',  # 刮
    0x522F: 'gēng',  # 刯
    0x5230: 'dào',  # 到
    0x5231: 'chuàng',  # 刱
    0x5232: 'kuī',  # 刲
    0x5233: 'kū',  # 刳
    0x5234: 'duò',  # 刴
    0x5235: 'èr',  # 刵
    0x5236: 'zhì',  # 制
    0x5237: 'shuā,shuà',  # 刷
    0x5238: 'quàn,xuàn',  # 券
    0x5239: 'chà,shā',  # 刹
    0x523A: 'cì,cī',  # 刺
    0x523B: 'kè',  # 刻
    0x523C: 'jié',  # 刼
    0x523D: 'guì',  # 刽
    0x523E: 'cì',  # 刾
    0x523F: 'guì',  # 刿
    0x5240: 'kǎi',  # 剀
    0x5241: 'duò',  # 剁
    0x5242: 'jì',  # 剂
    0x5243: 'tì',  # 剃
    0x5244: 'jǐng',  # 剄
    0x5245: 'lóu',  # 剅
    0x5246: 'luǒ',  # 剆
    0x5247: 'zé',  # 則
    0x5248: 'yuān',  # 剈
    0x5249: 'cuò',  # 剉
    0x524A: 'xiāo,xuē',  # 削
    0x524B: 'kēi,kè',  # 剋
    0x524C: 'là,lá',  # 剌
    0x524D: 'qián',  # 前
    0x524E: 'chà,shā',  # 剎
    0x524F: 'chuàng',  # 剏
    0x5250: 'guǎ',  # 剐
    0x5251: 'jiàn',  # 剑
    0x5252: 'cuò',  # 剒
    0x5253: 'lí',  # 剓
    0x5254: 'tī',  # 剔
    0x5255: 'fèi',  # 剕
    0x5256: 'pōu',  # 剖
    0x5257: 'chǎn,chàn',  # 剗
    0x5258: 'qí',  # 剘
    0x5259: 'chuàng',  # 剙
    0x525A: 'zì',  # 剚
    0x525B: 'gāng',  # 剛
    0x525C: 'wān',  # 剜
    0x525D: 'bāo,bō',  # 剝
    0x525E: 'jī',  # 剞
    0x525F: 'duō',  # 剟
    0x5260: 'qíng',  # 剠
    0x5261: 'yǎn,shàn',  # 剡
    0x5262: 'dū,zhuó',  # 剢
    0x5263: 'jiàn',  # 剣
    0x5264: 'jì',  # 剤
    0x5265: 'bāo,bō',  # 剥
    0x5266: 'yān',  # 剦
    0x5267: 'jù',  # 剧
    0x5268: 'huò',  # 剨
    0x5269: 'shèng',  # 剩
    0x526A: 'jiǎn',  # 剪
    0x526B: 'duó',  # 剫
    0x526C: 'zhì,duān',  # 剬
    0x526D: 'wū',  # 剭
    0x526E: 'guǎ',  # 剮
    0x526F: 'fù,pì',  # 副
    0x5270: 'shèng',  # 剰
    0x5271: 'jiàn',  # 剱
    0x5272: 'gē',  # 割
    0x5273: 'dá,zhá',  # 剳
    0x5274: 'kǎi',  # 剴
    0x5275: 'chuàng,chuāng',  # 創
    0x5276: 'chuán',  # 剶
    0x5277: 'chǎn',  # 剷
    0x5278: 'tuán,zhuān',  # 剸
    0x5279: 'lù,jiū',  # 剹
    0x527A: 'lí',  # 剺
    0x527B: 'pēng',  # 剻
    0x527C: 'shān',  # 剼
    0x527D: 'piāo',  # 剽
    0x527E: 'kōu',  # 剾
    0x527F: 'jiǎo,chāo',  # 剿
    0x5280: 'guā',  # 劀
    0x5281: 'qiāo',  # 劁
    0x5282: 'jué',  # 劂
    0x5283: 'huá,huà',  # 劃
    0x5284: 'zhā,zhá',  # 劄
    0x5285: 'zhuó',  # 劅
    0x5286: 'lián',  # 劆
    0x5287: 'jù',  # 劇
    0x5288: 'pī,pǐ',  # 劈
    0x5289: 'liú',  # 劉
    0x528A: 'guì',  # 劊
    0x528B: 'jiǎo,chāo',  # 劋
    0x528C: 'guì',  # 劌
    0x528D: 'jiàn',  # 劍
    0x528E: 'jiàn',  # 劎
    0x528F: 'tāng',  # 劏
    0x5290: 'huō',  # 劐
    0x5291: 'jì',  # 劑
    0x5292: 'jiàn',  # 劒
    0x5293: 'yì',  # 劓
    0x5294: 'jiàn',  # 劔
    0x5295: 'zhì',  # 劕
    0x5296: 'chán',  # 劖
    0x5297: 'zuān',  # 劗
    0x5298: 'mó',  # 劘
    0x5299: 'lí',  # 劙
    0x529A: 'zhú',  # 劚
    0x529B: 'lì',  # 力
    0x529C: 'yà',  # 劜
    0x529D: 'quàn',  # 劝
    0x529E: 'bàn',  # 办
    0x529F: 'gōng',  # 功
    0x52A0: 'jiā',  # 加
    0x52A1: 'wù',  # 务
    0x52A2: 'mài',  # 劢
    0x52A3: 'liè',  # 劣
    0x52A4: 'jìn,jìng',  # 劤
    0x52A5: 'kēng',  # 劥
    0x52A6: 'xié,liè',  # 劦
    0x52A7: 'zhǐ',  # 劧
    0x52A8: 'dòng',  # 动
    0x52A9: 'zhù,chú',  # 助
    0x52AA: 'nǔ',  # 努
    0x52AB: 'jié',  # 劫
    0x52AC: 'qú',  # 劬
    0x52AD: 'shào',  # 劭
    0x52AE: 'yì',  # 劮
    0x52AF: 'zhǔ',  # 劯
    0x52B0: 'miǎo',  # 劰
    0x52B1: 'lì',  # 励
    0x52B2: 'jìn,jìng',  # 劲
    0x52B3: 'láo',  # 劳
    0x52B4: 'láo',  # 労
    0x52B5: 'juàn',  # 劵
    0x52B6: 'kǒu',  # 劶
    0x52B7: 'yáng',  # 劷
    0x52B8: 'wā',  # 劸
    0x52B9: 'xiào',  # 効
    0x52BA: 'móu',  # 劺
    0x52BB: 'kuāng',  # 劻
    0x52BC: 'jié',  # 劼
    0x52BD: 'liè',  # 劽
    0x52BE: 'hé',  # 劾
    0x52BF: 'shì',  # 势
    0x52C0: 'kè',  # 勀
    0x52C1: 'jìn,jìng',  # 勁
    0x52C2: 'gào',  # 勂
    0x52C3: 'bó,bèi',  # 勃
    0x52C4: 'mǐn',  # 勄
    0x52C5: 'chì',  # 勅
    0x52C6: 'láng',  # 勆
    0x52C7: 'yǒng',  # 勇
    0x52C8: 'yǒng',  # 勈
    0x52C9: 'miǎn',  # 勉
    0x52CA: 'kè',  # 勊
    0x52CB: 'xūn',  # 勋
    0x52CC: 'juàn,juān',  # 勌
    0x52CD: 'qíng',  # 勍
    0x52CE: 'lù',  # 勎
    0x52CF: 'bù',  # 勏
    0x52D0: 'měng',  # 勐
    0x52D1: 'chì',  # 勑
    0x52D2: 'lè,lēi',  # 勒
    0x52D3: 'kài',  # 勓
    0x52D4: 'miǎn',  # 勔
    0x52D5: 'dòng',  # 動
    0x52D6: 'xù',  # 勖
    0x52D7: 'xù',  # 勗
    0x52D8: 'kān',  # 勘
    0x52D9: 'wù',  # 務
    0x52DA: 'yì',  # 勚
    0x52DB: 'xūn',  # 勛
    0x52DC: 'wěng,yǎng',  # 勜
    0x52DD: 'shèng',  # 勝
    0x52DE: 'láo',  # 勞
    0x52DF: 'mù',  # 募
    0x52E0: 'lù',  # 勠
    0x52E1: 'piāo',  # 勡
    0x52E2: 'shì',  # 勢
    0x52E3: 'jì',  # 勣
    0x52E4: 'qín',  # 勤
    0x52E5: 'jiàng',  # 勥
    0x52E6: 'jiǎo,chāo',  # 勦
    0x52E7: 'quàn',  # 勧
    0x52E8: 'xiàng',  # 勨
    0x52E9: 'yì',  # 勩
    0x52EA: 'qiāo',  # 勪
    0x52EB: 'fān',  # 勫
    0x52EC: 'juān',  # 勬
    0x52ED: 'tóng,dòng',  # 勭
    0x52EE: 'jù',  # 勮
    0x52EF: 'dān',  # 勯
    0x52F0: 'xié',  # 勰
    0x52F1: 'mài',  # 勱
    0x52F2: 'xūn',  # 勲
    0x52F3: 'xūn',  # 勳
    0x52F4: 'lǜ',  # 勴
    0x52F5: 'lì',  # 勵
    0x52F6: 'chè',  # 勶
    0x52F7: 'ráng,xiāng',  # 勷
    0x52F8: 'quàn',  # 勸
    0x52F9: 'bāo',  # 勹
    0x52FA: 'sháo',  # 勺
    0x52FB: 'yún',  # 勻
    0x52FC: 'jiū',  # 勼
    0x52FD: 'bào',  # 勽
    0x52FE: 'gōu,gòu',  # 勾
    0x52FF: 'wù',  # 勿
    0x5300: 'yún',  # 匀
    0x5301: 'mangmi',  # 匁
    0x5302: 'xiōng',  # 匂
    0x5303: 'gài',  # 匃
    0x5304: 'gài',  # 匄
    0x5305: 'bāo',  # 包
    0x5306: 'cōng',  # 匆
    0x5307: 'yì',  # 匇
    0x5308: 'xiōng',  # 匈
    0x5309: 'pēng',  # 匉
    0x530A: 'jū',  # 匊
    0x530B: 'táo,yáo',  # 匋
    0x530C: 'gé',  # 匌
    0x530D: 'pú',  # 匍
    0x530E: 'è',  # 匎
    0x530F: 'páo',  # 匏
    0x5310: 'fú',  # 匐
    0x5311: 'gōng',  # 匑
    0x5312: 'dá',  # 匒
    0x5313: 'jiù',  # 匓
    0x5314: 'gōng',  # 匔
    0x5315: 'bǐ',  # 匕
    0x5316: 'huà,huā',  # 化
    0x5317: 'běi,bèi',  # 北
    0x5318: 'nǎo',  # 匘
    0x5319: 'chí,shi',  # 匙
    0x531A: 'fāng',  # 匚
    0x531B: 'jiù',  # 匛
    0x531C: 'yí',  # 匜
    0x531D: 'zā',  # 匝
    0x531E: 'jiàng',  # 匞
    0x531F: 'kàng',  # 匟
    0x5320: 'jiàng',  # 匠
    0x5321: 'kuāng',  # 匡
    0x5322: 'hū',  # 匢
    0x5323: 'xiá',  # 匣
    0x5324: 'qū',  # 匤
    0x5325: 'fán',  # 匥
    0x5326: 'guǐ',  # 匦
    0x5327: 'qiè',  # 匧
    0x5328: 'zāng,cáng',  # 匨
    0x5329: 'kuāng',  # 匩
    0x532A: 'fěi',  # 匪
    0x532B: 'hū',  # 匫
    0x532C: 'yǔ',  # 匬
    0x532D: 'guǐ',  # 匭
    0x532E: 'kuì,guì',  # 匮
    0x532F: 'huì',  # 匯
    0x5330: 'dān',  # 匰
    0x5331: 'kuì,guì',  # 匱
    0x5332: 'lián',  # 匲
    0x5333: 'lián',  # 匳
    0x5334: 'suǎn',  # 匴
    0x5335: 'dú',  # 匵
    0x5336: 'jiù',  # 匶
    0x5337: 'jué',  # 匷
    0x5338: 'xì',  # 匸
    0x5339: 'pǐ',  # 匹
    0x533A: 'qū,ōu',  # 区
    0x533B: 'yī',  # 医
    0x533C: 'kē,qià',  # 匼
    0x533D: 'yǎn,yàn',  # 匽
    0x533E: 'biǎn',  # 匾
    0x533F: 'nì',  # 匿
    0x5340: 'qū,ōu',  # 區
    0x5341: 'shí',  # 十
    0x5342: 'xùn',  # 卂
    0x5343: 'qiān',  # 千
    0x5344: 'niàn',  # 卄
    0x5345: 'sà',  # 卅
    0x5346: 'zú',  # 卆
    0x5347: 'shēng',  # 升
    0x5348: 'wǔ',  # 午
    0x5349: 'huì',  # 卉
    0x534A: 'bàn',  # 半
    0x534B: 'shì',  # 卋
    0x534C: 'xì',  # 卌
    0x534D: 'wàn',  # 卍
    0x534E: 'huá,huà,huā',  # 华
    0x534F: 'xié',  # 协
    0x5350: 'wàn',  # 卐
    0x5351: 'bēi',  # 卑
    0x5352: 'zú,cù',  # 卒
    0x5353: 'zhuó',  # 卓
    0x5354: 'xié',  # 協
    0x5355: 'dān,shàn,chán',  # 单
    0x5356: 'mài',  # 卖
    0x5357: 'nán,nā',  # 南
    0x5358: 'dān',  # 単
    0x5359: 'jí',  # 卙
    0x535A: 'bó',  # 博
    0x535B: 'shuài,lǜ',  # 卛
    0x535C: 'bǔ,bo',  # 卜
    0x535D: 'guàn,kuàng',  # 卝
    0x535E: 'biàn',  # 卞
    0x535F: 'bǔ',  # 卟
    0x5360: 'zhān,zhàn',  # 占
    0x5361: 'qiǎ,kǎ',  # 卡
    0x5362: 'lú',  # 卢
    0x5363: 'yǒu',  # 卣
    0x5364: 'lǔ',  # 卤
    0x5365: 'xī',  # 卥
    0x5366: 'guà',  # 卦
    0x5367: 'wò',  # 卧
    0x5368: 'xiè',  # 卨
    0x5369: 'jié',  # 卩
    0x536A: 'jié',  # 卪
    0x536B: 'wèi',  # 卫
    0x536C: 'yǎng,áng',  # 卬
    0x536D: 'qióng',  # 卭
    0x536E: 'zhī',  # 卮
    0x536F: 'mǎo',  # 卯
    0x5370: 'yìn',  # 印
    0x5371: 'wēi',  # 危
    0x5372: 'shào',  # 卲
    0x5373: 'jí',  # 即
    0x5374: 'què',  # 却
    0x5375: 'luǎn',  # 卵
    0x5376: 'chǐ',  # 卶
    0x5377: 'juàn,juǎn',  # 卷
    0x5378: 'xiè',  # 卸
    0x5379: 'xù',  # 卹
    0x537A: 'jǐn',  # 卺
    0x537B: 'què',  # 卻
    0x537C: 'wù',  # 卼
    0x537D: 'jí',  # 卽
    0x537E: 'è',  # 卾
    0x537F: 'qīng',  # 卿
    0x5380: 'xī',  # 厀
    0x5381: 'sān',  # 厁
    0x5382: 'chǎng,ān,hàn',  # 厂
    0x5383: 'wēi,yán',  # 厃
    0x5384: 'è',  # 厄
    0x5385: 'tīng',  # 厅
    0x5386: 'lì',  # 历
    0x5387: 'zhé,zhái',  # 厇
    0x5388: 'hàn,àn',  # 厈
    0x5389: 'lì',  # 厉
    0x538A: 'yǎ',  # 厊
    0x538B: 'yā,yà',  # 压
    0x538C: 'yàn',  # 厌
    0x538D: 'shè',  # 厍
    0x538E: 'dǐ',  # 厎
    0x538F: 'zhǎ,zhǎi',  # 厏
    0x5390: 'páng',  # 厐
    0x5391: 'yá',  # 厑
    0x5392: 'qiè',  # 厒
    0x5393: 'yá',  # 厓
    0x5394: 'zhì,shī',  # 厔
    0x5395: 'cè',  # 厕
    0x5396: 'máng',  # 厖
    0x5397: 'tí',  # 厗
    0x5398: 'lí',  # 厘
    0x5399: 'shè',  # 厙
    0x539A: 'hòu',  # 厚
    0x539B: 'tīng',  # 厛
    0x539C: 'zuī',  # 厜
    0x539D: 'cuò',  # 厝
    0x539E: 'fèi',  # 厞
    0x539F: 'yuán',  # 原
    0x53A0: 'cè',  # 厠
    0x53A1: 'yuán',  # 厡
    0x53A2: 'xiāng',  # 厢
    0x53A3: 'yǎn',  # 厣
    0x53A4: 'lì',  # 厤
    0x53A5: 'jué',  # 厥
    0x53A6: 'shà,xià',  # 厦
    0x53A7: 'diān',  # 厧
    0x53A8: 'chú',  # 厨
    0x53A9: 'jiù',  # 厩
    0x53AA: 'jǐn',  # 厪
    0x53AB: 'áo',  # 厫
    0x53AC: 'guǐ',  # 厬
    0x53AD: 'yàn',  # 厭
    0x53AE: 'sī',  # 厮
    0x53AF: 'lì',  # 厯
    0x53B0: 'chǎng',  # 厰
    0x53B1: 'qiān,lán',  # 厱
    0x53B2: 'lì',  # 厲
    0x53B3: 'yán',  # 厳
    0x53B4: 'yǎn',  # 厴
    0x53B5: 'yuán',  # 厵
    0x53B6: 'sī,mǒu',  # 厶
    0x53B7: 'gōng,hóng',  # 厷
    0x53B8: 'lín,miǎo',  # 厸
    0x53B9: 'róu,qiú',  # 厹
    0x53BA: 'qù',  # 厺
    0x53BB: 'qù',  # 去
    0x53BC: 'keum',  # 厼
    0x53BD: 'lěi',  # 厽
    0x53BE: 'dū',  # 厾
    0x53BF: 'xiàn,xuán',  # 县
    0x53C0: 'zhuān',  # 叀
    0x53C1: 'sān',  # 叁
    0x53C2: 'cān,shēn,cēn,sān',  # 参
    0x53C3: 'cān,shēn,cēn,sān',  # 參
    0x53C4: 'cān,shēn,cēn,sān',  # 叄
    0x53C5: 'cān,shēn,cēn,sān',  # 叅
    0x53C6: 'ài',  # 叆
    0x53C7: 'dài',  # 叇
    0x53C8: 'yòu',  # 又
    0x53C9: 'chā,chá,chǎ',  # 叉
    0x53CA: 'jí',  # 及
    0x53CB: 'yǒu',  # 友
    0x53CC: 'shuāng',  # 双
    0x53CD: 'fǎn',  # 反
    0x53CE: 'shōu',  # 収
    0x53CF: 'guái',  # 叏
    0x53D0: 'bá',  # 叐
    0x53D1: 'fā,fà',  # 发
    0x53D2: 'ruò',  # 叒
    0x53D3: 'lì',  # 叓
    0x53D4: 'shū',  # 叔
    0x53D5: 'zhuó,yǐ,lì,jué',  # 叕
    0x53D6: 'qǔ',  # 取
    0x53D7: 'shòu',  # 受
    0x53D8: 'biàn',  # 变
    0x53D9: 'xù',  # 叙
    0x53DA: 'jiǎ',  # 叚
    0x53DB: 'pàn',  # 叛
    0x53DC: 'sǒu',  # 叜
    0x53DD: 'jí',  # 叝
    0x53DE: 'wèi,yù',  # 叞
    0x53DF: 'sǒu',  # 叟
    0x53E0: 'dié',  # 叠
    0x53E1: 'ruì',  # 叡
    0x53E2: 'cóng',  # 叢
    0x53E3: 'kǒu',  # 口
    0x53E4: 'gǔ',  # 古
    0x53E5: 'jù,gōu',  # 句
    0x53E6: 'lìng',  # 另
    0x53E7: 'guǎ',  # 叧
    0x53E8: 'tāo,dāo',  # 叨
    0x53E9: 'kòu',  # 叩
    0x53EA: 'zhī,zhǐ',  # 只
    0x53EB: 'jiào',  # 叫
    0x53EC: 'zhào,shào',  # 召
    0x53ED: 'bā',  # 叭
    0x53EE: 'dīng',  # 叮
    0x53EF: 'kě,kè',  # 可
    0x53F0: 'tái,tāi',  # 台
    0x53F1: 'chì',  # 叱
    0x53F2: 'shǐ',  # 史
    0x53F3: 'yòu',  # 右
    0x53F4: 'qiú',  # 叴
    0x53F5: 'pǒ',  # 叵
    0x53F6: 'yè,xié',  # 叶
    0x53F7: 'hào,háo',  # 号
    0x53F8: 'sī',  # 司
    0x53F9: 'tàn',  # 叹
    0x53FA: 'chǐ',  # 叺
    0x53FB: 'lè',  # 叻
    0x53FC: 'diāo',  # 叼
    0x53FD: 'jī',  # 叽
    0x53FE: 'dug',  # 叾
    0x53FF: 'hōng,hóng',  # 叿
    0x5400: 'miē',  # 吀
    0x5401: 'xū,yù',  # 吁
    0x5402: 'máng',  # 吂
    0x5403: 'chī',  # 吃
    0x5404: 'gè,gě',  # 各
    0x5405: 'xuān,sòng',  # 吅
    0x5406: 'yāo',  # 吆
    0x5407: 'zǐ',  # 吇
    0x5408: 'hé,gě',  # 合
    0x5409: 'jí',  # 吉
    0x540A: 'diào',  # 吊
    0x540B: 'dòu,cùn',  # 吋
    0x540C: 'tóng,tòng',  # 同
    0x540D: 'míng',  # 名
    0x540E: 'hòu',  # 后
    0x540F: 'lì',  # 吏
    0x5410: 'tǔ,tù',  # 吐
    0x5411: 'xiàng',  # 向
    0x5412: 'zhà,zhā',  # 吒
    0x5413: 'xià,hè',  # 吓
    0x5414: 'yē',  # 吔
    0x5415: 'lǚ',  # 吕
    0x5416: 'yā,ā',  # 吖
    0x5417: 'má,mǎ,ma',  # 吗
    0x5418: 'ǒu',  # 吘
    0x5419: 'huō',  # 吙
    0x541A: 'yī',  # 吚
    0x541B: 'jūn',  # 君
    0x541C: 'chǒu',  # 吜
    0x541D: 'lìn',  # 吝
    0x541E: 'tūn',  # 吞
    0x541F: 'yín',  # 吟
    0x5420: 'fèi',  # 吠
    0x5421: 'pǐ,bǐ',  # 吡
    0x5422: 'qìn',  # 吢
    0x5423: 'qìn',  # 吣
    0x5424: 'jiè,gè',  # 吤
    0x5425: 'bù',  # 吥
    0x5426: 'fǒu,pǐ',  # 否
    0x5427: 'bā,ba',  # 吧
    0x5428: 'dūn',  # 吨
    0x5429: 'fēn',  # 吩
    0x542A: 'é,huā',  # 吪
    0x542B: 'hán',  # 含
    0x542C: 'tīng',  # 听
    0x542D: 'háng,kēng',  # 吭
    0x542E: 'shǔn',  # 吮
    0x542F: 'qǐ',  # 启
    0x5430: 'hóng',  # 吰
    0x5431: 'zhī,zī',  # 吱
    0x5432: 'yǐn,shěn',  # 吲
    0x5433: 'wú',  # 吳
    0x5434: 'wú',  # 吴
    0x5435: 'chǎo,chāo',  # 吵
    0x5436: 'nà,nè',  # 吶
    0x5437: 'xuè,chuò,jué',  # 吷
    0x5438: 'xī',  # 吸
    0x5439: 'chuī',  # 吹
    0x543A: 'dōu,rú',  # 吺
    0x543B: 'wěn',  # 吻
    0x543C: 'hǒu',  # 吼
    0x543D: 'hǒu,hōng,ōu',  # 吽
    0x543E: 'wú,yù',  # 吾
    0x543F: 'gào',  # 吿
    0x5440: 'yā,ya',  # 呀
    0x5441: 'jùn',  # 呁
    0x5442: 'lǚ',  # 呂
    0x5443: 'è',  # 呃
    0x5444: 'gé',  # 呄
    0x5445: 'wěn',  # 呅
    0x5446: 'dāi',  # 呆
    0x5447: 'qǐ',  # 呇
    0x5448: 'chéng',  # 呈
    0x5449: 'wú',  # 呉
    0x544A: 'gào',  # 告
    0x544B: 'fū',  # 呋
    0x544C: 'jiào',  # 呌
    0x544D: 'hōng',  # 呍
    0x544E: 'chǐ',  # 呎
    0x544F: 'shēng',  # 呏
    0x5450: 'nà,nè',  # 呐
    0x5451: 'tūn,tiān',  # 呑
    0x5452: 'fǔ,ḿ',  # 呒
    0x5453: 'yì',  # 呓
    0x5454: 'dāi',  # 呔
    0x5455: 'ǒu,ōu,òu',  # 呕
    0x5456: 'lì',  # 呖
    0x5457: 'bei,bài',  # 呗
    0x5458: 'yuán,yún,yùn',  # 员
    0x5459: 'wāi,hé,wǒ,wā,guǎ,guō',  # 呙
    0x545A: 'huá,qì',  # 呚
    0x545B: 'qiāng,qiàng',  # 呛
    0x545C: 'wū',  # 呜
    0x545D: 'è',  # 呝
    0x545E: 'shī',  # 呞
    0x545F: 'juǎn',  # 呟
    0x5460: 'pěn',  # 呠
    0x5461: 'wěn,mǐn',  # 呡
    0x5462: 'ní,ne',  # 呢
    0x5463: 'ḿ,m̀,móu',  # 呣
    0x5464: 'líng',  # 呤
    0x5465: 'rán',  # 呥
    0x5466: 'yōu',  # 呦
    0x5467: 'dǐ',  # 呧
    0x5468: 'zhōu',  # 周
    0x5469: 'shì',  # 呩
    0x546A: 'zhòu',  # 呪
    0x546B: 'tiè,chè',  # 呫
    0x546C: 'xì',  # 呬
    0x546D: 'yì',  # 呭
    0x546E: 'qì,zhī',  # 呮
    0x546F: 'píng',  # 呯
    0x5470: 'zǐ,cī',  # 呰
    0x5471: 'guā,gū,guǎ',  # 呱
    0x5472: 'zī,cī',  # 呲
    0x5473: 'wèi',  # 味
    0x5474: 'xǔ,hǒu,gòu',  # 呴
    0x5475: 'hē,a,kē',  # 呵
    0x5476: 'náo',  # 呶
    0x5477: 'xiā',  # 呷
    0x5478: 'pēi',  # 呸
    0x5479: 'yì',  # 呹
    0x547A: 'xiāo,háo',  # 呺
    0x547B: 'shēn',  # 呻
    0x547C: 'hū',  # 呼
    0x547D: 'mìng',  # 命
    0x547E: 'dá,dàn',  # 呾
    0x547F: 'qū',  # 呿
    0x5480: 'jǔ,zuǐ',  # 咀
    0x5481: 'xián,gān',  # 咁
    0x5482: 'zā',  # 咂
    0x5483: 'tuō',  # 咃
    0x5484: 'duō',  # 咄
    0x5485: 'pǒu',  # 咅
    0x5486: 'páo',  # 咆
    0x5487: 'bì',  # 咇
    0x5488: 'fú',  # 咈
    0x5489: 'yǎng',  # 咉
    0x548A: 'hé,hè',  # 咊
    0x548B: 'zǎ,zé,zhā',  # 咋
    0x548C: 'hé,hè,huó,huò,hú',  # 和
    0x548D: 'hāi',  # 咍
    0x548E: 'jiù',  # 咎
    0x548F: 'yǒng',  # 咏
    0x5490: 'fù',  # 咐
    0x5491: 'dā',  # 咑
    0x5492: 'zhòu',  # 咒
    0x5493: 'wǎ',  # 咓
    0x5494: 'kǎ',  # 咔
    0x5495: 'gū',  # 咕
    0x5496: 'kā,gā',  # 咖
    0x5497: 'zuo',  # 咗
    0x5498: 'bù',  # 咘
    0x5499: 'lóng',  # 咙
    0x549A: 'dōng',  # 咚
    0x549B: 'níng',  # 咛
    0x549C: 'tuō',  # 咜
    0x549D: 'sī',  # 咝
    0x549E: 'xiàn,xián',  # 咞
    0x549F: 'huò',  # 咟
    0x54A0: 'qì',  # 咠
    0x54A1: 'èr',  # 咡
    0x54A2: 'è',  # 咢
    0x54A3: 'guāng',  # 咣
    0x54A4: 'zhà',  # 咤
    0x54A5: 'dié,xī',  # 咥
    0x54A6: 'yí',  # 咦
    0x54A7: 'liě,liē,lié,lie',  # 咧
    0x54A8: 'zī',  # 咨
    0x54A9: 'miē',  # 咩
    0x54AA: 'mī',  # 咪
    0x54AB: 'zhǐ',  # 咫
    0x54AC: 'yǎo',  # 咬
    0x54AD: 'jī,xī,qià',  # 咭
    0x54AE: 'zhòu',  # 咮
    0x54AF: 'kǎ,luò,lo,gē',  # 咯
    0x54B0: 'shù,xún',  # 咰
    0x54B1: 'zán,zá,zǎ',  # 咱
    0x54B2: 'xiào',  # 咲
    0x54B3: 'ké,hāi',  # 咳
    0x54B4: 'huī',  # 咴
    0x54B5: 'kuā',  # 咵
    0x54B6: 'huài,shì',  # 咶
    0x54B7: 'táo',  # 咷
    0x54B8: 'xián',  # 咸
    0x54B9: 'è,àn',  # 咹
    0x54BA: 'xuǎn,xuān',  # 咺
    0x54BB: 'xiū',  # 咻
    0x54BC: 'wāi,hé,wǒ,wā,guǎ,guō',  # 咼
    0x54BD: 'yān,yàn,yè',  # 咽
    0x54BE: 'lǎo',  # 咾
    0x54BF: 'yī',  # 咿
    0x54C0: 'āi',  # 哀
    0x54C1: 'pǐn',  # 品
    0x54C2: 'shěn',  # 哂
    0x54C3: 'tóng',  # 哃
    0x54C4: 'hōng,hǒng,hòng',  # 哄
    0x54C5: 'xiōng',  # 哅
    0x54C6: 'duō',  # 哆
    0x54C7: 'wā,wa',  # 哇
    0x54C8: 'hā,hǎ,hà',  # 哈
    0x54C9: 'zāi',  # 哉
    0x54CA: 'yòu',  # 哊
    0x54CB: 'diè,dì',  # 哋
    0x54CC: 'pài',  # 哌
    0x54CD: 'xiǎng',  # 响
    0x54CE: 'āi',  # 哎
    0x54CF: 'gén,hěn',  # 哏
    0x54D0: 'kuāng',  # 哐
    0x54D1: 'yǎ,yā',  # 哑
    0x54D2: 'dā',  # 哒
    0x54D3: 'xiāo',  # 哓
    0x54D4: 'bì',  # 哔
    0x54D5: 'yuě,huì',  # 哕
    0x54D6: 'nián',  # 哖
    0x54D7: 'huá,huā',  # 哗
    0x54D8: 'xíng',  # 哘
    0x54D9: 'kuài',  # 哙
    0x54DA: 'duǒ',  # 哚
    0x54DB: 'ppun',  # 哛
    0x54DC: 'jì,jiē,zhāi',  # 哜
    0x54DD: 'nóng',  # 哝
    0x54DE: 'mōu',  # 哞
    0x54DF: 'yō,yo',  # 哟
    0x54E0: 'hào',  # 哠
    0x54E1: 'yuán,yún,yùn',  # 員
    0x54E2: 'lòng',  # 哢
    0x54E3: 'pǒu',  # 哣
    0x54E4: 'máng',  # 哤
    0x54E5: 'gē',  # 哥
    0x54E6: 'ó,ò,é',  # 哦
    0x54E7: 'chī',  # 哧
    0x54E8: 'shào',  # 哨
    0x54E9: 'li,lǐ,lī',  # 哩
    0x54EA: 'nǎ,něi,na,né',  # 哪
    0x54EB: 'zú',  # 哫
    0x54EC: 'hè',  # 哬
    0x54ED: 'kū',  # 哭
    0x54EE: 'xiào',  # 哮
    0x54EF: 'xiàn',  # 哯
    0x54F0: 'láo',  # 哰
    0x54F1: 'pò,bā,bō',  # 哱
    0x54F2: 'zhé',  # 哲
    0x54F3: 'zhā',  # 哳
    0x54F4: 'liàng,láng',  # 哴
    0x54F5: 'bā',  # 哵
    0x54F6: 'miē',  # 哶
    0x54F7: 'liè,lǜ',  # 哷
    0x54F8: 'suī',  # 哸
    0x54F9: 'fú',  # 哹
    0x54FA: 'bǔ',  # 哺
    0x54FB: 'hān',  # 哻
    0x54FC: 'hēng,hng',  # 哼
    0x54FD: 'gěng',  # 哽
    0x54FE: 'chuò,yuè',  # 哾
    0x54FF: 'gě,jiā',  # 哿
    0x5500: 'yòu',  # 唀
    0x5501: 'yàn',  # 唁
    0x5502: 'gū',  # 唂
    0x5503: 'gū',  # 唃
    0x5504: 'bei,bài',  # 唄
    0x5505: 'hán,hàn',  # 唅
    0x5506: 'suō',  # 唆
    0x5507: 'chún',  # 唇
    0x5508: 'yì',  # 唈
    0x5509: 'āi,ài',  # 唉
    0x550A: 'jiá,qiǎn',  # 唊
    0x550B: 'tǔ,tù',  # 唋
    0x550C: 'dàn,xián,yán',  # 唌
    0x550D: 'wǎn',  # 唍
    0x550E: 'lì',  # 唎
    0x550F: 'xī',  # 唏
    0x5510: 'táng',  # 唐
    0x5511: 'zuò',  # 唑
    0x5512: 'qiú',  # 唒
    0x5513: 'chē',  # 唓
    0x5514: 'wù,wú,ńg,ń',  # 唔
    0x5515: 'zào',  # 唕
    0x5516: 'yǎ',  # 唖
    0x5517: 'dōu',  # 唗
    0x5518: 'qǐ',  # 唘
    0x5519: 'dí',  # 唙
    0x551A: 'qìn',  # 唚
    0x551B: 'mài',  # 唛
    0x551C: 'mas',  # 唜
    0x551D: 'gòng,hǒng,gǒng',  # 唝
    0x551E: 'dóu',  # 唞
    0x551F: 'keos',  # 唟
    0x5520: 'lào,láo',  # 唠
    0x5521: 'liǎng',  # 唡
    0x5522: 'suǒ',  # 唢
    0x5523: 'zào',  # 唣
    0x5524: 'huàn',  # 唤
    0x5525: 'léng',  # 唥
    0x5526: 'shā',  # 唦
    0x5527: 'jī',  # 唧
    0x5528: 'zǔ',  # 唨
    0x5529: 'wō,wěi',  # 唩
    0x552A: 'fěng',  # 唪
    0x552B: 'jìn,yín',  # 唫
    0x552C: 'hǔ,xià',  # 唬
    0x552D: 'qì',  # 唭
    0x552E: 'shòu',  # 售
    0x552F: 'wéi',  # 唯
    0x5530: 'shuā',  # 唰
    0x5531: 'chàng',  # 唱
    0x5532: 'ér,wā',  # 唲
    0x5533: 'lì',  # 唳
    0x5534: 'qiàng',  # 唴
    0x5535: 'ǎn',  # 唵
    0x5536: 'jiè,zé,jí',  # 唶
    0x5537: 'yō',  # 唷
    0x5538: 'niàn',  # 唸
    0x5539: 'yū',  # 唹
    0x553A: 'tiǎn',  # 唺
    0x553B: 'lài',  # 唻
    0x553C: 'shà',  # 唼
    0x553D: 'xī',  # 唽
    0x553E: 'tuò',  # 唾
    0x553F: 'hū',  # 唿
    0x5540: 'ái',  # 啀
    0x5541: 'zhōu,zhāo,tiào',  # 啁
    0x5542: 'gòu',  # 啂
    0x5543: 'kěn',  # 啃
    0x5544: 'zhuó',  # 啄
    0x5545: 'zhuó,zhào',  # 啅
    0x5546: 'shāng',  # 商
    0x5547: 'dí',  # 啇
    0x5548: 'hèng',  # 啈
    0x5549: 'lán,lín',  # 啉
    0x554A: 'ā,á,ǎ,à,a',  # 啊
    0x554B: 'cǎi',  # 啋
    0x554C: 'qiāng',  # 啌
    0x554D: 'zhūn,tūn,xiāng,duǐ',  # 啍
    0x554E: 'wǔ',  # 啎
    0x554F: 'wèn',  # 問
    0x5550: 'cuì,qi',  # 啐
    0x5551: 'shà,jié,dié,tì',  # 啑
    0x5552: 'gǔ',  # 啒
    0x5553: 'qǐ',  # 啓
    0x5554: 'qǐ',  # 啔
    0x5555: 'táo',  # 啕
    0x5556: 'dàn',  # 啖
    0x5557: 'dàn',  # 啗
    0x5558: 'yuē,wā',  # 啘
    0x5559: 'zǐ,cǐ',  # 啙
    0x555A: 'bǐ,tú',  # 啚
    0x555B: 'cuì',  # 啛
    0x555C: 'chuò,chuài',  # 啜
    0x555D: 'hé',  # 啝
    0x555E: 'yǎ,yā',  # 啞
    0x555F: 'qǐ',  # 啟
    0x5560: 'zhé',  # 啠
    0x5561: 'fēi',  # 啡
    0x5562: 'liǎng',  # 啢
    0x5563: 'xián',  # 啣
    0x5564: 'pí',  # 啤
    0x5565: 'shá',  # 啥
    0x5566: 'lā,la',  # 啦
    0x5567: 'zé',  # 啧
    0x5568: 'qíng,yīng',  # 啨
    0x5569: 'guà',  # 啩
    0x556A: 'pā',  # 啪
    0x556B: 'zhě,shì',  # 啫
    0x556C: 'sè',  # 啬
    0x556D: 'zhuàn',  # 啭
    0x556E: 'niè',  # 啮
    0x556F: 'guō',  # 啯
    0x5570: 'luō,luó,luo',  # 啰
    0x5571: 'yán',  # 啱
    0x5572: 'dī',  # 啲
    0x5573: 'quán',  # 啳
    0x5574: 'tān,chǎn,tuō',  # 啴
    0x5575: 'bo',  # 啵
    0x5576: 'dìng',  # 啶
    0x5577: 'lāng',  # 啷
    0x5578: 'xiào',  # 啸
    0x5579: 'jú',  # 啹
    0x557A: 'táng',  # 啺
    0x557B: 'chì',  # 啻
    0x557C: 'tí',  # 啼
    0x557D: 'ān,án',  # 啽
    0x557E: 'jiū',  # 啾
    0x557F: 'dàn',  # 啿
    0x5580: 'kā',  # 喀
    0x5581: 'yóng',  # 喁
    0x5582: 'wèi',  # 喂
    0x5583: 'nán',  # 喃
    0x5584: 'shàn',  # 善
    0x5585: 'yù',  # 喅
    0x5586: 'zhé',  # 喆
    0x5587: 'lǎ',  # 喇
    0x5588: 'jiē',  # 喈
    0x5589: 'hóu',  # 喉
    0x558A: 'hǎn',  # 喊
    0x558B: 'dié,zhá',  # 喋
    0x558C: 'zhōu',  # 喌
    0x558D: 'chái',  # 喍
    0x558E: 'wāi',  # 喎
    0x558F: 'nuò,rě',  # 喏
    0x5590: 'huò,guó,xù',  # 喐
    0x5591: 'yīn',  # 喑
    0x5592: 'zán,zá,zǎ',  # 喒
    0x5593: 'yāo',  # 喓
    0x5594: 'ō,wō',  # 喔
    0x5595: 'miǎn',  # 喕
    0x5596: 'hú',  # 喖
    0x5597: 'yǔn',  # 喗
    0x5598: 'chuǎn',  # 喘
    0x5599: 'huì',  # 喙
    0x559A: 'huàn',  # 喚
    0x559B: 'huàn,yuán,xuǎn,hé',  # 喛
    0x559C: 'xǐ',  # 喜
    0x559D: 'hē,hè,yè',  # 喝
    0x559E: 'jī',  # 喞
    0x559F: 'kuì',  # 喟
    0x55A0: 'zhǒng,chuáng',  # 喠
    0x55A1: 'wéi,wèi',  # 喡
    0x55A2: 'shà',  # 喢
    0x55A3: 'xǔ',  # 喣
    0x55A4: 'huáng',  # 喤
    0x55A5: 'duó,zhà',  # 喥
    0x55A6: 'yán',  # 喦
    0x55A7: 'xuān',  # 喧
    0x55A8: 'liàng',  # 喨
    0x55A9: 'yù',  # 喩
    0x55AA: 'sāng,sàng',  # 喪
    0x55AB: 'chī',  # 喫
    0x55AC: 'qiáo,jiāo',  # 喬
    0x55AD: 'yàn',  # 喭
    0x55AE: 'dān,shàn,chán',  # 單
    0x55AF: 'pèn,bēn',  # 喯
    0x55B0: 'cān,sūn,qī',  # 喰
    0x55B1: 'lí',  # 喱
    0x55B2: 'yō,yo',  # 喲
    0x55B3: 'zhā,chā',  # 喳
    0x55B4: 'wēi',  # 喴
    0x55B5: 'miāo',  # 喵
    0x55B6: 'yíng',  # 営
    0x55B7: 'pēn,pèn',  # 喷
    0x55B8: 'phos',  # 喸
    0x55B9: 'kuí',  # 喹
    0x55BA: 'xí',  # 喺
    0x55BB: 'yù',  # 喻
    0x55BC: 'jiē',  # 喼
    0x55BD: 'lóu,lou',  # 喽
    0x55BE: 'kù',  # 喾
    0x55BF: 'zào,qiāo',  # 喿
    0x55C0: 'hù',  # 嗀
    0x55C1: 'tí',  # 嗁
    0x55C2: 'yáo',  # 嗂
    0x55C3: 'hè,xiāo,xiào,hù',  # 嗃
    0x55C4: 'shà,á',  # 嗄
    0x55C5: 'xiù',  # 嗅
    0x55C6: 'qiāng,qiàng',  # 嗆
    0x55C7: 'sè',  # 嗇
    0x55C8: 'yōng',  # 嗈
    0x55C9: 'sù',  # 嗉
    0x55CA: 'gòng,hǒng,gǒng',  # 嗊
    0x55CB: 'xié',  # 嗋
    0x55CC: 'yì,ài',  # 嗌
    0x55CD: 'suō',  # 嗍
    0x55CE: 'má,mǎ,ma',  # 嗎
    0x55CF: 'chā',  # 嗏
    0x55D0: 'hài',  # 嗐
    0x55D1: 'kē,kè',  # 嗑
    0x55D2: 'tà,dā',  # 嗒
    0x55D3: 'sǎng',  # 嗓
    0x55D4: 'chēn',  # 嗔
    0x55D5: 'rù',  # 嗕
    0x55D6: 'sōu',  # 嗖
    0x55D7: 'wā,gǔ',  # 嗗
    0x55D8: 'jī',  # 嗘
    0x55D9: 'bēng,pǎng',  # 嗙
    0x55DA: 'wū',  # 嗚
    0x55DB: 'xián,qiàn,qiè',  # 嗛
    0x55DC: 'shì',  # 嗜
    0x55DD: 'gé',  # 嗝
    0x55DE: 'zī',  # 嗞
    0x55DF: 'jiē',  # 嗟
    0x55E0: 'lào',  # 嗠
    0x55E1: 'wēng',  # 嗡
    0x55E2: 'wà',  # 嗢
    0x55E3: 'sì',  # 嗣
    0x55E4: 'chī',  # 嗤
    0x55E5: 'háo',  # 嗥
    0x55E6: 'suō',  # 嗦
    0x55E7: 'jiālún',  # 嗧
    0x55E8: 'hāi,hēi',  # 嗨
    0x55E9: 'suǒ',  # 嗩
    0x55EA: 'qín',  # 嗪
    0x55EB: 'niè',  # 嗫
    0x55EC: 'hē',  # 嗬
    0x55ED: 'zi',  # 嗭
    0x55EE: 'sǎi',  # 嗮
    0x55EF: 'ǹg,ńg,ňg,ǹ,ń,ň',  # 嗯
    0x55F0: 'gě',  # 嗰
    0x55F1: 'ná',  # 嗱
    0x55F2: 'diǎ',  # 嗲
    0x55F3: 'ǎi,ài,āi',  # 嗳
    0x55F4: 'qiāng',  # 嗴
    0x55F5: 'tōng',  # 嗵
    0x55F6: 'bì',  # 嗶
    0x55F7: 'áo',  # 嗷
    0x55F8: 'áo',  # 嗸
    0x55F9: 'lián',  # 嗹
    0x55FA: 'zuī,suī',  # 嗺
    0x55FB: 'zhē,zhè,zhù,zhe',  # 嗻
    0x55FC: 'mò',  # 嗼
    0x55FD: 'sòu',  # 嗽
    0x55FE: 'sǒu',  # 嗾
    0x55FF: 'tǎn',  # 嗿
    0x5600: 'dí',  # 嘀
    0x5601: 'qī',  # 嘁
    0x5602: 'jiào',  # 嘂
    0x5603: 'chōng',  # 嘃
    0x5604: 'jiào,dǎo',  # 嘄
    0x5605: 'kǎi,gě',  # 嘅
    0x5606: 'tàn',  # 嘆
    0x5607: 'shān,càn',  # 嘇
    0x5608: 'cáo',  # 嘈
    0x5609: 'jiā',  # 嘉
    0x560A: 'ái',  # 嘊
    0x560B: 'xiào',  # 嘋
    0x560C: 'piāo',  # 嘌
    0x560D: 'lóu,lou',  # 嘍
    0x560E: 'gā,gá,gǎ',  # 嘎
    0x560F: 'gǔ',  # 嘏
    0x5610: 'xiāo,jiāo',  # 嘐
    0x5611: 'hū',  # 嘑
    0x5612: 'huì',  # 嘒
    0x5613: 'guō',  # 嘓
    0x5614: 'ǒu,ōu,òu',  # 嘔
    0x5615: 'xiān',  # 嘕
    0x5616: 'zé',  # 嘖
    0x5617: 'cháng',  # 嘗
    0x5618: 'xū,shī',  # 嘘
    0x5619: 'pó',  # 嘙
    0x561A: 'dē,dēi',  # 嘚
    0x561B: 'má,ma',  # 嘛
    0x561C: 'mà',  # 嘜
    0x561D: 'hú',  # 嘝
    0x561E: 'lei,lē',  # 嘞
    0x561F: 'dū',  # 嘟
    0x5620: 'gā,gá,gǎ',  # 嘠
    0x5621: 'tāng',  # 嘡
    0x5622: 'yě',  # 嘢
    0x5623: 'bēng',  # 嘣
    0x5624: 'yīng',  # 嘤
    0x5625: 'sāi',  # 嘥
    0x5626: 'jiào',  # 嘦
    0x5627: 'mì',  # 嘧
    0x5628: 'xiào',  # 嘨
    0x5629: 'huá,huā',  # 嘩
    0x562A: 'mǎi',  # 嘪
    0x562B: 'rán',  # 嘫
    0x562C: 'zuō',  # 嘬
    0x562D: 'pēng',  # 嘭
    0x562E: 'lào,láo',  # 嘮
    0x562F: 'xiào',  # 嘯
    0x5630: 'jī',  # 嘰
    0x5631: 'zhǔ',  # 嘱
    0x5632: 'cháo,zhāo',  # 嘲
    0x5633: 'kuì',  # 嘳
    0x5634: 'zuǐ',  # 嘴
    0x5635: 'xiāo',  # 嘵
    0x5636: 'sī',  # 嘶
    0x5637: 'háo',  # 嘷
    0x5638: 'fǔ,ḿ',  # 嘸
    0x5639: 'liáo',  # 嘹
    0x563A: 'qiáo,qiào',  # 嘺
    0x563B: 'xī',  # 嘻
    0x563C: 'chù,xù,shòu',  # 嘼
    0x563D: 'tān,chǎn',  # 嘽
    0x563E: 'dàn,tán',  # 嘾
    0x563F: 'hēi,mò',  # 嘿
    0x5640: 'xùn',  # 噀
    0x5641: 'ě',  # 噁
    0x5642: 'zūn',  # 噂
    0x5643: 'fān,bo',  # 噃
    0x5644: 'chī',  # 噄
    0x5645: 'huī',  # 噅
    0x5646: 'zǎn',  # 噆
    0x5647: 'chuáng',  # 噇
    0x5648: 'cù,zā,hé',  # 噈
    0x5649: 'dàn',  # 噉
    0x564A: 'jué',  # 噊
    0x564B: 'tūn,kuò',  # 噋
    0x564C: 'cēng',  # 噌
    0x564D: 'jiào',  # 噍
    0x564E: 'yē',  # 噎
    0x564F: 'xī',  # 噏
    0x5650: 'qì',  # 噐
    0x5651: 'háo',  # 噑
    0x5652: 'lián',  # 噒
    0x5653: 'xū,shī',  # 噓
    0x5654: 'dēng',  # 噔
    0x5655: 'huī',  # 噕
    0x5656: 'yín',  # 噖
    0x5657: 'pū',  # 噗
    0x5658: 'juē',  # 噘
    0x5659: 'qín',  # 噙
    0x565A: 'xún',  # 噚
    0x565B: 'niè',  # 噛
    0x565C: 'lū',  # 噜
    0x565D: 'sī',  # 噝
    0x565E: 'yǎn',  # 噞
    0x565F: 'yīng',  # 噟
    0x5660: 'dā',  # 噠
    0x5661: 'zhān',  # 噡
    0x5662: 'ō',  # 噢
    0x5663: 'zhòu,zhuó',  # 噣
    0x5664: 'jìn',  # 噤
    0x5665: 'nóng',  # 噥
    0x5666: 'yuě,huì',  # 噦
    0x5667: 'xiè',  # 噧
    0x5668: 'qì',  # 器
    0x5669: 'è',  # 噩
    0x566A: 'zào',  # 噪
    0x566B: 'yī',  # 噫
    0x566C: 'shì',  # 噬
    0x566D: 'jiào,qiào,chī',  # 噭
    0x566E: 'yuàn',  # 噮
    0x566F: 'ǎi,ài,āi',  # 噯
    0x5670: 'yōng,yǒng',  # 噰
    0x5671: 'jué,xué',  # 噱
    0x5672: 'kuài',  # 噲
    0x5673: 'yǔ',  # 噳
    0x5674: 'pēn,pèn',  # 噴
    0x5675: 'dào',  # 噵
    0x5676: 'gá',  # 噶
    0x5677: 'xīn,hěn,hèn',  # 噷
    0x5678: 'dūn',  # 噸
    0x5679: 'dāng',  # 噹
    0x567A: 'xīn',  # 噺
    0x567B: 'sāi',  # 噻
    0x567C: 'pī',  # 噼
    0x567D: 'pǐ',  # 噽
    0x567E: 'yīn',  # 噾
    0x567F: 'zuǐ',  # 噿
    0x5680: 'níng',  # 嚀
    0x5681: 'dí',  # 嚁
    0x5682: 'làn',  # 嚂
    0x5683: 'tà',  # 嚃
    0x5684: 'huò,ǒ',  # 嚄
    0x5685: 'rú',  # 嚅
    0x5686: 'hāo',  # 嚆
    0x5687: 'hè,xià',  # 嚇
    0x5688: 'yàn',  # 嚈
    0x5689: 'duō',  # 嚉
    0x568A: 'xiù,pì',  # 嚊
    0x568B: 'zhōu,chóu',  # 嚋
    0x568C: 'jì,jiē,zhāi',  # 嚌
    0x568D: 'jìn',  # 嚍
    0x568E: 'háo',  # 嚎
    0x568F: 'tì',  # 嚏
    0x5690: 'cháng',  # 嚐
    0x5691: 'xūn',  # 嚑
    0x5692: 'mē',  # 嚒
    0x5693: 'cā,chā',  # 嚓
    0x5694: 'tì',  # 嚔
    0x5695: 'lū',  # 嚕
    0x5696: 'huì',  # 嚖
    0x5697: 'bó,pào,bào',  # 嚗
    0x5698: 'yōu',  # 嚘
    0x5699: 'niè',  # 嚙
    0x569A: 'yín',  # 嚚
    0x569B: 'hù',  # 嚛
    0x569C: 'mèi,me,mò',  # 嚜
    0x569D: 'hōng',  # 嚝
    0x569E: 'zhé',  # 嚞
    0x569F: 'lí',  # 嚟
    0x56A0: 'liú',  # 嚠
    0x56A1: 'xié,hái',  # 嚡
    0x56A2: 'náng',  # 嚢
    0x56A3: 'xiāo',  # 嚣
    0x56A4: 'mō',  # 嚤
    0x56A5: 'yàn',  # 嚥
    0x56A6: 'lì',  # 嚦
    0x56A7: 'lú',  # 嚧
    0x56A8: 'lóng',  # 嚨
    0x56A9: 'pó',  # 嚩
    0x56AA: 'dàn',  # 嚪
    0x56AB: 'chèn',  # 嚫
    0x56AC: 'pín',  # 嚬
    0x56AD: 'pǐ',  # 嚭
    0x56AE: 'xiàng',  # 嚮
    0x56AF: 'huò',  # 嚯
    0x56B0: 'mè',  # 嚰
    0x56B1: 'xī',  # 嚱
    0x56B2: 'duǒ',  # 嚲
    0x56B3: 'kù',  # 嚳
    0x56B4: 'yán',  # 嚴
    0x56B5: 'chán',  # 嚵
    0x56B6: 'yīng',  # 嚶
    0x56B7: 'rǎng,rāng',  # 嚷
    0x56B8: 'diǎn,dím',  # 嚸
    0x56B9: 'lá',  # 嚹
    0x56BA: 'tà',  # 嚺
    0x56BB: 'xiāo',  # 嚻
    0x56BC: 'jiáo,jué,jiào',  # 嚼
    0x56BD: 'chuò',  # 嚽
    0x56BE: 'huàn,huān',  # 嚾
    0x56BF: 'huò',  # 嚿
    0x56C0: 'zhuàn',  # 囀
    0x56C1: 'niè',  # 囁
    0x56C2: 'xiāo',  # 囂
    0x56C3: 'zá,cà',  # 囃
    0x56C4: 'lí',  # 囄
    0x56C5: 'chǎn',  # 囅
    0x56C6: 'chài',  # 囆
    0x56C7: 'lì',  # 囇
    0x56C8: 'yì',  # 囈
    0x56C9: 'luō,luó,luo',  # 囉
    0x56CA: 'náng,nāng',  # 囊
    0x56CB: 'zá,zàn,cān',  # 囋
    0x56CC: 'sū',  # 囌
    0x56CD: 'xǐ',  # 囍
    0x56CE: 'zèng',  # 囎
    0x56CF: 'jiān',  # 囏
    0x56D0: 'yàn,zá,niè',  # 囐
    0x56D1: 'zhǔ',  # 囑
    0x56D2: 'lán',  # 囒
    0x56D3: 'niè',  # 囓
    0x56D4: 'nāng',  # 囔
    0x56D5: 'ramo',  # 囕
    0x56D6: 'luó,luō,luo',  # 囖
    0x56D7: 'wéi,guó',  # 囗
    0x56D8: 'huí',  # 囘
    0x56D9: 'yīn',  # 囙
    0x56DA: 'qiú',  # 囚
    0x56DB: 'sì',  # 四
    0x56DC: 'nín',  # 囜
    0x56DD: 'jiǎn,nān',  # 囝
    0x56DE: 'huí',  # 回
    0x56DF: 'xìn',  # 囟
    0x56E0: 'yīn',  # 因
    0x56E1: 'nān',  # 囡
    0x56E2: 'tuán',  # 团
    0x56E3: 'tuán',  # 団
    0x56E4: 'dùn,tún',  # 囤
    0x56E5: 'kàng',  # 囥
    0x56E6: 'yuān',  # 囦
    0x56E7: 'jiǒng',  # 囧
    0x56E8: 'piān',  # 囨
    0x56E9: 'yún',  # 囩
    0x56EA: 'cōng',  # 囪
    0x56EB: 'hú',  # 囫
    0x56EC: 'huí',  # 囬
    0x56ED: 'yuán',  # 园
    0x56EE: 'é',  # 囮
    0x56EF: 'guó',  # 囯
    0x56F0: 'kùn',  # 困
    0x56F1: 'cōng',  # 囱
    0x56F2: 'wéi,tōng',  # 囲
    0x56F3: 'tú',  # 図
    0x56F4: 'wéi',  # 围
    0x56F5: 'lún',  # 囵
    0x56F6: 'guó',  # 囶
    0x56F7: 'qūn',  # 囷
    0x56F8: 'rì',  # 囸
    0x56F9: 'líng',  # 囹
    0x56FA: 'gù',  # 固
    0x56FB: 'guó',  # 囻
    0x56FC: 'tāi',  # 囼
    0x56FD: 'guó',  # 国
    0x56FE: 'tú',  # 图
    0x56FF: 'yòu',  # 囿
    0x5700: 'guó',  # 圀
    0x5701: 'yín',  # 圁
    0x5702: 'hùn',  # 圂
    0x5703: 'pǔ',  # 圃
    0x5704: 'yǔ',  # 圄
    0x5705: 'hán',  # 圅
    0x5706: 'yuán',  # 圆
    0x5707: 'lún',  # 圇
    0x5708: 'quān,juàn,juān',  # 圈
    0x5709: 'yǔ',  # 圉
    0x570A: 'qīng',  # 圊
    0x570B: 'guó',  # 國
    0x570C: 'chuán,chuí',  # 圌
    0x570D: 'wéi',  # 圍
    0x570E: 'yuán',  # 圎
    0x570F: 'quān,juàn,juān',  # 圏
    0x5710: 'kū',  # 圐
    0x5711: 'pǔ',  # 圑
    0x5712: 'yuán',  # 園
    0x5713: 'yuán',  # 圓
    0x5714: 'yà',  # 圔
    0x5715: 'tuān',  # 圕
    0x5716: 'tú',  # 圖
    0x5717: 'tú',  # 圗
    0x5718: 'tuán',  # 團
    0x5719: 'lüè',  # 圙
    0x571A: 'huì',  # 圚
    0x571B: 'yì',  # 圛
    0x571C: 'huán,yuán',  # 圜
    0x571D: 'luán',  # 圝
    0x571E: 'luán',  # 圞
    0x571F: 'tǔ',  # 土
    0x5720: 'yà',  # 圠
    0x5721: 'tǔ',  # 圡
    0x5722: 'tǐng',  # 圢
    0x5723: 'shèng',  # 圣
    0x5724: 'pú',  # 圤
    0x5725: 'lù',  # 圥
    0x5726: 'kuài',  # 圦
    0x5727: 'yā',  # 圧
    0x5728: 'zài',  # 在
    0x5729: 'wéi,xū',  # 圩
    0x572A: 'gē',  # 圪
    0x572B: 'yù,zhūn',  # 圫
    0x572C: 'wū',  # 圬
    0x572D: 'guī',  # 圭
    0x572E: 'pǐ',  # 圮
    0x572F: 'yí',  # 圯
    0x5730: 'dì,de',  # 地
    0x5731: 'qiān,sú',  # 圱
    0x5732: 'qiān',  # 圲
    0x5733: 'zhèn',  # 圳
    0x5734: 'zhuó',  # 圴
    0x5735: 'dàng',  # 圵
    0x5736: 'qià',  # 圶
    0x5737: 'xià',  # 圷
    0x5738: 'shān',  # 圸
    0x5739: 'kuàng',  # 圹
    0x573A: 'cháng,chǎng',  # 场
    0x573B: 'qí,yín',  # 圻
    0x573C: 'niè',  # 圼
    0x573D: 'mò',  # 圽
    0x573E: 'jī',  # 圾
    0x573F: 'jiá',  # 圿
    0x5740: 'zhǐ',  # 址
    0x5741: 'zhǐ,zhì',  # 坁
    0x5742: 'bǎn',  # 坂
    0x5743: 'xūn',  # 坃
    0x5744: 'yì',  # 坄
    0x5745: 'qǐn',  # 坅
    0x5746: 'méi,fén',  # 坆
    0x5747: 'jūn',  # 均
    0x5748: 'rǒng,kēng',  # 坈
    0x5749: 'tún,dùn',  # 坉
    0x574A: 'fāng,fáng',  # 坊
    0x574B: 'bèn,fèn',  # 坋
    0x574C: 'bèn',  # 坌
    0x574D: 'tān',  # 坍
    0x574E: 'kǎn',  # 坎
    0x574F: 'huài',  # 坏
    0x5750: 'zuò',  # 坐
    0x5751: 'kēng',  # 坑
    0x5752: 'bì',  # 坒
    0x5753: 'jǐng',  # 坓
    0x5754: 'dì,làn',  # 坔
    0x5755: 'jīng',  # 坕
    0x5756: 'jì',  # 坖
    0x5757: 'kuài',  # 块
    0x5758: 'dǐ',  # 坘
    0x5759: 'jīng',  # 坙
    0x575A: 'jiān',  # 坚
    0x575B: 'tán',  # 坛
    0x575C: 'lì',  # 坜
    0x575D: 'bà',  # 坝
    0x575E: 'wù',  # 坞
    0x575F: 'fén',  # 坟
    0x5760: 'zhuì',  # 坠
    0x5761: 'pō',  # 坡
    0x5762: 'pǎn,bàn',  # 坢
    0x5763: 'táng',  # 坣
    0x5764: 'kūn',  # 坤
    0x5765: 'qū',  # 坥
    0x5766: 'tǎn',  # 坦
    0x5767: 'zhǐ',  # 坧
    0x5768: 'tuó',  # 坨
    0x5769: 'gān',  # 坩
    0x576A: 'píng',  # 坪
    0x576B: 'diàn',  # 坫
    0x576C: 'guà',  # 坬
    0x576D: 'ní',  # 坭
    0x576E: 'tái',  # 坮
    0x576F: 'pī',  # 坯
    0x5770: 'jiōng',  # 坰
    0x5771: 'yǎng',  # 坱
    0x5772: 'fó',  # 坲
    0x5773: 'ào',  # 坳
    0x5774: 'lù',  # 坴
    0x5775: 'qiū',  # 坵
    0x5776: 'mù,mǔ',  # 坶
    0x5777: 'kē,kě',  # 坷
    0x5778: 'gòu',  # 坸
    0x5779: 'xuè',  # 坹
    0x577A: 'fá',  # 坺
    0x577B: 'dǐ,chí',  # 坻
    0x577C: 'chè',  # 坼
    0x577D: 'líng',  # 坽
    0x577E: 'zhù',  # 坾
    0x577F: 'fù',  # 坿
    0x5780: 'hū',  # 垀
    0x5781: 'zhì',  # 垁
    0x5782: 'chuí',  # 垂
    0x5783: 'lā',  # 垃
    0x5784: 'lǒng',  # 垄
    0x5785: 'lǒng',  # 垅
    0x5786: 'lú',  # 垆
    0x5787: 'ào',  # 垇
    0x5788: 'dài',  # 垈
    0x5789: 'páo',  # 垉
    0x578A: 'mín',  # 垊
    0x578B: 'xíng',  # 型
    0x578C: 'dòng,tóng',  # 垌
    0x578D: 'jì',  # 垍
    0x578E: 'hè',  # 垎
    0x578F: 'lǜ',  # 垏
    0x5790: 'cí',  # 垐
    0x5791: 'chǐ',  # 垑
    0x5792: 'lěi',  # 垒
    0x5793: 'gāi',  # 垓
    0x5794: 'yīn',  # 垔
    0x5795: 'hòu',  # 垕
    0x5796: 'duī',  # 垖
    0x5797: 'zhào',  # 垗
    0x5798: 'fú',  # 垘
    0x5799: 'guāng',  # 垙
    0x579A: 'yáo',  # 垚
    0x579B: 'duǒ,duò',  # 垛
    0x579C: 'duǒ,duò',  # 垜
    0x579D: 'guǐ',  # 垝
    0x579E: 'chá',  # 垞
    0x579F: 'yáng',  # 垟
    0x57A0: 'yín',  # 垠
    0x57A1: 'fá',  # 垡
    0x57A2: 'gòu',  # 垢
    0x57A3: 'yuán',  # 垣
    0x57A4: 'dié',  # 垤
    0x57A5: 'xié',  # 垥
    0x57A6: 'kěn',  # 垦
    0x57A7: 'shǎng',  # 垧
    0x57A8: 'shǒu',  # 垨
    0x57A9: 'è',  # 垩
    0x57AA: 'bìng',  # 垪
    0x57AB: 'diàn',  # 垫
    0x57AC: 'hóng',  # 垬
    0x57AD: 'yā',  # 垭
    0x57AE: 'kuǎ',  # 垮
    0x57AF: 'dá',  # 垯
    0x57B0: 'kǎ',  # 垰
    0x57B1: 'dàng',  # 垱
    0x57B2: 'kǎi',  # 垲
    0x57B3: 'háng',  # 垳
    0x57B4: 'nǎo',  # 垴
    0x57B5: 'ǎn',  # 垵
    0x57B6: 'xīng',  # 垶
    0x57B7: 'xiàn',  # 垷
    0x57B8: 'yuàn,huán',  # 垸
    0x57B9: 'bāng',  # 垹
    0x57BA: 'póu,fú',  # 垺
    0x57BB: 'bà',  # 垻
    0x57BC: 'yì',  # 垼
    0x57BD: 'yìn',  # 垽
    0x57BE: 'hàn',  # 垾
    0x57BF: 'xù',  # 垿
    0x57C0: 'chuí',  # 埀
    0x57C1: 'cén',  # 埁
    0x57C2: 'gěng',  # 埂
    0x57C3: 'āi',  # 埃
    0x57C4: 'běng,fēng',  # 埄
    0x57C5: 'dì,fáng',  # 埅
    0x57C6: 'què,jué',  # 埆
    0x57C7: 'yǒng',  # 埇
    0x57C8: 'jùn',  # 埈
    0x57C9: 'xiá,jiā',  # 埉
    0x57CA: 'dì',  # 埊
    0x57CB: 'mái,mán',  # 埋
    0x57CC: 'làng',  # 埌
    0x57CD: 'juǎn',  # 埍
    0x57CE: 'chéng',  # 城
    0x57CF: 'yán,shān',  # 埏
    0x57D0: 'qín,jīn',  # 埐
    0x57D1: 'zhé',  # 埑
    0x57D2: 'liè',  # 埒
    0x57D3: 'liè',  # 埓
    0x57D4: 'pǔ,bù',  # 埔
    0x57D5: 'chéng',  # 埕
    0x57D6: 'huā',  # 埖
    0x57D7: 'bù',  # 埗
    0x57D8: 'shí',  # 埘
    0x57D9: 'xūn',  # 埙
    0x57DA: 'guō',  # 埚
    0x57DB: 'jiōng',  # 埛
    0x57DC: 'yě',  # 埜
    0x57DD: 'niàn',  # 埝
    0x57DE: 'dī',  # 埞
    0x57DF: 'yù',  # 域
    0x57E0: 'bù',  # 埠
    0x57E1: 'yà',  # 埡
    0x57E2: 'quán',  # 埢
    0x57E3: 'suì,sù',  # 埣
    0x57E4: 'pí,pì',  # 埤
    0x57E5: 'qīng,zhēng',  # 埥
    0x57E6: 'wǎn,wān',  # 埦
    0x57E7: 'jù',  # 埧
    0x57E8: 'lǔn',  # 埨
    0x57E9: 'zhēng,chéng',  # 埩
    0x57EA: 'kōng',  # 埪
    0x57EB: 'chǒng,shǎng',  # 埫
    0x57EC: 'dōng',  # 埬
    0x57ED: 'dài',  # 埭
    0x57EE: 'tán,tàn',  # 埮
    0x57EF: 'ǎn',  # 埯
    0x57F0: 'cǎi,cài',  # 埰
    0x57F1: 'chù,tòu',  # 埱
    0x57F2: 'běng',  # 埲
    0x57F3: 'xiàn,kǎn',  # 埳
    0x57F4: 'zhí',  # 埴
    0x57F5: 'duǒ',  # 埵
    0x57F6: 'yì,shì',  # 埶
    0x57F7: 'zhí',  # 執
    0x57F8: 'yì',  # 埸
    0x57F9: 'péi',  # 培
    0x57FA: 'jī',  # 基
    0x57FB: 'zhǔn',  # 埻
    0x57FC: 'qí',  # 埼
    0x57FD: 'sào,sǎo',  # 埽
    0x57FE: 'jù',  # 埾
    0x57FF: 'ní',  # 埿
    0x5800: 'kū',  # 堀
    0x5801: 'kè',  # 堁
    0x5802: 'táng',  # 堂
    0x5803: 'kūn',  # 堃
    0x5804: 'nì',  # 堄
    0x5805: 'jiān',  # 堅
    0x5806: 'duī',  # 堆
    0x5807: 'jīn',  # 堇
    0x5808: 'gāng',  # 堈
    0x5809: 'yù',  # 堉
    0x580A: 'è',  # 堊
    0x580B: 'péng,bèng',  # 堋
    0x580C: 'gù',  # 堌
    0x580D: 'tù',  # 堍
    0x580E: 'lèng',  # 堎
    0x580F: 'fāng',  # 堏
    0x5810: 'yá',  # 堐
    0x5811: 'qiàn',  # 堑
    0x5812: 'kūn',  # 堒
    0x5813: 'àn',  # 堓
    0x5814: 'shēn',  # 堔
    0x5815: 'duò,huī',  # 堕
    0x5816: 'nǎo',  # 堖
    0x5817: 'tū',  # 堗
    0x5818: 'chéng',  # 堘
    0x5819: 'yīn',  # 堙
    0x581A: 'huán',  # 堚
    0x581B: 'bì',  # 堛
    0x581C: 'liàn',  # 堜
    0x581D: 'guō',  # 堝
    0x581E: 'dié',  # 堞
    0x581F: 'zhuàn',  # 堟
    0x5820: 'hòu',  # 堠
    0x5821: 'bǎo,bǔ,pù',  # 堡
    0x5822: 'bǎo',  # 堢
    0x5823: 'yú',  # 堣
    0x5824: 'dī',  # 堤
    0x5825: 'máo,móu,wǔ',  # 堥
    0x5826: 'jiē',  # 堦
    0x5827: 'ruán',  # 堧
    0x5828: 'è,ài,yè',  # 堨
    0x5829: 'gèng',  # 堩
    0x582A: 'kān',  # 堪
    0x582B: 'zōng',  # 堫
    0x582C: 'yú',  # 堬
    0x582D: 'huáng',  # 堭
    0x582E: 'è',  # 堮
    0x582F: 'yáo',  # 堯
    0x5830: 'yàn',  # 堰
    0x5831: 'bào',  # 報
    0x5832: 'jí',  # 堲
    0x5833: 'méi',  # 堳
    0x5834: 'cháng,chǎng',  # 場
    0x5835: 'dǔ',  # 堵
    0x5836: 'tuó',  # 堶
    0x5837: 'yìn',  # 堷
    0x5838: 'féng',  # 堸
    0x5839: 'zhòng',  # 堹
    0x583A: 'jiè',  # 堺
    0x583B: 'jīn',  # 堻
    0x583C: 'fēng',  # 堼
    0x583D: 'gāng',  # 堽
    0x583E: 'chuǎn',  # 堾
    0x583F: 'jiǎn',  # 堿
    0x5840: 'píng',  # 塀
    0x5841: 'lěi',  # 塁
    0x5842: 'jiǎng',  # 塂
    0x5843: 'huāng',  # 塃
    0x5844: 'léng',  # 塄
    0x5845: 'duàn',  # 塅
    0x5846: 'wān',  # 塆
    0x5847: 'xuān',  # 塇
    0x5848: 'jì',  # 塈
    0x5849: 'jí',  # 塉
    0x584A: 'kuài',  # 塊
    0x584B: 'yíng',  # 塋
    0x584C: 'tā',  # 塌
    0x584D: 'chéng',  # 塍
    0x584E: 'yǒng',  # 塎
    0x584F: 'kǎi',  # 塏
    0x5850: 'sù',  # 塐
    0x5851: 'sù',  # 塑
    0x5852: 'shí',  # 塒
    0x5853: 'mì',  # 塓
    0x5854: 'tǎ',  # 塔
    0x5855: 'wěng',  # 塕
    0x5856: 'chéng',  # 塖
    0x5857: 'tú',  # 塗
    0x5858: 'táng',  # 塘
    0x5859: 'què',  # 塙
    0x585A: 'zhǒng',  # 塚
    0x585B: 'lì',  # 塛
    0x585C: 'péng',  # 塜
    0x585D: 'bàng',  # 塝
    0x585E: 'sāi,sài,sè',  # 塞
    0x585F: 'zàng',  # 塟
    0x5860: 'duī',  # 塠
    0x5861: 'tián',  # 塡
    0x5862: 'wù',  # 塢
    0x5863: 'zhèng',  # 塣
    0x5864: 'xūn',  # 塤
    0x5865: 'gé',  # 塥
    0x5866: 'zhèn',  # 塦
    0x5867: 'ài',  # 塧
    0x5868: 'gōng',  # 塨
    0x5869: 'yán',  # 塩
    0x586A: 'xiàn',  # 塪
    0x586B: 'tián,zhèn',  # 填
    0x586C: 'yuán',  # 塬
    0x586D: 'wēn',  # 塭
    0x586E: 'xiè',  # 塮
    0x586F: 'liù',  # 塯
    0x5870: 'hǎi',  # 塰
    0x5871: 'lǎng',  # 塱
    0x5872: 'cháng,chǎng',  # 塲
    0x5873: 'péng',  # 塳
    0x5874: 'bèng',  # 塴
    0x5875: 'chén',  # 塵
    0x5876: 'lù',  # 塶
    0x5877: 'lǔ',  # 塷
    0x5878: 'ōu,qiū',  # 塸
    0x5879: 'qiàn',  # 塹
    0x587A: 'méi',  # 塺
    0x587B: 'mò',  # 塻
    0x587C: 'zhuān,tuán',  # 塼
    0x587D: 'shuǎng',  # 塽
    0x587E: 'shú',  # 塾
    0x587F: 'lǒu',  # 塿
    0x5880: 'chí',  # 墀
    0x5881: 'màn',  # 墁
    0x5882: 'biāo',  # 墂
    0x5883: 'jìng',  # 境
    0x5884: 'qī',  # 墄
    0x5885: 'shù',  # 墅
    0x5886: 'zhì,dì',  # 墆
    0x5887: 'zhàng',  # 墇
    0x5888: 'kàn',  # 墈
    0x5889: 'yōng',  # 墉
    0x588A: 'diàn',  # 墊
    0x588B: 'chěn',  # 墋
    0x588C: 'zhǐ,zhuó',  # 墌
    0x588D: 'xì',  # 墍
    0x588E: 'guō',  # 墎
    0x588F: 'qiǎng',  # 墏
    0x5890: 'jìn',  # 墐
    0x5891: 'dì',  # 墑
    0x5892: 'shāng',  # 墒
    0x5893: 'mù',  # 墓
    0x5894: 'cuī',  # 墔
    0x5895: 'yàn',  # 墕
    0x5896: 'tǎ',  # 墖
    0x5897: 'zēng',  # 増
    0x5898: 'qián',  # 墘
    0x5899: 'qiáng',  # 墙
    0x589A: 'liáng',  # 墚
    0x589B: 'wèi',  # 墛
    0x589C: 'zhuì',  # 墜
    0x589D: 'qiāo',  # 墝
    0x589E: 'zēng',  # 增
    0x589F: 'xū',  # 墟
    0x58A0: 'shàn',  # 墠
    0x58A1: 'shàn',  # 墡
    0x58A2: 'fá',  # 墢
    0x58A3: 'pú',  # 墣
    0x58A4: 'kuài,tuí',  # 墤
    0x58A5: 'tuǎn,dǒng',  # 墥
    0x58A6: 'fán',  # 墦
    0x58A7: 'qiáo,què',  # 墧
    0x58A8: 'mò',  # 墨
    0x58A9: 'dūn',  # 墩
    0x58AA: 'dūn',  # 墪
    0x58AB: 'zūn,dūn',  # 墫
    0x58AC: 'dì',  # 墬
    0x58AD: 'shèng',  # 墭
    0x58AE: 'duò,huī',  # 墮
    0x58AF: 'duò',  # 墯
    0x58B0: 'tán',  # 墰
    0x58B1: 'dèng',  # 墱
    0x58B2: 'wú',  # 墲
    0x58B3: 'fén',  # 墳
    0x58B4: 'huáng',  # 墴
    0x58B5: 'tán',  # 墵
    0x58B6: 'dā',  # 墶
    0x58B7: 'yè',  # 墷
    0x58B8: 'zhù',  # 墸
    0x58B9: 'jiàn',  # 墹
    0x58BA: 'ào',  # 墺
    0x58BB: 'qiáng',  # 墻
    0x58BC: 'jī',  # 墼
    0x58BD: 'qiāo,áo',  # 墽
    0x58BE: 'kěn',  # 墾
    0x58BF: 'yì,tú',  # 墿
    0x58C0: 'pí',  # 壀
    0x58C1: 'bì',  # 壁
    0x58C2: 'diàn',  # 壂
    0x58C3: 'jiāng',  # 壃
    0x58C4: 'yě',  # 壄
    0x58C5: 'yōng',  # 壅
    0x58C6: 'xué,bó,jué',  # 壆
    0x58C7: 'tán',  # 壇
    0x58C8: 'lǎn',  # 壈
    0x58C9: 'jù',  # 壉
    0x58CA: 'huài',  # 壊
    0x58CB: 'dàng',  # 壋
    0x58CC: 'rǎng',  # 壌
    0x58CD: 'qiàn',  # 壍
    0x58CE: 'xūn',  # 壎
    0x58CF: 'xiàn,làn',  # 壏
    0x58D0: 'xǐ',  # 壐
    0x58D1: 'hè',  # 壑
    0x58D2: 'ài',  # 壒
    0x58D3: 'yā,yà',  # 壓
    0x58D4: 'dǎo',  # 壔
    0x58D5: 'háo',  # 壕
    0x58D6: 'ruán',  # 壖
    0x58D7: 'jìn',  # 壗
    0x58D8: 'lěi',  # 壘
    0x58D9: 'kuàng',  # 壙
    0x58DA: 'lú',  # 壚
    0x58DB: 'yán',  # 壛
    0x58DC: 'tán',  # 壜
    0x58DD: 'wéi',  # 壝
    0x58DE: 'huài',  # 壞
    0x58DF: 'lǒng',  # 壟
    0x58E0: 'lǒng',  # 壠
    0x58E1: 'ruǐ',  # 壡
    0x58E2: 'lì',  # 壢
    0x58E3: 'lín',  # 壣
    0x58E4: 'rǎng',  # 壤
    0x58E5: 'chán',  # 壥
    0x58E6: 'xūn',  # 壦
    0x58E7: 'yán',  # 壧
    0x58E8: 'lěi',  # 壨
    0x58E9: 'bà',  # 壩
    0x58EA: 'wān',  # 壪
    0x58EB: 'shì',  # 士
    0x58EC: 'rén',  # 壬
    0x58ED: 'san',  # 壭
    0x58EE: 'zhuàng',  # 壮
    0x58EF: 'zhuàng',  # 壯
    0x58F0: 'shēng',  # 声
    0x58F1: 'yī',  # 壱
    0x58F2: 'mài',  # 売
    0x58F3: 'ké,qiào',  # 壳
    0x58F4: 'zhù',  # 壴
    0x58F5: 'zhuàng',  # 壵
    0x58F6: 'hú',  # 壶
    0x58F7: 'hú',  # 壷
    0x58F8: 'kǔn',  # 壸
    0x58F9: 'yī',  # 壹
    0x58FA: 'hú',  # 壺
    0x58FB: 'xù',  # 壻
    0x58FC: 'kǔn',  # 壼
    0x58FD: 'shòu',  # 壽
    0x58FE: 'mǎng',  # 壾
    0x58FF: 'cún',  # 壿
    0x5900: 'shòu',  # 夀
    0x5901: 'yī',  # 夁
    0x5902: 'zhǐ,zhōng',  # 夂
    0x5903: 'gǔ,yíng',  # 夃
    0x5904: 'chǔ,chù',  # 处
    0x5905: 'jiàng,xiáng',  # 夅
    0x5906: 'féng,fēng,páng',  # 夆
    0x5907: 'bèi',  # 备
    0x5908: 'zhāi',  # 夈
    0x5909: 'biàn',  # 変
    0x590A: 'suī',  # 夊
    0x590B: 'qūn',  # 夋
    0x590C: 'líng',  # 夌
    0x590D: 'fù',  # 复
    0x590E: 'cuò',  # 夎
    0x590F: 'xià',  # 夏
    0x5910: 'xiòng,xuàn',  # 夐
    0x5911: 'xiè',  # 夑
    0x5912: 'náo',  # 夒
    0x5913: 'xià',  # 夓
    0x5914: 'kuí',  # 夔
    0x5915: 'xī',  # 夕
    0x5916: 'wài',  # 外
    0x5917: 'yuàn,wǎn,wān,yuān',  # 夗
    0x5918: 'mǎo,wǎn',  # 夘
    0x5919: 'sù',  # 夙
    0x591A: 'duō',  # 多
    0x591B: 'duō',  # 夛
    0x591C: 'yè',  # 夜
    0x591D: 'qíng',  # 夝
    0x591E: 'oes',  # 夞
    0x591F: 'gòu',  # 够
    0x5920: 'gòu',  # 夠
    0x5921: 'qì',  # 夡
    0x5922: 'mèng',  # 夢
    0x5923: 'mèng',  # 夣
    0x5924: 'yín',  # 夤
    0x5925: 'huǒ',  # 夥
    0x5926: 'chěn',  # 夦
    0x5927: 'dà,dài,tài',  # 大
    0x5928: 'cè',  # 夨
    0x5929: 'tiān',  # 天
    0x592A: 'tài',  # 太
    0x592B: 'fū,fú',  # 夫
    0x592C: 'guài',  # 夬
    0x592D: 'yāo',  # 夭
    0x592E: 'yāng',  # 央
    0x592F: 'hāng,bèn',  # 夯
    0x5930: 'gǎo',  # 夰
    0x5931: 'shī',  # 失
    0x5932: 'tāo,běn',  # 夲
    0x5933: 'tài',  # 夳
    0x5934: 'tóu,tou',  # 头
    0x5935: 'yǎn,tāo',  # 夵
    0x5936: 'bǐ',  # 夶
    0x5937: 'yí',  # 夷
    0x5938: 'kuā,kuà',  # 夸
    0x5939: 'jiā,jiá,gā',  # 夹
    0x593A: 'duó',  # 夺
    0x593B: 'huà',  # 夻
    0x593C: 'kuǎng',  # 夼
    0x593D: 'yǔn',  # 夽
    0x593E: 'jiā,jiá,gā',  # 夾
    0x593F: 'bā',  # 夿
    0x5940: 'ēn',  # 奀
    0x5941: 'lián',  # 奁
    0x5942: 'huàn',  # 奂
    0x5943: 'dī,tì',  # 奃
    0x5944: 'yǎn,yān',  # 奄
    0x5945: 'pào',  # 奅
    0x5946: 'juàn',  # 奆
    0x5947: 'qí,jī',  # 奇
    0x5948: 'nài',  # 奈
    0x5949: 'fèng',  # 奉
    0x594A: 'xié',  # 奊
    0x594B: 'fèn',  # 奋
    0x594C: 'diǎn',  # 奌
    0x594D: 'quān,juàn',  # 奍
    0x594E: 'kuí',  # 奎
    0x594F: 'zòu',  # 奏
    0x5950: 'huàn',  # 奐
    0x5951: 'qì,qiè,xiè',  # 契
    0x5952: 'kāi',  # 奒
    0x5953: 'shē,chǐ,zhà',  # 奓
    0x5954: 'bēn,bèn',  # 奔
    0x5955: 'yì',  # 奕
    0x5956: 'jiǎng',  # 奖
    0x5957: 'tào',  # 套
    0x5958: 'zàng,zhuǎng',  # 奘
    0x5959: 'běn',  # 奙
    0x595A: 'xī',  # 奚
    0x595B: 'huǎng',  # 奛
    0x595C: 'fěi',  # 奜
    0x595D: 'diāo',  # 奝
    0x595E: 'xùn,zhuì',  # 奞
    0x595F: 'bēng',  # 奟
    0x5960: 'diàn',  # 奠
    0x5961: 'ào',  # 奡
    0x5962: 'shē',  # 奢
    0x5963: 'wěng',  # 奣
    0x5964: 'pò,hǎ,tǎi',  # 奤
    0x5965: 'ào,yù',  # 奥
    0x5966: 'wù',  # 奦
    0x5967: 'ào,yù',  # 奧
    0x5968: 'jiǎng',  # 奨
    0x5969: 'lián',  # 奩
    0x596A: 'duó',  # 奪
    0x596B: 'yūn',  # 奫
    0x596C: 'jiǎng',  # 奬
    0x596D: 'shì',  # 奭
    0x596E: 'fèn',  # 奮
    0x596F: 'huò',  # 奯
    0x5970: 'bì',  # 奰
    0x5971: 'luán',  # 奱
    0x5972: 'duǒ,chě',  # 奲
    0x5973: 'nǚ,rǔ',  # 女
    0x5974: 'nú',  # 奴
    0x5975: 'dǐng,dīng,tiǎn',  # 奵
    0x5976: 'nǎi',  # 奶
    0x5977: 'qiān',  # 奷
    0x5978: 'jiān',  # 奸
    0x5979: 'tā,jiě',  # 她
    0x597A: 'jiǔ',  # 奺
    0x597B: 'nuán',  # 奻
    0x597C: 'chà',  # 奼
    0x597D: 'hǎo,hào',  # 好
    0x597E: 'xiān',  # 奾
    0x597F: 'fàn',  # 奿
    0x5980: 'jǐ',  # 妀
    0x5981: 'shuò',  # 妁
    0x5982: 'rú',  # 如
    0x5983: 'fēi,pèi',  # 妃
    0x5984: 'wàng',  # 妄
    0x5985: 'hóng',  # 妅
    0x5986: 'zhuāng',  # 妆
    0x5987: 'fù',  # 妇
    0x5988: 'mā',  # 妈
    0x5989: 'dān',  # 妉
    0x598A: 'rèn',  # 妊
    0x598B: 'fū,yōu',  # 妋
    0x598C: 'jìng',  # 妌
    0x598D: 'yán',  # 妍
    0x598E: 'hài,jiè',  # 妎
    0x598F: 'wèn',  # 妏
    0x5990: 'zhōng',  # 妐
    0x5991: 'pā',  # 妑
    0x5992: 'dù',  # 妒
    0x5993: 'jì',  # 妓
    0x5994: 'kēng,háng',  # 妔
    0x5995: 'zhòng',  # 妕
    0x5996: 'yāo',  # 妖
    0x5997: 'jìn',  # 妗
    0x5998: 'yún',  # 妘
    0x5999: 'miào',  # 妙
    0x599A: 'fǒu,pēi,pī',  # 妚
    0x599B: 'chī',  # 妛
    0x599C: 'yuè,jué',  # 妜
    0x599D: 'zhuāng',  # 妝
    0x599E: 'niū',  # 妞
    0x599F: 'yàn',  # 妟
    0x59A0: 'nà,nàn',  # 妠
    0x59A1: 'xīn',  # 妡
    0x59A2: 'fén',  # 妢
    0x59A3: 'bǐ',  # 妣
    0x59A4: 'yú',  # 妤
    0x59A5: 'tuǒ',  # 妥
    0x59A6: 'fēng',  # 妦
    0x59A7: 'wàn,yuán',  # 妧
    0x59A8: 'fáng',  # 妨
    0x59A9: 'wǔ',  # 妩
    0x59AA: 'yù',  # 妪
    0x59AB: 'guī',  # 妫
    0x59AC: 'dù',  # 妬
    0x59AD: 'bá',  # 妭
    0x59AE: 'nī',  # 妮
    0x59AF: 'zhóu',  # 妯
    0x59B0: 'zhuó',  # 妰
    0x59B1: 'zhāo',  # 妱
    0x59B2: 'dá',  # 妲
    0x59B3: 'nǐ,nǎi',  # 妳
    0x59B4: 'yuàn',  # 妴
    0x59B5: 'tǒu',  # 妵
    0x59B6: 'xián,xuán,xù',  # 妶
    0x59B7: 'zhí,yì',  # 妷
    0x59B8: 'ē',  # 妸
    0x59B9: 'mèi',  # 妹
    0x59BA: 'mò',  # 妺
    0x59BB: 'qī,qì',  # 妻
    0x59BC: 'bì',  # 妼
    0x59BD: 'shēn',  # 妽
    0x59BE: 'qiè',  # 妾
    0x59BF: 'ē',  # 妿
    0x59C0: 'hé',  # 姀
    0x59C1: 'xǔ,xū',  # 姁
    0x59C2: 'fá',  # 姂
    0x59C3: 'zhēng',  # 姃
    0x59C4: 'mín',  # 姄
    0x59C5: 'bàn',  # 姅
    0x59C6: 'mǔ',  # 姆
    0x59C7: 'fū,fú',  # 姇
    0x59C8: 'líng',  # 姈
    0x59C9: 'zǐ',  # 姉
    0x59CA: 'zǐ',  # 姊
    0x59CB: 'shǐ',  # 始
    0x59CC: 'rǎn',  # 姌
    0x59CD: 'shān,shàn',  # 姍
    0x59CE: 'yāng',  # 姎
    0x59CF: 'mán',  # 姏
    0x59D0: 'jiě',  # 姐
    0x59D1: 'gū',  # 姑
    0x59D2: 'sì',  # 姒
    0x59D3: 'xìng',  # 姓
    0x59D4: 'wěi,wēi',  # 委
    0x59D5: 'zī',  # 姕
    0x59D6: 'jù',  # 姖
    0x59D7: 'shān,shàn',  # 姗
    0x59D8: 'pīn',  # 姘
    0x59D9: 'rèn',  # 姙
    0x59DA: 'yáo',  # 姚
    0x59DB: 'dòng',  # 姛
    0x59DC: 'jiāng',  # 姜
    0x59DD: 'shū',  # 姝
    0x59DE: 'jí',  # 姞
    0x59DF: 'gāi',  # 姟
    0x59E0: 'xiàng',  # 姠
    0x59E1: 'huá,huó',  # 姡
    0x59E2: 'juān',  # 姢
    0x59E3: 'jiāo,xiáo',  # 姣
    0x59E4: 'gòu,dù',  # 姤
    0x59E5: 'mǔ,lǎo',  # 姥
    0x59E6: 'jiān',  # 姦
    0x59E7: 'jiān',  # 姧
    0x59E8: 'yí',  # 姨
    0x59E9: 'nián,niàn',  # 姩
    0x59EA: 'zhí',  # 姪
    0x59EB: 'zhěn',  # 姫
    0x59EC: 'jī',  # 姬
    0x59ED: 'xiàn',  # 姭
    0x59EE: 'héng',  # 姮
    0x59EF: 'guāng',  # 姯
    0x59F0: 'jūn,xún',  # 姰
    0x59F1: 'kuā,hù',  # 姱
    0x59F2: 'yàn',  # 姲
    0x59F3: 'mǐng',  # 姳
    0x59F4: 'liè',  # 姴
    0x59F5: 'pèi',  # 姵
    0x59F6: 'è,yà',  # 姶
    0x59F7: 'yòu',  # 姷
    0x59F8: 'yán',  # 姸
    0x59F9: 'chà',  # 姹
    0x59FA: 'shēn,xiān',  # 姺
    0x59FB: 'yīn',  # 姻
    0x59FC: 'shí',  # 姼
    0x59FD: 'guǐ',  # 姽
    0x59FE: 'quán',  # 姾
    0x59FF: 'zī',  # 姿
    0x5A00: 'sōng',  # 娀
    0x5A01: 'wēi',  # 威
    0x5A02: 'hóng',  # 娂
    0x5A03: 'wá',  # 娃
    0x5A04: 'lóu',  # 娄
    0x5A05: 'yà',  # 娅
    0x5A06: 'ráo,rǎo',  # 娆
    0x5A07: 'jiāo',  # 娇
    0x5A08: 'luán',  # 娈
    0x5A09: 'pīng',  # 娉
    0x5A0A: 'xiàn',  # 娊
    0x5A0B: 'shào,shāo',  # 娋
    0x5A0C: 'lǐ',  # 娌
    0x5A0D: 'chéng,shèng',  # 娍
    0x5A0E: 'xiē',  # 娎
    0x5A0F: 'máng',  # 娏
    0x5A10: 'fū',  # 娐
    0x5A11: 'suō',  # 娑
    0x5A12: 'wǔ,mǔ',  # 娒
    0x5A13: 'wěi',  # 娓
    0x5A14: 'kè',  # 娔
    0x5A15: 'chuò,lài',  # 娕
    0x5A16: 'chuò',  # 娖
    0x5A17: 'tǐng',  # 娗
    0x5A18: 'niáng',  # 娘
    0x5A19: 'xíng',  # 娙
    0x5A1A: 'nán',  # 娚
    0x5A1B: 'yú',  # 娛
    0x5A1C: 'nà,nuó',  # 娜
    0x5A1D: 'pōu,bǐ',  # 娝
    0x5A1E: 'něi,suī',  # 娞
    0x5A1F: 'juān',  # 娟
    0x5A20: 'shēn',  # 娠
    0x5A21: 'zhì',  # 娡
    0x5A22: 'hán',  # 娢
    0x5A23: 'dì',  # 娣
    0x5A24: 'zhuāng',  # 娤
    0x5A25: 'é',  # 娥
    0x5A26: 'pín',  # 娦
    0x5A27: 'tuì',  # 娧
    0x5A28: 'mǎn',  # 娨
    0x5A29: 'miǎn',  # 娩
    0x5A2A: 'wú,wù,yú',  # 娪
    0x5A2B: 'yán',  # 娫
    0x5A2C: 'wǔ',  # 娬
    0x5A2D: 'xī,āi',  # 娭
    0x5A2E: 'yán',  # 娮
    0x5A2F: 'yú',  # 娯
    0x5A30: 'sì',  # 娰
    0x5A31: 'yú',  # 娱
    0x5A32: 'wā',  # 娲
    0x5A33: 'lì',  # 娳
    0x5A34: 'xián',  # 娴
    0x5A35: 'jū',  # 娵
    0x5A36: 'qǔ',  # 娶
    0x5A37: 'zhuì,shuì',  # 娷
    0x5A38: 'qī',  # 娸
    0x5A39: 'xián',  # 娹
    0x5A3A: 'zhuó',  # 娺
    0x5A3B: 'dōng,dòng',  # 娻
    0x5A3C: 'chāng',  # 娼
    0x5A3D: 'lù',  # 娽
    0x5A3E: 'ǎi,ái,è',  # 娾
    0x5A3F: 'ē,ě',  # 娿
    0x5A40: 'ē',  # 婀
    0x5A41: 'lóu',  # 婁
    0x5A42: 'mián',  # 婂
    0x5A43: 'cóng',  # 婃
    0x5A44: 'pǒu,péi,bù',  # 婄
    0x5A45: 'jú',  # 婅
    0x5A46: 'pó',  # 婆
    0x5A47: 'cǎi',  # 婇
    0x5A48: 'líng',  # 婈
    0x5A49: 'wǎn',  # 婉
    0x5A4A: 'biǎo',  # 婊
    0x5A4B: 'xiāo',  # 婋
    0x5A4C: 'shū',  # 婌
    0x5A4D: 'qǐ',  # 婍
    0x5A4E: 'huī',  # 婎
    0x5A4F: 'fù,fàn',  # 婏
    0x5A50: 'wǒ',  # 婐
    0x5A51: 'wǒ',  # 婑
    0x5A52: 'tán',  # 婒
    0x5A53: 'fēi',  # 婓
    0x5A54: 'fēi',  # 婔
    0x5A55: 'jié',  # 婕
    0x5A56: 'tiān',  # 婖
    0x5A57: 'ní,nǐ',  # 婗
    0x5A58: 'quán,juàn',  # 婘
    0x5A59: 'jìng',  # 婙
    0x5A5A: 'hūn',  # 婚
    0x5A5B: 'jīng',  # 婛
    0x5A5C: 'qiān,jǐn',  # 婜
    0x5A5D: 'diàn',  # 婝
    0x5A5E: 'xìng',  # 婞
    0x5A5F: 'hù',  # 婟
    0x5A60: 'wān,wà',  # 婠
    0x5A61: 'lái,lài',  # 婡
    0x5A62: 'bì',  # 婢
    0x5A63: 'yīn',  # 婣
    0x5A64: 'zhōu,chōu',  # 婤
    0x5A65: 'chuò,nào',  # 婥
    0x5A66: 'fù',  # 婦
    0x5A67: 'jìng',  # 婧
    0x5A68: 'lún',  # 婨
    0x5A69: 'nüè',  # 婩
    0x5A6A: 'lán',  # 婪
    0x5A6B: 'hùn,kūn',  # 婫
    0x5A6C: 'yín',  # 婬
    0x5A6D: 'yà',  # 婭
    0x5A6E: 'jū',  # 婮
    0x5A6F: 'lì',  # 婯
    0x5A70: 'diǎn',  # 婰
    0x5A71: 'xián',  # 婱
    0x5A72: 'huā',  # 婲
    0x5A73: 'huà',  # 婳
    0x5A74: 'yīng',  # 婴
    0x5A75: 'chán',  # 婵
    0x5A76: 'shěn',  # 婶
    0x5A77: 'tíng',  # 婷
    0x5A78: 'dàng,yáng',  # 婸
    0x5A79: 'yǎo',  # 婹
    0x5A7A: 'wù',  # 婺
    0x5A7B: 'nàn',  # 婻
    0x5A7C: 'ruò,chuò',  # 婼
    0x5A7D: 'jiǎ',  # 婽
    0x5A7E: 'tōu,yú',  # 婾
    0x5A7F: 'xù',  # 婿
    0x5A80: 'yù,yú',  # 媀
    0x5A81: 'wéi,wěi',  # 媁
    0x5A82: 'dì,tí',  # 媂
    0x5A83: 'róu',  # 媃
    0x5A84: 'měi',  # 媄
    0x5A85: 'dān',  # 媅
    0x5A86: 'ruǎn,nèn',  # 媆
    0x5A87: 'qīn',  # 媇
    0x5A88: 'huī',  # 媈
    0x5A89: 'wò',  # 媉
    0x5A8A: 'qián',  # 媊
    0x5A8B: 'chūn',  # 媋
    0x5A8C: 'miáo',  # 媌
    0x5A8D: 'fù',  # 媍
    0x5A8E: 'jiě',  # 媎
    0x5A8F: 'duān',  # 媏
    0x5A90: 'yí,pèi',  # 媐
    0x5A91: 'zhòng',  # 媑
    0x5A92: 'méi',  # 媒
    0x5A93: 'huáng',  # 媓
    0x5A94: 'mián,miǎn',  # 媔
    0x5A95: 'ān',  # 媕
    0x5A96: 'yīng',  # 媖
    0x5A97: 'xuān',  # 媗
    0x5A98: 'jiē',  # 媘
    0x5A99: 'wēi',  # 媙
    0x5A9A: 'mèi',  # 媚
    0x5A9B: 'yuàn,yuán',  # 媛
    0x5A9C: 'zhēng',  # 媜
    0x5A9D: 'qiū',  # 媝
    0x5A9E: 'tí',  # 媞
    0x5A9F: 'xiè',  # 媟
    0x5AA0: 'tuó,duò',  # 媠
    0x5AA1: 'liàn',  # 媡
    0x5AA2: 'mào',  # 媢
    0x5AA3: 'rǎn',  # 媣
    0x5AA4: 'sī',  # 媤
    0x5AA5: 'piān',  # 媥
    0x5AA6: 'wèi',  # 媦
    0x5AA7: 'wā',  # 媧
    0x5AA8: 'cù',  # 媨
    0x5AA9: 'hú',  # 媩
    0x5AAA: 'ǎo',  # 媪
    0x5AAB: 'jié',  # 媫
    0x5AAC: 'bǎo',  # 媬
    0x5AAD: 'xū',  # 媭
    0x5AAE: 'tōu,yú',  # 媮
    0x5AAF: 'guī',  # 媯
    0x5AB0: 'chú,zòu',  # 媰
    0x5AB1: 'yáo',  # 媱
    0x5AB2: 'pì',  # 媲
    0x5AB3: 'xí',  # 媳
    0x5AB4: 'yuán',  # 媴
    0x5AB5: 'yìng',  # 媵
    0x5AB6: 'róng',  # 媶
    0x5AB7: 'rù',  # 媷
    0x5AB8: 'chī',  # 媸
    0x5AB9: 'liú',  # 媹
    0x5ABA: 'měi',  # 媺
    0x5ABB: 'pán',  # 媻
    0x5ABC: 'ǎo',  # 媼
    0x5ABD: 'mā',  # 媽
    0x5ABE: 'gòu',  # 媾
    0x5ABF: 'kuì',  # 媿
    0x5AC0: 'qín,shēn',  # 嫀
    0x5AC1: 'jià',  # 嫁
    0x5AC2: 'sǎo',  # 嫂
    0x5AC3: 'zhēn,zhěn',  # 嫃
    0x5AC4: 'yuán',  # 嫄
    0x5AC5: 'jiē,suǒ',  # 嫅
    0x5AC6: 'róng',  # 嫆
    0x5AC7: 'míng,mǐng',  # 嫇
    0x5AC8: 'yīng',  # 嫈
    0x5AC9: 'jí',  # 嫉
    0x5ACA: 'sù',  # 嫊
    0x5ACB: 'niǎo',  # 嫋
    0x5ACC: 'xián',  # 嫌
    0x5ACD: 'tāo',  # 嫍
    0x5ACE: 'páng',  # 嫎
    0x5ACF: 'láng',  # 嫏
    0x5AD0: 'nǎo',  # 嫐
    0x5AD1: 'biáo',  # 嫑
    0x5AD2: 'ài',  # 嫒
    0x5AD3: 'pì',  # 嫓
    0x5AD4: 'pín',  # 嫔
    0x5AD5: 'yì',  # 嫕
    0x5AD6: 'piáo,piāo',  # 嫖
    0x5AD7: 'yù',  # 嫗
    0x5AD8: 'léi',  # 嫘
    0x5AD9: 'xuán',  # 嫙
    0x5ADA: 'màn',  # 嫚
    0x5ADB: 'yī',  # 嫛
    0x5ADC: 'zhāng',  # 嫜
    0x5ADD: 'kāng',  # 嫝
    0x5ADE: 'yōng',  # 嫞
    0x5ADF: 'nì',  # 嫟
    0x5AE0: 'lí',  # 嫠
    0x5AE1: 'dí',  # 嫡
    0x5AE2: 'guī',  # 嫢
    0x5AE3: 'yān',  # 嫣
    0x5AE4: 'jǐn,jìn',  # 嫤
    0x5AE5: 'zhuān',  # 嫥
    0x5AE6: 'cháng',  # 嫦
    0x5AE7: 'zé',  # 嫧
    0x5AE8: 'hān,nǎn',  # 嫨
    0x5AE9: 'nèn',  # 嫩
    0x5AEA: 'lào',  # 嫪
    0x5AEB: 'mó',  # 嫫
    0x5AEC: 'zhē',  # 嫬
    0x5AED: 'hù',  # 嫭
    0x5AEE: 'hù',  # 嫮
    0x5AEF: 'ào',  # 嫯
    0x5AF0: 'nèn',  # 嫰
    0x5AF1: 'qiáng',  # 嫱
    0x5AF2: 'mā,má',  # 嫲
    0x5AF3: 'piè',  # 嫳
    0x5AF4: 'gū',  # 嫴
    0x5AF5: 'wǔ',  # 嫵
    0x5AF6: 'qiáo',  # 嫶
    0x5AF7: 'tuǒ',  # 嫷
    0x5AF8: 'zhǎn',  # 嫸
    0x5AF9: 'miáo',  # 嫹
    0x5AFA: 'xián',  # 嫺
    0x5AFB: 'xián',  # 嫻
    0x5AFC: 'mò',  # 嫼
    0x5AFD: 'liáo',  # 嫽
    0x5AFE: 'lián',  # 嫾
    0x5AFF: 'huà',  # 嫿
    0x5B00: 'guī',  # 嬀
    0x5B01: 'dēng',  # 嬁
    0x5B02: 'zhí',  # 嬂
    0x5B03: 'xū',  # 嬃
    0x5B04: 'yī',  # 嬄
    0x5B05: 'huà',  # 嬅
    0x5B06: 'xī',  # 嬆
    0x5B07: 'kuì',  # 嬇
    0x5B08: 'ráo,rǎo',  # 嬈
    0x5B09: 'xī',  # 嬉
    0x5B0A: 'yàn',  # 嬊
    0x5B0B: 'chán',  # 嬋
    0x5B0C: 'jiāo',  # 嬌
    0x5B0D: 'měi',  # 嬍
    0x5B0E: 'fàn',  # 嬎
    0x5B0F: 'fān',  # 嬏
    0x5B10: 'xiān,yǎn,jìn',  # 嬐
    0x5B11: 'yì',  # 嬑
    0x5B12: 'huì',  # 嬒
    0x5B13: 'jiào',  # 嬓
    0x5B14: 'fù',  # 嬔
    0x5B15: 'shì',  # 嬕
    0x5B16: 'bì',  # 嬖
    0x5B17: 'shàn',  # 嬗
    0x5B18: 'suì',  # 嬘
    0x5B19: 'qiáng',  # 嬙
    0x5B1A: 'liǎn',  # 嬚
    0x5B1B: 'huán,xuān,qióng',  # 嬛
    0x5B1C: 'xīn',  # 嬜
    0x5B1D: 'niǎo',  # 嬝
    0x5B1E: 'dǒng',  # 嬞
    0x5B1F: 'yǐ',  # 嬟
    0x5B20: 'cān',  # 嬠
    0x5B21: 'ài',  # 嬡
    0x5B22: 'niáng',  # 嬢
    0x5B23: 'níng',  # 嬣
    0x5B24: 'mó',  # 嬤
    0x5B25: 'tiǎo',  # 嬥
    0x5B26: 'chóu',  # 嬦
    0x5B27: 'jìn',  # 嬧
    0x5B28: 'cí',  # 嬨
    0x5B29: 'yú',  # 嬩
    0x5B2A: 'pín',  # 嬪
    0x5B2B: 'róng',  # 嬫
    0x5B2C: 'rú',  # 嬬
    0x5B2D: 'nǎi',  # 嬭
    0x5B2E: 'yān,yàn',  # 嬮
    0x5B2F: 'tái',  # 嬯
    0x5B30: 'yīng',  # 嬰
    0x5B31: 'qiàn',  # 嬱
    0x5B32: 'niǎo',  # 嬲
    0x5B33: 'yuè',  # 嬳
    0x5B34: 'yíng',  # 嬴
    0x5B35: 'mián',  # 嬵
    0x5B36: 'bí',  # 嬶
    0x5B37: 'mó',  # 嬷
    0x5B38: 'shěn',  # 嬸
    0x5B39: 'xìng',  # 嬹
    0x5B3A: 'nì',  # 嬺
    0x5B3B: 'dú',  # 嬻
    0x5B3C: 'liǔ',  # 嬼
    0x5B3D: 'yuān',  # 嬽
    0x5B3E: 'lǎn',  # 嬾
    0x5B3F: 'yàn',  # 嬿
    0x5B40: 'shuāng',  # 孀
    0x5B41: 'líng',  # 孁
    0x5B42: 'jiǎo',  # 孂
    0x5B43: 'niáng',  # 孃
    0x5B44: 'lǎn',  # 孄
    0x5B45: 'xiān,qiān',  # 孅
    0x5B46: 'yīng',  # 孆
    0x5B47: 'shuāng',  # 孇
    0x5B48: 'xié,huī',  # 孈
    0x5B49: 'huān,quán',  # 孉
    0x5B4A: 'mǐ',  # 孊
    0x5B4B: 'lí,lì',  # 孋
    0x5B4C: 'luán',  # 孌
    0x5B4D: 'yǎn',  # 孍
    0x5B4E: 'zhú,chuò',  # 孎
    0x5B4F: 'lǎn',  # 孏
    0x5B50: 'zǐ',  # 子
    0x5B51: 'jié',  # 孑
    0x5B52: 'jué',  # 孒
    0x5B53: 'jué',  # 孓
    0x5B54: 'kǒng',  # 孔
    0x5B55: 'yùn',  # 孕
    0x5B56: 'zī,mā',  # 孖
    0x5B57: 'zì',  # 字
    0x5B58: 'cún',  # 存
    0x5B59: 'sūn,xùn',  # 孙
    0x5B5A: 'fú',  # 孚
    0x5B5B: 'bèi',  # 孛
    0x5B5C: 'zī',  # 孜
    0x5B5D: 'xiào',  # 孝
    0x5B5E: 'xìn',  # 孞
    0x5B5F: 'mèng',  # 孟
    0x5B60: 'sì',  # 孠
    0x5B61: 'tāi',  # 孡
    0x5B62: 'bāo',  # 孢
    0x5B63: 'jì',  # 季
    0x5B64: 'gū',  # 孤
    0x5B65: 'nú',  # 孥
    0x5B66: 'xué',  # 学
    0x5B67: 'yòu,niū',  # 孧
    0x5B68: 'zhuǎn',  # 孨
    0x5B69: 'hái',  # 孩
    0x5B6A: 'luán',  # 孪
    0x5B6B: 'sūn,xùn',  # 孫
    0x5B6C: 'nāo',  # 孬
    0x5B6D: 'miē',  # 孭
    0x5B6E: 'cóng',  # 孮
    0x5B6F: 'qiān',  # 孯
    0x5B70: 'shú',  # 孰
    0x5B71: 'chán,càn',  # 孱
    0x5B72: 'yā',  # 孲
    0x5B73: 'zī',  # 孳
    0x5B74: 'nǐ',  # 孴
    0x5B75: 'fū',  # 孵
    0x5B76: 'zī',  # 孶
    0x5B77: 'lí',  # 孷
    0x5B78: 'xué',  # 學
    0x5B79: 'bò',  # 孹
    0x5B7A: 'rú',  # 孺
    0x5B7B: 'nái',  # 孻
    0x5B7C: 'niè',  # 孼
    0x5B7D: 'niè',  # 孽
    0x5B7E: 'yīng',  # 孾
    0x5B7F: 'luán',  # 孿
    0x5B80: 'mián',  # 宀
    0x5B81: 'níng,nìng,zhù',  # 宁
    0x5B82: 'rǒng',  # 宂
    0x5B83: 'tā',  # 它
    0x5B84: 'guǐ',  # 宄
    0x5B85: 'zhái',  # 宅
    0x5B86: 'qióng',  # 宆
    0x5B87: 'yǔ',  # 宇
    0x5B88: 'shǒu',  # 守
    0x5B89: 'ān',  # 安
    0x5B8A: 'tū,jiā',  # 宊
    0x5B8B: 'sòng',  # 宋
    0x5B8C: 'wán',  # 完
    0x5B8D: 'ròu',  # 宍
    0x5B8E: 'yǎo',  # 宎
    0x5B8F: 'hóng',  # 宏
    0x5B90: 'yí',  # 宐
    0x5B91: 'jǐng',  # 宑
    0x5B92: 'zhūn',  # 宒
    0x5B93: 'mì,fú',  # 宓
    0x5B94: 'zhǔ',  # 宔
    0x5B95: 'dàng',  # 宕
    0x5B96: 'hóng',  # 宖
    0x5B97: 'zōng',  # 宗
    0x5B98: 'guān',  # 官
    0x5B99: 'zhòu',  # 宙
    0x5B9A: 'dìng',  # 定
    0x5B9B: 'wǎn,yuān',  # 宛
    0x5B9C: 'yí',  # 宜
    0x5B9D: 'bǎo',  # 宝
    0x5B9E: 'shí',  # 实
    0x5B9F: 'shí',  # 実
    0x5BA0: 'chǒng',  # 宠
    0x5BA1: 'shěn',  # 审
    0x5BA2: 'kè',  # 客
    0x5BA3: 'xuān',  # 宣
    0x5BA4: 'shì',  # 室
    0x5BA5: 'yòu',  # 宥
    0x5BA6: 'huàn',  # 宦
    0x5BA7: 'yí',  # 宧
    0x5BA8: 'tiǎo',  # 宨
    0x5BA9: 'shǐ',  # 宩
    0x5BAA: 'xiàn',  # 宪
    0x5BAB: 'gōng',  # 宫
    0x5BAC: 'chéng',  # 宬
    0x5BAD: 'qún',  # 宭
    0x5BAE: 'gōng',  # 宮
    0x5BAF: 'xiāo',  # 宯
    0x5BB0: 'zǎi',  # 宰
    0x5BB1: 'zhà',  # 宱
    0x5BB2: 'bǎo,shí',  # 宲
    0x5BB3: 'hài',  # 害
    0x5BB4: 'yàn',  # 宴
    0x5BB5: 'xiāo',  # 宵
    0x5BB6: 'jiā,jia,jie',  # 家
    0x5BB7: 'shěn',  # 宷
    0x5BB8: 'chén',  # 宸
    0x5BB9: 'róng',  # 容
    0x5BBA: 'huāng,huǎng',  # 宺
    0x5BBB: 'mì',  # 宻
    0x5BBC: 'kòu',  # 宼
    0x5BBD: 'kuān',  # 宽
    0x5BBE: 'bīn',  # 宾
    0x5BBF: 'sù,xiǔ,xiù',  # 宿
    0x5BC0: 'cǎi,cài',  # 寀
    0x5BC1: 'zǎn',  # 寁
    0x5BC2: 'jì',  # 寂
    0x5BC3: 'yuān',  # 寃
    0x5BC4: 'jì',  # 寄
    0x5BC5: 'yín',  # 寅
    0x5BC6: 'mì',  # 密
    0x5BC7: 'kòu',  # 寇
    0x5BC8: 'qīng',  # 寈
    0x5BC9: 'hè',  # 寉
    0x5BCA: 'zhēn',  # 寊
    0x5BCB: 'jiàn',  # 寋
    0x5BCC: 'fù',  # 富
    0x5BCD: 'níng,nìng',  # 寍
    0x5BCE: 'bǐng,bìng',  # 寎
    0x5BCF: 'huán',  # 寏
    0x5BD0: 'mèi',  # 寐
    0x5BD1: 'qǐn',  # 寑
    0x5BD2: 'hán',  # 寒
    0x5BD3: 'yù',  # 寓
    0x5BD4: 'shí',  # 寔
    0x5BD5: 'níng,nìng',  # 寕
    0x5BD6: 'jìn,qǐn',  # 寖
    0x5BD7: 'níng,nìng',  # 寗
    0x5BD8: 'zhì',  # 寘
    0x5BD9: 'yǔ',  # 寙
    0x5BDA: 'bǎo',  # 寚
    0x5BDB: 'kuān',  # 寛
    0x5BDC: 'níng,nìng',  # 寜
    0x5BDD: 'qǐn',  # 寝
    0x5BDE: 'mò',  # 寞
    0x5BDF: 'chá',  # 察
    0x5BE0: 'jù,lóu',  # 寠
    0x5BE1: 'guǎ',  # 寡
    0x5BE2: 'qǐn',  # 寢
    0x5BE3: 'hū',  # 寣
    0x5BE4: 'wù',  # 寤
    0x5BE5: 'liáo',  # 寥
    0x5BE6: 'shí',  # 實
    0x5BE7: 'níng,nìng',  # 寧
    0x5BE8: 'zhài',  # 寨
    0x5BE9: 'shěn',  # 審
    0x5BEA: 'wěi',  # 寪
    0x5BEB: 'xiě,xiè',  # 寫
    0x5BEC: 'kuān',  # 寬
    0x5BED: 'huì',  # 寭
    0x5BEE: 'liáo',  # 寮
    0x5BEF: 'jùn',  # 寯
    0x5BF0: 'huán',  # 寰
    0x5BF1: 'yì',  # 寱
    0x5BF2: 'yí',  # 寲
    0x5BF3: 'bǎo',  # 寳
    0x5BF4: 'qīn,qìn',  # 寴
    0x5BF5: 'chǒng',  # 寵
    0x5BF6: 'bǎo',  # 寶
    0x5BF7: 'fēng',  # 寷
    0x5BF8: 'cùn',  # 寸
    0x5BF9: 'duì',  # 对
    0x5BFA: 'sì',  # 寺
    0x5BFB: 'xún',  # 寻
    0x5BFC: 'dǎo',  # 导
    0x5BFD: 'lüè,luó',  # 寽
    0x5BFE: 'duì',  # 対
    0x5BFF: 'shòu',  # 寿
    0x5C00: 'pǒ',  # 尀
    0x5C01: 'fēng',  # 封
    0x5C02: 'zhuān',  # 専
    0x5C03: 'fū',  # 尃
    0x5C04: 'shè,yè,yì',  # 射
    0x5C05: 'kēi,kè',  # 尅
    0x5C06: 'jiāng,jiàng',  # 将
    0x5C07: 'jiāng,jiàng',  # 將
    0x5C08: 'zhuān',  # 專
    0x5C09: 'wèi,yù',  # 尉
    0x5C0A: 'zūn',  # 尊
    0x5C0B: 'xún',  # 尋
    0x5C0C: 'shù,zhù',  # 尌
    0x5C0D: 'duì',  # 對
    0x5C0E: 'dǎo',  # 導
    0x5C0F: 'xiǎo',  # 小
    0x5C10: 'jié,jí',  # 尐
    0x5C11: 'shǎo,shào',  # 少
    0x5C12: 'ěr',  # 尒
    0x5C13: 'ěr',  # 尓
    0x5C14: 'ěr',  # 尔
    0x5C15: 'gǎ',  # 尕
    0x5C16: 'jiān',  # 尖
    0x5C17: 'shú',  # 尗
    0x5C18: 'chén',  # 尘
    0x5C19: 'shàng',  # 尙
    0x5C1A: 'shàng',  # 尚
    0x5C1B: 'mó',  # 尛
    0x5C1C: 'gá',  # 尜
    0x5C1D: 'cháng',  # 尝
    0x5C1E: 'liáo',  # 尞
    0x5C1F: 'xiǎn',  # 尟
    0x5C20: 'xiǎn',  # 尠
    0x5C21: 'hùn',  # 尡
    0x5C22: 'yóu',  # 尢
    0x5C23: 'wāng',  # 尣
    0x5C24: 'yóu',  # 尤
    0x5C25: 'liào',  # 尥
    0x5C26: 'liào',  # 尦
    0x5C27: 'yáo',  # 尧
    0x5C28: 'lóng,máng,méng,páng',  # 尨
    0x5C29: 'wāng',  # 尩
    0x5C2A: 'wāng',  # 尪
    0x5C2B: 'wāng',  # 尫
    0x5C2C: 'gà',  # 尬
    0x5C2D: 'yáo',  # 尭
    0x5C2E: 'duò',  # 尮
    0x5C2F: 'kuì,kuǐ',  # 尯
    0x5C30: 'zhǒng',  # 尰
    0x5C31: 'jiù',  # 就
    0x5C32: 'gān',  # 尲
    0x5C33: 'gǔ',  # 尳
    0x5C34: 'gān',  # 尴
    0x5C35: 'tuí',  # 尵
    0x5C36: 'gān',  # 尶
    0x5C37: 'gān',  # 尷
    0x5C38: 'shī',  # 尸
    0x5C39: 'yǐn',  # 尹
    0x5C3A: 'chǐ,chě',  # 尺
    0x5C3B: 'kāo',  # 尻
    0x5C3C: 'ní',  # 尼
    0x5C3D: 'jìn,jǐn',  # 尽
    0x5C3E: 'wěi,yǐ',  # 尾
    0x5C3F: 'niào,suī',  # 尿
    0x5C40: 'jú',  # 局
    0x5C41: 'pì',  # 屁
    0x5C42: 'céng',  # 层
    0x5C43: 'xì',  # 屃
    0x5C44: 'bī',  # 屄
    0x5C45: 'jū',  # 居
    0x5C46: 'jiè',  # 屆
    0x5C47: 'tián',  # 屇
    0x5C48: 'qū',  # 屈
    0x5C49: 'tì',  # 屉
    0x5C4A: 'jiè',  # 届
    0x5C4B: 'wū',  # 屋
    0x5C4C: 'diǎo',  # 屌
    0x5C4D: 'shī',  # 屍
    0x5C4E: 'shǐ',  # 屎
    0x5C4F: 'píng,bǐng',  # 屏
    0x5C50: 'jī',  # 屐
    0x5C51: 'xiè',  # 屑
    0x5C52: 'zhěn',  # 屒
    0x5C53: 'xì',  # 屓
    0x5C54: 'ní',  # 屔
    0x5C55: 'zhǎn',  # 展
    0x5C56: 'xī',  # 屖
    0x5C57: 'wěi',  # 屗
    0x5C58: 'mǎn',  # 屘
    0x5C59: 'ē',  # 屙
    0x5C5A: 'lòu',  # 屚
    0x5C5B: 'pǐng,bǐng',  # 屛
    0x5C5C: 'tì',  # 屜
    0x5C5D: 'fèi',  # 屝
    0x5C5E: 'shǔ,zhǔ',  # 属
    0x5C5F: 'xiè,tì',  # 屟
    0x5C60: 'tú',  # 屠
    0x5C61: 'lǚ',  # 屡
    0x5C62: 'lǚ',  # 屢
    0x5C63: 'xǐ',  # 屣
    0x5C64: 'céng',  # 層
    0x5C65: 'lǚ',  # 履
    0x5C66: 'jù',  # 屦
    0x5C67: 'xiè',  # 屧
    0x5C68: 'jù',  # 屨
    0x5C69: 'juē',  # 屩
    0x5C6A: 'liáo',  # 屪
    0x5C6B: 'juē',  # 屫
    0x5C6C: 'shǔ,zhǔ',  # 屬
    0x5C6D: 'xì',  # 屭
    0x5C6E: 'chè,cǎo',  # 屮
    0x5C6F: 'tún,zhūn',  # 屯
    0x5C70: 'nì,jǐ',  # 屰
    0x5C71: 'shān',  # 山
    0x5C72: 'wā',  # 屲
    0x5C73: 'xiān',  # 屳
    0x5C74: 'lì',  # 屴
    0x5C75: 'àn',  # 屵
    0x5C76: 'huì',  # 屶
    0x5C77: 'huì',  # 屷
    0x5C78: 'hóng,lóng',  # 屸
    0x5C79: 'yì',  # 屹
    0x5C7A: 'qǐ',  # 屺
    0x5C7B: 'rèn',  # 屻
    0x5C7C: 'wù',  # 屼
    0x5C7D: 'hàn,àn',  # 屽
    0x5C7E: 'shēn',  # 屾
    0x5C7F: 'yǔ',  # 屿
    0x5C80: 'chū',  # 岀
    0x5C81: 'suì',  # 岁
    0x5C82: 'qǐ,kǎi',  # 岂
    0x5C83: 'rèn',  # 岃
    0x5C84: 'yuè',  # 岄
    0x5C85: 'bǎn',  # 岅
    0x5C86: 'yǎo',  # 岆
    0x5C87: 'áng',  # 岇
    0x5C88: 'yá',  # 岈
    0x5C89: 'wù',  # 岉
    0x5C8A: 'jié',  # 岊
    0x5C8B: 'è',  # 岋
    0x5C8C: 'jí',  # 岌
    0x5C8D: 'qiān',  # 岍
    0x5C8E: 'fén',  # 岎
    0x5C8F: 'wán',  # 岏
    0x5C90: 'qí',  # 岐
    0x5C91: 'cén',  # 岑
    0x5C92: 'qián',  # 岒
    0x5C93: 'qí',  # 岓
    0x5C94: 'chà',  # 岔
    0x5C95: 'jiè',  # 岕
    0x5C96: 'qū',  # 岖
    0x5C97: 'gǎng',  # 岗
    0x5C98: 'xiàn',  # 岘
    0x5C99: 'ào',  # 岙
    0x5C9A: 'lán',  # 岚
    0x5C9B: 'dǎo',  # 岛
    0x5C9C: 'bā',  # 岜
    0x5C9D: 'zuò',  # 岝
    0x5C9E: 'zuò',  # 岞
    0x5C9F: 'yǎng',  # 岟
    0x5CA0: 'jù',  # 岠
    0x5CA1: 'gāng',  # 岡
    0x5CA2: 'kě',  # 岢
    0x5CA3: 'gǒu',  # 岣
    0x5CA4: 'xuè',  # 岤
    0x5CA5: 'pō',  # 岥
    0x5CA6: 'lì',  # 岦
    0x5CA7: 'tiáo',  # 岧
    0x5CA8: 'jū,jǔ',  # 岨
    0x5CA9: 'yán',  # 岩
    0x5CAA: 'fú',  # 岪
    0x5CAB: 'xiù',  # 岫
    0x5CAC: 'jiǎ',  # 岬
    0x5CAD: 'lǐng,líng',  # 岭
    0x5CAE: 'tuó',  # 岮
    0x5CAF: 'pī',  # 岯
    0x5CB0: 'ào',  # 岰
    0x5CB1: 'dài',  # 岱
    0x5CB2: 'kuàng',  # 岲
    0x5CB3: 'yuè',  # 岳
    0x5CB4: 'qū',  # 岴
    0x5CB5: 'hù',  # 岵
    0x5CB6: 'pò',  # 岶
    0x5CB7: 'mín',  # 岷
    0x5CB8: 'àn',  # 岸
    0x5CB9: 'tiáo',  # 岹
    0x5CBA: 'lǐng,líng',  # 岺
    0x5CBB: 'dī',  # 岻
    0x5CBC: 'píng',  # 岼
    0x5CBD: 'dōng',  # 岽
    0x5CBE: 'zhān',  # 岾
    0x5CBF: 'kuī',  # 岿
    0x5CC0: 'xiù',  # 峀
    0x5CC1: 'mǎo',  # 峁
    0x5CC2: 'tóng',  # 峂
    0x5CC3: 'xué',  # 峃
    0x5CC4: 'yì',  # 峄
    0x5CC5: 'biàn',  # 峅
    0x5CC6: 'hé',  # 峆
    0x5CC7: 'kè,bā',  # 峇
    0x5CC8: 'luò',  # 峈
    0x5CC9: 'é',  # 峉
    0x5CCA: 'fù,niè',  # 峊
    0x5CCB: 'xún',  # 峋
    0x5CCC: 'dié',  # 峌
    0x5CCD: 'lù',  # 峍
    0x5CCE: 'ěn',  # 峎
    0x5CCF: 'ér',  # 峏
    0x5CD0: 'gāi',  # 峐
    0x5CD1: 'quán',  # 峑
    0x5CD2: 'tóng,dòng',  # 峒
    0x5CD3: 'yí',  # 峓
    0x5CD4: 'mǔ',  # 峔
    0x5CD5: 'shí',  # 峕
    0x5CD6: 'ān',  # 峖
    0x5CD7: 'wéi',  # 峗
    0x5CD8: 'huán',  # 峘
    0x5CD9: 'zhì,shì',  # 峙
    0x5CDA: 'mì',  # 峚
    0x5CDB: 'lǐ',  # 峛
    0x5CDC: 'fǎ',  # 峜
    0x5CDD: 'tóng',  # 峝
    0x5CDE: 'wéi',  # 峞
    0x5CDF: 'yòu',  # 峟
    0x5CE0: 'qiǎ',  # 峠
    0x5CE1: 'xiá',  # 峡
    0x5CE2: 'lǐ',  # 峢
    0x5CE3: 'yáo',  # 峣
    0x5CE4: 'jiào,qiáo',  # 峤
    0x5CE5: 'zhēng',  # 峥
    0x5CE6: 'luán',  # 峦
    0x5CE7: 'jiāo',  # 峧
    0x5CE8: 'é',  # 峨
    0x5CE9: 'é',  # 峩
    0x5CEA: 'yù',  # 峪
    0x5CEB: 'xié,yé',  # 峫
    0x5CEC: 'bū',  # 峬
    0x5CED: 'qiào',  # 峭
    0x5CEE: 'qún',  # 峮
    0x5CEF: 'fēng',  # 峯
    0x5CF0: 'fēng',  # 峰
    0x5CF1: 'náo',  # 峱
    0x5CF2: 'lǐ',  # 峲
    0x5CF3: 'yōu',  # 峳
    0x5CF4: 'xiàn',  # 峴
    0x5CF5: 'róng',  # 峵
    0x5CF6: 'dǎo',  # 島
    0x5CF7: 'shēn',  # 峷
    0x5CF8: 'chéng',  # 峸
    0x5CF9: 'tú',  # 峹
    0x5CFA: 'gěng',  # 峺
    0x5CFB: 'jùn',  # 峻
    0x5CFC: 'gào',  # 峼
    0x5CFD: 'xiá',  # 峽
    0x5CFE: 'yín',  # 峾
    0x5CFF: 'wú',  # 峿
    0x5D00: 'lǎng',  # 崀
    0x5D01: 'kàn',  # 崁
    0x5D02: 'láo',  # 崂
    0x5D03: 'lái',  # 崃
    0x5D04: 'xiǎn',  # 崄
    0x5D05: 'què',  # 崅
    0x5D06: 'kōng',  # 崆
    0x5D07: 'chóng',  # 崇
    0x5D08: 'chóng',  # 崈
    0x5D09: 'tà',  # 崉
    0x5D0A: 'lín',  # 崊
    0x5D0B: 'huà',  # 崋
    0x5D0C: 'jū',  # 崌
    0x5D0D: 'lái',  # 崍
    0x5D0E: 'qí',  # 崎
    0x5D0F: 'mín',  # 崏
    0x5D10: 'kūn',  # 崐
    0x5D11: 'kūn',  # 崑
    0x5D12: 'zú,cuì',  # 崒
    0x5D13: 'gù',  # 崓
    0x5D14: 'cuī',  # 崔
    0x5D15: 'yá',  # 崕
    0x5D16: 'yá',  # 崖
    0x5D17: 'gǎng,gāng',  # 崗
    0x5D18: 'lún',  # 崘
    0x5D19: 'lún',  # 崙
    0x5D1A: 'líng,léng',  # 崚
    0x5D1B: 'jué',  # 崛
    0x5D1C: 'duǒ',  # 崜
    0x5D1D: 'zhēng',  # 崝
    0x5D1E: 'guō',  # 崞
    0x5D1F: 'yín',  # 崟
    0x5D20: 'dōng,dòng',  # 崠
    0x5D21: 'hán',  # 崡
    0x5D22: 'zhēng',  # 崢
    0x5D23: 'wěi',  # 崣
    0x5D24: 'xiáo',  # 崤
    0x5D25: 'pí,bǐ',  # 崥
    0x5D26: 'yān',  # 崦
    0x5D27: 'sōng',  # 崧
    0x5D28: 'jié',  # 崨
    0x5D29: 'bēng',  # 崩
    0x5D2A: 'zú',  # 崪
    0x5D2B: 'jué',  # 崫
    0x5D2C: 'dōng',  # 崬
    0x5D2D: 'zhǎn,chán',  # 崭
    0x5D2E: 'gù',  # 崮
    0x5D2F: 'yín',  # 崯
    0x5D30: 'zī',  # 崰
    0x5D31: 'zè',  # 崱
    0x5D32: 'huáng',  # 崲
    0x5D33: 'yú',  # 崳
    0x5D34: 'wǎi,wēi',  # 崴
    0x5D35: 'yáng,dàng',  # 崵
    0x5D36: 'fēng',  # 崶
    0x5D37: 'qiú',  # 崷
    0x5D38: 'yáng',  # 崸
    0x5D39: 'tí',  # 崹
    0x5D3A: 'yǐ',  # 崺
    0x5D3B: 'zhì,shì',  # 崻
    0x5D3C: 'shì,dié',  # 崼
    0x5D3D: 'zǎi',  # 崽
    0x5D3E: 'yǎo',  # 崾
    0x5D3F: 'è',  # 崿
    0x5D40: 'zhù',  # 嵀
    0x5D41: 'kān,zhàn',  # 嵁
    0x5D42: 'lǜ',  # 嵂
    0x5D43: 'yǎn',  # 嵃
    0x5D44: 'měi',  # 嵄
    0x5D45: 'hán',  # 嵅
    0x5D46: 'jī',  # 嵆
    0x5D47: 'jī',  # 嵇
    0x5D48: 'huàn',  # 嵈
    0x5D49: 'tíng',  # 嵉
    0x5D4A: 'shèng',  # 嵊
    0x5D4B: 'méi',  # 嵋
    0x5D4C: 'qiàn,kàn',  # 嵌
    0x5D4D: 'wù,máo',  # 嵍
    0x5D4E: 'yú',  # 嵎
    0x5D4F: 'zōng',  # 嵏
    0x5D50: 'lán',  # 嵐
    0x5D51: 'kě,jié',  # 嵑
    0x5D52: 'yán',  # 嵒
    0x5D53: 'yán',  # 嵓
    0x5D54: 'wēi,wěi',  # 嵔
    0x5D55: 'zōng',  # 嵕
    0x5D56: 'chá',  # 嵖
    0x5D57: 'suì',  # 嵗
    0x5D58: 'róng',  # 嵘
    0x5D59: 'kē',  # 嵙
    0x5D5A: 'qīn',  # 嵚
    0x5D5B: 'yú',  # 嵛
    0x5D5C: 'qí',  # 嵜
    0x5D5D: 'lǒu',  # 嵝
    0x5D5E: 'tú',  # 嵞
    0x5D5F: 'cuī',  # 嵟
    0x5D60: 'xī',  # 嵠
    0x5D61: 'wěng',  # 嵡
    0x5D62: 'cāng',  # 嵢
    0x5D63: 'dàng,táng',  # 嵣
    0x5D64: 'róng,yíng',  # 嵤
    0x5D65: 'jié',  # 嵥
    0x5D66: 'kǎi,ái',  # 嵦
    0x5D67: 'liú',  # 嵧
    0x5D68: 'wù',  # 嵨
    0x5D69: 'sōng',  # 嵩
    0x5D6A: 'kāo,qiāo',  # 嵪
    0x5D6B: 'zī',  # 嵫
    0x5D6C: 'wéi',  # 嵬
    0x5D6D: 'bēng',  # 嵭
    0x5D6E: 'diān',  # 嵮
    0x5D6F: 'cuó',  # 嵯
    0x5D70: 'qīn,qiǎn',  # 嵰
    0x5D71: 'yǒng',  # 嵱
    0x5D72: 'niè',  # 嵲
    0x5D73: 'cuó',  # 嵳
    0x5D74: 'jǐ',  # 嵴
    0x5D75: 'shí',  # 嵵
    0x5D76: 'ruò',  # 嵶
    0x5D77: 'sǒng',  # 嵷
    0x5D78: 'zǒng',  # 嵸
    0x5D79: 'jiàng',  # 嵹
    0x5D7A: 'liáo',  # 嵺
    0x5D7B: 'kāng',  # 嵻
    0x5D7C: 'chǎn',  # 嵼
    0x5D7D: 'dié,dì',  # 嵽
    0x5D7E: 'cēn',  # 嵾
    0x5D7F: 'dǐng',  # 嵿
    0x5D80: 'tū',  # 嶀
    0x5D81: 'lǒu',  # 嶁
    0x5D82: 'zhàng',  # 嶂
    0x5D83: 'zhǎn,chán',  # 嶃
    0x5D84: 'zhǎn,chán',  # 嶄
    0x5D85: 'áo,ào',  # 嶅
    0x5D86: 'cáo',  # 嶆
    0x5D87: 'qū',  # 嶇
    0x5D88: 'qiāng',  # 嶈
    0x5D89: 'wěi',  # 嶉
    0x5D8A: 'zuǐ',  # 嶊
    0x5D8B: 'dǎo',  # 嶋
    0x5D8C: 'dǎo',  # 嶌
    0x5D8D: 'xí',  # 嶍
    0x5D8E: 'yù',  # 嶎
    0x5D8F: 'pǐ,pèi',  # 嶏
    0x5D90: 'lóng',  # 嶐
    0x5D91: 'xiàng',  # 嶑
    0x5D92: 'céng',  # 嶒
    0x5D93: 'bō',  # 嶓
    0x5D94: 'qīn',  # 嶔
    0x5D95: 'jiāo',  # 嶕
    0x5D96: 'yān',  # 嶖
    0x5D97: 'láo',  # 嶗
    0x5D98: 'zhàn',  # 嶘
    0x5D99: 'lín',  # 嶙
    0x5D9A: 'liáo',  # 嶚
    0x5D9B: 'liáo',  # 嶛
    0x5D9C: 'qín',  # 嶜
    0x5D9D: 'dèng',  # 嶝
    0x5D9E: 'tuò',  # 嶞
    0x5D9F: 'zūn',  # 嶟
    0x5DA0: 'jiào,qiáo',  # 嶠
    0x5DA1: 'jué,guì',  # 嶡
    0x5DA2: 'yáo',  # 嶢
    0x5DA3: 'jiāo',  # 嶣
    0x5DA4: 'yáo',  # 嶤
    0x5DA5: 'jué',  # 嶥
    0x5DA6: 'zhān,shàn',  # 嶦
    0x5DA7: 'yì',  # 嶧
    0x5DA8: 'xué',  # 嶨
    0x5DA9: 'náo',  # 嶩
    0x5DAA: 'yè',  # 嶪
    0x5DAB: 'yè',  # 嶫
    0x5DAC: 'yí',  # 嶬
    0x5DAD: 'niè',  # 嶭
    0x5DAE: 'xiǎn',  # 嶮
    0x5DAF: 'jí',  # 嶯
    0x5DB0: 'xiè,jiè',  # 嶰
    0x5DB1: 'kě,jié',  # 嶱
    0x5DB2: 'guī,xī,juàn',  # 嶲
    0x5DB3: 'dì',  # 嶳
    0x5DB4: 'ào',  # 嶴
    0x5DB5: 'zuì',  # 嶵
    0x5DB6: 'wēi',  # 嶶
    0x5DB7: 'yí',  # 嶷
    0x5DB8: 'róng',  # 嶸
    0x5DB9: 'dǎo',  # 嶹
    0x5DBA: 'lǐng',  # 嶺
    0x5DBB: 'jié',  # 嶻
    0x5DBC: 'yǔ',  # 嶼
    0x5DBD: 'yuè',  # 嶽
    0x5DBE: 'yǐn',  # 嶾
    0x5DBF: 'rū',  # 嶿
    0x5DC0: 'jié',  # 巀
    0x5DC1: 'lì,liè',  # 巁
    0x5DC2: 'guī,xī,juàn',  # 巂
    0x5DC3: 'lóng',  # 巃
    0x5DC4: 'lóng',  # 巄
    0x5DC5: 'diān',  # 巅
    0x5DC6: 'yíng,hōng',  # 巆
    0x5DC7: 'xī',  # 巇
    0x5DC8: 'jú',  # 巈
    0x5DC9: 'chán',  # 巉
    0x5DCA: 'yǐng',  # 巊
    0x5DCB: 'kuī',  # 巋
    0x5DCC: 'yán',  # 巌
    0x5DCD: 'wēi',  # 巍
    0x5DCE: 'náo',  # 巎
    0x5DCF: 'quán',  # 巏
    0x5DD0: 'chǎo',  # 巐
    0x5DD1: 'cuán',  # 巑
    0x5DD2: 'luán',  # 巒
    0x5DD3: 'diān',  # 巓
    0x5DD4: 'diān',  # 巔
    0x5DD5: 'niè',  # 巕
    0x5DD6: 'yán',  # 巖
    0x5DD7: 'yán',  # 巗
    0x5DD8: 'yǎn',  # 巘
    0x5DD9: 'kuí',  # 巙
    0x5DDA: 'yǎn',  # 巚
    0x5DDB: 'chuān',  # 巛
    0x5DDC: 'kuài',  # 巜
    0x5DDD: 'chuān',  # 川
    0x5DDE: 'zhōu',  # 州
    0x5DDF: 'huāng',  # 巟
    0x5DE0: 'jīng,xíng',  # 巠
    0x5DE1: 'xún',  # 巡
    0x5DE2: 'cháo',  # 巢
    0x5DE3: 'cháo',  # 巣
    0x5DE4: 'liè',  # 巤
    0x5DE5: 'gōng',  # 工
    0x5DE6: 'zuǒ',  # 左
    0x5DE7: 'qiǎo',  # 巧
    0x5DE8: 'jù',  # 巨
    0x5DE9: 'gǒng',  # 巩
    0x5DEA: 'jù',  # 巪
    0x5DEB: 'wū',  # 巫
    0x5DEC: 'gū',  # 巬
    0x5DED: 'gū',  # 巭
    0x5DEE: 'chà,chā,chāi,cī',  # 差
    0x5DEF: 'qiú',  # 巯
    0x5DF0: 'qiú',  # 巰
    0x5DF1: 'jǐ',  # 己
    0x5DF2: 'yǐ',  # 已
    0x5DF3: 'sì',  # 巳
    0x5DF4: 'bā',  # 巴
    0x5DF5: 'zhī',  # 巵
    0x5DF6: 'zhāo',  # 巶
    0x5DF7: 'xiàng,hàng',  # 巷
    0x5DF8: 'yí',  # 巸
    0x5DF9: 'jǐn',  # 巹
    0x5DFA: 'xùn',  # 巺
    0x5DFB: 'juàn,juǎn',  # 巻
    0x5DFC: 'phas',  # 巼
    0x5DFD: 'xùn',  # 巽
    0x5DFE: 'jīn',  # 巾
    0x5DFF: 'fú',  # 巿
    0x5E00: 'zā',  # 帀
    0x5E01: 'bì',  # 币
    0x5E02: 'shì',  # 市
    0x5E03: 'bù',  # 布
    0x5E04: 'dīng',  # 帄
    0x5E05: 'shuài',  # 帅
    0x5E06: 'fān',  # 帆
    0x5E07: 'niè',  # 帇
    0x5E08: 'shī',  # 师
    0x5E09: 'fēn',  # 帉
    0x5E0A: 'pà',  # 帊
    0x5E0B: 'zhǐ',  # 帋
    0x5E0C: 'xī',  # 希
    0x5E0D: 'hù',  # 帍
    0x5E0E: 'dàn',  # 帎
    0x5E0F: 'wéi',  # 帏
    0x5E10: 'zhàng',  # 帐
    0x5E11: 'tǎng,nú',  # 帑
    0x5E12: 'dài',  # 帒
    0x5E13: 'mò,wà',  # 帓
    0x5E14: 'pèi',  # 帔
    0x5E15: 'pà',  # 帕
    0x5E16: 'tiè,tiě,tiē',  # 帖
    0x5E17: 'fú',  # 帗
    0x5E18: 'lián',  # 帘
    0x5E19: 'zhì',  # 帙
    0x5E1A: 'zhǒu',  # 帚
    0x5E1B: 'bó',  # 帛
    0x5E1C: 'zhì',  # 帜
    0x5E1D: 'dì',  # 帝
    0x5E1E: 'mò',  # 帞
    0x5E1F: 'yì',  # 帟
    0x5E20: 'yì',  # 帠
    0x5E21: 'píng',  # 帡
    0x5E22: 'qià',  # 帢
    0x5E23: 'juàn,juǎn',  # 帣
    0x5E24: 'rú',  # 帤
    0x5E25: 'shuài',  # 帥
    0x5E26: 'dài',  # 带
    0x5E27: 'zhēn',  # 帧
    0x5E28: 'shuì',  # 帨
    0x5E29: 'qiāo',  # 帩
    0x5E2A: 'zhēn',  # 帪
    0x5E2B: 'shī',  # 師
    0x5E2C: 'qún',  # 帬
    0x5E2D: 'xí',  # 席
    0x5E2E: 'bāng',  # 帮
    0x5E2F: 'dài',  # 帯
    0x5E30: 'guī',  # 帰
    0x5E31: 'chóu,dào',  # 帱
    0x5E32: 'píng',  # 帲
    0x5E33: 'zhàng',  # 帳
    0x5E34: 'jiǎn,jiān,sàn',  # 帴
    0x5E35: 'wān',  # 帵
    0x5E36: 'dài',  # 帶
    0x5E37: 'wéi',  # 帷
    0x5E38: 'cháng',  # 常
    0x5E39: 'shà,qiè',  # 帹
    0x5E3A: 'qí,jì',  # 帺
    0x5E3B: 'zé',  # 帻
    0x5E3C: 'guó',  # 帼
    0x5E3D: 'mào',  # 帽
    0x5E3E: 'zhǔ',  # 帾
    0x5E3F: 'hóu',  # 帿
    0x5E40: 'zhēn',  # 幀
    0x5E41: 'zhèng',  # 幁
    0x5E42: 'mì',  # 幂
    0x5E43: 'wéi',  # 幃
    0x5E44: 'wò',  # 幄
    0x5E45: 'fú',  # 幅
    0x5E46: 'yì',  # 幆
    0x5E47: 'bāng',  # 幇
    0x5E48: 'píng',  # 幈
    0x5E49: 'dié',  # 幉
    0x5E4A: 'gōng',  # 幊
    0x5E4B: 'pán',  # 幋
    0x5E4C: 'huǎng',  # 幌
    0x5E4D: 'tāo',  # 幍
    0x5E4E: 'mì',  # 幎
    0x5E4F: 'jià',  # 幏
    0x5E50: 'téng',  # 幐
    0x5E51: 'huī',  # 幑
    0x5E52: 'zhōng',  # 幒
    0x5E53: 'shān,qiāo,shēn',  # 幓
    0x5E54: 'màn',  # 幔
    0x5E55: 'mù',  # 幕
    0x5E56: 'biāo',  # 幖
    0x5E57: 'guó',  # 幗
    0x5E58: 'zé',  # 幘
    0x5E59: 'mù',  # 幙
    0x5E5A: 'bāng',  # 幚
    0x5E5B: 'zhàng',  # 幛
    0x5E5C: 'jǐng',  # 幜
    0x5E5D: 'chǎn,chàn',  # 幝
    0x5E5E: 'fú',  # 幞
    0x5E5F: 'zhì',  # 幟
    0x5E60: 'hū',  # 幠
    0x5E61: 'fān',  # 幡
    0x5E62: 'chuáng,zhuàng',  # 幢
    0x5E63: 'bì',  # 幣
    0x5E64: 'bì',  # 幤
    0x5E65: 'zhǎng',  # 幥
    0x5E66: 'mì',  # 幦
    0x5E67: 'qiāo',  # 幧
    0x5E68: 'chān,chàn',  # 幨
    0x5E69: 'fén',  # 幩
    0x5E6A: 'méng',  # 幪
    0x5E6B: 'bāng',  # 幫
    0x5E6C: 'chóu,dào',  # 幬
    0x5E6D: 'miè',  # 幭
    0x5E6E: 'chú',  # 幮
    0x5E6F: 'jié',  # 幯
    0x5E70: 'xiǎn',  # 幰
    0x5E71: 'lán',  # 幱
    0x5E72: 'gān,gàn',  # 干
    0x5E73: 'píng',  # 平
    0x5E74: 'nián',  # 年
    0x5E75: 'jiān',  # 幵
    0x5E76: 'bìng,bīng',  # 并
    0x5E77: 'bìng,bīng',  # 幷
    0x5E78: 'xìng',  # 幸
    0x5E79: 'gàn',  # 幹
    0x5E7A: 'yāo',  # 幺
    0x5E7B: 'huàn',  # 幻
    0x5E7C: 'yòu',  # 幼
    0x5E7D: 'yōu',  # 幽
    0x5E7E: 'jī,jǐ',  # 幾
    0x5E7F: 'guǎng,ān',  # 广
    0x5E80: 'pǐ',  # 庀
    0x5E81: 'tīng',  # 庁
    0x5E82: 'zè',  # 庂
    0x5E83: 'guǎng',  # 広
    0x5E84: 'zhuāng',  # 庄
    0x5E85: 'mó,mā,me',  # 庅
    0x5E86: 'qìng',  # 庆
    0x5E87: 'bì',  # 庇
    0x5E88: 'qín',  # 庈
    0x5E89: 'dùn,tún',  # 庉
    0x5E8A: 'chuáng',  # 床
    0x5E8B: 'guǐ',  # 庋
    0x5E8C: 'yǎ',  # 庌
    0x5E8D: 'bài,tīng',  # 庍
    0x5E8E: 'jiè',  # 庎
    0x5E8F: 'xù',  # 序
    0x5E90: 'lú',  # 庐
    0x5E91: 'wǔ',  # 庑
    0x5E92: 'zhuāng',  # 庒
    0x5E93: 'kù',  # 库
    0x5E94: 'yīng,yìng',  # 应
    0x5E95: 'dǐ,de',  # 底
    0x5E96: 'páo',  # 庖
    0x5E97: 'diàn',  # 店
    0x5E98: 'yā',  # 庘
    0x5E99: 'miào',  # 庙
    0x5E9A: 'gēng',  # 庚
    0x5E9B: 'cì',  # 庛
    0x5E9C: 'fǔ',  # 府
    0x5E9D: 'tóng',  # 庝
    0x5E9E: 'páng',  # 庞
    0x5E9F: 'fèi',  # 废
    0x5EA0: 'xiáng',  # 庠
    0x5EA1: 'yǐ',  # 庡
    0x5EA2: 'zhì',  # 庢
    0x5EA3: 'tiāo',  # 庣
    0x5EA4: 'zhì',  # 庤
    0x5EA5: 'xiū',  # 庥
    0x5EA6: 'dù,duó',  # 度
    0x5EA7: 'zuò',  # 座
    0x5EA8: 'xiāo',  # 庨
    0x5EA9: 'tú',  # 庩
    0x5EAA: 'guǐ',  # 庪
    0x5EAB: 'kù',  # 庫
    0x5EAC: 'máng,méng,páng',  # 庬
    0x5EAD: 'tíng',  # 庭
    0x5EAE: 'yóu',  # 庮
    0x5EAF: 'bū',  # 庯
    0x5EB0: 'bìng,píng',  # 庰
    0x5EB1: 'chěng',  # 庱
    0x5EB2: 'lái',  # 庲
    0x5EB3: 'bēi',  # 庳
    0x5EB4: 'jī,cuò',  # 庴
    0x5EB5: 'ān',  # 庵
    0x5EB6: 'shù',  # 庶
    0x5EB7: 'kāng',  # 康
    0x5EB8: 'yōng',  # 庸
    0x5EB9: 'tuǒ',  # 庹
    0x5EBA: 'sōng',  # 庺
    0x5EBB: 'shù',  # 庻
    0x5EBC: 'qǐng',  # 庼
    0x5EBD: 'yù',  # 庽
    0x5EBE: 'yǔ',  # 庾
    0x5EBF: 'miào',  # 庿
    0x5EC0: 'sōu',  # 廀
    0x5EC1: 'cè',  # 廁
    0x5EC2: 'xiāng',  # 廂
    0x5EC3: 'fèi',  # 廃
    0x5EC4: 'jiù',  # 廄
    0x5EC5: 'è',  # 廅
    0x5EC6: 'guī,wěi,huì',  # 廆
    0x5EC7: 'liù',  # 廇
    0x5EC8: 'shà,xià',  # 廈
    0x5EC9: 'lián',  # 廉
    0x5ECA: 'láng',  # 廊
    0x5ECB: 'sōu',  # 廋
    0x5ECC: 'zhì',  # 廌
    0x5ECD: 'bù',  # 廍
    0x5ECE: 'qǐng',  # 廎
    0x5ECF: 'jiù',  # 廏
    0x5ED0: 'jiù',  # 廐
    0x5ED1: 'jǐn,qín',  # 廑
    0x5ED2: 'áo',  # 廒
    0x5ED3: 'kuò',  # 廓
    0x5ED4: 'lóu',  # 廔
    0x5ED5: 'yìn',  # 廕
    0x5ED6: 'liào',  # 廖
    0x5ED7: 'dài',  # 廗
    0x5ED8: 'lù',  # 廘
    0x5ED9: 'yì',  # 廙
    0x5EDA: 'chú',  # 廚
    0x5EDB: 'chán',  # 廛
    0x5EDC: 'tú',  # 廜
    0x5EDD: 'sī',  # 廝
    0x5EDE: 'xīn',  # 廞
    0x5EDF: 'miào',  # 廟
    0x5EE0: 'chǎng',  # 廠
    0x5EE1: 'wǔ',  # 廡
    0x5EE2: 'fèi',  # 廢
    0x5EE3: 'guǎng',  # 廣
    0x5EE4: 'kù',  # 廤
    0x5EE5: 'kuài',  # 廥
    0x5EE6: 'bì',  # 廦
    0x5EE7: 'qiáng,sè',  # 廧
    0x5EE8: 'xiè',  # 廨
    0x5EE9: 'lǐn',  # 廩
    0x5EEA: 'lǐn',  # 廪
    0x5EEB: 'liáo',  # 廫
    0x5EEC: 'lú',  # 廬
    0x5EED: 'jì',  # 廭
    0x5EEE: 'yǐng',  # 廮
    0x5EEF: 'xiān',  # 廯
    0x5EF0: 'tīng',  # 廰
    0x5EF1: 'yōng',  # 廱
    0x5EF2: 'lí',  # 廲
    0x5EF3: 'tīng',  # 廳
    0x5EF4: 'yǐn,yìn',  # 廴
    0x5EF5: 'xún',  # 廵
    0x5EF6: 'yán',  # 延
    0x5EF7: 'tíng',  # 廷
    0x5EF8: 'dí',  # 廸
    0x5EF9: 'pò,pǎi',  # 廹
    0x5EFA: 'jiàn',  # 建
    0x5EFB: 'huí',  # 廻
    0x5EFC: 'nǎi',  # 廼
    0x5EFD: 'huí',  # 廽
    0x5EFE: 'gǒng',  # 廾
    0x5EFF: 'niàn',  # 廿
    0x5F00: 'kāi',  # 开
    0x5F01: 'biàn',  # 弁
    0x5F02: 'yì',  # 异
    0x5F03: 'qì',  # 弃
    0x5F04: 'nòng,lòng',  # 弄
    0x5F05: 'fèn',  # 弅
    0x5F06: 'jǔ',  # 弆
    0x5F07: 'yǎn',  # 弇
    0x5F08: 'yì',  # 弈
    0x5F09: 'zàng',  # 弉
    0x5F0A: 'bì',  # 弊
    0x5F0B: 'yì',  # 弋
    0x5F0C: 'yī',  # 弌
    0x5F0D: 'èr',  # 弍
    0x5F0E: 'sān',  # 弎
    0x5F0F: 'shì',  # 式
    0x5F10: 'èr',  # 弐
    0x5F11: 'shì',  # 弑
    0x5F12: 'shì',  # 弒
    0x5F13: 'gōng',  # 弓
    0x5F14: 'diào',  # 弔
    0x5F15: 'yǐn',  # 引
    0x5F16: 'hù',  # 弖
    0x5F17: 'fú',  # 弗
    0x5F18: 'hóng',  # 弘
    0x5F19: 'wū',  # 弙
    0x5F1A: 'tuí',  # 弚
    0x5F1B: 'chí',  # 弛
    0x5F1C: 'jiàng',  # 弜
    0x5F1D: 'bà',  # 弝
    0x5F1E: 'shěn',  # 弞
    0x5F1F: 'dì,tì,tuí',  # 弟
    0x5F20: 'zhāng',  # 张
    0x5F21: 'jué,zhāng',  # 弡
    0x5F22: 'tāo',  # 弢
    0x5F23: 'fǔ',  # 弣
    0x5F24: 'dǐ',  # 弤
    0x5F25: 'mí,mǐ',  # 弥
    0x5F26: 'xián',  # 弦
    0x5F27: 'hú',  # 弧
    0x5F28: 'chāo',  # 弨
    0x5F29: 'nǔ',  # 弩
    0x5F2A: 'jìng',  # 弪
    0x5F2B: 'zhěn',  # 弫
    0x5F2C: 'yi',  # 弬
    0x5F2D: 'mǐ',  # 弭
    0x5F2E: 'juàn,quān',  # 弮
    0x5F2F: 'wān',  # 弯
    0x5F30: 'shāo',  # 弰
    0x5F31: 'ruò',  # 弱
    0x5F32: 'xuān,yuān',  # 弲
    0x5F33: 'jìng',  # 弳
    0x5F34: 'diāo',  # 弴
    0x5F35: 'zhāng',  # 張
    0x5F36: 'jiàng',  # 弶
    0x5F37: 'qiáng,qiǎng,jiàng',  # 強
    0x5F38: 'péng',  # 弸
    0x5F39: 'dàn,tán',  # 弹
    0x5F3A: 'qiáng,qiǎng,jiàng',  # 强
    0x5F3B: 'bì',  # 弻
    0x5F3C: 'bì',  # 弼
    0x5F3D: 'shè',  # 弽
    0x5F3E: 'dàn,tán',  # 弾
    0x5F3F: 'jiǎn',  # 弿
    0x5F40: 'gòu',  # 彀
    0x5F41: 'gē',  # 彁
    0x5F42: 'fā',  # 彂
    0x5F43: 'bì',  # 彃
    0x5F44: 'kōu',  # 彄
    0x5F45: 'jiǎn',  # 彅
    0x5F46: 'biè',  # 彆
    0x5F47: 'xiāo',  # 彇
    0x5F48: 'dàn,tán',  # 彈
    0x5F49: 'guō',  # 彉
    0x5F4A: 'qiáng,qiǎng,jiàng',  # 彊
    0x5F4B: 'hóng',  # 彋
    0x5F4C: 'mí,mǐ',  # 彌
    0x5F4D: 'guō',  # 彍
    0x5F4E: 'wān',  # 彎
    0x5F4F: 'jué',  # 彏
    0x5F50: 'jì,xuě',  # 彐
    0x5F51: 'jì',  # 彑
    0x5F52: 'guī',  # 归
    0x5F53: 'dāng,dàng',  # 当
    0x5F54: 'lù',  # 彔
    0x5F55: 'lù',  # 录
    0x5F56: 'tuàn',  # 彖
    0x5F57: 'huì',  # 彗
    0x5F58: 'zhì',  # 彘
    0x5F59: 'huì',  # 彙
    0x5F5A: 'huì',  # 彚
    0x5F5B: 'yí',  # 彛
    0x5F5C: 'yí',  # 彜
    0x5F5D: 'yí',  # 彝
    0x5F5E: 'yí',  # 彞
    0x5F5F: 'huò',  # 彟
    0x5F60: 'huò',  # 彠
    0x5F61: 'shān,xiǎn',  # 彡
    0x5F62: 'xíng',  # 形
    0x5F63: 'wén',  # 彣
    0x5F64: 'tóng',  # 彤
    0x5F65: 'yàn',  # 彥
    0x5F66: 'yàn',  # 彦
    0x5F67: 'yù',  # 彧
    0x5F68: 'chī',  # 彨
    0x5F69: 'cǎi',  # 彩
    0x5F6A: 'biāo',  # 彪
    0x5F6B: 'diāo',  # 彫
    0x5F6C: 'bīn',  # 彬
    0x5F6D: 'péng,bāng',  # 彭
    0x5F6E: 'yǒng',  # 彮
    0x5F6F: 'piāo,piào',  # 彯
    0x5F70: 'zhāng',  # 彰
    0x5F71: 'yǐng',  # 影
    0x5F72: 'chī',  # 彲
    0x5F73: 'chì',  # 彳
    0x5F74: 'zhuó,bó',  # 彴
    0x5F75: 'tuǒ,yí',  # 彵
    0x5F76: 'jí',  # 彶
    0x5F77: 'páng,fǎng',  # 彷
    0x5F78: 'zhōng',  # 彸
    0x5F79: 'yì',  # 役
    0x5F7A: 'wǎng',  # 彺
    0x5F7B: 'chè',  # 彻
    0x5F7C: 'bǐ',  # 彼
    0x5F7D: 'dī',  # 彽
    0x5F7E: 'líng',  # 彾
    0x5F7F: 'fù',  # 彿
    0x5F80: 'wǎng',  # 往
    0x5F81: 'zhēng',  # 征
    0x5F82: 'cú',  # 徂
    0x5F83: 'wǎng',  # 徃
    0x5F84: 'jìng',  # 径
    0x5F85: 'dài,dāi',  # 待
    0x5F86: 'xī',  # 徆
    0x5F87: 'xùn',  # 徇
    0x5F88: 'hěn',  # 很
    0x5F89: 'yáng',  # 徉
    0x5F8A: 'huái',  # 徊
    0x5F8B: 'lǜ',  # 律
    0x5F8C: 'hòu',  # 後
    0x5F8D: 'wàng,jiā,wā',  # 徍
    0x5F8E: 'chěng,zhèng',  # 徎
    0x5F8F: 'zhì',  # 徏
    0x5F90: 'xú',  # 徐
    0x5F91: 'jìng',  # 徑
    0x5F92: 'tú',  # 徒
    0x5F93: 'cóng',  # 従
    0x5F94: 'cóng',  # 徔
    0x5F95: 'lài,lái',  # 徕
    0x5F96: 'cóng',  # 徖
    0x5F97: 'dé,děi,de',  # 得
    0x5F98: 'pái',  # 徘
    0x5F99: 'xǐ',  # 徙
    0x5F9A: 'dōng',  # 徚
    0x5F9B: 'jì',  # 徛
    0x5F9C: 'cháng',  # 徜
    0x5F9D: 'zhì',  # 徝
    0x5F9E: 'cóng,zòng',  # 從
    0x5F9F: 'zhōu',  # 徟
    0x5FA0: 'lái,lài',  # 徠
    0x5FA1: 'yù',  # 御
    0x5FA2: 'xiè',  # 徢
    0x5FA3: 'jiè',  # 徣
    0x5FA4: 'jiàn',  # 徤
    0x5FA5: 'shì,tǐ',  # 徥
    0x5FA6: 'jiǎ,xiá',  # 徦
    0x5FA7: 'biàn',  # 徧
    0x5FA8: 'huáng',  # 徨
    0x5FA9: 'fù',  # 復
    0x5FAA: 'xún',  # 循
    0x5FAB: 'wěi',  # 徫
    0x5FAC: 'páng',  # 徬
    0x5FAD: 'yáo',  # 徭
    0x5FAE: 'wēi',  # 微
    0x5FAF: 'xī',  # 徯
    0x5FB0: 'zhēng',  # 徰
    0x5FB1: 'piào',  # 徱
    0x5FB2: 'tí,chí',  # 徲
    0x5FB3: 'dé',  # 徳
    0x5FB4: 'zhǐ,zhēng',  # 徴
    0x5FB5: 'zhǐ,zhēng',  # 徵
    0x5FB6: 'bié',  # 徶
    0x5FB7: 'dé',  # 德
    0x5FB8: 'zhǒng,chōng',  # 徸
    0x5FB9: 'chè',  # 徹
    0x5FBA: 'jiǎo,yáo',  # 徺
    0x5FBB: 'huì',  # 徻
    0x5FBC: 'jiǎo,jiào',  # 徼
    0x5FBD: 'huī',  # 徽
    0x5FBE: 'méi',  # 徾
    0x5FBF: 'lòng,lǒng',  # 徿
    0x5FC0: 'xiāng',  # 忀
    0x5FC1: 'bào',  # 忁
    0x5FC2: 'qú,jù',  # 忂
    0x5FC3: 'xīn',  # 心
    0x5FC4: 'xīn',  # 忄
    0x5FC5: 'bì',  # 必
    0x5FC6: 'yì',  # 忆
    0x5FC7: 'lè',  # 忇
    0x5FC8: 'rén',  # 忈
    0x5FC9: 'dāo',  # 忉
    0x5FCA: 'dìng,tìng',  # 忊
    0x5FCB: 'gǎi',  # 忋
    0x5FCC: 'jì',  # 忌
    0x5FCD: 'rěn',  # 忍
    0x5FCE: 'rén',  # 忎
    0x5FCF: 'chàn',  # 忏
    0x5FD0: 'tǎn',  # 忐
    0x5FD1: 'tè',  # 忑
    0x5FD2: 'tè,tuī',  # 忒
    0x5FD3: 'gān,hàn',  # 忓
    0x5FD4: 'yì,qì',  # 忔
    0x5FD5: 'shì,tài',  # 忕
    0x5FD6: 'cǔn',  # 忖
    0x5FD7: 'zhì',  # 志
    0x5FD8: 'wàng',  # 忘
    0x5FD9: 'máng',  # 忙
    0x5FDA: 'xī,liě',  # 忚
    0x5FDB: 'fān',  # 忛
    0x5FDC: 'yīng,yìng',  # 応
    0x5FDD: 'tiǎn',  # 忝
    0x5FDE: 'mǐn,wěn,mín',  # 忞
    0x5FDF: 'mǐn,wěn,mín',  # 忟
    0x5FE0: 'zhōng',  # 忠
    0x5FE1: 'chōng',  # 忡
    0x5FE2: 'wù',  # 忢
    0x5FE3: 'jí',  # 忣
    0x5FE4: 'wǔ',  # 忤
    0x5FE5: 'xì',  # 忥
    0x5FE6: 'jiá',  # 忦
    0x5FE7: 'yōu',  # 忧
    0x5FE8: 'wán',  # 忨
    0x5FE9: 'cōng',  # 忩
    0x5FEA: 'sōng,zhōng',  # 忪
    0x5FEB: 'kuài',  # 快
    0x5FEC: 'yù,shū',  # 忬
    0x5FED: 'biàn',  # 忭
    0x5FEE: 'zhì',  # 忮
    0x5FEF: 'qí,shì',  # 忯
    0x5FF0: 'cuì',  # 忰
    0x5FF1: 'chén',  # 忱
    0x5FF2: 'tài',  # 忲
    0x5FF3: 'tún,zhūn,dùn',  # 忳
    0x5FF4: 'qián,qín',  # 忴
    0x5FF5: 'niàn',  # 念
    0x5FF6: 'hún',  # 忶
    0x5FF7: 'xiōng',  # 忷
    0x5FF8: 'niǔ',  # 忸
    0x5FF9: 'kuáng,wǎng',  # 忹
    0x5FFA: 'xiān',  # 忺
    0x5FFB: 'xīn',  # 忻
    0x5FFC: 'kāng,hàng',  # 忼
    0x5FFD: 'hū',  # 忽
    0x5FFE: 'kài,xì',  # 忾
    0x5FFF: 'fèn',  # 忿
    0x6000: 'huái',  # 怀
    0x6001: 'tài',  # 态
    0x6002: 'sǒng',  # 怂
    0x6003: 'wǔ',  # 怃
    0x6004: 'òu',  # 怄
    0x6005: 'chàng',  # 怅
    0x6006: 'chuàng',  # 怆
    0x6007: 'jù',  # 怇
    0x6008: 'yì',  # 怈
    0x6009: 'bǎo,bào',  # 怉
    0x600A: 'chāo',  # 怊
    0x600B: 'mín,mén',  # 怋
    0x600C: 'pēi',  # 怌
    0x600D: 'zuò,zhà',  # 怍
    0x600E: 'zěn',  # 怎
    0x600F: 'yàng',  # 怏
    0x6010: 'kòu,jù',  # 怐
    0x6011: 'bàn',  # 怑
    0x6012: 'nù',  # 怒
    0x6013: 'náo,niú',  # 怓
    0x6014: 'zhēng',  # 怔
    0x6015: 'pà',  # 怕
    0x6016: 'bù',  # 怖
    0x6017: 'tiē,zhān',  # 怗
    0x6018: 'hù,gù',  # 怘
    0x6019: 'hù',  # 怙
    0x601A: 'cū,jù,zū',  # 怚
    0x601B: 'dá',  # 怛
    0x601C: 'lián',  # 怜
    0x601D: 'sī,sāi',  # 思
    0x601E: 'yóu,chóu',  # 怞
    0x601F: 'dì',  # 怟
    0x6020: 'dài',  # 怠
    0x6021: 'yí',  # 怡
    0x6022: 'tū,dié',  # 怢
    0x6023: 'yóu',  # 怣
    0x6024: 'fū',  # 怤
    0x6025: 'jí',  # 急
    0x6026: 'pēng',  # 怦
    0x6027: 'xìng',  # 性
    0x6028: 'yuàn',  # 怨
    0x6029: 'ní',  # 怩
    0x602A: 'guài',  # 怪
    0x602B: 'fú',  # 怫
    0x602C: 'xì',  # 怬
    0x602D: 'bì',  # 怭
    0x602E: 'yōu,yào',  # 怮
    0x602F: 'qiè',  # 怯
    0x6030: 'xuàn',  # 怰
    0x6031: 'cōng',  # 怱
    0x6032: 'bǐng',  # 怲
    0x6033: 'huǎng',  # 怳
    0x6034: 'xù,xuè',  # 怴
    0x6035: 'chù',  # 怵
    0x6036: 'bì,pī',  # 怶
    0x6037: 'shù',  # 怷
    0x6038: 'xī,shù',  # 怸
    0x6039: 'tān',  # 怹
    0x603A: 'yǒng',  # 怺
    0x603B: 'zǒng',  # 总
    0x603C: 'duì',  # 怼
    0x603D: 'mì',  # 怽
    0x603E: 'gi',  # 怾
    0x603F: 'yì',  # 怿
    0x6040: 'shì',  # 恀
    0x6041: 'nèn,nín',  # 恁
    0x6042: 'xún',  # 恂
    0x6043: 'shì',  # 恃
    0x6044: 'xì',  # 恄
    0x6045: 'lǎo',  # 恅
    0x6046: 'héng',  # 恆
    0x6047: 'kuāng',  # 恇
    0x6048: 'móu',  # 恈
    0x6049: 'zhǐ',  # 恉
    0x604A: 'xié',  # 恊
    0x604B: 'liàn',  # 恋
    0x604C: 'tiāo,yáo',  # 恌
    0x604D: 'huǎng',  # 恍
    0x604E: 'dié',  # 恎
    0x604F: 'hào',  # 恏
    0x6050: 'kǒng',  # 恐
    0x6051: 'guǐ',  # 恑
    0x6052: 'héng',  # 恒
    0x6053: 'xī,qī,xù',  # 恓
    0x6054: 'xiào,jiǎo',  # 恔
    0x6055: 'shù',  # 恕
    0x6056: 'sī',  # 恖
    0x6057: 'hū,kuā',  # 恗
    0x6058: 'qiū',  # 恘
    0x6059: 'yàng',  # 恙
    0x605A: 'huì',  # 恚
    0x605B: 'huí',  # 恛
    0x605C: 'chì',  # 恜
    0x605D: 'jiá',  # 恝
    0x605E: 'yí',  # 恞
    0x605F: 'xiōng',  # 恟
    0x6060: 'guài',  # 恠
    0x6061: 'lìn',  # 恡
    0x6062: 'huī',  # 恢
    0x6063: 'zì',  # 恣
    0x6064: 'xù',  # 恤
    0x6065: 'chǐ',  # 恥
    0x6066: 'shàng',  # 恦
    0x6067: 'nǜ',  # 恧
    0x6068: 'hèn',  # 恨
    0x6069: 'ēn',  # 恩
    0x606A: 'kè',  # 恪
    0x606B: 'dòng',  # 恫
    0x606C: 'tián',  # 恬
    0x606D: 'gōng',  # 恭
    0x606E: 'quán,zhuān',  # 恮
    0x606F: 'xī',  # 息
    0x6070: 'qià',  # 恰
    0x6071: 'yuè',  # 恱
    0x6072: 'pēng',  # 恲
    0x6073: 'kěn',  # 恳
    0x6074: 'dé',  # 恴
    0x6075: 'huì',  # 恵
    0x6076: 'è,wù,ě,wū',  # 恶
    0x6077: 'qiū',  # 恷
    0x6078: 'tòng',  # 恸
    0x6079: 'yān',  # 恹
    0x607A: 'kǎi',  # 恺
    0x607B: 'cè',  # 恻
    0x607C: 'nǎo',  # 恼
    0x607D: 'yùn',  # 恽
    0x607E: 'máng',  # 恾
    0x607F: 'yǒng',  # 恿
    0x6080: 'yǒng',  # 悀
    0x6081: 'yuān,juàn',  # 悁
    0x6082: 'pī,pǐ',  # 悂
    0x6083: 'kǔn',  # 悃
    0x6084: 'qiǎo,qiāo',  # 悄
    0x6085: 'yuè',  # 悅
    0x6086: 'yù,shū',  # 悆
    0x6087: 'tú',  # 悇
    0x6088: 'jiè,kè',  # 悈
    0x6089: 'xī',  # 悉
    0x608A: 'zhé',  # 悊
    0x608B: 'lìn',  # 悋
    0x608C: 'tì',  # 悌
    0x608D: 'hàn',  # 悍
    0x608E: 'hào,jiào',  # 悎
    0x608F: 'qiè',  # 悏
    0x6090: 'tì',  # 悐
    0x6091: 'bù',  # 悑
    0x6092: 'yì',  # 悒
    0x6093: 'qiàn',  # 悓
    0x6094: 'huǐ',  # 悔
    0x6095: 'xī',  # 悕
    0x6096: 'bèi',  # 悖
    0x6097: 'mán,mèn',  # 悗
    0x6098: 'yī,yì',  # 悘
    0x6099: 'hēng,hèng',  # 悙
    0x609A: 'sǒng',  # 悚
    0x609B: 'quān',  # 悛
    0x609C: 'chěng',  # 悜
    0x609D: 'kuī,lǐ',  # 悝
    0x609E: 'wù',  # 悞
    0x609F: 'wù',  # 悟
    0x60A0: 'yōu',  # 悠
    0x60A1: 'lí',  # 悡
    0x60A2: 'liàng',  # 悢
    0x60A3: 'huàn',  # 患
    0x60A4: 'cōng',  # 悤
    0x60A5: 'yì,niàn',  # 悥
    0x60A6: 'yuè',  # 悦
    0x60A7: 'lì',  # 悧
    0x60A8: 'nín',  # 您
    0x60A9: 'nǎo',  # 悩
    0x60AA: 'è',  # 悪
    0x60AB: 'què',  # 悫
    0x60AC: 'xuán',  # 悬
    0x60AD: 'qiān',  # 悭
    0x60AE: 'wù',  # 悮
    0x60AF: 'mǐn',  # 悯
    0x60B0: 'cóng',  # 悰
    0x60B1: 'fěi',  # 悱
    0x60B2: 'bēi',  # 悲
    0x60B3: 'dé',  # 悳
    0x60B4: 'cuì',  # 悴
    0x60B5: 'chàng',  # 悵
    0x60B6: 'mèn,mēn',  # 悶
    0x60B7: 'lì',  # 悷
    0x60B8: 'jì',  # 悸
    0x60B9: 'guàn',  # 悹
    0x60BA: 'guàn',  # 悺
    0x60BB: 'xìng',  # 悻
    0x60BC: 'dào',  # 悼
    0x60BD: 'qī',  # 悽
    0x60BE: 'kōng,kǒng',  # 悾
    0x60BF: 'tiǎn',  # 悿
    0x60C0: 'lǔn,lùn',  # 惀
    0x60C1: 'xī',  # 惁
    0x60C2: 'kǎn',  # 惂
    0x60C3: 'gǔn',  # 惃
    0x60C4: 'nì',  # 惄
    0x60C5: 'qíng',  # 情
    0x60C6: 'chóu',  # 惆
    0x60C7: 'dūn',  # 惇
    0x60C8: 'guǒ',  # 惈
    0x60C9: 'zhān',  # 惉
    0x60CA: 'jīng',  # 惊
    0x60CB: 'wǎn',  # 惋
    0x60CC: 'yuān,wǎn',  # 惌
    0x60CD: 'jīn',  # 惍
    0x60CE: 'jì',  # 惎
    0x60CF: 'lán,lín',  # 惏
    0x60D0: 'yù,xù',  # 惐
    0x60D1: 'huò',  # 惑
    0x60D2: 'hé,hè',  # 惒
    0x60D3: 'juàn,quán',  # 惓
    0x60D4: 'tán,dàn',  # 惔
    0x60D5: 'tì',  # 惕
    0x60D6: 'tì',  # 惖
    0x60D7: 'niàn',  # 惗
    0x60D8: 'wǎng',  # 惘
    0x60D9: 'chuò,chuì',  # 惙
    0x60DA: 'hū',  # 惚
    0x60DB: 'hūn,mèn',  # 惛
    0x60DC: 'xī',  # 惜
    0x60DD: 'chǎng',  # 惝
    0x60DE: 'xīn',  # 惞
    0x60DF: 'wéi',  # 惟
    0x60E0: 'huì',  # 惠
    0x60E1: 'è,wù,ě,wū',  # 惡
    0x60E2: 'suǒ,ruǐ',  # 惢
    0x60E3: 'zǒng',  # 惣
    0x60E4: 'jiān',  # 惤
    0x60E5: 'yǒng',  # 惥
    0x60E6: 'diàn',  # 惦
    0x60E7: 'jù',  # 惧
    0x60E8: 'cǎn',  # 惨
    0x60E9: 'chéng',  # 惩
    0x60EA: 'dé',  # 惪
    0x60EB: 'bèi',  # 惫
    0x60EC: 'qiè',  # 惬
    0x60ED: 'cán',  # 惭
    0x60EE: 'dàn,dá',  # 惮
    0x60EF: 'guàn',  # 惯
    0x60F0: 'duò',  # 惰
    0x60F1: 'nǎo',  # 惱
    0x60F2: 'yùn',  # 惲
    0x60F3: 'xiǎng',  # 想
    0x60F4: 'zhuì',  # 惴
    0x60F5: 'dié',  # 惵
    0x60F6: 'huáng',  # 惶
    0x60F7: 'chǔn',  # 惷
    0x60F8: 'qióng',  # 惸
    0x60F9: 'rě',  # 惹
    0x60FA: 'xīng',  # 惺
    0x60FB: 'cè',  # 惻
    0x60FC: 'biǎn',  # 惼
    0x60FD: 'mǐn',  # 惽
    0x60FE: 'zōng',  # 惾
    0x60FF: 'tí,shì',  # 惿
    0x6100: 'qiǎo',  # 愀
    0x6101: 'chóu',  # 愁
    0x6102: 'bèi',  # 愂
    0x6103: 'xuān',  # 愃
    0x6104: 'wēi',  # 愄
    0x6105: 'gé',  # 愅
    0x6106: 'qiān',  # 愆
    0x6107: 'wěi',  # 愇
    0x6108: 'yù',  # 愈
    0x6109: 'yú,tōu',  # 愉
    0x610A: 'bì',  # 愊
    0x610B: 'xuān',  # 愋
    0x610C: 'huàn',  # 愌
    0x610D: 'mǐn',  # 愍
    0x610E: 'bì',  # 愎
    0x610F: 'yì',  # 意
    0x6110: 'miǎn',  # 愐
    0x6111: 'yǒng',  # 愑
    0x6112: 'qì,kài',  # 愒
    0x6113: 'dàng,shāng,táng,yáng',  # 愓
    0x6114: 'yīn',  # 愔
    0x6115: 'è',  # 愕
    0x6116: 'chén,xìn,dān',  # 愖
    0x6117: 'mào',  # 愗
    0x6118: 'kè,qià',  # 愘
    0x6119: 'kè',  # 愙
    0x611A: 'yú',  # 愚
    0x611B: 'ài',  # 愛
    0x611C: 'qiè',  # 愜
    0x611D: 'yǎn',  # 愝
    0x611E: 'nuò',  # 愞
    0x611F: 'gǎn',  # 感
    0x6120: 'yùn',  # 愠
    0x6121: 'còng,sōng',  # 愡
    0x6122: 'sāi,sī,sǐ',  # 愢
    0x6123: 'lèng',  # 愣
    0x6124: 'fèn',  # 愤
    0x6125: 'yīng',  # 愥
    0x6126: 'kuì',  # 愦
    0x6127: 'kuì',  # 愧
    0x6128: 'què',  # 愨
    0x6129: 'gōng,gòng,hǒng',  # 愩
    0x612A: 'yún',  # 愪
    0x612B: 'sù',  # 愫
    0x612C: 'sù,shuò',  # 愬
    0x612D: 'qí',  # 愭
    0x612E: 'yáo,yào',  # 愮
    0x612F: 'sǒng',  # 愯
    0x6130: 'huàng',  # 愰
    0x6131: 'jí',  # 愱
    0x6132: 'gǔ',  # 愲
    0x6133: 'jù',  # 愳
    0x6134: 'chuàng',  # 愴
    0x6135: 'nì',  # 愵
    0x6136: 'xié',  # 愶
    0x6137: 'kǎi',  # 愷
    0x6138: 'zhěng',  # 愸
    0x6139: 'yǒng',  # 愹
    0x613A: 'cǎo',  # 愺
    0x613B: 'xùn',  # 愻
    0x613C: 'shèn',  # 愼
    0x613D: 'bó',  # 愽
    0x613E: 'kài,xì',  # 愾
    0x613F: 'yuàn',  # 愿
    0x6140: 'xì,xié',  # 慀
    0x6141: 'hùn',  # 慁
    0x6142: 'yǒng',  # 慂
    0x6143: 'yǎng',  # 慃
    0x6144: 'lì',  # 慄
    0x6145: 'cǎo,sāo',  # 慅
    0x6146: 'tāo',  # 慆
    0x6147: 'yīn',  # 慇
    0x6148: 'cí',  # 慈
    0x6149: 'xù,chù',  # 慉
    0x614A: 'qiàn,qiè',  # 慊
    0x614B: 'tài',  # 態
    0x614C: 'huāng',  # 慌
    0x614D: 'yùn',  # 慍
    0x614E: 'shèn',  # 慎
    0x614F: 'mǐng',  # 慏
    0x6150: 'gōng,gòng,hǒng',  # 慐
    0x6151: 'shè',  # 慑
    0x6152: 'cáo,cóng',  # 慒
    0x6153: 'piāo',  # 慓
    0x6154: 'mù',  # 慔
    0x6155: 'mù',  # 慕
    0x6156: 'guó',  # 慖
    0x6157: 'chì',  # 慗
    0x6158: 'cǎn',  # 慘
    0x6159: 'cán',  # 慙
    0x615A: 'cán',  # 慚
    0x615B: 'cuī',  # 慛
    0x615C: 'mín',  # 慜
    0x615D: 'tè',  # 慝
    0x615E: 'zhāng',  # 慞
    0x615F: 'tòng',  # 慟
    0x6160: 'ào,áo',  # 慠
    0x6161: 'shuǎng',  # 慡
    0x6162: 'màn',  # 慢
    0x6163: 'guàn',  # 慣
    0x6164: 'què',  # 慤
    0x6165: 'zào',  # 慥
    0x6166: 'jiù',  # 慦
    0x6167: 'huì',  # 慧
    0x6168: 'kǎi',  # 慨
    0x6169: 'lián,liǎn',  # 慩
    0x616A: 'òu',  # 慪
    0x616B: 'sǒng',  # 慫
    0x616C: 'qín,jìn,jǐn',  # 慬
    0x616D: 'yìn',  # 慭
    0x616E: 'lǜ',  # 慮
    0x616F: 'shāng',  # 慯
    0x6170: 'wèi',  # 慰
    0x6171: 'tuán',  # 慱
    0x6172: 'mán',  # 慲
    0x6173: 'qiān',  # 慳
    0x6174: 'shè',  # 慴
    0x6175: 'yōng',  # 慵
    0x6176: 'qìng',  # 慶
    0x6177: 'kāng',  # 慷
    0x6178: 'dì,chì',  # 慸
    0x6179: 'zhí,zhé',  # 慹
    0x617A: 'lóu,lǚ',  # 慺
    0x617B: 'juàn',  # 慻
    0x617C: 'qī',  # 慼
    0x617D: 'qī',  # 慽
    0x617E: 'yù',  # 慾
    0x617F: 'píng',  # 慿
    0x6180: 'liáo',  # 憀
    0x6181: 'còng',  # 憁
    0x6182: 'yōu',  # 憂
    0x6183: 'chōng',  # 憃
    0x6184: 'zhī,zhì',  # 憄
    0x6185: 'tòng',  # 憅
    0x6186: 'chēng',  # 憆
    0x6187: 'qì',  # 憇
    0x6188: 'qū',  # 憈
    0x6189: 'péng',  # 憉
    0x618A: 'bèi',  # 憊
    0x618B: 'biē',  # 憋
    0x618C: 'qióng',  # 憌
    0x618D: 'jiāo',  # 憍
    0x618E: 'zēng',  # 憎
    0x618F: 'chì',  # 憏
    0x6190: 'lián',  # 憐
    0x6191: 'píng',  # 憑
    0x6192: 'kuì',  # 憒
    0x6193: 'huì',  # 憓
    0x6194: 'qiáo',  # 憔
    0x6195: 'chéng,dèng,zhèng',  # 憕
    0x6196: 'yìn',  # 憖
    0x6197: 'yìn',  # 憗
    0x6198: 'xǐ,xī',  # 憘
    0x6199: 'xǐ',  # 憙
    0x619A: 'dàn,dá',  # 憚
    0x619B: 'tán',  # 憛
    0x619C: 'duò',  # 憜
    0x619D: 'duì',  # 憝
    0x619E: 'duì,dùn,tūn',  # 憞
    0x619F: 'sù',  # 憟
    0x61A0: 'jué',  # 憠
    0x61A1: 'cè',  # 憡
    0x61A2: 'xiāo,jiāo',  # 憢
    0x61A3: 'fān',  # 憣
    0x61A4: 'fèn',  # 憤
    0x61A5: 'láo',  # 憥
    0x61A6: 'lào,láo',  # 憦
    0x61A7: 'chōng',  # 憧
    0x61A8: 'hān',  # 憨
    0x61A9: 'qì',  # 憩
    0x61AA: 'xián,xiàn',  # 憪
    0x61AB: 'mǐn',  # 憫
    0x61AC: 'jǐng',  # 憬
    0x61AD: 'liǎo,liáo',  # 憭
    0x61AE: 'wǔ',  # 憮
    0x61AF: 'cǎn',  # 憯
    0x61B0: 'jué',  # 憰
    0x61B1: 'cù',  # 憱
    0x61B2: 'xiàn',  # 憲
    0x61B3: 'tǎn',  # 憳
    0x61B4: 'shéng',  # 憴
    0x61B5: 'pī',  # 憵
    0x61B6: 'yì',  # 憶
    0x61B7: 'chù',  # 憷
    0x61B8: 'xiān',  # 憸
    0x61B9: 'náo,nǎo,náng',  # 憹
    0x61BA: 'dàn',  # 憺
    0x61BB: 'tǎn',  # 憻
    0x61BC: 'jǐng,jìng',  # 憼
    0x61BD: 'sōng',  # 憽
    0x61BE: 'hàn',  # 憾
    0x61BF: 'jiǎo,jǐ',  # 憿
    0x61C0: 'wèi',  # 懀
    0x61C1: 'xuān,huān',  # 懁
    0x61C2: 'dǒng',  # 懂
    0x61C3: 'qín',  # 懃
    0x61C4: 'qín',  # 懄
    0x61C5: 'jù',  # 懅
    0x61C6: 'cǎo,sāo,sào',  # 懆
    0x61C7: 'kěn',  # 懇
    0x61C8: 'xiè',  # 懈
    0x61C9: 'yīng,yìng',  # 應
    0x61CA: 'ào',  # 懊
    0x61CB: 'mào',  # 懋
    0x61CC: 'yì',  # 懌
    0x61CD: 'lǐn',  # 懍
    0x61CE: 'sè',  # 懎
    0x61CF: 'jùn',  # 懏
    0x61D0: 'huái',  # 懐
    0x61D1: 'mèn',  # 懑
    0x61D2: 'lǎn',  # 懒
    0x61D3: 'ài',  # 懓
    0x61D4: 'lǐn',  # 懔
    0x61D5: 'yān',  # 懕
    0x61D6: 'guō',  # 懖
    0x61D7: 'xià',  # 懗
    0x61D8: 'chì',  # 懘
    0x61D9: 'yǔ,yú',  # 懙
    0x61DA: 'yìn',  # 懚
    0x61DB: 'dāi',  # 懛
    0x61DC: 'mèng,méng,měng',  # 懜
    0x61DD: 'ài,yì,nǐ',  # 懝
    0x61DE: 'méng,měng',  # 懞
    0x61DF: 'duì',  # 懟
    0x61E0: 'qí,jī,jì',  # 懠
    0x61E1: 'mǒ',  # 懡
    0x61E2: 'lán,xiàn',  # 懢
    0x61E3: 'mèn',  # 懣
    0x61E4: 'chóu',  # 懤
    0x61E5: 'zhì',  # 懥
    0x61E6: 'nuò',  # 懦
    0x61E7: 'nuò',  # 懧
    0x61E8: 'yān',  # 懨
    0x61E9: 'yǎng',  # 懩
    0x61EA: 'bó',  # 懪
    0x61EB: 'zhì',  # 懫
    0x61EC: 'kuàng',  # 懬
    0x61ED: 'kuǎng',  # 懭
    0x61EE: 'yōu,yǒu',  # 懮
    0x61EF: 'fū',  # 懯
    0x61F0: 'liú,liǔ',  # 懰
    0x61F1: 'miè',  # 懱
    0x61F2: 'chéng',  # 懲
    0x61F3: 'huì',  # 懳
    0x61F4: 'chàn',  # 懴
    0x61F5: 'měng',  # 懵
    0x61F6: 'lǎn',  # 懶
    0x61F7: 'huái',  # 懷
    0x61F8: 'xuán',  # 懸
    0x61F9: 'ràng',  # 懹
    0x61FA: 'chàn',  # 懺
    0x61FB: 'jì',  # 懻
    0x61FC: 'jù',  # 懼
    0x61FD: 'huān',  # 懽
    0x61FE: 'shè',  # 懾
    0x61FF: 'yì',  # 懿
    0x6200: 'liàn',  # 戀
    0x6201: 'nǎn',  # 戁
    0x6202: 'mí,mó',  # 戂
    0x6203: 'tǎng',  # 戃
    0x6204: 'jué',  # 戄
    0x6205: 'gàng,zhuàng',  # 戅
    0x6206: 'gàng,zhuàng',  # 戆
    0x6207: 'gàng,zhuàng',  # 戇
    0x6208: 'gē',  # 戈
    0x6209: 'yuè',  # 戉
    0x620A: 'wù',  # 戊
    0x620B: 'jiān',  # 戋
    0x620C: 'xū',  # 戌
    0x620D: 'shù',  # 戍
    0x620E: 'róng',  # 戎
    0x620F: 'xì,hū',  # 戏
    0x6210: 'chéng',  # 成
    0x6211: 'wǒ',  # 我
    0x6212: 'jiè',  # 戒
    0x6213: 'gē',  # 戓
    0x6214: 'jiān',  # 戔
    0x6215: 'qiāng',  # 戕
    0x6216: 'huò',  # 或
    0x6217: 'qiāng,qiàng',  # 戗
    0x6218: 'zhàn',  # 战
    0x6219: 'dòng',  # 戙
    0x621A: 'qī',  # 戚
    0x621B: 'jiá',  # 戛
    0x621C: 'dié',  # 戜
    0x621D: 'zéi',  # 戝
    0x621E: 'jiá',  # 戞
    0x621F: 'jǐ',  # 戟
    0x6220: 'zhí',  # 戠
    0x6221: 'kān',  # 戡
    0x6222: 'jí',  # 戢
    0x6223: 'kuí',  # 戣
    0x6224: 'gài',  # 戤
    0x6225: 'děng',  # 戥
    0x6226: 'zhàn',  # 戦
    0x6227: 'qiāng,qiàng',  # 戧
    0x6228: 'gē',  # 戨
    0x6229: 'jiǎn',  # 戩
    0x622A: 'jié',  # 截
    0x622B: 'yù',  # 戫
    0x622C: 'jiǎn',  # 戬
    0x622D: 'yǎn',  # 戭
    0x622E: 'lù',  # 戮
    0x622F: 'xì,hū',  # 戯
    0x6230: 'zhàn',  # 戰
    0x6231: 'xì,hū',  # 戱
    0x6232: 'xì,hū',  # 戲
    0x6233: 'chuō',  # 戳
    0x6234: 'dài',  # 戴
    0x6235: 'qú',  # 戵
    0x6236: 'hù',  # 戶
    0x6237: 'hù',  # 户
    0x6238: 'hù',  # 戸
    0x6239: 'è',  # 戹
    0x623A: 'shì',  # 戺
    0x623B: 'tì',  # 戻
    0x623C: 'mǎo',  # 戼
    0x623D: 'hù',  # 戽
    0x623E: 'lì',  # 戾
    0x623F: 'fáng',  # 房
    0x6240: 'suǒ',  # 所
    0x6241: 'biǎn,piān',  # 扁
    0x6242: 'diàn',  # 扂
    0x6243: 'jiōng',  # 扃
    0x6244: 'shǎng,jiōng',  # 扄
    0x6245: 'yí',  # 扅
    0x6246: 'yǐ',  # 扆
    0x6247: 'shàn,shān',  # 扇
    0x6248: 'hù',  # 扈
    0x6249: 'fēi',  # 扉
    0x624A: 'yǎn',  # 扊
    0x624B: 'shǒu',  # 手
    0x624C: 'shǒu',  # 扌
    0x624D: 'cái',  # 才
    0x624E: 'zā,zhā,zhá',  # 扎
    0x624F: 'qiú',  # 扏
    0x6250: 'lè,lì,cái',  # 扐
    0x6251: 'pū',  # 扑
    0x6252: 'bā,pá',  # 扒
    0x6253: 'dǎ,dá',  # 打
    0x6254: 'rēng',  # 扔
    0x6255: 'fǎn,fú',  # 払
    0x6256: 'rù',  # 扖
    0x6257: 'zài',  # 扗
    0x6258: 'tuō',  # 托
    0x6259: 'zhàng',  # 扙
    0x625A: 'diǎo,dí,yuē,lì',  # 扚
    0x625B: 'káng,gāng',  # 扛
    0x625C: 'yū,wū',  # 扜
    0x625D: 'yū,wū,kū',  # 扝
    0x625E: 'hàn',  # 扞
    0x625F: 'shēn',  # 扟
    0x6260: 'chā',  # 扠
    0x6261: 'tuō,chǐ,yǐ',  # 扡
    0x6262: 'gǔ,xì,gē,jié',  # 扢
    0x6263: 'kòu',  # 扣
    0x6264: 'wù',  # 扤
    0x6265: 'dèn',  # 扥
    0x6266: 'qiān',  # 扦
    0x6267: 'zhí',  # 执
    0x6268: 'rèn',  # 扨
    0x6269: 'kuò',  # 扩
    0x626A: 'mén',  # 扪
    0x626B: 'sǎo,sào',  # 扫
    0x626C: 'yáng',  # 扬
    0x626D: 'niǔ',  # 扭
    0x626E: 'bàn',  # 扮
    0x626F: 'chě',  # 扯
    0x6270: 'rǎo',  # 扰
    0x6271: 'xī,chā,qì',  # 扱
    0x6272: 'qián,qín',  # 扲
    0x6273: 'bān',  # 扳
    0x6274: 'jiá',  # 扴
    0x6275: 'yú',  # 扵
    0x6276: 'fú',  # 扶
    0x6277: 'bā,ào',  # 扷
    0x6278: 'xī,zhé',  # 扸
    0x6279: 'pī',  # 批
    0x627A: 'zhǐ',  # 扺
    0x627B: 'zhì,sǔn,kǎn',  # 扻
    0x627C: 'è',  # 扼
    0x627D: 'dèn',  # 扽
    0x627E: 'zhǎo',  # 找
    0x627F: 'chéng',  # 承
    0x6280: 'jì',  # 技
    0x6281: 'yǎn',  # 抁
    0x6282: 'kuáng,wǎng,zài',  # 抂
    0x6283: 'biàn',  # 抃
    0x6284: 'chāo',  # 抄
    0x6285: 'jū',  # 抅
    0x6286: 'wěn',  # 抆
    0x6287: 'hú,gǔ',  # 抇
    0x6288: 'yuè',  # 抈
    0x6289: 'jué',  # 抉
    0x628A: 'bǎ,bà',  # 把
    0x628B: 'qìn',  # 抋
    0x628C: 'dǎn,shěn',  # 抌
    0x628D: 'zhěng',  # 抍
    0x628E: 'yǔn',  # 抎
    0x628F: 'wán',  # 抏
    0x6290: 'nè,nì,ruì,nà',  # 抐
    0x6291: 'yì',  # 抑
    0x6292: 'shū',  # 抒
    0x6293: 'zhuā',  # 抓
    0x6294: 'póu',  # 抔
    0x6295: 'tóu',  # 投
    0x6296: 'dǒu',  # 抖
    0x6297: 'kàng',  # 抗
    0x6298: 'zhē,zhé,shé',  # 折
    0x6299: 'póu,pōu,fū',  # 抙
    0x629A: 'fǔ',  # 抚
    0x629B: 'pāo',  # 抛
    0x629C: 'bá',  # 抜
    0x629D: 'ǎo,ào,niù',  # 抝
    0x629E: 'zé',  # 択
    0x629F: 'tuán',  # 抟
    0x62A0: 'kōu',  # 抠
    0x62A1: 'lūn,lún',  # 抡
    0x62A2: 'qiāng,qiǎng,chēng',  # 抢
    0x62A3: 'yún',  # 抣
    0x62A4: 'hù',  # 护
    0x62A5: 'bào',  # 报
    0x62A6: 'bǐng',  # 抦
    0x62A7: 'zhǐ,zhǎi',  # 抧
    0x62A8: 'pēng',  # 抨
    0x62A9: 'nán',  # 抩
    0x62AA: 'bù,pū',  # 抪
    0x62AB: 'pī',  # 披
    0x62AC: 'tái',  # 抬
    0x62AD: 'yǎo,tāo',  # 抭
    0x62AE: 'zhěn',  # 抮
    0x62AF: 'zhā',  # 抯
    0x62B0: 'yāng',  # 抰
    0x62B1: 'bào',  # 抱
    0x62B2: 'hē,hè,qiā',  # 抲
    0x62B3: 'nǐ,ní',  # 抳
    0x62B4: 'yè',  # 抴
    0x62B5: 'dǐ',  # 抵
    0x62B6: 'chì',  # 抶
    0x62B7: 'pī,pēi',  # 抷
    0x62B8: 'jiā',  # 抸
    0x62B9: 'mǒ,mò,mā',  # 抹
    0x62BA: 'mèi',  # 抺
    0x62BB: 'chēn',  # 抻
    0x62BC: 'yā',  # 押
    0x62BD: 'chōu',  # 抽
    0x62BE: 'qū',  # 抾
    0x62BF: 'mǐn',  # 抿
    0x62C0: 'zhù',  # 拀
    0x62C1: 'jiā,yá',  # 拁
    0x62C2: 'fú,bì',  # 拂
    0x62C3: 'zhǎ',  # 拃
    0x62C4: 'zhǔ',  # 拄
    0x62C5: 'dān,dàn,dǎn',  # 担
    0x62C6: 'chāi,cā',  # 拆
    0x62C7: 'mǔ',  # 拇
    0x62C8: 'niān',  # 拈
    0x62C9: 'lā,lá',  # 拉
    0x62CA: 'fǔ',  # 拊
    0x62CB: 'pāo',  # 拋
    0x62CC: 'bàn,pàn',  # 拌
    0x62CD: 'pāi',  # 拍
    0x62CE: 'līn',  # 拎
    0x62CF: 'ná',  # 拏
    0x62D0: 'guǎi',  # 拐
    0x62D1: 'qián',  # 拑
    0x62D2: 'jù',  # 拒
    0x62D3: 'tuò,tà,zhí',  # 拓
    0x62D4: 'bá',  # 拔
    0x62D5: 'tuō',  # 拕
    0x62D6: 'tuō',  # 拖
    0x62D7: 'ǎo,ào,niù',  # 拗
    0x62D8: 'jū,gōu',  # 拘
    0x62D9: 'zhuō',  # 拙
    0x62DA: 'pàn,pīn,fān',  # 拚
    0x62DB: 'zhāo',  # 招
    0x62DC: 'bài',  # 拜
    0x62DD: 'bài',  # 拝
    0x62DE: 'dǐ',  # 拞
    0x62DF: 'nǐ',  # 拟
    0x62E0: 'jù',  # 拠
    0x62E1: 'kuò',  # 拡
    0x62E2: 'lǒng',  # 拢
    0x62E3: 'jiǎn',  # 拣
    0x62E4: 'qiǎ',  # 拤
    0x62E5: 'yōng',  # 拥
    0x62E6: 'lán',  # 拦
    0x62E7: 'níng,nǐng,nìng',  # 拧
    0x62E8: 'bō',  # 拨
    0x62E9: 'zé,zhái',  # 择
    0x62EA: 'qiān',  # 拪
    0x62EB: 'hén',  # 拫
    0x62EC: 'kuò,guā',  # 括
    0x62ED: 'shì',  # 拭
    0x62EE: 'jié,jiá',  # 拮
    0x62EF: 'zhěng',  # 拯
    0x62F0: 'nǐn',  # 拰
    0x62F1: 'gǒng',  # 拱
    0x62F2: 'gǒng',  # 拲
    0x62F3: 'quán',  # 拳
    0x62F4: 'shuān',  # 拴
    0x62F5: 'cún,zùn',  # 拵
    0x62F6: 'zā,zǎn',  # 拶
    0x62F7: 'kǎo',  # 拷
    0x62F8: 'yí,chǐ,hài',  # 拸
    0x62F9: 'xié',  # 拹
    0x62FA: 'cè,sè,chuò',  # 拺
    0x62FB: 'huī',  # 拻
    0x62FC: 'pīn',  # 拼
    0x62FD: 'zhuài,zhuāi,yè',  # 拽
    0x62FE: 'shí,shè',  # 拾
    0x62FF: 'ná',  # 拿
    0x6300: 'bāi',  # 挀
    0x6301: 'chí',  # 持
    0x6302: 'guà',  # 挂
    0x6303: 'zhì',  # 挃
    0x6304: 'kuò,guāng',  # 挄
    0x6305: 'duò',  # 挅
    0x6306: 'duǒ,duò',  # 挆
    0x6307: 'zhǐ',  # 指
    0x6308: 'qiè',  # 挈
    0x6309: 'àn',  # 按
    0x630A: 'nòng',  # 挊
    0x630B: 'zhèn',  # 挋
    0x630C: 'gé',  # 挌
    0x630D: 'jiào',  # 挍
    0x630E: 'kuà,kū',  # 挎
    0x630F: 'dòng',  # 挏
    0x6310: 'rú,ná',  # 挐
    0x6311: 'tiāo,tiǎo',  # 挑
    0x6312: 'liè',  # 挒
    0x6313: 'zhā',  # 挓
    0x6314: 'lǚ',  # 挔
    0x6315: 'dié,shè',  # 挕
    0x6316: 'wā',  # 挖
    0x6317: 'jué',  # 挗
    0x6318: 'liě',  # 挘
    0x6319: 'jǔ',  # 挙
    0x631A: 'zhì',  # 挚
    0x631B: 'luán',  # 挛
    0x631C: 'yà,yǎ',  # 挜
    0x631D: 'zhuā,wō',  # 挝
    0x631E: 'tà',  # 挞
    0x631F: 'xié,jiā',  # 挟
    0x6320: 'náo',  # 挠
    0x6321: 'dǎng,dàng',  # 挡
    0x6322: 'jiǎo',  # 挢
    0x6323: 'zhèng,zhēng',  # 挣
    0x6324: 'jǐ',  # 挤
    0x6325: 'huī',  # 挥
    0x6326: 'xián',  # 挦
    0x6327: 'yǔ',  # 挧
    0x6328: 'āi,ái',  # 挨
    0x6329: 'tuō,shuì',  # 挩
    0x632A: 'nuó',  # 挪
    0x632B: 'cuò',  # 挫
    0x632C: 'bó',  # 挬
    0x632D: 'gěng',  # 挭
    0x632E: 'tǐ,tì',  # 挮
    0x632F: 'zhèn',  # 振
    0x6330: 'chéng',  # 挰
    0x6331: 'suō,shā',  # 挱
    0x6332: 'suō,shā',  # 挲
    0x6333: 'kēng,qiān',  # 挳
    0x6334: 'měi',  # 挴
    0x6335: 'nòng',  # 挵
    0x6336: 'jú',  # 挶
    0x6337: 'bàng,péng',  # 挷
    0x6338: 'jiǎn',  # 挸
    0x6339: 'yì',  # 挹
    0x633A: 'tǐng',  # 挺
    0x633B: 'shān',  # 挻
    0x633C: 'ruó',  # 挼
    0x633D: 'wǎn',  # 挽
    0x633E: 'xié,jiā',  # 挾
    0x633F: 'chā',  # 挿
    0x6340: 'péng',  # 捀
    0x6341: 'jiǎo,kù',  # 捁
    0x6342: 'wǔ',  # 捂
    0x6343: 'jùn',  # 捃
    0x6344: 'jiù',  # 捄
    0x6345: 'tǒng',  # 捅
    0x6346: 'kǔn',  # 捆
    0x6347: 'huò,chì',  # 捇
    0x6348: 'tú,shū,chá',  # 捈
    0x6349: 'zhuō',  # 捉
    0x634A: 'póu,pōu,fū',  # 捊
    0x634B: 'luō,lǚ',  # 捋
    0x634C: 'bā',  # 捌
    0x634D: 'hàn',  # 捍
    0x634E: 'shāo,shào',  # 捎
    0x634F: 'niē',  # 捏
    0x6350: 'juān',  # 捐
    0x6351: 'zè',  # 捑
    0x6352: 'shù,sǒng,sōu',  # 捒
    0x6353: 'yé,yú',  # 捓
    0x6354: 'jué,zhuó',  # 捔
    0x6355: 'bǔ',  # 捕
    0x6356: 'wán',  # 捖
    0x6357: 'bù,pú,zhì',  # 捗
    0x6358: 'zùn',  # 捘
    0x6359: 'yè',  # 捙
    0x635A: 'zhāi',  # 捚
    0x635B: 'lǚ',  # 捛
    0x635C: 'sōu',  # 捜
    0x635D: 'tuō,shuì',  # 捝
    0x635E: 'lāo',  # 捞
    0x635F: 'sǔn',  # 损
    0x6360: 'bāng',  # 捠
    0x6361: 'jiǎn',  # 捡
    0x6362: 'huàn',  # 换
    0x6363: 'dǎo',  # 捣
    0x6364: 'wěi',  # 捤
    0x6365: 'wàn,wǎn,wān,yù',  # 捥
    0x6366: 'qín',  # 捦
    0x6367: 'pěng',  # 捧
    0x6368: 'shě',  # 捨
    0x6369: 'liè',  # 捩
    0x636A: 'mín',  # 捪
    0x636B: 'mén',  # 捫
    0x636C: 'fǔ,fù,bǔ',  # 捬
    0x636D: 'bǎi',  # 捭
    0x636E: 'jù,jū',  # 据
    0x636F: 'dáo',  # 捯
    0x6370: 'wǒ,luò,luǒ',  # 捰
    0x6371: 'ái',  # 捱
    0x6372: 'juǎn,quán',  # 捲
    0x6373: 'yuè',  # 捳
    0x6374: 'zǒng',  # 捴
    0x6375: 'chēn',  # 捵
    0x6376: 'chuí',  # 捶
    0x6377: 'jié',  # 捷
    0x6378: 'tū',  # 捸
    0x6379: 'bèn',  # 捹
    0x637A: 'nà',  # 捺
    0x637B: 'niǎn,niē',  # 捻
    0x637C: 'ruó,wěi,ré',  # 捼
    0x637D: 'zuó',  # 捽
    0x637E: 'wò,xiá',  # 捾
    0x637F: 'qī',  # 捿
    0x6380: 'xiān',  # 掀
    0x6381: 'chéng',  # 掁
    0x6382: 'diān',  # 掂
    0x6383: 'sǎo,sào',  # 掃
    0x6384: 'lūn,lún',  # 掄
    0x6385: 'qìng,qiàn',  # 掅
    0x6386: 'gāng',  # 掆
    0x6387: 'duō',  # 掇
    0x6388: 'shòu',  # 授
    0x6389: 'diào',  # 掉
    0x638A: 'pǒu,póu',  # 掊
    0x638B: 'dǐ',  # 掋
    0x638C: 'zhǎng',  # 掌
    0x638D: 'hùn',  # 掍
    0x638E: 'jǐ',  # 掎
    0x638F: 'tāo',  # 掏
    0x6390: 'qiā',  # 掐
    0x6391: 'qí',  # 掑
    0x6392: 'pái,pǎi',  # 排
    0x6393: 'shū',  # 掓
    0x6394: 'qiān,wàn',  # 掔
    0x6395: 'líng',  # 掕
    0x6396: 'yè,yē',  # 掖
    0x6397: 'yà,yǎ',  # 掗
    0x6398: 'jué',  # 掘
    0x6399: 'zhēng,zhèng',  # 掙
    0x639A: 'liǎng',  # 掚
    0x639B: 'guà',  # 掛
    0x639C: 'nǐ,niè,yì',  # 掜
    0x639D: 'huò,xù',  # 掝
    0x639E: 'shàn,yàn,yǎn',  # 掞
    0x639F: 'zhěng,dìng',  # 掟
    0x63A0: 'lüè',  # 掠
    0x63A1: 'cǎi',  # 採
    0x63A2: 'tàn',  # 探
    0x63A3: 'chè',  # 掣
    0x63A4: 'bīng',  # 掤
    0x63A5: 'jiē',  # 接
    0x63A6: 'tì',  # 掦
    0x63A7: 'kòng',  # 控
    0x63A8: 'tuī',  # 推
    0x63A9: 'yǎn',  # 掩
    0x63AA: 'cuò',  # 措
    0x63AB: 'zōu,zhōu,chōu',  # 掫
    0x63AC: 'jū',  # 掬
    0x63AD: 'tiàn',  # 掭
    0x63AE: 'qián',  # 掮
    0x63AF: 'kèn',  # 掯
    0x63B0: 'bāi',  # 掰
    0x63B1: 'pá',  # 掱
    0x63B2: 'jiē',  # 掲
    0x63B3: 'lǔ',  # 掳
    0x63B4: 'guó',  # 掴
    0x63B5: 'mìng',  # 掵
    0x63B6: 'jié',  # 掶
    0x63B7: 'zhì',  # 掷
    0x63B8: 'dǎn,shàn',  # 掸
    0x63B9: 'mēng',  # 掹
    0x63BA: 'chān,xiān,càn,shǎn',  # 掺
    0x63BB: 'sāo',  # 掻
    0x63BC: 'guàn',  # 掼
    0x63BD: 'pèng',  # 掽
    0x63BE: 'yuàn',  # 掾
    0x63BF: 'nuò',  # 掿
    0x63C0: 'jiǎn',  # 揀
    0x63C1: 'zhēng,kēng',  # 揁
    0x63C2: 'jiū,yóu',  # 揂
    0x63C3: 'jiǎn,jiān',  # 揃
    0x63C4: 'yú',  # 揄
    0x63C5: 'yán',  # 揅
    0x63C6: 'kuí',  # 揆
    0x63C7: 'nǎn',  # 揇
    0x63C8: 'hōng',  # 揈
    0x63C9: 'róu',  # 揉
    0x63CA: 'pì,chè',  # 揊
    0x63CB: 'wēi',  # 揋
    0x63CC: 'sāi',  # 揌
    0x63CD: 'zòu',  # 揍
    0x63CE: 'xuān',  # 揎
    0x63CF: 'miáo',  # 描
    0x63D0: 'tí,dī,dǐ',  # 提
    0x63D1: 'niē',  # 揑
    0x63D2: 'chā',  # 插
    0x63D3: 'shì',  # 揓
    0x63D4: 'zǒng,sōng',  # 揔
    0x63D5: 'zhèn,zhēn',  # 揕
    0x63D6: 'yī',  # 揖
    0x63D7: 'xún',  # 揗
    0x63D8: 'huáng,yóng',  # 揘
    0x63D9: 'biǎn',  # 揙
    0x63DA: 'yáng',  # 揚
    0x63DB: 'huàn',  # 換
    0x63DC: 'yǎn',  # 揜
    0x63DD: 'zǎn,zuàn',  # 揝
    0x63DE: 'ǎn',  # 揞
    0x63DF: 'xū,jū',  # 揟
    0x63E0: 'yà',  # 揠
    0x63E1: 'wò',  # 握
    0x63E2: 'ké,qiā',  # 揢
    0x63E3: 'chuǎi,chuài,chuāi,tuán,zhuī',  # 揣
    0x63E4: 'jí',  # 揤
    0x63E5: 'tì,dì',  # 揥
    0x63E6: 'là,lá',  # 揦
    0x63E7: 'là',  # 揧
    0x63E8: 'chéng',  # 揨
    0x63E9: 'kāi',  # 揩
    0x63EA: 'jiū',  # 揪
    0x63EB: 'jiū',  # 揫
    0x63EC: 'tú',  # 揬
    0x63ED: 'jiē,qì',  # 揭
    0x63EE: 'huī',  # 揮
    0x63EF: 'gèn',  # 揯
    0x63F0: 'chòng,dǒng',  # 揰
    0x63F1: 'xiāo',  # 揱
    0x63F2: 'shé,dié,yè',  # 揲
    0x63F3: 'xiē',  # 揳
    0x63F4: 'yuán',  # 援
    0x63F5: 'qián,jiàn,jiǎn',  # 揵
    0x63F6: 'yé',  # 揶
    0x63F7: 'chā',  # 揷
    0x63F8: 'zhā',  # 揸
    0x63F9: 'bēi',  # 揹
    0x63FA: 'yáo',  # 揺
    0x63FB: 'wēi',  # 揻
    0x63FC: 'bèng',  # 揼
    0x63FD: 'lǎn',  # 揽
    0x63FE: 'wèn',  # 揾
    0x63FF: 'qìn',  # 揿
    0x6400: 'chān',  # 搀
    0x6401: 'gē,gé',  # 搁
    0x6402: 'lǒu,lōu',  # 搂
    0x6403: 'zǒng',  # 搃
    0x6404: 'gèn',  # 搄
    0x6405: 'jiǎo',  # 搅
    0x6406: 'gòu',  # 搆
    0x6407: 'qìn',  # 搇
    0x6408: 'róng',  # 搈
    0x6409: 'què',  # 搉
    0x640A: 'chōu,zǒu',  # 搊
    0x640B: 'chuāi',  # 搋
    0x640C: 'zhǎn',  # 搌
    0x640D: 'sǔn',  # 損
    0x640E: 'sūn',  # 搎
    0x640F: 'bó',  # 搏
    0x6410: 'chù',  # 搐
    0x6411: 'róng,náng,nǎng',  # 搑
    0x6412: 'bàng,péng',  # 搒
    0x6413: 'cuō',  # 搓
    0x6414: 'sāo',  # 搔
    0x6415: 'kē,è',  # 搕
    0x6416: 'yáo',  # 搖
    0x6417: 'dǎo',  # 搗
    0x6418: 'zhī',  # 搘
    0x6419: 'nù,nuò,nòu',  # 搙
    0x641A: 'lā,xié,xiàn',  # 搚
    0x641B: 'jiān',  # 搛
    0x641C: 'sōu',  # 搜
    0x641D: 'qiǔ',  # 搝
    0x641E: 'gǎo',  # 搞
    0x641F: 'xiǎn,xiān',  # 搟
    0x6420: 'shuò',  # 搠
    0x6421: 'sǎng',  # 搡
    0x6422: 'jìn',  # 搢
    0x6423: 'miè',  # 搣
    0x6424: 'è',  # 搤
    0x6425: 'chuí',  # 搥
    0x6426: 'nuò',  # 搦
    0x6427: 'shān',  # 搧
    0x6428: 'tà',  # 搨
    0x6429: 'jié,zhé',  # 搩
    0x642A: 'táng',  # 搪
    0x642B: 'pán,bān,pó',  # 搫
    0x642C: 'bān',  # 搬
    0x642D: 'dā',  # 搭
    0x642E: 'lì',  # 搮
    0x642F: 'tāo',  # 搯
    0x6430: 'hú',  # 搰
    0x6431: 'zhì,nái',  # 搱
    0x6432: 'wā,wǎ,wà',  # 搲
    0x6433: 'huá',  # 搳
    0x6434: 'qiān',  # 搴
    0x6435: 'wèn',  # 搵
    0x6436: 'qiāng,qiǎng,chēng',  # 搶
    0x6437: 'tián,shēn',  # 搷
    0x6438: 'zhēn',  # 搸
    0x6439: 'è',  # 搹
    0x643A: 'xié',  # 携
    0x643B: 'ná,nuò',  # 搻
    0x643C: 'quán',  # 搼
    0x643D: 'chá',  # 搽
    0x643E: 'zhà',  # 搾
    0x643F: 'gé',  # 搿
    0x6440: 'wǔ',  # 摀
    0x6441: 'èn',  # 摁
    0x6442: 'shè',  # 摂
    0x6443: 'gāng',  # 摃
    0x6444: 'shè,niè',  # 摄
    0x6445: 'shū',  # 摅
    0x6446: 'bǎi',  # 摆
    0x6447: 'yáo',  # 摇
    0x6448: 'bìn',  # 摈
    0x6449: 'sōu',  # 摉
    0x644A: 'tān',  # 摊
    0x644B: 'sà,shā,shǎi',  # 摋
    0x644C: 'chǎn,sùn',  # 摌
    0x644D: 'suō',  # 摍
    0x644E: 'jiū,liú,liáo,jiǎo,náo',  # 摎
    0x644F: 'chōng',  # 摏
    0x6450: 'chuāng',  # 摐
    0x6451: 'guó',  # 摑
    0x6452: 'bìng',  # 摒
    0x6453: 'féng,pěng',  # 摓
    0x6454: 'shuāi',  # 摔
    0x6455: 'dì,tú,zhí',  # 摕
    0x6456: 'qì,jì,chá',  # 摖
    0x6457: 'sōu,sǒng',  # 摗
    0x6458: 'zhāi',  # 摘
    0x6459: 'liǎn,liàn',  # 摙
    0x645A: 'chēng',  # 摚
    0x645B: 'chī',  # 摛
    0x645C: 'guàn',  # 摜
    0x645D: 'lù',  # 摝
    0x645E: 'luò',  # 摞
    0x645F: 'lǒu,lōu',  # 摟
    0x6460: 'zǒng',  # 摠
    0x6461: 'gài,xì',  # 摡
    0x6462: 'hù,chū',  # 摢
    0x6463: 'zhā',  # 摣
    0x6464: 'qiāng',  # 摤
    0x6465: 'tàng',  # 摥
    0x6466: 'huà',  # 摦
    0x6467: 'cuī',  # 摧
    0x6468: 'zhì,nái',  # 摨
    0x6469: 'mó,mā',  # 摩
    0x646A: 'jiāng,qiàng',  # 摪
    0x646B: 'guī',  # 摫
    0x646C: 'yǐng',  # 摬
    0x646D: 'zhí',  # 摭
    0x646E: 'áo,qiáo',  # 摮
    0x646F: 'zhì',  # 摯
    0x6470: 'niè,chè',  # 摰
    0x6471: 'mán,màn',  # 摱
    0x6472: 'chàn,cán',  # 摲
    0x6473: 'kōu',  # 摳
    0x6474: 'chū',  # 摴
    0x6475: 'sè,mí,sù',  # 摵
    0x6476: 'tuán',  # 摶
    0x6477: 'jiǎo,chāo',  # 摷
    0x6478: 'mō',  # 摸
    0x6479: 'mó',  # 摹
    0x647A: 'zhé',  # 摺
    0x647B: 'chān,xiān,càn,shǎn',  # 摻
    0x647C: 'kēng,qiān',  # 摼
    0x647D: 'biào,biāo',  # 摽
    0x647E: 'jiàng',  # 摾
    0x647F: 'yáo',  # 摿
    0x6480: 'gòu',  # 撀
    0x6481: 'qiān',  # 撁
    0x6482: 'liào',  # 撂
    0x6483: 'jī',  # 撃
    0x6484: 'yīng',  # 撄
    0x6485: 'juē,jué',  # 撅
    0x6486: 'piē',  # 撆
    0x6487: 'piē,piě',  # 撇
    0x6488: 'lāo',  # 撈
    0x6489: 'dūn',  # 撉
    0x648A: 'xiàn',  # 撊
    0x648B: 'ruán',  # 撋
    0x648C: 'guì',  # 撌
    0x648D: 'zǎn,zān,zēn,qián',  # 撍
    0x648E: 'yī',  # 撎
    0x648F: 'xián',  # 撏
    0x6490: 'chēng',  # 撐
    0x6491: 'chēng',  # 撑
    0x6492: 'sā,sǎ',  # 撒
    0x6493: 'náo',  # 撓
    0x6494: 'hòng',  # 撔
    0x6495: 'sī',  # 撕
    0x6496: 'hàn',  # 撖
    0x6497: 'héng,guàng',  # 撗
    0x6498: 'dā',  # 撘
    0x6499: 'zǔn',  # 撙
    0x649A: 'niǎn',  # 撚
    0x649B: 'lǐn',  # 撛
    0x649C: 'zhěng,chéng',  # 撜
    0x649D: 'huī,wéi',  # 撝
    0x649E: 'zhuàng',  # 撞
    0x649F: 'jiǎo',  # 撟
    0x64A0: 'jǐ',  # 撠
    0x64A1: 'cāo',  # 撡
    0x64A2: 'dǎn',  # 撢
    0x64A3: 'dǎn,shàn',  # 撣
    0x64A4: 'chè',  # 撤
    0x64A5: 'bō',  # 撥
    0x64A6: 'chě',  # 撦
    0x64A7: 'juē',  # 撧
    0x64A8: 'xiāo,sōu',  # 撨
    0x64A9: 'liāo,liáo',  # 撩
    0x64AA: 'bèn',  # 撪
    0x64AB: 'fǔ',  # 撫
    0x64AC: 'qiào',  # 撬
    0x64AD: 'bō',  # 播
    0x64AE: 'cuō,zuǒ',  # 撮
    0x64AF: 'zhuó',  # 撯
    0x64B0: 'zhuàn',  # 撰
    0x64B1: 'wěi,tuǒ',  # 撱
    0x64B2: 'pū',  # 撲
    0x64B3: 'qìn',  # 撳
    0x64B4: 'dūn',  # 撴
    0x64B5: 'niǎn',  # 撵
    0x64B6: 'huá',  # 撶
    0x64B7: 'xié',  # 撷
    0x64B8: 'lū',  # 撸
    0x64B9: 'jiǎo',  # 撹
    0x64BA: 'cuān',  # 撺
    0x64BB: 'tà',  # 撻
    0x64BC: 'hàn',  # 撼
    0x64BD: 'qiào,yāo,jī',  # 撽
    0x64BE: 'zhuā,wō',  # 撾
    0x64BF: 'jiǎn',  # 撿
    0x64C0: 'gǎn',  # 擀
    0x64C1: 'yōng',  # 擁
    0x64C2: 'léi,lèi',  # 擂
    0x64C3: 'nǎng',  # 擃
    0x64C4: 'lǔ',  # 擄
    0x64C5: 'shàn',  # 擅
    0x64C6: 'zhuó',  # 擆
    0x64C7: 'zé,zhái',  # 擇
    0x64C8: 'pǔ',  # 擈
    0x64C9: 'chuò',  # 擉
    0x64CA: 'jī',  # 擊
    0x64CB: 'dǎng,dàng',  # 擋
    0x64CC: 'sè',  # 擌
    0x64CD: 'cāo',  # 操
    0x64CE: 'qíng',  # 擎
    0x64CF: 'qíng,jǐng',  # 擏
    0x64D0: 'huàn',  # 擐
    0x64D1: 'jiē',  # 擑
    0x64D2: 'qín',  # 擒
    0x64D3: 'kuǎi',  # 擓
    0x64D4: 'dān,dàn',  # 擔
    0x64D5: 'xié',  # 擕
    0x64D6: 'qiā,jiā,yè',  # 擖
    0x64D7: 'pǐ,bò',  # 擗
    0x64D8: 'bò,bāi',  # 擘
    0x64D9: 'ào',  # 擙
    0x64DA: 'jù,jū',  # 據
    0x64DB: 'yè',  # 擛
    0x64DC: 'è',  # 擜
    0x64DD: 'mēng',  # 擝
    0x64DE: 'sòu,sǒu',  # 擞
    0x64DF: 'mí',  # 擟
    0x64E0: 'jǐ',  # 擠
    0x64E1: 'tái',  # 擡
    0x64E2: 'zhuó',  # 擢
    0x64E3: 'dǎo',  # 擣
    0x64E4: 'xǐng',  # 擤
    0x64E5: 'lǎn',  # 擥
    0x64E6: 'cā',  # 擦
    0x64E7: 'jǔ',  # 擧
    0x64E8: 'yē',  # 擨
    0x64E9: 'rǔ',  # 擩
    0x64EA: 'yè',  # 擪
    0x64EB: 'yè',  # 擫
    0x64EC: 'nǐ',  # 擬
    0x64ED: 'huò',  # 擭
    0x64EE: 'jié',  # 擮
    0x64EF: 'bìn',  # 擯
    0x64F0: 'níng,nǐng,nìng',  # 擰
    0x64F1: 'gē,gé',  # 擱
    0x64F2: 'zhì',  # 擲
    0x64F3: 'zhì,jié',  # 擳
    0x64F4: 'kuò',  # 擴
    0x64F5: 'mó',  # 擵
    0x64F6: 'jiàn',  # 擶
    0x64F7: 'xié',  # 擷
    0x64F8: 'liè,là',  # 擸
    0x64F9: 'tān',  # 擹
    0x64FA: 'bǎi',  # 擺
    0x64FB: 'sòu,sǒu',  # 擻
    0x64FC: 'lū',  # 擼
    0x64FD: 'lì,luò,yuè',  # 擽
    0x64FE: 'rǎo',  # 擾
    0x64FF: 'tī,zhì,zhāi',  # 擿
    0x6500: 'pān',  # 攀
    0x6501: 'yǎng',  # 攁
    0x6502: 'léi,lèi',  # 攂
    0x6503: 'cā,sǎ',  # 攃
    0x6504: 'shū',  # 攄
    0x6505: 'zǎn',  # 攅
    0x6506: 'niǎn',  # 攆
    0x6507: 'xiǎn',  # 攇
    0x6508: 'jùn,pèi',  # 攈
    0x6509: 'huō',  # 攉
    0x650A: 'lì,luò',  # 攊
    0x650B: 'là,lài',  # 攋
    0x650C: 'huàn',  # 攌
    0x650D: 'yíng',  # 攍
    0x650E: 'lú,luó',  # 攎
    0x650F: 'lǒng',  # 攏
    0x6510: 'qiān',  # 攐
    0x6511: 'qiān',  # 攑
    0x6512: 'zǎn,cuán',  # 攒
    0x6513: 'qiān',  # 攓
    0x6514: 'lán',  # 攔
    0x6515: 'xiān,jiān',  # 攕
    0x6516: 'yīng',  # 攖
    0x6517: 'méi',  # 攗
    0x6518: 'rǎng',  # 攘
    0x6519: 'chān',  # 攙
    0x651A: 'wěng',  # 攚
    0x651B: 'cuān',  # 攛
    0x651C: 'xié',  # 攜
    0x651D: 'shè,niè',  # 攝
    0x651E: 'luó',  # 攞
    0x651F: 'jùn',  # 攟
    0x6520: 'mí,mǐ,mó',  # 攠
    0x6521: 'chī',  # 攡
    0x6522: 'zǎn,cuán',  # 攢
    0x6523: 'luán',  # 攣
    0x6524: 'tān',  # 攤
    0x6525: 'zuàn',  # 攥
    0x6526: 'lì,shài',  # 攦
    0x6527: 'diān',  # 攧
    0x6528: 'wā',  # 攨
    0x6529: 'dǎng',  # 攩
    0x652A: 'jiǎo',  # 攪
    0x652B: 'jué',  # 攫
    0x652C: 'lǎn',  # 攬
    0x652D: 'lì,luǒ',  # 攭
    0x652E: 'nǎng',  # 攮
    0x652F: 'zhī',  # 支
    0x6530: 'guì',  # 攰
    0x6531: 'guǐ,guì',  # 攱
    0x6532: 'qī,yǐ,jī',  # 攲
    0x6533: 'xún',  # 攳
    0x6534: 'pū',  # 攴
    0x6535: 'pū',  # 攵
    0x6536: 'shōu',  # 收
    0x6537: 'kǎo',  # 攷
    0x6538: 'yōu',  # 攸
    0x6539: 'gǎi',  # 改
    0x653A: 'yǐ',  # 攺
    0x653B: 'gōng',  # 攻
    0x653C: 'gān,hàn',  # 攼
    0x653D: 'bān',  # 攽
    0x653E: 'fàng',  # 放
    0x653F: 'zhèng',  # 政
    0x6540: 'pò',  # 敀
    0x6541: 'diān',  # 敁
    0x6542: 'kòu',  # 敂
    0x6543: 'mǐn',  # 敃
    0x6544: 'wù,móu',  # 敄
    0x6545: 'gù',  # 故
    0x6546: 'hé',  # 敆
    0x6547: 'cè',  # 敇
    0x6548: 'xiào',  # 效
    0x6549: 'mǐ',  # 敉
    0x654A: 'chù,shōu',  # 敊
    0x654B: 'gé,guó,è',  # 敋
    0x654C: 'dí',  # 敌
    0x654D: 'xù',  # 敍
    0x654E: 'jiào,jiāo',  # 敎
    0x654F: 'mǐn',  # 敏
    0x6550: 'chén',  # 敐
    0x6551: 'jiù',  # 救
    0x6552: 'shēn',  # 敒
    0x6553: 'duó,duì',  # 敓
    0x6554: 'yǔ',  # 敔
    0x6555: 'chì',  # 敕
    0x6556: 'áo',  # 敖
    0x6557: 'bài',  # 敗
    0x6558: 'xù',  # 敘
    0x6559: 'jiào,jiāo',  # 教
    0x655A: 'duó,duì',  # 敚
    0x655B: 'liǎn',  # 敛
    0x655C: 'niè',  # 敜
    0x655D: 'bì',  # 敝
    0x655E: 'chǎng',  # 敞
    0x655F: 'diǎn',  # 敟
    0x6560: 'duō,què',  # 敠
    0x6561: 'yì',  # 敡
    0x6562: 'gǎn',  # 敢
    0x6563: 'sàn,sǎn',  # 散
    0x6564: 'kě',  # 敤
    0x6565: 'yàn',  # 敥
    0x6566: 'dūn,duì',  # 敦
    0x6567: 'qī,yǐ,jī',  # 敧
    0x6568: 'tǒu',  # 敨
    0x6569: 'xiào,xué',  # 敩
    0x656A: 'duō,què',  # 敪
    0x656B: 'jiǎo',  # 敫
    0x656C: 'jìng',  # 敬
    0x656D: 'yáng',  # 敭
    0x656E: 'xiá',  # 敮
    0x656F: 'mǐn',  # 敯
    0x6570: 'shù,shǔ,shuò',  # 数
    0x6571: 'ái,zhú',  # 敱
    0x6572: 'qiāo',  # 敲
    0x6573: 'ái',  # 敳
    0x6574: 'zhěng',  # 整
    0x6575: 'dí',  # 敵
    0x6576: 'chén',  # 敶
    0x6577: 'fū',  # 敷
    0x6578: 'shù,shǔ,shuò',  # 數
    0x6579: 'liáo',  # 敹
    0x657A: 'qū',  # 敺
    0x657B: 'xiòng,xuàn',  # 敻
    0x657C: 'yǐ',  # 敼
    0x657D: 'jiǎo',  # 敽
    0x657E: 'shàn',  # 敾
    0x657F: 'jiǎo',  # 敿
    0x6580: 'zhuó,zhú',  # 斀
    0x6581: 'yì,dù',  # 斁
    0x6582: 'liǎn',  # 斂
    0x6583: 'bì',  # 斃
    0x6584: 'lí,tái',  # 斄
    0x6585: 'xiào',  # 斅
    0x6586: 'xiào',  # 斆
    0x6587: 'wén',  # 文
    0x6588: 'xué',  # 斈
    0x6589: 'qí',  # 斉
    0x658A: 'qí',  # 斊
    0x658B: 'zhāi',  # 斋
    0x658C: 'bīn',  # 斌
    0x658D: 'jué,jiào',  # 斍
    0x658E: 'zhāi',  # 斎
    0x658F: 'láng',  # 斏
    0x6590: 'fěi,fēi',  # 斐
    0x6591: 'bān',  # 斑
    0x6592: 'bān',  # 斒
    0x6593: 'lán',  # 斓
    0x6594: 'yǔ,zhōng',  # 斔
    0x6595: 'lán',  # 斕
    0x6596: 'wěi,mén',  # 斖
    0x6597: 'dǒu,dòu',  # 斗
    0x6598: 'shēng',  # 斘
    0x6599: 'liào',  # 料
    0x659A: 'jiǎ',  # 斚
    0x659B: 'hú',  # 斛
    0x659C: 'xié',  # 斜
    0x659D: 'jiǎ',  # 斝
    0x659E: 'yǔ',  # 斞
    0x659F: 'zhēn',  # 斟
    0x65A0: 'jiào',  # 斠
    0x65A1: 'wò,guǎn',  # 斡
    0x65A2: 'tǒu,tiǎo',  # 斢
    0x65A3: 'dòu',  # 斣
    0x65A4: 'jīn',  # 斤
    0x65A5: 'chì',  # 斥
    0x65A6: 'yín,zhì',  # 斦
    0x65A7: 'fǔ',  # 斧
    0x65A8: 'qiāng',  # 斨
    0x65A9: 'zhǎn',  # 斩
    0x65AA: 'qú',  # 斪
    0x65AB: 'zhuó',  # 斫
    0x65AC: 'zhǎn',  # 斬
    0x65AD: 'duàn',  # 断
    0x65AE: 'zhuó',  # 斮
    0x65AF: 'sī',  # 斯
    0x65B0: 'xīn',  # 新
    0x65B1: 'zhuó',  # 斱
    0x65B2: 'zhuó',  # 斲
    0x65B3: 'qín',  # 斳
    0x65B4: 'lín',  # 斴
    0x65B5: 'zhuó',  # 斵
    0x65B6: 'chù',  # 斶
    0x65B7: 'duàn',  # 斷
    0x65B8: 'zhú',  # 斸
    0x65B9: 'fāng',  # 方
    0x65BA: 'chǎn,jiè',  # 斺
    0x65BB: 'háng',  # 斻
    0x65BC: 'yú,wū',  # 於
    0x65BD: 'shī',  # 施
    0x65BE: 'pèi',  # 斾
    0x65BF: 'liú,yóu',  # 斿
    0x65C0: 'mèi',  # 旀
    0x65C1: 'páng,bàng',  # 旁
    0x65C2: 'qí',  # 旂
    0x65C3: 'zhān',  # 旃
    0x65C4: 'máo,mào',  # 旄
    0x65C5: 'lǚ',  # 旅
    0x65C6: 'pèi',  # 旆
    0x65C7: 'pī,bì',  # 旇
    0x65C8: 'liú',  # 旈
    0x65C9: 'fū',  # 旉
    0x65CA: 'fǎng',  # 旊
    0x65CB: 'xuán,xuàn',  # 旋
    0x65CC: 'jīng',  # 旌
    0x65CD: 'jīng',  # 旍
    0x65CE: 'nǐ',  # 旎
    0x65CF: 'zú',  # 族
    0x65D0: 'zhào',  # 旐
    0x65D1: 'yǐ',  # 旑
    0x65D2: 'liú',  # 旒
    0x65D3: 'shāo',  # 旓
    0x65D4: 'jiàn',  # 旔
    0x65D5: 'eos',  # 旕
    0x65D6: 'yǐ',  # 旖
    0x65D7: 'qí',  # 旗
    0x65D8: 'zhì',  # 旘
    0x65D9: 'fān',  # 旙
    0x65DA: 'piāo',  # 旚
    0x65DB: 'fān',  # 旛
    0x65DC: 'zhān',  # 旜
    0x65DD: 'kuài',  # 旝
    0x65DE: 'suì',  # 旞
    0x65DF: 'yú',  # 旟
    0x65E0: 'wú',  # 无
    0x65E1: 'jì',  # 旡
    0x65E2: 'jì',  # 既
    0x65E3: 'jì',  # 旣
    0x65E4: 'huò',  # 旤
    0x65E5: 'rì',  # 日
    0x65E6: 'dàn',  # 旦
    0x65E7: 'jiù',  # 旧
    0x65E8: 'zhǐ',  # 旨
    0x65E9: 'zǎo',  # 早
    0x65EA: 'xié',  # 旪
    0x65EB: 'tiāo',  # 旫
    0x65EC: 'xún',  # 旬
    0x65ED: 'xù',  # 旭
    0x65EE: 'gā',  # 旮
    0x65EF: 'lá',  # 旯
    0x65F0: 'gàn,hàn',  # 旰
    0x65F1: 'hàn',  # 旱
    0x65F2: 'tái,yīng',  # 旲
    0x65F3: 'dì,dí,de',  # 旳
    0x65F4: 'xù,xū',  # 旴
    0x65F5: 'chǎn',  # 旵
    0x65F6: 'shí',  # 时
    0x65F7: 'kuàng',  # 旷
    0x65F8: 'yáng',  # 旸
    0x65F9: 'shí',  # 旹
    0x65FA: 'wàng',  # 旺
    0x65FB: 'mín',  # 旻
    0x65FC: 'mín',  # 旼
    0x65FD: 'tūn,zhùn',  # 旽
    0x65FE: 'chūn',  # 旾
    0x65FF: 'wù,wǔ',  # 旿
    0x6600: 'yún',  # 昀
    0x6601: 'bèi',  # 昁
    0x6602: 'áng',  # 昂
    0x6603: 'zè',  # 昃
    0x6604: 'bǎn',  # 昄
    0x6605: 'jié',  # 昅
    0x6606: 'kūn',  # 昆
    0x6607: 'shēng',  # 昇
    0x6608: 'hù',  # 昈
    0x6609: 'fǎng',  # 昉
    0x660A: 'hào',  # 昊
    0x660B: 'guì',  # 昋
    0x660C: 'chāng',  # 昌
    0x660D: 'xuān',  # 昍
    0x660E: 'míng',  # 明
    0x660F: 'hūn',  # 昏
    0x6610: 'fēn',  # 昐
    0x6611: 'qǐn',  # 昑
    0x6612: 'hū',  # 昒
    0x6613: 'yì',  # 易
    0x6614: 'xī',  # 昔
    0x6615: 'xīn',  # 昕
    0x6616: 'yán',  # 昖
    0x6617: 'zè',  # 昗
    0x6618: 'fǎng',  # 昘
    0x6619: 'tán',  # 昙
    0x661A: 'shèn',  # 昚
    0x661B: 'jù',  # 昛
    0x661C: 'yáng',  # 昜
    0x661D: 'zǎn',  # 昝
    0x661E: 'bǐng',  # 昞
    0x661F: 'xīng',  # 星
    0x6620: 'yìng',  # 映
    0x6621: 'xuàn',  # 昡
    0x6622: 'pò',  # 昢
    0x6623: 'zhěn',  # 昣
    0x6624: 'líng',  # 昤
    0x6625: 'chūn',  # 春
    0x6626: 'hào',  # 昦
    0x6627: 'mèi',  # 昧
    0x6628: 'zuó',  # 昨
    0x6629: 'mò',  # 昩
    0x662A: 'biàn',  # 昪
    0x662B: 'xù',  # 昫
    0x662C: 'hūn',  # 昬
    0x662D: 'zhāo',  # 昭
    0x662E: 'zòng',  # 昮
    0x662F: 'shì',  # 是
    0x6630: 'shì',  # 昰
    0x6631: 'yù',  # 昱
    0x6632: 'fèi',  # 昲
    0x6633: 'dié,yì',  # 昳
    0x6634: 'mǎo',  # 昴
    0x6635: 'nì',  # 昵
    0x6636: 'chǎng',  # 昶
    0x6637: 'wēn',  # 昷
    0x6638: 'dōng',  # 昸
    0x6639: 'ǎi',  # 昹
    0x663A: 'bǐng',  # 昺
    0x663B: 'áng',  # 昻
    0x663C: 'zhòu',  # 昼
    0x663D: 'lóng',  # 昽
    0x663E: 'xiǎn',  # 显
    0x663F: 'kuàng',  # 昿
    0x6640: 'tiǎo',  # 晀
    0x6641: 'cháo',  # 晁
    0x6642: 'shí',  # 時
    0x6643: 'huǎng,huàng',  # 晃
    0x6644: 'huǎng',  # 晄
    0x6645: 'xuān',  # 晅
    0x6646: 'kuí',  # 晆
    0x6647: 'xù,kuā',  # 晇
    0x6648: 'jiǎo',  # 晈
    0x6649: 'jìn',  # 晉
    0x664A: 'zhì',  # 晊
    0x664B: 'jìn',  # 晋
    0x664C: 'shǎng',  # 晌
    0x664D: 'tóng',  # 晍
    0x664E: 'hǒng',  # 晎
    0x664F: 'yàn',  # 晏
    0x6650: 'gāi',  # 晐
    0x6651: 'xiǎng',  # 晑
    0x6652: 'shài',  # 晒
    0x6653: 'xiǎo',  # 晓
    0x6654: 'yè',  # 晔
    0x6655: 'yùn,yūn',  # 晕
    0x6656: 'huī',  # 晖
    0x6657: 'hán',  # 晗
    0x6658: 'hàn',  # 晘
    0x6659: 'jùn',  # 晙
    0x665A: 'wǎn',  # 晚
    0x665B: 'xiàn',  # 晛
    0x665C: 'kūn',  # 晜
    0x665D: 'zhòu',  # 晝
    0x665E: 'xī',  # 晞
    0x665F: 'shèng,chéng',  # 晟
    0x6660: 'shèng',  # 晠
    0x6661: 'bū',  # 晡
    0x6662: 'zhé',  # 晢
    0x6663: 'zhé',  # 晣
    0x6664: 'wù',  # 晤
    0x6665: 'wǎn',  # 晥
    0x6666: 'huì',  # 晦
    0x6667: 'hào',  # 晧
    0x6668: 'chén',  # 晨
    0x6669: 'wǎn',  # 晩
    0x666A: 'tiǎn',  # 晪
    0x666B: 'zhuó',  # 晫
    0x666C: 'zuì',  # 晬
    0x666D: 'zhǒu',  # 晭
    0x666E: 'pǔ',  # 普
    0x666F: 'jǐng,yǐng',  # 景
    0x6670: 'xī',  # 晰
    0x6671: 'shǎn',  # 晱
    0x6672: 'nǐ',  # 晲
    0x6673: 'xī',  # 晳
    0x6674: 'qíng',  # 晴
    0x6675: 'qǐ,dù',  # 晵
    0x6676: 'jīng',  # 晶
    0x6677: 'guǐ',  # 晷
    0x6678: 'zhěng',  # 晸
    0x6679: 'yì',  # 晹
    0x667A: 'zhì',  # 智
    0x667B: 'àn,ǎn,yǎn',  # 晻
    0x667C: 'wǎn',  # 晼
    0x667D: 'lín',  # 晽
    0x667E: 'liàng',  # 晾
    0x667F: 'chēng',  # 晿
    0x6680: 'wǎng,wàng',  # 暀
    0x6681: 'xiǎo',  # 暁
    0x6682: 'zàn',  # 暂
    0x6683: 'fēi',  # 暃
    0x6684: 'xuān',  # 暄
    0x6685: 'xuǎn',  # 暅
    0x6686: 'yí',  # 暆
    0x6687: 'xiá',  # 暇
    0x6688: 'yùn,yūn',  # 暈
    0x6689: 'huī',  # 暉
    0x668A: 'xǔ',  # 暊
    0x668B: 'mǐn,mín',  # 暋
    0x668C: 'kuí',  # 暌
    0x668D: 'yē',  # 暍
    0x668E: 'yìng',  # 暎
    0x668F: 'shǔ,dǔ',  # 暏
    0x6690: 'wěi',  # 暐
    0x6691: 'shǔ',  # 暑
    0x6692: 'qíng',  # 暒
    0x6693: 'mào',  # 暓
    0x6694: 'nán',  # 暔
    0x6695: 'jiǎn,lán',  # 暕
    0x6696: 'nuǎn',  # 暖
    0x6697: 'àn',  # 暗
    0x6698: 'yáng',  # 暘
    0x6699: 'chūn',  # 暙
    0x669A: 'yáo',  # 暚
    0x669B: 'suǒ',  # 暛
    0x669C: 'pǔ',  # 暜
    0x669D: 'míng',  # 暝
    0x669E: 'jiǎo',  # 暞
    0x669F: 'kǎi',  # 暟
    0x66A0: 'hào',  # 暠
    0x66A1: 'wěng',  # 暡
    0x66A2: 'chàng',  # 暢
    0x66A3: 'qì',  # 暣
    0x66A4: 'hào',  # 暤
    0x66A5: 'yàn',  # 暥
    0x66A6: 'lì',  # 暦
    0x66A7: 'ài',  # 暧
    0x66A8: 'jì',  # 暨
    0x66A9: 'jì',  # 暩
    0x66AA: 'mèn',  # 暪
    0x66AB: 'zàn',  # 暫
    0x66AC: 'xiè',  # 暬
    0x66AD: 'hào',  # 暭
    0x66AE: 'mù',  # 暮
    0x66AF: 'mù',  # 暯
    0x66B0: 'cōng',  # 暰
    0x66B1: 'nì',  # 暱
    0x66B2: 'zhāng',  # 暲
    0x66B3: 'huì',  # 暳
    0x66B4: 'bào,pù',  # 暴
    0x66B5: 'hàn',  # 暵
    0x66B6: 'xuán',  # 暶
    0x66B7: 'chuán',  # 暷
    0x66B8: 'liáo',  # 暸
    0x66B9: 'xiān',  # 暹
    0x66BA: 'tǎn',  # 暺
    0x66BB: 'jǐng',  # 暻
    0x66BC: 'piē',  # 暼
    0x66BD: 'lín',  # 暽
    0x66BE: 'tūn',  # 暾
    0x66BF: 'xī,xǐ',  # 暿
    0x66C0: 'yì',  # 曀
    0x66C1: 'jì',  # 曁
    0x66C2: 'huàng',  # 曂
    0x66C3: 'dài',  # 曃
    0x66C4: 'yè',  # 曄
    0x66C5: 'yè',  # 曅
    0x66C6: 'lì',  # 曆
    0x66C7: 'tán',  # 曇
    0x66C8: 'tóng',  # 曈
    0x66C9: 'xiǎo',  # 曉
    0x66CA: 'fèi',  # 曊
    0x66CB: 'shěn',  # 曋
    0x66CC: 'zhào',  # 曌
    0x66CD: 'hào',  # 曍
    0x66CE: 'yì',  # 曎
    0x66CF: 'xiàng',  # 曏
    0x66D0: 'xīng',  # 曐
    0x66D1: 'shēn',  # 曑
    0x66D2: 'jiǎo',  # 曒
    0x66D3: 'bào',  # 曓
    0x66D4: 'jìng',  # 曔
    0x66D5: 'yàn',  # 曕
    0x66D6: 'ài',  # 曖
    0x66D7: 'yè',  # 曗
    0x66D8: 'rú',  # 曘
    0x66D9: 'shǔ',  # 曙
    0x66DA: 'méng',  # 曚
    0x66DB: 'xūn',  # 曛
    0x66DC: 'yào',  # 曜
    0x66DD: 'pù,bào',  # 曝
    0x66DE: 'lì',  # 曞
    0x66DF: 'chén',  # 曟
    0x66E0: 'kuàng',  # 曠
    0x66E1: 'dié',  # 曡
    0x66E2: 'liǎo',  # 曢
    0x66E3: 'yàn',  # 曣
    0x66E4: 'huò',  # 曤
    0x66E5: 'lú',  # 曥
    0x66E6: 'xī',  # 曦
    0x66E7: 'róng',  # 曧
    0x66E8: 'lóng',  # 曨
    0x66E9: 'nǎng',  # 曩
    0x66EA: 'luǒ',  # 曪
    0x66EB: 'luán',  # 曫
    0x66EC: 'shài',  # 曬
    0x66ED: 'tǎng',  # 曭
    0x66EE: 'yǎn',  # 曮
    0x66EF: 'zhú',  # 曯
    0x66F0: 'yuē',  # 曰
    0x66F1: 'yuē',  # 曱
    0x66F2: 'qū,qǔ',  # 曲
    0x66F3: 'yè',  # 曳
    0x66F4: 'gēng,gèng',  # 更
    0x66F5: 'yè',  # 曵
    0x66F6: 'hū,hù',  # 曶
    0x66F7: 'hé',  # 曷
    0x66F8: 'shū',  # 書
    0x66F9: 'cáo',  # 曹
    0x66FA: 'cáo',  # 曺
    0x66FB: 'shēng',  # 曻
    0x66FC: 'màn',  # 曼
    0x66FD: 'zēng,céng',  # 曽
    0x66FE: 'zēng,céng',  # 曾
    0x66FF: 'tì',  # 替
    0x6700: 'zuì',  # 最
    0x6701: 'cǎn,qián,jiàn',  # 朁
    0x6702: 'xù',  # 朂
    0x6703: 'huì,kuài',  # 會
    0x6704: 'yǐn',  # 朄
    0x6705: 'qiè,hé',  # 朅
    0x6706: 'fēn',  # 朆
    0x6707: 'bì,pí',  # 朇
    0x6708: 'yuè',  # 月
    0x6709: 'yǒu,yòu',  # 有
    0x670A: 'ruǎn',  # 朊
    0x670B: 'péng',  # 朋
    0x670C: 'fén,bān',  # 朌
    0x670D: 'fú,fù',  # 服
    0x670E: 'líng',  # 朎
    0x670F: 'fěi,kū',  # 朏
    0x6710: 'qú,xù,chǔn',  # 朐
    0x6711: 'tì',  # 朑
    0x6712: 'nǜ,gǎ',  # 朒
    0x6713: 'tiǎo',  # 朓
    0x6714: 'shuò',  # 朔
    0x6715: 'zhèn',  # 朕
    0x6716: 'lǎng',  # 朖
    0x6717: 'lǎng',  # 朗
    0x6718: 'juān,zuī',  # 朘
    0x6719: 'míng',  # 朙
    0x671A: 'huāng,máng,wáng',  # 朚
    0x671B: 'wàng',  # 望
    0x671C: 'tūn',  # 朜
    0x671D: 'zhāo,cháo',  # 朝
    0x671E: 'jī',  # 朞
    0x671F: 'qī,jī',  # 期
    0x6720: 'yīng',  # 朠
    0x6721: 'zōng',  # 朡
    0x6722: 'wàng',  # 朢
    0x6723: 'tóng,chuáng',  # 朣
    0x6724: 'lǎng',  # 朤
    0x6725: 'láo',  # 朥
    0x6726: 'méng',  # 朦
    0x6727: 'lóng',  # 朧
    0x6728: 'mù',  # 木
    0x6729: 'tin',  # 朩
    0x672A: 'wèi',  # 未
    0x672B: 'mò',  # 末
    0x672C: 'běn',  # 本
    0x672D: 'zhá',  # 札
    0x672E: 'shù,shú,zhú',  # 朮
    0x672F: 'shù,shú,zhú',  # 术
    0x6730: 'teul',  # 朰
    0x6731: 'zhū,shú',  # 朱
    0x6732: 'rén',  # 朲
    0x6733: 'bā',  # 朳
    0x6734: 'pǔ,pò,pō,piáo',  # 朴
    0x6735: 'duǒ',  # 朵
    0x6736: 'duǒ',  # 朶
    0x6737: 'dāo,tiáo,mù',  # 朷
    0x6738: 'lì',  # 朸
    0x6739: 'qiú,guǐ',  # 朹
    0x673A: 'jī',  # 机
    0x673B: 'jiū',  # 朻
    0x673C: 'bǐ',  # 朼
    0x673D: 'xiǔ',  # 朽
    0x673E: 'chéng,chēng',  # 朾
    0x673F: 'cì',  # 朿
    0x6740: 'shā',  # 杀
    0x6741: 'rù',  # 杁
    0x6742: 'zá',  # 杂
    0x6743: 'quán',  # 权
    0x6744: 'qiān',  # 杄
    0x6745: 'yú,wū',  # 杅
    0x6746: 'gān,gǎn',  # 杆
    0x6747: 'wū',  # 杇
    0x6748: 'chā,chà',  # 杈
    0x6749: 'shān,shā',  # 杉
    0x674A: 'xún',  # 杊
    0x674B: 'fán',  # 杋
    0x674C: 'wù',  # 杌
    0x674D: 'zǐ',  # 杍
    0x674E: 'lǐ',  # 李
    0x674F: 'xìng',  # 杏
    0x6750: 'cái',  # 材
    0x6751: 'cūn',  # 村
    0x6752: 'rèn,ér',  # 杒
    0x6753: 'sháo,biāo',  # 杓
    0x6754: 'tuō,zhé',  # 杔
    0x6755: 'dì,duò',  # 杕
    0x6756: 'zhàng',  # 杖
    0x6757: 'máng',  # 杗
    0x6758: 'chì',  # 杘
    0x6759: 'yì',  # 杙
    0x675A: 'gū,gài',  # 杚
    0x675B: 'gōng',  # 杛
    0x675C: 'dù',  # 杜
    0x675D: 'yí,lì,lí,duò,tuò',  # 杝
    0x675E: 'qǐ',  # 杞
    0x675F: 'shù',  # 束
    0x6760: 'gàng,gāng',  # 杠
    0x6761: 'tiáo,tiāo',  # 条
    0x6762: 'jié',  # 杢
    0x6763: 'mián',  # 杣
    0x6764: 'wàn',  # 杤
    0x6765: 'lái',  # 来
    0x6766: 'jiǔ',  # 杦
    0x6767: 'máng',  # 杧
    0x6768: 'yáng',  # 杨
    0x6769: 'mà,mǎ',  # 杩
    0x676A: 'miǎo',  # 杪
    0x676B: 'sì,zhǐ,xǐ',  # 杫
    0x676C: 'yuán,wán',  # 杬
    0x676D: 'háng',  # 杭
    0x676E: 'fèi,bèi',  # 杮
    0x676F: 'bēi',  # 杯
    0x6770: 'jié',  # 杰
    0x6771: 'dōng',  # 東
    0x6772: 'gǎo',  # 杲
    0x6773: 'yǎo',  # 杳
    0x6774: 'xiān',  # 杴
    0x6775: 'chǔ',  # 杵
    0x6776: 'chūn',  # 杶
    0x6777: 'pá',  # 杷
    0x6778: 'shū,duì',  # 杸
    0x6779: 'huà',  # 杹
    0x677A: 'xīn',  # 杺
    0x677B: 'niǔ,chǒu',  # 杻
    0x677C: 'zhù',  # 杼
    0x677D: 'chǒu',  # 杽
    0x677E: 'sōng',  # 松
    0x677F: 'bǎn',  # 板
    0x6780: 'sōng',  # 枀
    0x6781: 'jí',  # 极
    0x6782: 'wò,yuè',  # 枂
    0x6783: 'jìn',  # 枃
    0x6784: 'gòu',  # 构
    0x6785: 'jī',  # 枅
    0x6786: 'máo',  # 枆
    0x6787: 'pí',  # 枇
    0x6788: 'pī,mì',  # 枈
    0x6789: 'wǎng',  # 枉
    0x678A: 'àng',  # 枊
    0x678B: 'fāng,bìng',  # 枋
    0x678C: 'fén',  # 枌
    0x678D: 'yì',  # 枍
    0x678E: 'fú,fū',  # 枎
    0x678F: 'nán',  # 枏
    0x6790: 'xī',  # 析
    0x6791: 'hù,dǐ',  # 枑
    0x6792: 'yā',  # 枒
    0x6793: 'dōu',  # 枓
    0x6794: 'xín',  # 枔
    0x6795: 'zhěn',  # 枕
    0x6796: 'yǎo,yāo',  # 枖
    0x6797: 'lín',  # 林
    0x6798: 'ruì',  # 枘
    0x6799: 'ě,è',  # 枙
    0x679A: 'méi',  # 枚
    0x679B: 'zhào',  # 枛
    0x679C: 'guǒ',  # 果
    0x679D: 'zhī,qí',  # 枝
    0x679E: 'cōng,zōng',  # 枞
    0x679F: 'yùn',  # 枟
    0x67A0: 'huà',  # 枠
    0x67A1: 'shēng',  # 枡
    0x67A2: 'shū',  # 枢
    0x67A3: 'zǎo',  # 枣
    0x67A4: 'dì,duò',  # 枤
    0x67A5: 'lì',  # 枥
    0x67A6: 'lú',  # 枦
    0x67A7: 'jiǎn',  # 枧
    0x67A8: 'chéng',  # 枨
    0x67A9: 'sōng',  # 枩
    0x67AA: 'qiāng',  # 枪
    0x67AB: 'fēng',  # 枫
    0x67AC: 'zhān',  # 枬
    0x67AD: 'xiāo',  # 枭
    0x67AE: 'xiān,zhēn',  # 枮
    0x67AF: 'kū',  # 枯
    0x67B0: 'píng',  # 枰
    0x67B1: 'sì,tái',  # 枱
    0x67B2: 'xǐ',  # 枲
    0x67B3: 'zhǐ',  # 枳
    0x67B4: 'guǎi',  # 枴
    0x67B5: 'xiāo',  # 枵
    0x67B6: 'jià',  # 架
    0x67B7: 'jiā',  # 枷
    0x67B8: 'jǔ,gǒu',  # 枸
    0x67B9: 'bāo,fú',  # 枹
    0x67BA: 'mò',  # 枺
    0x67BB: 'yì,xiè',  # 枻
    0x67BC: 'yè',  # 枼
    0x67BD: 'yè',  # 枽
    0x67BE: 'shì',  # 枾
    0x67BF: 'niè',  # 枿
    0x67C0: 'bǐ',  # 柀
    0x67C1: 'tuó,duò',  # 柁
    0x67C2: 'yí,duò,lí',  # 柂
    0x67C3: 'líng',  # 柃
    0x67C4: 'bǐng',  # 柄
    0x67C5: 'nǐ,chì',  # 柅
    0x67C6: 'lā',  # 柆
    0x67C7: 'hé',  # 柇
    0x67C8: 'pán,bàn',  # 柈
    0x67C9: 'fán',  # 柉
    0x67CA: 'zhōng',  # 柊
    0x67CB: 'dài',  # 柋
    0x67CC: 'cí',  # 柌
    0x67CD: 'yǎng,yàng,yāng,yīng',  # 柍
    0x67CE: 'fū,fǔ,fù',  # 柎
    0x67CF: 'bǎi,bó,bò',  # 柏
    0x67D0: 'mǒu',  # 某
    0x67D1: 'gān',  # 柑
    0x67D2: 'qī',  # 柒
    0x67D3: 'rǎn',  # 染
    0x67D4: 'róu',  # 柔
    0x67D5: 'mào',  # 柕
    0x67D6: 'sháo,shào',  # 柖
    0x67D7: 'sōng',  # 柗
    0x67D8: 'zhè',  # 柘
    0x67D9: 'xiá',  # 柙
    0x67DA: 'yòu,yóu',  # 柚
    0x67DB: 'shēn',  # 柛
    0x67DC: 'guì,jǔ',  # 柜
    0x67DD: 'tuò',  # 柝
    0x67DE: 'zuò,zhà',  # 柞
    0x67DF: 'nán',  # 柟
    0x67E0: 'níng',  # 柠
    0x67E1: 'yǒng',  # 柡
    0x67E2: 'dǐ,chí',  # 柢
    0x67E3: 'zhì,dié',  # 柣
    0x67E4: 'zhā,zǔ,zū',  # 柤
    0x67E5: 'chá,zhā',  # 查
    0x67E6: 'dàn',  # 柦
    0x67E7: 'gū',  # 柧
    0x67E8: 'bù,pū',  # 柨
    0x67E9: 'jiù',  # 柩
    0x67EA: 'āo,ào',  # 柪
    0x67EB: 'fú',  # 柫
    0x67EC: 'jiǎn',  # 柬
    0x67ED: 'bā,fú,pèi,bó,biē',  # 柭
    0x67EE: 'duò,zuó,wù',  # 柮
    0x67EF: 'kē',  # 柯
    0x67F0: 'nài',  # 柰
    0x67F1: 'zhù',  # 柱
    0x67F2: 'bì,bié',  # 柲
    0x67F3: 'liǔ',  # 柳
    0x67F4: 'chái',  # 柴
    0x67F5: 'shān',  # 柵
    0x67F6: 'sì',  # 柶
    0x67F7: 'zhù',  # 柷
    0x67F8: 'bēi,pēi',  # 柸
    0x67F9: 'shì,fèi',  # 柹
    0x67FA: 'guǎi',  # 柺
    0x67FB: 'chá,zhā',  # 査
    0x67FC: 'yǎo',  # 柼
    0x67FD: 'chēng',  # 柽
    0x67FE: 'jiù',  # 柾
    0x67FF: 'shì',  # 柿
    0x6800: 'zhī',  # 栀
    0x6801: 'liǔ',  # 栁
    0x6802: 'méi',  # 栂
    0x6803: 'lì',  # 栃
    0x6804: 'róng',  # 栄
    0x6805: 'zhà,shān,shi,cè',  # 栅
    0x6806: 'zǎo',  # 栆
    0x6807: 'biāo',  # 标
    0x6808: 'zhàn',  # 栈
    0x6809: 'zhì',  # 栉
    0x680A: 'lóng',  # 栊
    0x680B: 'dòng',  # 栋
    0x680C: 'lú',  # 栌
    0x680D: 'saeng',  # 栍
    0x680E: 'lì,yuè',  # 栎
    0x680F: 'lán',  # 栏
    0x6810: 'yǒng',  # 栐
    0x6811: 'shù',  # 树
    0x6812: 'xún',  # 栒
    0x6813: 'shuān',  # 栓
    0x6814: 'qì,qiè',  # 栔
    0x6815: 'chén',  # 栕
    0x6816: 'qī,xī',  # 栖
    0x6817: 'lì',  # 栗
    0x6818: 'yí',  # 栘
    0x6819: 'xiáng',  # 栙
    0x681A: 'zhèn',  # 栚
    0x681B: 'lì',  # 栛
    0x681C: 'sè',  # 栜
    0x681D: 'guā,tiǎn',  # 栝
    0x681E: 'kān',  # 栞
    0x681F: 'bēn,bīng',  # 栟
    0x6820: 'rěn',  # 栠
    0x6821: 'xiào,jiào',  # 校
    0x6822: 'bǎi',  # 栢
    0x6823: 'rěn',  # 栣
    0x6824: 'bìng',  # 栤
    0x6825: 'zī',  # 栥
    0x6826: 'chóu',  # 栦
    0x6827: 'yì,xiè',  # 栧
    0x6828: 'cì',  # 栨
    0x6829: 'xǔ',  # 栩
    0x682A: 'zhū',  # 株
    0x682B: 'jiàn,zùn',  # 栫
    0x682C: 'zuì',  # 栬
    0x682D: 'ér',  # 栭
    0x682E: 'ěr',  # 栮
    0x682F: 'yǒu,yù',  # 栯
    0x6830: 'fá',  # 栰
    0x6831: 'gǒng',  # 栱
    0x6832: 'kǎo',  # 栲
    0x6833: 'lǎo',  # 栳
    0x6834: 'zhān',  # 栴
    0x6835: 'liè',  # 栵
    0x6836: 'yīn',  # 栶
    0x6837: 'yàng',  # 样
    0x6838: 'hé,hú',  # 核
    0x6839: 'gēn',  # 根
    0x683A: 'zhī,yì',  # 栺
    0x683B: 'shì',  # 栻
    0x683C: 'gé',  # 格
    0x683D: 'zāi',  # 栽
    0x683E: 'luán',  # 栾
    0x683F: 'fú',  # 栿
    0x6840: 'jié',  # 桀
    0x6841: 'héng,háng',  # 桁
    0x6842: 'guì',  # 桂
    0x6843: 'táo',  # 桃
    0x6844: 'guāng,guàng',  # 桄
    0x6845: 'wéi',  # 桅
    0x6846: 'kuàng',  # 框
    0x6847: 'rú',  # 桇
    0x6848: 'àn',  # 案
    0x6849: 'ān',  # 桉
    0x684A: 'juàn',  # 桊
    0x684B: 'yí,tí',  # 桋
    0x684C: 'zhuō',  # 桌
    0x684D: 'kū',  # 桍
    0x684E: 'zhì',  # 桎
    0x684F: 'qióng',  # 桏
    0x6850: 'tóng',  # 桐
    0x6851: 'sāng',  # 桑
    0x6852: 'sāng',  # 桒
    0x6853: 'huán',  # 桓
    0x6854: 'jié,jú',  # 桔
    0x6855: 'jiù',  # 桕
    0x6856: 'xuè',  # 桖
    0x6857: 'duò',  # 桗
    0x6858: 'chuí',  # 桘
    0x6859: 'yú,móu',  # 桙
    0x685A: 'zā,zǎn',  # 桚
    0x685B: 'kasei',  # 桛
    0x685C: 'yīng',  # 桜
    0x685D: 'jié',  # 桝
    0x685E: 'liǔ',  # 桞
    0x685F: 'zhàn',  # 桟
    0x6860: 'yā',  # 桠
    0x6861: 'ráo,náo',  # 桡
    0x6862: 'zhēn',  # 桢
    0x6863: 'dàng',  # 档
    0x6864: 'qī',  # 桤
    0x6865: 'qiáo',  # 桥
    0x6866: 'huà',  # 桦
    0x6867: 'guì,huì',  # 桧
    0x6868: 'jiǎng',  # 桨
    0x6869: 'zhuāng',  # 桩
    0x686A: 'xún',  # 桪
    0x686B: 'suō',  # 桫
    0x686C: 'shā',  # 桬
    0x686D: 'chén,zhèn',  # 桭
    0x686E: 'bēi',  # 桮
    0x686F: 'tīng,yíng',  # 桯
    0x6870: 'guā',  # 桰
    0x6871: 'jìng',  # 桱
    0x6872: 'bó',  # 桲
    0x6873: 'bèn,fàn',  # 桳
    0x6874: 'fú',  # 桴
    0x6875: 'ruí',  # 桵
    0x6876: 'tǒng',  # 桶
    0x6877: 'jué',  # 桷
    0x6878: 'xī',  # 桸
    0x6879: 'láng',  # 桹
    0x687A: 'liǔ',  # 桺
    0x687B: 'fēng,fèng',  # 桻
    0x687C: 'qī',  # 桼
    0x687D: 'wěn',  # 桽
    0x687E: 'jūn',  # 桾
    0x687F: 'gǎn',  # 桿
    0x6880: 'sù,yìn',  # 梀
    0x6881: 'liáng',  # 梁
    0x6882: 'qiú',  # 梂
    0x6883: 'tǐng,tìng',  # 梃
    0x6884: 'yǒu',  # 梄
    0x6885: 'méi',  # 梅
    0x6886: 'bāng',  # 梆
    0x6887: 'lòng',  # 梇
    0x6888: 'pēng',  # 梈
    0x6889: 'zhuāng',  # 梉
    0x688A: 'dì',  # 梊
    0x688B: 'xuān,juān,xié',  # 梋
    0x688C: 'tú,chá',  # 梌
    0x688D: 'zào',  # 梍
    0x688E: 'āo,yòu',  # 梎
    0x688F: 'gù',  # 梏
    0x6890: 'bì',  # 梐
    0x6891: 'dí',  # 梑
    0x6892: 'hán',  # 梒
    0x6893: 'zǐ',  # 梓
    0x6894: 'zhī',  # 梔
    0x6895: 'rèn,ér',  # 梕
    0x6896: 'bèi',  # 梖
    0x6897: 'gěng',  # 梗
    0x6898: 'jiǎn',  # 梘
    0x6899: 'huàn',  # 梙
    0x689A: 'wǎn',  # 梚
    0x689B: 'nuó',  # 梛
    0x689C: 'jiā',  # 梜
    0x689D: 'tiáo,tiāo',  # 條
    0x689E: 'jì',  # 梞
    0x689F: 'xiāo',  # 梟
    0x68A0: 'lǚ',  # 梠
    0x68A1: 'kuǎn',  # 梡
    0x68A2: 'shāo,sào',  # 梢
    0x68A3: 'chén',  # 梣
    0x68A4: 'fēn',  # 梤
    0x68A5: 'sōng',  # 梥
    0x68A6: 'mèng',  # 梦
    0x68A7: 'wú',  # 梧
    0x68A8: 'lí',  # 梨
    0x68A9: 'sì,qǐ',  # 梩
    0x68AA: 'dòu',  # 梪
    0x68AB: 'qǐn',  # 梫
    0x68AC: 'yǐng',  # 梬
    0x68AD: 'suō',  # 梭
    0x68AE: 'jū',  # 梮
    0x68AF: 'tī',  # 梯
    0x68B0: 'xiè',  # 械
    0x68B1: 'kǔn',  # 梱
    0x68B2: 'zhuō',  # 梲
    0x68B3: 'shū',  # 梳
    0x68B4: 'chān,yán',  # 梴
    0x68B5: 'fàn',  # 梵
    0x68B6: 'wěi',  # 梶
    0x68B7: 'jìng',  # 梷
    0x68B8: 'lí',  # 梸
    0x68B9: 'bīn,bīng',  # 梹
    0x68BA: 'xià',  # 梺
    0x68BB: 'fó',  # 梻
    0x68BC: 'chóu,táo,dào',  # 梼
    0x68BD: 'zhì',  # 梽
    0x68BE: 'lái',  # 梾
    0x68BF: 'lián,liǎn',  # 梿
    0x68C0: 'jiǎn',  # 检
    0x68C1: 'zhuō',  # 棁
    0x68C2: 'líng',  # 棂
    0x68C3: 'lí',  # 棃
    0x68C4: 'qì',  # 棄
    0x68C5: 'bǐng',  # 棅
    0x68C6: 'lún',  # 棆
    0x68C7: 'cōng,sōng',  # 棇
    0x68C8: 'qiàn',  # 棈
    0x68C9: 'mián',  # 棉
    0x68CA: 'qí',  # 棊
    0x68CB: 'qí',  # 棋
    0x68CC: 'cǎi',  # 棌
    0x68CD: 'gùn,hùn',  # 棍
    0x68CE: 'chán',  # 棎
    0x68CF: 'dé,zhé',  # 棏
    0x68D0: 'fěi',  # 棐
    0x68D1: 'pái,bèi,pèi',  # 棑
    0x68D2: 'bàng',  # 棒
    0x68D3: 'bàng,pǒu,bèi,bēi',  # 棓
    0x68D4: 'hūn',  # 棔
    0x68D5: 'zōng',  # 棕
    0x68D6: 'chéng',  # 棖
    0x68D7: 'zǎo',  # 棗
    0x68D8: 'jí',  # 棘
    0x68D9: 'lì,liè',  # 棙
    0x68DA: 'péng',  # 棚
    0x68DB: 'yù',  # 棛
    0x68DC: 'yù',  # 棜
    0x68DD: 'gù',  # 棝
    0x68DE: 'jùn',  # 棞
    0x68DF: 'dòng',  # 棟
    0x68E0: 'táng',  # 棠
    0x68E1: 'gāng',  # 棡
    0x68E2: 'wǎng',  # 棢
    0x68E3: 'dì,dài,tì',  # 棣
    0x68E4: 'què',  # 棤
    0x68E5: 'fán',  # 棥
    0x68E6: 'chēng',  # 棦
    0x68E7: 'zhàn',  # 棧
    0x68E8: 'qǐ',  # 棨
    0x68E9: 'yuān',  # 棩
    0x68EA: 'yǎn,yàn',  # 棪
    0x68EB: 'yù',  # 棫
    0x68EC: 'quān,juàn',  # 棬
    0x68ED: 'yì',  # 棭
    0x68EE: 'sēn',  # 森
    0x68EF: 'rěn,shěn',  # 棯
    0x68F0: 'chuí',  # 棰
    0x68F1: 'léng,lēng,líng',  # 棱
    0x68F2: 'qī',  # 棲
    0x68F3: 'zhuō',  # 棳
    0x68F4: 'fú,sù',  # 棴
    0x68F5: 'kē',  # 棵
    0x68F6: 'lái',  # 棶
    0x68F7: 'zōu,sǒu',  # 棷
    0x68F8: 'zōu',  # 棸
    0x68F9: 'zhào,zhuō',  # 棹
    0x68FA: 'guān',  # 棺
    0x68FB: 'fēn',  # 棻
    0x68FC: 'fén',  # 棼
    0x68FD: 'chēn,shēn',  # 棽
    0x68FE: 'qíng',  # 棾
    0x68FF: 'ní,nǐ',  # 棿
    0x6900: 'wǎn',  # 椀
    0x6901: 'guǒ',  # 椁
    0x6902: 'lù',  # 椂
    0x6903: 'háo',  # 椃
    0x6904: 'jiē,qiè',  # 椄
    0x6905: 'yǐ,yī',  # 椅
    0x6906: 'chóu,zhòu,diāo',  # 椆
    0x6907: 'jǔ',  # 椇
    0x6908: 'jú',  # 椈
    0x6909: 'chéng,shèng',  # 椉
    0x690A: 'zú,cuì',  # 椊
    0x690B: 'liáng',  # 椋
    0x690C: 'qiāng,kōng',  # 椌
    0x690D: 'zhí',  # 植
    0x690E: 'zhuī,chuí',  # 椎
    0x690F: 'yā',  # 椏
    0x6910: 'jū',  # 椐
    0x6911: 'bēi',  # 椑
    0x6912: 'jiāo',  # 椒
    0x6913: 'zhuó',  # 椓
    0x6914: 'zī',  # 椔
    0x6915: 'bīn',  # 椕
    0x6916: 'péng',  # 椖
    0x6917: 'dìng',  # 椗
    0x6918: 'chǔ',  # 椘
    0x6919: 'chāng',  # 椙
    0x691A: 'mēn',  # 椚
    0x691B: 'huā',  # 椛
    0x691C: 'jiǎn',  # 検
    0x691D: 'guī',  # 椝
    0x691E: 'xì',  # 椞
    0x691F: 'dú',  # 椟
    0x6920: 'qiàn',  # 椠
    0x6921: 'dào',  # 椡
    0x6922: 'guì',  # 椢
    0x6923: 'diǎn',  # 椣
    0x6924: 'luó',  # 椤
    0x6925: 'zhī',  # 椥
    0x6926: 'quān,juàn,quán',  # 椦
    0x6927: 'myeong',  # 椧
    0x6928: 'fǔ',  # 椨
    0x6929: 'gēng',  # 椩
    0x692A: 'pèng',  # 椪
    0x692B: 'shàn',  # 椫
    0x692C: 'yí',  # 椬
    0x692D: 'tuǒ',  # 椭
    0x692E: 'sēn',  # 椮
    0x692F: 'duǒ,chuán',  # 椯
    0x6930: 'yē',  # 椰
    0x6931: 'fù',  # 椱
    0x6932: 'wěi,huī',  # 椲
    0x6933: 'wēi',  # 椳
    0x6934: 'duàn',  # 椴
    0x6935: 'jiǎ,jiā',  # 椵
    0x6936: 'zōng',  # 椶
    0x6937: 'jiān,hán',  # 椷
    0x6938: 'yí',  # 椸
    0x6939: 'zhēn,shèn',  # 椹
    0x693A: 'xí',  # 椺
    0x693B: 'yàn,yà',  # 椻
    0x693C: 'yǎn',  # 椼
    0x693D: 'chuán',  # 椽
    0x693E: 'jiān',  # 椾
    0x693F: 'chūn',  # 椿
    0x6940: 'yǔ',  # 楀
    0x6941: 'hé',  # 楁
    0x6942: 'zhā,chá',  # 楂
    0x6943: 'wò',  # 楃
    0x6944: 'piān',  # 楄
    0x6945: 'bī',  # 楅
    0x6946: 'yāo',  # 楆
    0x6947: 'guō,kuǎ',  # 楇
    0x6948: 'xū',  # 楈
    0x6949: 'ruò',  # 楉
    0x694A: 'yáng',  # 楊
    0x694B: 'là',  # 楋
    0x694C: 'yán',  # 楌
    0x694D: 'běn',  # 楍
    0x694E: 'huī',  # 楎
    0x694F: 'kuí',  # 楏
    0x6950: 'jiè',  # 楐
    0x6951: 'kuí',  # 楑
    0x6952: 'sī',  # 楒
    0x6953: 'fēng',  # 楓
    0x6954: 'xiē',  # 楔
    0x6955: 'tuǒ',  # 楕
    0x6956: 'jí,zhì',  # 楖
    0x6957: 'jiàn',  # 楗
    0x6958: 'mù',  # 楘
    0x6959: 'máo',  # 楙
    0x695A: 'chǔ',  # 楚
    0x695B: 'kǔ,hù',  # 楛
    0x695C: 'hú',  # 楜
    0x695D: 'liàn',  # 楝
    0x695E: 'léng',  # 楞
    0x695F: 'tíng',  # 楟
    0x6960: 'nán',  # 楠
    0x6961: 'yú',  # 楡
    0x6962: 'yóu,yǒu',  # 楢
    0x6963: 'méi',  # 楣
    0x6964: 'sǒng,cōng',  # 楤
    0x6965: 'xuàn,yuán',  # 楥
    0x6966: 'xuàn',  # 楦
    0x6967: 'yǎng,yàng,yīng',  # 楧
    0x6968: 'zhēn',  # 楨
    0x6969: 'pián',  # 楩
    0x696A: 'dié,yè',  # 楪
    0x696B: 'jí',  # 楫
    0x696C: 'jiē',  # 楬
    0x696D: 'yè',  # 業
    0x696E: 'chǔ',  # 楮
    0x696F: 'shǔn,dùn',  # 楯
    0x6970: 'yú',  # 楰
    0x6971: 'còu,zòu',  # 楱
    0x6972: 'wēi',  # 楲
    0x6973: 'méi',  # 楳
    0x6974: 'dì,dǐ,shì',  # 楴
    0x6975: 'jí',  # 極
    0x6976: 'jié',  # 楶
    0x6977: 'kǎi,jiē',  # 楷
    0x6978: 'qiū',  # 楸
    0x6979: 'yíng',  # 楹
    0x697A: 'róu,ròu',  # 楺
    0x697B: 'huáng',  # 楻
    0x697C: 'lóu',  # 楼
    0x697D: 'lè,yuè',  # 楽
    0x697E: 'quán',  # 楾
    0x697F: 'xiāng',  # 楿
    0x6980: 'pǐn',  # 榀
    0x6981: 'shǐ',  # 榁
    0x6982: 'gài',  # 概
    0x6983: 'tán',  # 榃
    0x6984: 'lǎn',  # 榄
    0x6985: 'wēn,yùn',  # 榅
    0x6986: 'yú',  # 榆
    0x6987: 'chèn',  # 榇
    0x6988: 'lǘ',  # 榈
    0x6989: 'jǔ',  # 榉
    0x698A: 'shén',  # 榊
    0x698B: 'chū',  # 榋
    0x698C: 'bī,pi',  # 榌
    0x698D: 'xiè',  # 榍
    0x698E: 'jiǎ',  # 榎
    0x698F: 'yì',  # 榏
    0x6990: 'zhǎn,niǎn,zhèn',  # 榐
    0x6991: 'fú,fù,bó',  # 榑
    0x6992: 'nuò',  # 榒
    0x6993: 'mì',  # 榓
    0x6994: 'láng',  # 榔
    0x6995: 'róng',  # 榕
    0x6996: 'gǔ',  # 榖
    0x6997: 'jiàn,jìn',  # 榗
    0x6998: 'jǔ',  # 榘
    0x6999: 'tā',  # 榙
    0x699A: 'yǎo',  # 榚
    0x699B: 'zhēn',  # 榛
    0x699C: 'bǎng,bàng',  # 榜
    0x699D: 'shā,xiè',  # 榝
    0x699E: 'yuán',  # 榞
    0x699F: 'zǐ',  # 榟
    0x69A0: 'míng',  # 榠
    0x69A1: 'sù',  # 榡
    0x69A2: 'jià',  # 榢
    0x69A3: 'yáo',  # 榣
    0x69A4: 'jié',  # 榤
    0x69A5: 'huàng',  # 榥
    0x69A6: 'gàn',  # 榦
    0x69A7: 'fěi',  # 榧
    0x69A8: 'zhà',  # 榨
    0x69A9: 'qián',  # 榩
    0x69AA: 'mà,mā',  # 榪
    0x69AB: 'sǔn',  # 榫
    0x69AC: 'yuán',  # 榬
    0x69AD: 'xiè',  # 榭
    0x69AE: 'róng',  # 榮
    0x69AF: 'shí',  # 榯
    0x69B0: 'zhī',  # 榰
    0x69B1: 'cuī',  # 榱
    0x69B2: 'wēn',  # 榲
    0x69B3: 'tíng',  # 榳
    0x69B4: 'liú',  # 榴
    0x69B5: 'róng',  # 榵
    0x69B6: 'táng',  # 榶
    0x69B7: 'què',  # 榷
    0x69B8: 'zhāi',  # 榸
    0x69B9: 'sì',  # 榹
    0x69BA: 'shèng',  # 榺
    0x69BB: 'tà',  # 榻
    0x69BC: 'kē',  # 榼
    0x69BD: 'xī',  # 榽
    0x69BE: 'gù',  # 榾
    0x69BF: 'qī',  # 榿
    0x69C0: 'gǎo',  # 槀
    0x69C1: 'gǎo',  # 槁
    0x69C2: 'sūn',  # 槂
    0x69C3: 'pán',  # 槃
    0x69C4: 'tāo',  # 槄
    0x69C5: 'gé',  # 槅
    0x69C6: 'chūn',  # 槆
    0x69C7: 'diān',  # 槇
    0x69C8: 'nòu',  # 槈
    0x69C9: 'jí',  # 槉
    0x69CA: 'shuò',  # 槊
    0x69CB: 'gòu',  # 構
    0x69CC: 'chuí',  # 槌
    0x69CD: 'qiāng',  # 槍
    0x69CE: 'chá',  # 槎
    0x69CF: 'qiǎn,lián,xiàn',  # 槏
    0x69D0: 'huái',  # 槐
    0x69D1: 'méi',  # 槑
    0x69D2: 'xù',  # 槒
    0x69D3: 'gàng',  # 槓
    0x69D4: 'gāo',  # 槔
    0x69D5: 'zhuō',  # 槕
    0x69D6: 'tuó',  # 槖
    0x69D7: 'qiáo',  # 槗
    0x69D8: 'yàng',  # 様
    0x69D9: 'diān,zhěn,zhēn',  # 槙
    0x69DA: 'jiǎ',  # 槚
    0x69DB: 'jiàn,kǎn',  # 槛
    0x69DC: 'zuì',  # 槜
    0x69DD: 'dǎo',  # 槝
    0x69DE: 'lóng',  # 槞
    0x69DF: 'bīn,bīng',  # 槟
    0x69E0: 'zhū',  # 槠
    0x69E1: 'sāng',  # 槡
    0x69E2: 'xí,dié',  # 槢
    0x69E3: 'jī,guī',  # 槣
    0x69E4: 'lián,liǎn',  # 槤
    0x69E5: 'huì',  # 槥
    0x69E6: 'róng,yōng',  # 槦
    0x69E7: 'qiàn',  # 槧
    0x69E8: 'guǒ',  # 槨
    0x69E9: 'gài',  # 槩
    0x69EA: 'gài',  # 槪
    0x69EB: 'tuán,shuàn,quán',  # 槫
    0x69EC: 'huà',  # 槬
    0x69ED: 'qì,sè',  # 槭
    0x69EE: 'sēn',  # 槮
    0x69EF: 'cuī,zhǐ',  # 槯
    0x69F0: 'pèng',  # 槰
    0x69F1: 'yǒu,chǎo',  # 槱
    0x69F2: 'hú',  # 槲
    0x69F3: 'jiǎng',  # 槳
    0x69F4: 'hù',  # 槴
    0x69F5: 'huàn',  # 槵
    0x69F6: 'guì',  # 槶
    0x69F7: 'niè',  # 槷
    0x69F8: 'yì',  # 槸
    0x69F9: 'gāo',  # 槹
    0x69FA: 'kāng',  # 槺
    0x69FB: 'guī',  # 槻
    0x69FC: 'guī',  # 槼
    0x69FD: 'cáo',  # 槽
    0x69FE: 'màn,wàn',  # 槾
    0x69FF: 'jǐn',  # 槿
    0x6A00: 'dī',  # 樀
    0x6A01: 'zhuāng',  # 樁
    0x6A02: 'lè,yuè,yào,lào',  # 樂
    0x6A03: 'láng',  # 樃
    0x6A04: 'chén',  # 樄
    0x6A05: 'cōng,zōng',  # 樅
    0x6A06: 'lí,chī',  # 樆
    0x6A07: 'xiū',  # 樇
    0x6A08: 'qíng',  # 樈
    0x6A09: 'shǎng',  # 樉
    0x6A0A: 'fán',  # 樊
    0x6A0B: 'tōng',  # 樋
    0x6A0C: 'guàn',  # 樌
    0x6A0D: 'zé',  # 樍
    0x6A0E: 'sù',  # 樎
    0x6A0F: 'léi,lěi',  # 樏
    0x6A10: 'lǔ',  # 樐
    0x6A11: 'liáng',  # 樑
    0x6A12: 'mì',  # 樒
    0x6A13: 'lóu',  # 樓
    0x6A14: 'cháo,jiǎo,chāo',  # 樔
    0x6A15: 'sù',  # 樕
    0x6A16: 'kē',  # 樖
    0x6A17: 'chū',  # 樗
    0x6A18: 'táng',  # 樘
    0x6A19: 'biāo',  # 標
    0x6A1A: 'lù',  # 樚
    0x6A1B: 'jiū,liáo',  # 樛
    0x6A1C: 'zhè',  # 樜
    0x6A1D: 'zhā',  # 樝
    0x6A1E: 'shū',  # 樞
    0x6A1F: 'zhāng',  # 樟
    0x6A20: 'mán',  # 樠
    0x6A21: 'mó,mú',  # 模
    0x6A22: 'niǎo,mù',  # 樢
    0x6A23: 'yàng',  # 樣
    0x6A24: 'tiáo',  # 樤
    0x6A25: 'péng',  # 樥
    0x6A26: 'zhù',  # 樦
    0x6A27: 'shā,xiè',  # 樧
    0x6A28: 'xī',  # 樨
    0x6A29: 'quán',  # 権
    0x6A2A: 'héng,hèng',  # 横
    0x6A2B: 'jiān',  # 樫
    0x6A2C: 'cōng',  # 樬
    0x6A2D: 'jī',  # 樭
    0x6A2E: 'yān',  # 樮
    0x6A2F: 'qiáng',  # 樯
    0x6A30: 'xuě',  # 樰
    0x6A31: 'yīng',  # 樱
    0x6A32: 'èr',  # 樲
    0x6A33: 'xún',  # 樳
    0x6A34: 'zhí',  # 樴
    0x6A35: 'qiáo',  # 樵
    0x6A36: 'zuī',  # 樶
    0x6A37: 'cóng',  # 樷
    0x6A38: 'pǔ',  # 樸
    0x6A39: 'shù',  # 樹
    0x6A3A: 'huà',  # 樺
    0x6A3B: 'guì',  # 樻
    0x6A3C: 'zhēn',  # 樼
    0x6A3D: 'zūn',  # 樽
    0x6A3E: 'yuè',  # 樾
    0x6A3F: 'shàn',  # 樿
    0x6A40: 'xī',  # 橀
    0x6A41: 'chūn',  # 橁
    0x6A42: 'diàn',  # 橂
    0x6A43: 'fá,fèi',  # 橃
    0x6A44: 'gǎn',  # 橄
    0x6A45: 'mó',  # 橅
    0x6A46: 'wú',  # 橆
    0x6A47: 'qiāo',  # 橇
    0x6A48: 'ráo,náo',  # 橈
    0x6A49: 'lìn',  # 橉
    0x6A4A: 'liú',  # 橊
    0x6A4B: 'qiáo',  # 橋
    0x6A4C: 'xiàn',  # 橌
    0x6A4D: 'rùn',  # 橍
    0x6A4E: 'fǎn',  # 橎
    0x6A4F: 'zhǎn,jiǎn',  # 橏
    0x6A50: 'tuó',  # 橐
    0x6A51: 'liáo',  # 橑
    0x6A52: 'yún',  # 橒
    0x6A53: 'shùn',  # 橓
    0x6A54: 'tuí,dūn',  # 橔
    0x6A55: 'chēng',  # 橕
    0x6A56: 'táng,chēng',  # 橖
    0x6A57: 'méng',  # 橗
    0x6A58: 'jú',  # 橘
    0x6A59: 'chéng',  # 橙
    0x6A5A: 'sù,qiū',  # 橚
    0x6A5B: 'jué',  # 橛
    0x6A5C: 'jué',  # 橜
    0x6A5D: 'tán,diàn',  # 橝
    0x6A5E: 'huì',  # 橞
    0x6A5F: 'jī',  # 機
    0x6A60: 'nuó',  # 橠
    0x6A61: 'xiàng',  # 橡
    0x6A62: 'tuǒ',  # 橢
    0x6A63: 'níng',  # 橣
    0x6A64: 'ruǐ',  # 橤
    0x6A65: 'zhū',  # 橥
    0x6A66: 'tóng,chuáng',  # 橦
    0x6A67: 'zēng,céng',  # 橧
    0x6A68: 'fén,fèn,fèi',  # 橨
    0x6A69: 'qióng',  # 橩
    0x6A6A: 'rǎn,yān',  # 橪
    0x6A6B: 'héng,hèng',  # 橫
    0x6A6C: 'qián',  # 橬
    0x6A6D: 'gū',  # 橭
    0x6A6E: 'liǔ',  # 橮
    0x6A6F: 'lào',  # 橯
    0x6A70: 'gāo',  # 橰
    0x6A71: 'chú',  # 橱
    0x6A72: 'xǐ',  # 橲
    0x6A73: 'shèng',  # 橳
    0x6A74: 'zǐ',  # 橴
    0x6A75: 'zān',  # 橵
    0x6A76: 'jǐ',  # 橶
    0x6A77: 'dōu',  # 橷
    0x6A78: 'jīng',  # 橸
    0x6A79: 'lǔ',  # 橹
    0x6A7A: 'xiàn',  # 橺
    0x6A7B: 'cū,chu',  # 橻
    0x6A7C: 'yuán',  # 橼
    0x6A7D: 'tà',  # 橽
    0x6A7E: 'shū,qiāo',  # 橾
    0x6A7F: 'jiāng',  # 橿
    0x6A80: 'tán',  # 檀
    0x6A81: 'lǐn',  # 檁
    0x6A82: 'nóng',  # 檂
    0x6A83: 'yǐn',  # 檃
    0x6A84: 'xí',  # 檄
    0x6A85: 'huì',  # 檅
    0x6A86: 'shān',  # 檆
    0x6A87: 'zuì',  # 檇
    0x6A88: 'xuán',  # 檈
    0x6A89: 'chēng',  # 檉
    0x6A8A: 'gàn',  # 檊
    0x6A8B: 'jū',  # 檋
    0x6A8C: 'zuì',  # 檌
    0x6A8D: 'yì',  # 檍
    0x6A8E: 'qín',  # 檎
    0x6A8F: 'pǔ',  # 檏
    0x6A90: 'yán',  # 檐
    0x6A91: 'léi',  # 檑
    0x6A92: 'fēng',  # 檒
    0x6A93: 'huǐ',  # 檓
    0x6A94: 'dàng',  # 檔
    0x6A95: 'jì',  # 檕
    0x6A96: 'suì',  # 檖
    0x6A97: 'bò',  # 檗
    0x6A98: 'píng,bò',  # 檘
    0x6A99: 'chéng',  # 檙
    0x6A9A: 'chǔ',  # 檚
    0x6A9B: 'zhuā',  # 檛
    0x6A9C: 'guì,huì',  # 檜
    0x6A9D: 'jí',  # 檝
    0x6A9E: 'jiě',  # 檞
    0x6A9F: 'jiǎ',  # 檟
    0x6AA0: 'qíng',  # 檠
    0x6AA1: 'zhái,shì,tú',  # 檡
    0x6AA2: 'jiǎn',  # 檢
    0x6AA3: 'qiáng',  # 檣
    0x6AA4: 'dào',  # 檤
    0x6AA5: 'yǐ',  # 檥
    0x6AA6: 'biāo,biǎo',  # 檦
    0x6AA7: 'sōng',  # 檧
    0x6AA8: 'shē',  # 檨
    0x6AA9: 'lǐn',  # 檩
    0x6AAA: 'lì',  # 檪
    0x6AAB: 'chá',  # 檫
    0x6AAC: 'méng',  # 檬
    0x6AAD: 'yín',  # 檭
    0x6AAE: 'chóu,táo,dǎo',  # 檮
    0x6AAF: 'tái',  # 檯
    0x6AB0: 'mián',  # 檰
    0x6AB1: 'qí',  # 檱
    0x6AB2: 'tuán',  # 檲
    0x6AB3: 'bīn,bīng',  # 檳
    0x6AB4: 'huò',  # 檴
    0x6AB5: 'jì',  # 檵
    0x6AB6: 'qiān,lián',  # 檶
    0x6AB7: 'nǐ,mí',  # 檷
    0x6AB8: 'níng',  # 檸
    0x6AB9: 'yī',  # 檹
    0x6ABA: 'gǎo',  # 檺
    0x6ABB: 'jiàn,kǎn',  # 檻
    0x6ABC: 'yǐn',  # 檼
    0x6ABD: 'nòu,ruǎn,rú',  # 檽
    0x6ABE: 'qǐng',  # 檾
    0x6ABF: 'yǎn',  # 檿
    0x6AC0: 'qí',  # 櫀
    0x6AC1: 'mì',  # 櫁
    0x6AC2: 'zhào',  # 櫂
    0x6AC3: 'guì',  # 櫃
    0x6AC4: 'chūn',  # 櫄
    0x6AC5: 'jī,jì',  # 櫅
    0x6AC6: 'kuí',  # 櫆
    0x6AC7: 'pó',  # 櫇
    0x6AC8: 'dèng',  # 櫈
    0x6AC9: 'chú',  # 櫉
    0x6ACA: 'gé',  # 櫊
    0x6ACB: 'mián',  # 櫋
    0x6ACC: 'yōu',  # 櫌
    0x6ACD: 'zhì',  # 櫍
    0x6ACE: 'huǎng,guǒ,gǔ',  # 櫎
    0x6ACF: 'qiān',  # 櫏
    0x6AD0: 'lěi',  # 櫐
    0x6AD1: 'léi,lěi',  # 櫑
    0x6AD2: 'sà',  # 櫒
    0x6AD3: 'lǔ',  # 櫓
    0x6AD4: 'lì',  # 櫔
    0x6AD5: 'cuán',  # 櫕
    0x6AD6: 'lǜ,chū',  # 櫖
    0x6AD7: 'miè,mèi',  # 櫗
    0x6AD8: 'huì',  # 櫘
    0x6AD9: 'ōu',  # 櫙
    0x6ADA: 'lǘ',  # 櫚
    0x6ADB: 'zhì',  # 櫛
    0x6ADC: 'gāo',  # 櫜
    0x6ADD: 'dú',  # 櫝
    0x6ADE: 'yuán',  # 櫞
    0x6ADF: 'lì,yuè',  # 櫟
    0x6AE0: 'fèi',  # 櫠
    0x6AE1: 'zhuó,zhù',  # 櫡
    0x6AE2: 'sǒu',  # 櫢
    0x6AE3: 'lián,liǎn',  # 櫣
    0x6AE4: 'jiàng',  # 櫤
    0x6AE5: 'chú',  # 櫥
    0x6AE6: 'qìng',  # 櫦
    0x6AE7: 'zhū',  # 櫧
    0x6AE8: 'lú',  # 櫨
    0x6AE9: 'yán',  # 櫩
    0x6AEA: 'lì',  # 櫪
    0x6AEB: 'zhū',  # 櫫
    0x6AEC: 'chèn',  # 櫬
    0x6AED: 'jué,jì',  # 櫭
    0x6AEE: 'è',  # 櫮
    0x6AEF: 'sū',  # 櫯
    0x6AF0: 'huái,guī',  # 櫰
    0x6AF1: 'niè',  # 櫱
    0x6AF2: 'yù',  # 櫲
    0x6AF3: 'lóng',  # 櫳
    0x6AF4: 'là,lài',  # 櫴
    0x6AF5: 'qiáo',  # 櫵
    0x6AF6: 'xiǎn',  # 櫶
    0x6AF7: 'guī',  # 櫷
    0x6AF8: 'jǔ',  # 櫸
    0x6AF9: 'xiāo',  # 櫹
    0x6AFA: 'líng',  # 櫺
    0x6AFB: 'yīng',  # 櫻
    0x6AFC: 'jiān',  # 櫼
    0x6AFD: 'yǐn',  # 櫽
    0x6AFE: 'yòu,yóu',  # 櫾
    0x6AFF: 'yíng',  # 櫿
    0x6B00: 'xiāng',  # 欀
    0x6B01: 'nóng',  # 欁
    0x6B02: 'bó',  # 欂
    0x6B03: 'chán,zhàn',  # 欃
    0x6B04: 'lán',  # 欄
    0x6B05: 'jǔ',  # 欅
    0x6B06: 'shuāng',  # 欆
    0x6B07: 'shè',  # 欇
    0x6B08: 'wéi,zuì',  # 欈
    0x6B09: 'cóng',  # 欉
    0x6B0A: 'quán',  # 權
    0x6B0B: 'qú',  # 欋
    0x6B0C: 'cáng',  # 欌
    0x6B0D: 'jiù',  # 欍
    0x6B0E: 'yù',  # 欎
    0x6B0F: 'luó',  # 欏
    0x6B10: 'lì',  # 欐
    0x6B11: 'cuán',  # 欑
    0x6B12: 'luán',  # 欒
    0x6B13: 'dǎng',  # 欓
    0x6B14: 'qú',  # 欔
    0x6B15: 'yán',  # 欕
    0x6B16: 'lǎn',  # 欖
    0x6B17: 'lán',  # 欗
    0x6B18: 'zhú',  # 欘
    0x6B19: 'léi',  # 欙
    0x6B1A: 'lǐ',  # 欚
    0x6B1B: 'bà',  # 欛
    0x6B1C: 'náng',  # 欜
    0x6B1D: 'yù',  # 欝
    0x6B1E: 'líng',  # 欞
    0x6B1F: 'guàn',  # 欟
    0x6B20: 'qiàn',  # 欠
    0x6B21: 'cì',  # 次
    0x6B22: 'huān',  # 欢
    0x6B23: 'xīn',  # 欣
    0x6B24: 'yú',  # 欤
    0x6B25: 'yù,yì',  # 欥
    0x6B26: 'qiān,xiān',  # 欦
    0x6B27: 'ōu',  # 欧
    0x6B28: 'xū',  # 欨
    0x6B29: 'chāo',  # 欩
    0x6B2A: 'chù,qù,xì',  # 欪
    0x6B2B: 'qì',  # 欫
    0x6B2C: 'kài,ài',  # 欬
    0x6B2D: 'yì,yīn',  # 欭
    0x6B2E: 'jué',  # 欮
    0x6B2F: 'xì,kài',  # 欯
    0x6B30: 'xù',  # 欰
    0x6B31: 'hē',  # 欱
    0x6B32: 'yù',  # 欲
    0x6B33: 'kuài',  # 欳
    0x6B34: 'láng',  # 欴
    0x6B35: 'kuǎn',  # 欵
    0x6B36: 'shuò,sòu',  # 欶
    0x6B37: 'xī',  # 欷
    0x6B38: 'èi,èi,ěi,èi,ǎi',  # 欸
    0x6B39: 'qī',  # 欹
    0x6B3A: 'qī',  # 欺
    0x6B3B: 'xū,chuā',  # 欻
    0x6B3C: 'chǐ,chuài',  # 欼
    0x6B3D: 'qīn',  # 欽
    0x6B3E: 'kuǎn',  # 款
    0x6B3F: 'kǎn,qiàn',  # 欿
    0x6B40: 'kuǎn',  # 歀
    0x6B41: 'kǎn,kè',  # 歁
    0x6B42: 'chuǎn,chuán',  # 歂
    0x6B43: 'shà',  # 歃
    0x6B44: 'guā',  # 歄
    0x6B45: 'yān,yīn',  # 歅
    0x6B46: 'xīn',  # 歆
    0x6B47: 'xiē',  # 歇
    0x6B48: 'yú',  # 歈
    0x6B49: 'qiàn',  # 歉
    0x6B4A: 'xiāo',  # 歊
    0x6B4B: 'yē',  # 歋
    0x6B4C: 'gē',  # 歌
    0x6B4D: 'wū',  # 歍
    0x6B4E: 'tàn',  # 歎
    0x6B4F: 'jìn,qūn',  # 歏
    0x6B50: 'ōu',  # 歐
    0x6B51: 'hū',  # 歑
    0x6B52: 'tì',  # 歒
    0x6B53: 'huān',  # 歓
    0x6B54: 'xū',  # 歔
    0x6B55: 'pēn',  # 歕
    0x6B56: 'xǐ',  # 歖
    0x6B57: 'xiào',  # 歗
    0x6B58: 'xū',  # 歘
    0x6B59: 'xī,shè',  # 歙
    0x6B5A: 'shàn',  # 歚
    0x6B5B: 'liǎn,hān',  # 歛
    0x6B5C: 'chù',  # 歜
    0x6B5D: 'yì',  # 歝
    0x6B5E: 'è',  # 歞
    0x6B5F: 'yú',  # 歟
    0x6B60: 'chuò',  # 歠
    0x6B61: 'huān',  # 歡
    0x6B62: 'zhǐ',  # 止
    0x6B63: 'zhèng,zhēng',  # 正
    0x6B64: 'cǐ',  # 此
    0x6B65: 'bù',  # 步
    0x6B66: 'wǔ',  # 武
    0x6B67: 'qí',  # 歧
    0x6B68: 'bù',  # 歨
    0x6B69: 'bù',  # 歩
    0x6B6A: 'wāi',  # 歪
    0x6B6B: 'jù',  # 歫
    0x6B6C: 'qián',  # 歬
    0x6B6D: 'zhì,chí',  # 歭
    0x6B6E: 'sè',  # 歮
    0x6B6F: 'chǐ',  # 歯
    0x6B70: 'sè,shà',  # 歰
    0x6B71: 'zhǒng',  # 歱
    0x6B72: 'suì',  # 歲
    0x6B73: 'suì',  # 歳
    0x6B74: 'lì',  # 歴
    0x6B75: 'zé',  # 歵
    0x6B76: 'yú',  # 歶
    0x6B77: 'lì',  # 歷
    0x6B78: 'guī',  # 歸
    0x6B79: 'dǎi',  # 歹
    0x6B7A: 'è',  # 歺
    0x6B7B: 'sǐ',  # 死
    0x6B7C: 'jiān',  # 歼
    0x6B7D: 'zhé',  # 歽
    0x6B7E: 'mò,wěn',  # 歾
    0x6B7F: 'mò',  # 歿
    0x6B80: 'yāo',  # 殀
    0x6B81: 'mò',  # 殁
    0x6B82: 'cú',  # 殂
    0x6B83: 'yāng',  # 殃
    0x6B84: 'tiǎn',  # 殄
    0x6B85: 'shēng',  # 殅
    0x6B86: 'dài',  # 殆
    0x6B87: 'shāng',  # 殇
    0x6B88: 'xù',  # 殈
    0x6B89: 'xùn',  # 殉
    0x6B8A: 'shū',  # 殊
    0x6B8B: 'cán',  # 残
    0x6B8C: 'jǐng',  # 殌
    0x6B8D: 'piǎo',  # 殍
    0x6B8E: 'qià',  # 殎
    0x6B8F: 'qiú',  # 殏
    0x6B90: 'sù',  # 殐
    0x6B91: 'qíng,jìng',  # 殑
    0x6B92: 'yǔn',  # 殒
    0x6B93: 'liàn',  # 殓
    0x6B94: 'yì',  # 殔
    0x6B95: 'fǒu,bó',  # 殕
    0x6B96: 'zhí,shi',  # 殖
    0x6B97: 'yè,yān,yàn',  # 殗
    0x6B98: 'cán',  # 殘
    0x6B99: 'hūn,mèi',  # 殙
    0x6B9A: 'dān',  # 殚
    0x6B9B: 'jí',  # 殛
    0x6B9C: 'dié',  # 殜
    0x6B9D: 'zhēn',  # 殝
    0x6B9E: 'yǔn',  # 殞
    0x6B9F: 'wēn',  # 殟
    0x6BA0: 'chòu',  # 殠
    0x6BA1: 'bìn',  # 殡
    0x6BA2: 'tì',  # 殢
    0x6BA3: 'jìn',  # 殣
    0x6BA4: 'shāng',  # 殤
    0x6BA5: 'yín',  # 殥
    0x6BA6: 'chī',  # 殦
    0x6BA7: 'jiù',  # 殧
    0x6BA8: 'kuì,huì',  # 殨
    0x6BA9: 'cuàn',  # 殩
    0x6BAA: 'yì',  # 殪
    0x6BAB: 'dān',  # 殫
    0x6BAC: 'dù',  # 殬
    0x6BAD: 'jiāng',  # 殭
    0x6BAE: 'liàn',  # 殮
    0x6BAF: 'bìn',  # 殯
    0x6BB0: 'dú',  # 殰
    0x6BB1: 'jiān',  # 殱
    0x6BB2: 'jiān',  # 殲
    0x6BB3: 'shū',  # 殳
    0x6BB4: 'ōu',  # 殴
    0x6BB5: 'duàn',  # 段
    0x6BB6: 'zhù',  # 殶
    0x6BB7: 'yīn,yān,yǐn',  # 殷
    0x6BB8: 'qìng,kēng,shēng',  # 殸
    0x6BB9: 'yì',  # 殹
    0x6BBA: 'shā',  # 殺
    0x6BBB: 'ké,qiào',  # 殻
    0x6BBC: 'ké,qiào',  # 殼
    0x6BBD: 'xiáo,yáo,xiào',  # 殽
    0x6BBE: 'xùn',  # 殾
    0x6BBF: 'diàn',  # 殿
    0x6BC0: 'huǐ',  # 毀
    0x6BC1: 'huǐ',  # 毁
    0x6BC2: 'gǔ',  # 毂
    0x6BC3: 'qiāo',  # 毃
    0x6BC4: 'jī',  # 毄
    0x6BC5: 'yì',  # 毅
    0x6BC6: 'ōu',  # 毆
    0x6BC7: 'huǐ',  # 毇
    0x6BC8: 'duàn',  # 毈
    0x6BC9: 'yī',  # 毉
    0x6BCA: 'xiāo',  # 毊
    0x6BCB: 'wú',  # 毋
    0x6BCC: 'guàn,wān',  # 毌
    0x6BCD: 'mǔ',  # 母
    0x6BCE: 'měi',  # 毎
    0x6BCF: 'měi',  # 每
    0x6BD0: 'ǎi',  # 毐
    0x6BD1: 'jiě',  # 毑
    0x6BD2: 'dú,dài',  # 毒
    0x6BD3: 'yù',  # 毓
    0x6BD4: 'bǐ',  # 比
    0x6BD5: 'bì',  # 毕
    0x6BD6: 'bì',  # 毖
    0x6BD7: 'pí',  # 毗
    0x6BD8: 'pí',  # 毘
    0x6BD9: 'bì',  # 毙
    0x6BDA: 'chán',  # 毚
    0x6BDB: 'máo',  # 毛
    0x6BDC: 'háo',  # 毜
    0x6BDD: 'cǎi',  # 毝
    0x6BDE: 'bǐ',  # 毞
    0x6BDF: 'liě',  # 毟
    0x6BE0: 'jiā',  # 毠
    0x6BE1: 'zhān',  # 毡
    0x6BE2: 'sāi',  # 毢
    0x6BE3: 'mù',  # 毣
    0x6BE4: 'tuò',  # 毤
    0x6BE5: 'xún,xùn',  # 毥
    0x6BE6: 'ěr',  # 毦
    0x6BE7: 'róng',  # 毧
    0x6BE8: 'xiǎn',  # 毨
    0x6BE9: 'jū',  # 毩
    0x6BEA: 'mú',  # 毪
    0x6BEB: 'háo',  # 毫
    0x6BEC: 'qiú',  # 毬
    0x6BED: 'dòu,nuò',  # 毭
    0x6BEE: 'shā',  # 毮
    0x6BEF: 'tǎn',  # 毯
    0x6BF0: 'péi',  # 毰
    0x6BF1: 'jū',  # 毱
    0x6BF2: 'duō',  # 毲
    0x6BF3: 'cuì',  # 毳
    0x6BF4: 'bī',  # 毴
    0x6BF5: 'sān',  # 毵
    0x6BF6: 'sān',  # 毶
    0x6BF7: 'mào',  # 毷
    0x6BF8: 'sāi,suī',  # 毸
    0x6BF9: 'shū',  # 毹
    0x6BFA: 'shū',  # 毺
    0x6BFB: 'tuò',  # 毻
    0x6BFC: 'hé',  # 毼
    0x6BFD: 'jiàn',  # 毽
    0x6BFE: 'tà',  # 毾
    0x6BFF: 'sān',  # 毿
    0x6C00: 'lǘ',  # 氀
    0x6C01: 'mú',  # 氁
    0x6C02: 'máo',  # 氂
    0x6C03: 'tóng',  # 氃
    0x6C04: 'rǒng',  # 氄
    0x6C05: 'chǎng',  # 氅
    0x6C06: 'pǔ',  # 氆
    0x6C07: 'lǔ',  # 氇
    0x6C08: 'zhān',  # 氈
    0x6C09: 'sào',  # 氉
    0x6C0A: 'zhān',  # 氊
    0x6C0B: 'méng',  # 氋
    0x6C0C: 'lǔ',  # 氌
    0x6C0D: 'qú',  # 氍
    0x6C0E: 'dié',  # 氎
    0x6C0F: 'shì,zhī',  # 氏
    0x6C10: 'dī,dǐ',  # 氐
    0x6C11: 'mín',  # 民
    0x6C12: 'jué',  # 氒
    0x6C13: 'méng,máng',  # 氓
    0x6C14: 'qì',  # 气
    0x6C15: 'piē',  # 氕
    0x6C16: 'nǎi',  # 氖
    0x6C17: 'qì',  # 気
    0x6C18: 'dāo',  # 氘
    0x6C19: 'xiān',  # 氙
    0x6C1A: 'chuān',  # 氚
    0x6C1B: 'fēn',  # 氛
    0x6C1C: 'yáng,rì',  # 氜
    0x6C1D: 'nèi',  # 氝
    0x6C1E: 'nèi',  # 氞
    0x6C1F: 'fú',  # 氟
    0x6C20: 'shēn',  # 氠
    0x6C21: 'dōng',  # 氡
    0x6C22: 'qīng',  # 氢
    0x6C23: 'qì',  # 氣
    0x6C24: 'yīn',  # 氤
    0x6C25: 'xī',  # 氥
    0x6C26: 'hài',  # 氦
    0x6C27: 'yǎng',  # 氧
    0x6C28: 'ān',  # 氨
    0x6C29: 'yà',  # 氩
    0x6C2A: 'kè',  # 氪
    0x6C2B: 'qīng',  # 氫
    0x6C2C: 'yà',  # 氬
    0x6C2D: 'dōng',  # 氭
    0x6C2E: 'dàn',  # 氮
    0x6C2F: 'lǜ',  # 氯
    0x6C30: 'qíng',  # 氰
    0x6C31: 'yǎng',  # 氱
    0x6C32: 'yūn',  # 氲
    0x6C33: 'yūn',  # 氳
    0x6C34: 'shuǐ',  # 水
    0x6C35: 'shuǐ',  # 氵
    0x6C36: 'zhěng,chéng,zhèng',  # 氶
    0x6C37: 'bīng',  # 氷
    0x6C38: 'yǒng',  # 永
    0x6C39: 'dàng',  # 氹
    0x6C3A: 'shuǐ',  # 氺
    0x6C3B: 'lè',  # 氻
    0x6C3C: 'nì',  # 氼
    0x6C3D: 'tǔn',  # 氽
    0x6C3E: 'fàn',  # 氾
    0x6C3F: 'guǐ,jiǔ',  # 氿
    0x6C40: 'tīng',  # 汀
    0x6C41: 'zhī',  # 汁
    0x6C42: 'qiú',  # 求
    0x6C43: 'bīn,pà,pā',  # 汃
    0x6C44: 'zè',  # 汄
    0x6C45: 'miǎn',  # 汅
    0x6C46: 'cuān',  # 汆
    0x6C47: 'huì',  # 汇
    0x6C48: 'diāo',  # 汈
    0x6C49: 'hàn',  # 汉
    0x6C4A: 'chà',  # 汊
    0x6C4B: 'zhuó,què',  # 汋
    0x6C4C: 'chuàn',  # 汌
    0x6C4D: 'wán',  # 汍
    0x6C4E: 'fàn',  # 汎
    0x6C4F: 'tài,dà',  # 汏
    0x6C50: 'xī',  # 汐
    0x6C51: 'tuō',  # 汑
    0x6C52: 'máng',  # 汒
    0x6C53: 'qiú',  # 汓
    0x6C54: 'qì',  # 汔
    0x6C55: 'shàn',  # 汕
    0x6C56: 'pìn',  # 汖
    0x6C57: 'hàn,hán',  # 汗
    0x6C58: 'qiān',  # 汘
    0x6C59: 'wū',  # 汙
    0x6C5A: 'wū',  # 汚
    0x6C5B: 'xùn',  # 汛
    0x6C5C: 'sì',  # 汜
    0x6C5D: 'rǔ',  # 汝
    0x6C5E: 'gǒng',  # 汞
    0x6C5F: 'jiāng',  # 江
    0x6C60: 'chí',  # 池
    0x6C61: 'wū',  # 污
    0x6C62: 'tu',  # 汢
    0x6C63: 'jiǔ',  # 汣
    0x6C64: 'tāng,shāng',  # 汤
    0x6C65: 'zhī,jì',  # 汥
    0x6C66: 'zhǐ',  # 汦
    0x6C67: 'qiān',  # 汧
    0x6C68: 'mì',  # 汨
    0x6C69: 'gǔ,yù',  # 汩
    0x6C6A: 'wāng',  # 汪
    0x6C6B: 'jǐng',  # 汫
    0x6C6C: 'jǐng',  # 汬
    0x6C6D: 'ruì',  # 汭
    0x6C6E: 'jūn',  # 汮
    0x6C6F: 'hóng',  # 汯
    0x6C70: 'tài',  # 汰
    0x6C71: 'tài',  # 汱
    0x6C72: 'jí',  # 汲
    0x6C73: 'biàn',  # 汳
    0x6C74: 'biàn',  # 汴
    0x6C75: 'gàn,hán,cén',  # 汵
    0x6C76: 'wèn,mén',  # 汶
    0x6C77: 'zhōng',  # 汷
    0x6C78: 'fāng,pāng',  # 汸
    0x6C79: 'xiōng',  # 汹
    0x6C7A: 'jué',  # 決
    0x6C7B: 'hǔ,huǎng',  # 汻
    0x6C7C: 'niú,yóu',  # 汼
    0x6C7D: 'qì',  # 汽
    0x6C7E: 'fén',  # 汾
    0x6C7F: 'xù',  # 汿
    0x6C80: 'xù',  # 沀
    0x6C81: 'qìn',  # 沁
    0x6C82: 'yí',  # 沂
    0x6C83: 'wò',  # 沃
    0x6C84: 'yún',  # 沄
    0x6C85: 'yuán',  # 沅
    0x6C86: 'hàng',  # 沆
    0x6C87: 'yǎn',  # 沇
    0x6C88: 'shěn,chén',  # 沈
    0x6C89: 'chén',  # 沉
    0x6C8A: 'dàn',  # 沊
    0x6C8B: 'yóu',  # 沋
    0x6C8C: 'dùn',  # 沌
    0x6C8D: 'hù',  # 沍
    0x6C8E: 'huò',  # 沎
    0x6C8F: 'qī',  # 沏
    0x6C90: 'mù',  # 沐
    0x6C91: 'nǜ,niǔ',  # 沑
    0x6C92: 'méi,mò',  # 沒
    0x6C93: 'tà,dá',  # 沓
    0x6C94: 'miǎn',  # 沔
    0x6C95: 'mì,wù',  # 沕
    0x6C96: 'chōng',  # 沖
    0x6C97: 'hóng,pāng',  # 沗
    0x6C98: 'bǐ',  # 沘
    0x6C99: 'shā,shà',  # 沙
    0x6C9A: 'zhǐ',  # 沚
    0x6C9B: 'pèi',  # 沛
    0x6C9C: 'pàn',  # 沜
    0x6C9D: 'zhuǐ,zǐ',  # 沝
    0x6C9E: 'zā',  # 沞
    0x6C9F: 'gōu',  # 沟
    0x6CA0: 'pài',  # 沠
    0x6CA1: 'méi,mò',  # 没
    0x6CA2: 'zé',  # 沢
    0x6CA3: 'fēng',  # 沣
    0x6CA4: 'òu,ōu',  # 沤
    0x6CA5: 'lì',  # 沥
    0x6CA6: 'lún',  # 沦
    0x6CA7: 'cāng',  # 沧
    0x6CA8: 'fēng',  # 沨
    0x6CA9: 'wéi',  # 沩
    0x6CAA: 'hù',  # 沪
    0x6CAB: 'mò',  # 沫
    0x6CAC: 'mèi',  # 沬
    0x6CAD: 'shù',  # 沭
    0x6CAE: 'jǔ,jù',  # 沮
    0x6CAF: 'zá',  # 沯
    0x6CB0: 'tuō,duó',  # 沰
    0x6CB1: 'tuó',  # 沱
    0x6CB2: 'tuó,duò',  # 沲
    0x6CB3: 'hé',  # 河
    0x6CB4: 'lì',  # 沴
    0x6CB5: 'mǐ,lì',  # 沵
    0x6CB6: 'yí,chí',  # 沶
    0x6CB7: 'fā',  # 沷
    0x6CB8: 'fèi',  # 沸
    0x6CB9: 'yóu',  # 油
    0x6CBA: 'tián',  # 沺
    0x6CBB: 'zhì',  # 治
    0x6CBC: 'zhǎo',  # 沼
    0x6CBD: 'gū',  # 沽
    0x6CBE: 'zhān',  # 沾
    0x6CBF: 'yán',  # 沿
    0x6CC0: 'sī',  # 泀
    0x6CC1: 'kuàng',  # 況
    0x6CC2: 'jiǒng',  # 泂
    0x6CC3: 'jū',  # 泃
    0x6CC4: 'xiè,yì',  # 泄
    0x6CC5: 'qiú',  # 泅
    0x6CC6: 'yì,dié',  # 泆
    0x6CC7: 'jiā',  # 泇
    0x6CC8: 'zhōng',  # 泈
    0x6CC9: 'quán',  # 泉
    0x6CCA: 'bó,pō',  # 泊
    0x6CCB: 'huì',  # 泋
    0x6CCC: 'mì,bì',  # 泌
    0x6CCD: 'bēn,bèn',  # 泍
    0x6CCE: 'zé',  # 泎
    0x6CCF: 'chù,shè',  # 泏
    0x6CD0: 'lè',  # 泐
    0x6CD1: 'yōu,yòu,āo',  # 泑
    0x6CD2: 'gū',  # 泒
    0x6CD3: 'hóng',  # 泓
    0x6CD4: 'gān',  # 泔
    0x6CD5: 'fǎ',  # 法
    0x6CD6: 'mǎo',  # 泖
    0x6CD7: 'sì',  # 泗
    0x6CD8: 'hū',  # 泘
    0x6CD9: 'pēng,píng',  # 泙
    0x6CDA: 'cǐ',  # 泚
    0x6CDB: 'fàn',  # 泛
    0x6CDC: 'zhī',  # 泜
    0x6CDD: 'sù',  # 泝
    0x6CDE: 'nìng',  # 泞
    0x6CDF: 'chēng',  # 泟
    0x6CE0: 'líng',  # 泠
    0x6CE1: 'pào,pāo',  # 泡
    0x6CE2: 'bō',  # 波
    0x6CE3: 'qì',  # 泣
    0x6CE4: 'sì',  # 泤
    0x6CE5: 'ní,nì',  # 泥
    0x6CE6: 'jú',  # 泦
    0x6CE7: 'yuè,sà',  # 泧
    0x6CE8: 'zhù',  # 注
    0x6CE9: 'shēng',  # 泩
    0x6CEA: 'lèi',  # 泪
    0x6CEB: 'xuàn',  # 泫
    0x6CEC: 'jué,xuè',  # 泬
    0x6CED: 'fú',  # 泭
    0x6CEE: 'pàn',  # 泮
    0x6CEF: 'mǐn',  # 泯
    0x6CF0: 'tài',  # 泰
    0x6CF1: 'yāng',  # 泱
    0x6CF2: 'jǐ',  # 泲
    0x6CF3: 'yǒng',  # 泳
    0x6CF4: 'guàn',  # 泴
    0x6CF5: 'bèng',  # 泵
    0x6CF6: 'xué',  # 泶
    0x6CF7: 'lóng,shuāng',  # 泷
    0x6CF8: 'lú',  # 泸
    0x6CF9: 'dàn',  # 泹
    0x6CFA: 'luò,pō',  # 泺
    0x6CFB: 'xiè',  # 泻
    0x6CFC: 'pō',  # 泼
    0x6CFD: 'zé,shì',  # 泽
    0x6CFE: 'jīng',  # 泾
    0x6CFF: 'yín',  # 泿
    0x6D00: 'pán',  # 洀
    0x6D01: 'jié',  # 洁
    0x6D02: 'yè',  # 洂
    0x6D03: 'huī',  # 洃
    0x6D04: 'huí',  # 洄
    0x6D05: 'zài',  # 洅
    0x6D06: 'chéng',  # 洆
    0x6D07: 'yīn',  # 洇
    0x6D08: 'wéi',  # 洈
    0x6D09: 'hòu',  # 洉
    0x6D0A: 'jiàn',  # 洊
    0x6D0B: 'yáng',  # 洋
    0x6D0C: 'liè',  # 洌
    0x6D0D: 'sì',  # 洍
    0x6D0E: 'jì',  # 洎
    0x6D0F: 'ér',  # 洏
    0x6D10: 'xíng',  # 洐
    0x6D11: 'fú,fù',  # 洑
    0x6D12: 'sǎ,xǐ',  # 洒
    0x6D13: 'sè,qì,zì',  # 洓
    0x6D14: 'zhǐ',  # 洔
    0x6D15: 'yìn',  # 洕
    0x6D16: 'wú',  # 洖
    0x6D17: 'xǐ,xiǎn',  # 洗
    0x6D18: 'kǎo,kào',  # 洘
    0x6D19: 'zhū',  # 洙
    0x6D1A: 'jiàng',  # 洚
    0x6D1B: 'luò',  # 洛
    0x6D1C: 'luò',  # 洜
    0x6D1D: 'àn,yàn,è',  # 洝
    0x6D1E: 'dòng',  # 洞
    0x6D1F: 'yí',  # 洟
    0x6D20: 'sì',  # 洠
    0x6D21: 'lěi,lèi',  # 洡
    0x6D22: 'yī',  # 洢
    0x6D23: 'mǐ',  # 洣
    0x6D24: 'quán',  # 洤
    0x6D25: 'jīn',  # 津
    0x6D26: 'pò',  # 洦
    0x6D27: 'wěi',  # 洧
    0x6D28: 'xiáo',  # 洨
    0x6D29: 'xiè',  # 洩
    0x6D2A: 'hóng',  # 洪
    0x6D2B: 'xù',  # 洫
    0x6D2C: 'sù,shuò',  # 洬
    0x6D2D: 'kuāng',  # 洭
    0x6D2E: 'táo',  # 洮
    0x6D2F: 'qiè,jié',  # 洯
    0x6D30: 'jù',  # 洰
    0x6D31: 'ěr',  # 洱
    0x6D32: 'zhōu',  # 洲
    0x6D33: 'rù',  # 洳
    0x6D34: 'píng',  # 洴
    0x6D35: 'xún',  # 洵
    0x6D36: 'xiōng',  # 洶
    0x6D37: 'zhì',  # 洷
    0x6D38: 'guāng',  # 洸
    0x6D39: 'huán',  # 洹
    0x6D3A: 'míng',  # 洺
    0x6D3B: 'huó',  # 活
    0x6D3C: 'wā',  # 洼
    0x6D3D: 'qià',  # 洽
    0x6D3E: 'pài',  # 派
    0x6D3F: 'wū',  # 洿
    0x6D40: 'qū',  # 浀
    0x6D41: 'liú',  # 流
    0x6D42: 'yì',  # 浂
    0x6D43: 'jiā',  # 浃
    0x6D44: 'jìng',  # 浄
    0x6D45: 'qiǎn,jiān',  # 浅
    0x6D46: 'jiāng,jiàng',  # 浆
    0x6D47: 'jiāo',  # 浇
    0x6D48: 'zhēn',  # 浈
    0x6D49: 'shī',  # 浉
    0x6D4A: 'zhuó',  # 浊
    0x6D4B: 'cè',  # 测
    0x6D4C: 'fá',  # 浌
    0x6D4D: 'kuài,huì',  # 浍
    0x6D4E: 'jì,jǐ',  # 济
    0x6D4F: 'liú',  # 浏
    0x6D50: 'chǎn',  # 浐
    0x6D51: 'hún',  # 浑
    0x6D52: 'hǔ,xǔ',  # 浒
    0x6D53: 'nóng',  # 浓
    0x6D54: 'xún',  # 浔
    0x6D55: 'jìn',  # 浕
    0x6D56: 'liè',  # 浖
    0x6D57: 'qiú',  # 浗
    0x6D58: 'wěi',  # 浘
    0x6D59: 'zhè',  # 浙
    0x6D5A: 'jùn,xùn',  # 浚
    0x6D5B: 'hán',  # 浛
    0x6D5C: 'bāng',  # 浜
    0x6D5D: 'máng',  # 浝
    0x6D5E: 'zhuó',  # 浞
    0x6D5F: 'yōu,dí',  # 浟
    0x6D60: 'xī',  # 浠
    0x6D61: 'bó',  # 浡
    0x6D62: 'dòu',  # 浢
    0x6D63: 'huàn',  # 浣
    0x6D64: 'hóng',  # 浤
    0x6D65: 'yì',  # 浥
    0x6D66: 'pǔ',  # 浦
    0x6D67: 'yǐng,chéng,yíng',  # 浧
    0x6D68: 'lǎn',  # 浨
    0x6D69: 'hào',  # 浩
    0x6D6A: 'làng',  # 浪
    0x6D6B: 'hǎn',  # 浫
    0x6D6C: 'lǐ',  # 浬
    0x6D6D: 'gēng',  # 浭
    0x6D6E: 'fú',  # 浮
    0x6D6F: 'wú',  # 浯
    0x6D70: 'lì',  # 浰
    0x6D71: 'chún',  # 浱
    0x6D72: 'féng,hóng',  # 浲
    0x6D73: 'yì',  # 浳
    0x6D74: 'yù',  # 浴
    0x6D75: 'tóng',  # 浵
    0x6D76: 'láo',  # 浶
    0x6D77: 'hǎi',  # 海
    0x6D78: 'jìn',  # 浸
    0x6D79: 'jiā',  # 浹
    0x6D7A: 'chōng',  # 浺
    0x6D7B: 'jiǒng,jiōng',  # 浻
    0x6D7C: 'měi',  # 浼
    0x6D7D: 'suī,něi',  # 浽
    0x6D7E: 'chēng',  # 浾
    0x6D7F: 'pèi',  # 浿
    0x6D80: 'xiàn',  # 涀
    0x6D81: 'shèn',  # 涁
    0x6D82: 'tú',  # 涂
    0x6D83: 'kùn',  # 涃
    0x6D84: 'pīng',  # 涄
    0x6D85: 'niè',  # 涅
    0x6D86: 'hàn',  # 涆
    0x6D87: 'jīng',  # 涇
    0x6D88: 'xiāo',  # 消
    0x6D89: 'shè',  # 涉
    0x6D8A: 'niǎn',  # 涊
    0x6D8B: 'tū',  # 涋
    0x6D8C: 'yǒng,chōng',  # 涌
    0x6D8D: 'xiào',  # 涍
    0x6D8E: 'xián',  # 涎
    0x6D8F: 'tǐng',  # 涏
    0x6D90: 'é',  # 涐
    0x6D91: 'sù',  # 涑
    0x6D92: 'tūn,yūn',  # 涒
    0x6D93: 'juān',  # 涓
    0x6D94: 'cén',  # 涔
    0x6D95: 'tì',  # 涕
    0x6D96: 'lì',  # 涖
    0x6D97: 'shuì',  # 涗
    0x6D98: 'sì',  # 涘
    0x6D99: 'lèi',  # 涙
    0x6D9A: 'shuì',  # 涚
    0x6D9B: 'tāo',  # 涛
    0x6D9C: 'dú',  # 涜
    0x6D9D: 'lào',  # 涝
    0x6D9E: 'lái',  # 涞
    0x6D9F: 'lián',  # 涟
    0x6DA0: 'wéi',  # 涠
    0x6DA1: 'wō,guō',  # 涡
    0x6DA2: 'yún',  # 涢
    0x6DA3: 'huàn',  # 涣
    0x6DA4: 'dí',  # 涤
    0x6DA5: 'hēng',  # 涥
    0x6DA6: 'rùn',  # 润
    0x6DA7: 'jiàn',  # 涧
    0x6DA8: 'zhǎng,zhàng',  # 涨
    0x6DA9: 'sè',  # 涩
    0x6DAA: 'fú',  # 涪
    0x6DAB: 'guān',  # 涫
    0x6DAC: 'xìng',  # 涬
    0x6DAD: 'shòu,tāo',  # 涭
    0x6DAE: 'shuàn',  # 涮
    0x6DAF: 'yá',  # 涯
    0x6DB0: 'chuò',  # 涰
    0x6DB1: 'zhàng',  # 涱
    0x6DB2: 'yè',  # 液
    0x6DB3: 'kōng,náng',  # 涳
    0x6DB4: 'wǎn,wò,yuān',  # 涴
    0x6DB5: 'hán',  # 涵
    0x6DB6: 'tuō,tuò',  # 涶
    0x6DB7: 'dōng',  # 涷
    0x6DB8: 'hé',  # 涸
    0x6DB9: 'wō',  # 涹
    0x6DBA: 'jū',  # 涺
    0x6DBB: 'shè',  # 涻
    0x6DBC: 'liáng,liàng',  # 涼
    0x6DBD: 'hūn',  # 涽
    0x6DBE: 'tà',  # 涾
    0x6DBF: 'zhuō',  # 涿
    0x6DC0: 'diàn',  # 淀
    0x6DC1: 'qiè,jí',  # 淁
    0x6DC2: 'dé',  # 淂
    0x6DC3: 'juàn',  # 淃
    0x6DC4: 'zī',  # 淄
    0x6DC5: 'xī',  # 淅
    0x6DC6: 'xiáo',  # 淆
    0x6DC7: 'qí',  # 淇
    0x6DC8: 'gǔ',  # 淈
    0x6DC9: 'guǒ,guàn',  # 淉
    0x6DCA: 'yān',  # 淊
    0x6DCB: 'lín,lìn',  # 淋
    0x6DCC: 'tǎng,chǎng',  # 淌
    0x6DCD: 'zhōu',  # 淍
    0x6DCE: 'pěng',  # 淎
    0x6DCF: 'hào',  # 淏
    0x6DD0: 'chāng',  # 淐
    0x6DD1: 'shū',  # 淑
    0x6DD2: 'qī',  # 淒
    0x6DD3: 'fāng',  # 淓
    0x6DD4: 'zhí',  # 淔
    0x6DD5: 'lù',  # 淕
    0x6DD6: 'nào,chuò,zhuō',  # 淖
    0x6DD7: 'jú',  # 淗
    0x6DD8: 'táo',  # 淘
    0x6DD9: 'cóng',  # 淙
    0x6DDA: 'lèi',  # 淚
    0x6DDB: 'zhè',  # 淛
    0x6DDC: 'píng,péng',  # 淜
    0x6DDD: 'féi',  # 淝
    0x6DDE: 'sōng',  # 淞
    0x6DDF: 'tiǎn',  # 淟
    0x6DE0: 'pì,pèi',  # 淠
    0x6DE1: 'dàn',  # 淡
    0x6DE2: 'yù,xù',  # 淢
    0x6DE3: 'ní',  # 淣
    0x6DE4: 'yū',  # 淤
    0x6DE5: 'lù',  # 淥
    0x6DE6: 'gàn',  # 淦
    0x6DE7: 'mì',  # 淧
    0x6DE8: 'jìng,chēng',  # 淨
    0x6DE9: 'líng',  # 淩
    0x6DEA: 'lún',  # 淪
    0x6DEB: 'yín',  # 淫
    0x6DEC: 'cuì',  # 淬
    0x6DED: 'qú',  # 淭
    0x6DEE: 'huái',  # 淮
    0x6DEF: 'yù',  # 淯
    0x6DF0: 'niǎn,shěn',  # 淰
    0x6DF1: 'shēn',  # 深
    0x6DF2: 'biāo,hǔ',  # 淲
    0x6DF3: 'chún,zhūn',  # 淳
    0x6DF4: 'hū',  # 淴
    0x6DF5: 'yuān',  # 淵
    0x6DF6: 'lái',  # 淶
    0x6DF7: 'hùn,hún',  # 混
    0x6DF8: 'qīng',  # 淸
    0x6DF9: 'yān',  # 淹
    0x6DFA: 'qiǎn',  # 淺
    0x6DFB: 'tiān',  # 添
    0x6DFC: 'miǎo',  # 淼
    0x6DFD: 'zhǐ',  # 淽
    0x6DFE: 'yǐn',  # 淾
    0x6DFF: 'bó',  # 淿
    0x6E00: 'bèn',  # 渀
    0x6E01: 'yuān',  # 渁
    0x6E02: 'wèn,mín',  # 渂
    0x6E03: 'ruò,rè,luò',  # 渃
    0x6E04: 'fēi',  # 渄
    0x6E05: 'qīng',  # 清
    0x6E06: 'yuān',  # 渆
    0x6E07: 'kě',  # 渇
    0x6E08: 'jì,jǐ',  # 済
    0x6E09: 'shè',  # 渉
    0x6E0A: 'yuān',  # 渊
    0x6E0B: 'sè',  # 渋
    0x6E0C: 'lù',  # 渌
    0x6E0D: 'zì',  # 渍
    0x6E0E: 'dú,dòu',  # 渎
    0x6E0F: 'yī',  # 渏
    0x6E10: 'jiàn,jiān',  # 渐
    0x6E11: 'miǎn,shéng',  # 渑
    0x6E12: 'pài',  # 渒
    0x6E13: 'xī',  # 渓
    0x6E14: 'yú',  # 渔
    0x6E15: 'yuān',  # 渕
    0x6E16: 'shěn',  # 渖
    0x6E17: 'shèn',  # 渗
    0x6E18: 'róu',  # 渘
    0x6E19: 'huàn',  # 渙
    0x6E1A: 'zhǔ',  # 渚
    0x6E1B: 'jiǎn',  # 減
    0x6E1C: 'nuǎn,nuán',  # 渜
    0x6E1D: 'yú',  # 渝
    0x6E1E: 'qiú,wù',  # 渞
    0x6E1F: 'tíng,tīng',  # 渟
    0x6E20: 'qú,jù',  # 渠
    0x6E21: 'dù',  # 渡
    0x6E22: 'fēng',  # 渢
    0x6E23: 'zhā',  # 渣
    0x6E24: 'bó',  # 渤
    0x6E25: 'wò',  # 渥
    0x6E26: 'wō,guō',  # 渦
    0x6E27: 'tí,dī,dì',  # 渧
    0x6E28: 'wěi',  # 渨
    0x6E29: 'wēn',  # 温
    0x6E2A: 'rú',  # 渪
    0x6E2B: 'xiè',  # 渫
    0x6E2C: 'cè',  # 測
    0x6E2D: 'wèi',  # 渭
    0x6E2E: 'hé',  # 渮
    0x6E2F: 'gǎng,jiǎng',  # 港
    0x6E30: 'yān,yǎn',  # 渰
    0x6E31: 'hóng',  # 渱
    0x6E32: 'xuàn',  # 渲
    0x6E33: 'mǐ',  # 渳
    0x6E34: 'kě',  # 渴
    0x6E35: 'máo',  # 渵
    0x6E36: 'yīng',  # 渶
    0x6E37: 'yǎn',  # 渷
    0x6E38: 'yóu',  # 游
    0x6E39: 'hōng,qìng',  # 渹
    0x6E3A: 'miǎo',  # 渺
    0x6E3B: 'shěng',  # 渻
    0x6E3C: 'měi',  # 渼
    0x6E3D: 'zāi',  # 渽
    0x6E3E: 'hún',  # 渾
    0x6E3F: 'nài',  # 渿
    0x6E40: 'guǐ',  # 湀
    0x6E41: 'chì',  # 湁
    0x6E42: 'è',  # 湂
    0x6E43: 'pài',  # 湃
    0x6E44: 'méi',  # 湄
    0x6E45: 'liàn',  # 湅
    0x6E46: 'qì',  # 湆
    0x6E47: 'qì',  # 湇
    0x6E48: 'méi',  # 湈
    0x6E49: 'tián',  # 湉
    0x6E4A: 'còu',  # 湊
    0x6E4B: 'wéi',  # 湋
    0x6E4C: 'cān',  # 湌
    0x6E4D: 'tuān',  # 湍
    0x6E4E: 'miǎn',  # 湎
    0x6E4F: 'huì,mǐn,xū',  # 湏
    0x6E50: 'pò',  # 湐
    0x6E51: 'xǔ,xū',  # 湑
    0x6E52: 'jí',  # 湒
    0x6E53: 'pén',  # 湓
    0x6E54: 'jiān',  # 湔
    0x6E55: 'jiǎn',  # 湕
    0x6E56: 'hú',  # 湖
    0x6E57: 'fèng',  # 湗
    0x6E58: 'xiāng',  # 湘
    0x6E59: 'yì',  # 湙
    0x6E5A: 'yìn',  # 湚
    0x6E5B: 'zhàn',  # 湛
    0x6E5C: 'shí',  # 湜
    0x6E5D: 'jiē',  # 湝
    0x6E5E: 'zhēn',  # 湞
    0x6E5F: 'huáng',  # 湟
    0x6E60: 'tàn',  # 湠
    0x6E61: 'yú',  # 湡
    0x6E62: 'bì',  # 湢
    0x6E63: 'mǐn,hūn',  # 湣
    0x6E64: 'shī',  # 湤
    0x6E65: 'tū',  # 湥
    0x6E66: 'shēng',  # 湦
    0x6E67: 'yǒng',  # 湧
    0x6E68: 'jú',  # 湨
    0x6E69: 'dòng',  # 湩
    0x6E6A: 'tuàn,nuǎn',  # 湪
    0x6E6B: 'qiū,jiǎo',  # 湫
    0x6E6C: 'qiū,jiǎo',  # 湬
    0x6E6D: 'qiú',  # 湭
    0x6E6E: 'yān,yīn',  # 湮
    0x6E6F: 'tāng,shāng',  # 湯
    0x6E70: 'lóng',  # 湰
    0x6E71: 'huò',  # 湱
    0x6E72: 'yuán',  # 湲
    0x6E73: 'nǎn',  # 湳
    0x6E74: 'bàn,pán',  # 湴
    0x6E75: 'yǒu',  # 湵
    0x6E76: 'quán',  # 湶
    0x6E77: 'zhuāng,hún',  # 湷
    0x6E78: 'liàng',  # 湸
    0x6E79: 'chán',  # 湹
    0x6E7A: 'xián',  # 湺
    0x6E7B: 'chún',  # 湻
    0x6E7C: 'niè',  # 湼
    0x6E7D: 'zī',  # 湽
    0x6E7E: 'wān',  # 湾
    0x6E7F: 'shī',  # 湿
    0x6E80: 'mǎn',  # 満
    0x6E81: 'yíng',  # 溁
    0x6E82: 'là',  # 溂
    0x6E83: 'kuì,huì',  # 溃
    0x6E84: 'féng,hóng',  # 溄
    0x6E85: 'jiàn,jiān',  # 溅
    0x6E86: 'xù',  # 溆
    0x6E87: 'lóu',  # 溇
    0x6E88: 'wéi',  # 溈
    0x6E89: 'gài',  # 溉
    0x6E8A: 'bō',  # 溊
    0x6E8B: 'yíng',  # 溋
    0x6E8C: 'pō',  # 溌
    0x6E8D: 'jìn',  # 溍
    0x6E8E: 'yàn,guì',  # 溎
    0x6E8F: 'táng',  # 溏
    0x6E90: 'yuán',  # 源
    0x6E91: 'suǒ',  # 溑
    0x6E92: 'yuán',  # 溒
    0x6E93: 'lián,liǎn,nián,xián,xiàn',  # 溓
    0x6E94: 'yǎo',  # 溔
    0x6E95: 'méng',  # 溕
    0x6E96: 'zhǔn',  # 準
    0x6E97: 'chéng',  # 溗
    0x6E98: 'kè',  # 溘
    0x6E99: 'tài',  # 溙
    0x6E9A: 'dá,tǎ',  # 溚
    0x6E9B: 'wā',  # 溛
    0x6E9C: 'liū,liù',  # 溜
    0x6E9D: 'gōu',  # 溝
    0x6E9E: 'sāo',  # 溞
    0x6E9F: 'míng',  # 溟
    0x6EA0: 'zhà',  # 溠
    0x6EA1: 'shí',  # 溡
    0x6EA2: 'yì',  # 溢
    0x6EA3: 'lùn',  # 溣
    0x6EA4: 'mǎ',  # 溤
    0x6EA5: 'pǔ',  # 溥
    0x6EA6: 'wēi',  # 溦
    0x6EA7: 'lì',  # 溧
    0x6EA8: 'zāi',  # 溨
    0x6EA9: 'wù',  # 溩
    0x6EAA: 'xī',  # 溪
    0x6EAB: 'wēn',  # 溫
    0x6EAC: 'qiāng',  # 溬
    0x6EAD: 'zé',  # 溭
    0x6EAE: 'shī',  # 溮
    0x6EAF: 'sù',  # 溯
    0x6EB0: 'ái',  # 溰
    0x6EB1: 'zhēn,qín',  # 溱
    0x6EB2: 'sōu',  # 溲
    0x6EB3: 'yún',  # 溳
    0x6EB4: 'xiù',  # 溴
    0x6EB5: 'yīn',  # 溵
    0x6EB6: 'róng',  # 溶
    0x6EB7: 'hùn',  # 溷
    0x6EB8: 'sù',  # 溸
    0x6EB9: 'suò',  # 溹
    0x6EBA: 'nì,niào',  # 溺
    0x6EBB: 'tā',  # 溻
    0x6EBC: 'shī',  # 溼
    0x6EBD: 'rù',  # 溽
    0x6EBE: 'āi',  # 溾
    0x6EBF: 'pàn',  # 溿
    0x6EC0: 'chù,xù',  # 滀
    0x6EC1: 'chú',  # 滁
    0x6EC2: 'pāng',  # 滂
    0x6EC3: 'wěng,wēng',  # 滃
    0x6EC4: 'cāng',  # 滄
    0x6EC5: 'miè',  # 滅
    0x6EC6: 'gé',  # 滆
    0x6EC7: 'diān',  # 滇
    0x6EC8: 'hào,xuè',  # 滈
    0x6EC9: 'huàng',  # 滉
    0x6ECA: 'qì,xì,xiē',  # 滊
    0x6ECB: 'zī',  # 滋
    0x6ECC: 'dí',  # 滌
    0x6ECD: 'zhì',  # 滍
    0x6ECE: 'xíng,yíng',  # 滎
    0x6ECF: 'fǔ',  # 滏
    0x6ED0: 'jié',  # 滐
    0x6ED1: 'huá',  # 滑
    0x6ED2: 'gē',  # 滒
    0x6ED3: 'zǐ',  # 滓
    0x6ED4: 'tāo',  # 滔
    0x6ED5: 'téng',  # 滕
    0x6ED6: 'suī',  # 滖
    0x6ED7: 'bì',  # 滗
    0x6ED8: 'jiào',  # 滘
    0x6ED9: 'huì',  # 滙
    0x6EDA: 'gǔn',  # 滚
    0x6EDB: 'yín',  # 滛
    0x6EDC: 'zé,hào',  # 滜
    0x6EDD: 'lóng',  # 滝
    0x6EDE: 'zhì',  # 滞
    0x6EDF: 'yàn',  # 滟
    0x6EE0: 'shè',  # 滠
    0x6EE1: 'mǎn',  # 满
    0x6EE2: 'yíng',  # 滢
    0x6EE3: 'chún',  # 滣
    0x6EE4: 'lǜ',  # 滤
    0x6EE5: 'làn',  # 滥
    0x6EE6: 'luán',  # 滦
    0x6EE7: 'yáo',  # 滧
    0x6EE8: 'bīn',  # 滨
    0x6EE9: 'tān',  # 滩
    0x6EEA: 'yù',  # 滪
    0x6EEB: 'xiǔ',  # 滫
    0x6EEC: 'hù',  # 滬
    0x6EED: 'bì',  # 滭
    0x6EEE: 'biāo',  # 滮
    0x6EEF: 'zhì',  # 滯
    0x6EF0: 'jiàng',  # 滰
    0x6EF1: 'kòu',  # 滱
    0x6EF2: 'shèn',  # 滲
    0x6EF3: 'shāng',  # 滳
    0x6EF4: 'dī',  # 滴
    0x6EF5: 'mì',  # 滵
    0x6EF6: 'áo',  # 滶
    0x6EF7: 'lǔ',  # 滷
    0x6EF8: 'hǔ,xǔ',  # 滸
    0x6EF9: 'hū',  # 滹
    0x6EFA: 'yōu',  # 滺
    0x6EFB: 'chǎn',  # 滻
    0x6EFC: 'fàn',  # 滼
    0x6EFD: 'yōng',  # 滽
    0x6EFE: 'gǔn',  # 滾
    0x6EFF: 'mǎn',  # 滿
    0x6F00: 'qǐng',  # 漀
    0x6F01: 'yú',  # 漁
    0x6F02: 'piāo,piǎo,piào',  # 漂
    0x6F03: 'jì',  # 漃
    0x6F04: 'yá',  # 漄
    0x6F05: 'cháo',  # 漅
    0x6F06: 'qī',  # 漆
    0x6F07: 'xǐ',  # 漇
    0x6F08: 'jì',  # 漈
    0x6F09: 'lù',  # 漉
    0x6F0A: 'lóu',  # 漊
    0x6F0B: 'lóng',  # 漋
    0x6F0C: 'jǐn',  # 漌
    0x6F0D: 'guó',  # 漍
    0x6F0E: 'cóng,sǒng',  # 漎
    0x6F0F: 'lòu',  # 漏
    0x6F10: 'zhí',  # 漐
    0x6F11: 'gài',  # 漑
    0x6F12: 'qiáng',  # 漒
    0x6F13: 'lí',  # 漓
    0x6F14: 'yǎn',  # 演
    0x6F15: 'cáo',  # 漕
    0x6F16: 'jiào',  # 漖
    0x6F17: 'cōng',  # 漗
    0x6F18: 'chún',  # 漘
    0x6F19: 'tuán,zhuān',  # 漙
    0x6F1A: 'òu,ōu',  # 漚
    0x6F1B: 'téng',  # 漛
    0x6F1C: 'yě',  # 漜
    0x6F1D: 'xí',  # 漝
    0x6F1E: 'mì',  # 漞
    0x6F1F: 'táng',  # 漟
    0x6F20: 'mò',  # 漠
    0x6F21: 'shāng',  # 漡
    0x6F22: 'hàn',  # 漢
    0x6F23: 'lián',  # 漣
    0x6F24: 'lǎn',  # 漤
    0x6F25: 'wā',  # 漥
    0x6F26: 'chí',  # 漦
    0x6F27: 'gān',  # 漧
    0x6F28: 'féng,péng',  # 漨
    0x6F29: 'xuán',  # 漩
    0x6F2A: 'yī',  # 漪
    0x6F2B: 'màn',  # 漫
    0x6F2C: 'zì',  # 漬
    0x6F2D: 'mǎng',  # 漭
    0x6F2E: 'kāng',  # 漮
    0x6F2F: 'luò,tà',  # 漯
    0x6F30: 'bēn,pēng',  # 漰
    0x6F31: 'shù',  # 漱
    0x6F32: 'zhǎng,zhàng',  # 漲
    0x6F33: 'zhāng',  # 漳
    0x6F34: 'chóng,zhuàng',  # 漴
    0x6F35: 'xù',  # 漵
    0x6F36: 'huàn',  # 漶
    0x6F37: 'huǒ,huò,kuò',  # 漷
    0x6F38: 'jiàn,jiān',  # 漸
    0x6F39: 'yān',  # 漹
    0x6F3A: 'shuǎng',  # 漺
    0x6F3B: 'liáo,liú',  # 漻
    0x6F3C: 'cuǐ,cuī',  # 漼
    0x6F3D: 'tí',  # 漽
    0x6F3E: 'yàng',  # 漾
    0x6F3F: 'jiāng,jiàng',  # 漿
    0x6F40: 'cóng,zǒng',  # 潀
    0x6F41: 'yǐng',  # 潁
    0x6F42: 'hóng',  # 潂
    0x6F43: 'xiǔ',  # 潃
    0x6F44: 'shù',  # 潄
    0x6F45: 'guàn',  # 潅
    0x6F46: 'yíng',  # 潆
    0x6F47: 'xiāo',  # 潇
    0x6F48: 'cóng,zōng',  # 潈
    0x6F49: 'kūn',  # 潉
    0x6F4A: 'xù',  # 潊
    0x6F4B: 'liàn',  # 潋
    0x6F4C: 'zhì',  # 潌
    0x6F4D: 'wéi',  # 潍
    0x6F4E: 'pì,piē',  # 潎
    0x6F4F: 'yù',  # 潏
    0x6F50: 'jiào,qiáo',  # 潐
    0x6F51: 'pō',  # 潑
    0x6F52: 'dàng,xiàng',  # 潒
    0x6F53: 'huì',  # 潓
    0x6F54: 'jié',  # 潔
    0x6F55: 'wǔ',  # 潕
    0x6F56: 'pá',  # 潖
    0x6F57: 'jí',  # 潗
    0x6F58: 'pān',  # 潘
    0x6F59: 'wéi',  # 潙
    0x6F5A: 'sù',  # 潚
    0x6F5B: 'qián',  # 潛
    0x6F5C: 'qián',  # 潜
    0x6F5D: 'xī,yà',  # 潝
    0x6F5E: 'lù',  # 潞
    0x6F5F: 'xì',  # 潟
    0x6F60: 'xùn',  # 潠
    0x6F61: 'dùn',  # 潡
    0x6F62: 'huáng,guāng',  # 潢
    0x6F63: 'mǐn',  # 潣
    0x6F64: 'rùn',  # 潤
    0x6F65: 'sù',  # 潥
    0x6F66: 'lǎo,lào,liáo',  # 潦
    0x6F67: 'zhēn',  # 潧
    0x6F68: 'cōng,zòng',  # 潨
    0x6F69: 'yì',  # 潩
    0x6F6A: 'zhí,zhì',  # 潪
    0x6F6B: 'wān',  # 潫
    0x6F6C: 'tān,shàn',  # 潬
    0x6F6D: 'tán',  # 潭
    0x6F6E: 'cháo',  # 潮
    0x6F6F: 'xún',  # 潯
    0x6F70: 'kuì,huì',  # 潰
    0x6F71: 'yē',  # 潱
    0x6F72: 'shào',  # 潲
    0x6F73: 'tú,zhā',  # 潳
    0x6F74: 'zhū',  # 潴
    0x6F75: 'sàn,sǎ',  # 潵
    0x6F76: 'hēi',  # 潶
    0x6F77: 'bì',  # 潷
    0x6F78: 'shān',  # 潸
    0x6F79: 'chán',  # 潹
    0x6F7A: 'chán',  # 潺
    0x6F7B: 'shǔ',  # 潻
    0x6F7C: 'tóng',  # 潼
    0x6F7D: 'pū',  # 潽
    0x6F7E: 'lín',  # 潾
    0x6F7F: 'wéi',  # 潿
    0x6F80: 'sè',  # 澀
    0x6F81: 'sè',  # 澁
    0x6F82: 'chéng',  # 澂
    0x6F83: 'jiǒng',  # 澃
    0x6F84: 'chéng,dèng',  # 澄
    0x6F85: 'huà',  # 澅
    0x6F86: 'jiāo',  # 澆
    0x6F87: 'lào',  # 澇
    0x6F88: 'chè',  # 澈
    0x6F89: 'gǎn',  # 澉
    0x6F8A: 'cūn,cún',  # 澊
    0x6F8B: 'jǐng',  # 澋
    0x6F8C: 'sī',  # 澌
    0x6F8D: 'shù,zhù',  # 澍
    0x6F8E: 'péng',  # 澎
    0x6F8F: 'hán',  # 澏
    0x6F90: 'yún',  # 澐
    0x6F91: 'liū,liù',  # 澑
    0x6F92: 'hòng,gǒng',  # 澒
    0x6F93: 'fú',  # 澓
    0x6F94: 'hào',  # 澔
    0x6F95: 'hé',  # 澕
    0x6F96: 'xián',  # 澖
    0x6F97: 'jiàn',  # 澗
    0x6F98: 'shān',  # 澘
    0x6F99: 'xì',  # 澙
    0x6F9A: 'ào,yù',  # 澚
    0x6F9B: 'lǔ',  # 澛
    0x6F9C: 'lán',  # 澜
    0x6F9D: 'nìng',  # 澝
    0x6F9E: 'yú',  # 澞
    0x6F9F: 'lǐn',  # 澟
    0x6FA0: 'miǎn,shéng',  # 澠
    0x6FA1: 'zǎo',  # 澡
    0x6FA2: 'dāng',  # 澢
    0x6FA3: 'huàn',  # 澣
    0x6FA4: 'zé,shì',  # 澤
    0x6FA5: 'xiè',  # 澥
    0x6FA6: 'yù',  # 澦
    0x6FA7: 'lǐ',  # 澧
    0x6FA8: 'shì',  # 澨
    0x6FA9: 'xué',  # 澩
    0x6FAA: 'líng',  # 澪
    0x6FAB: 'wàn,màn',  # 澫
    0x6FAC: 'zī',  # 澬
    0x6FAD: 'yōng,yǒng',  # 澭
    0x6FAE: 'kuài,huì',  # 澮
    0x6FAF: 'càn',  # 澯
    0x6FB0: 'liàn',  # 澰
    0x6FB1: 'diàn',  # 澱
    0x6FB2: 'yè',  # 澲
    0x6FB3: 'ào',  # 澳
    0x6FB4: 'huán',  # 澴
    0x6FB5: 'zhēn',  # 澵
    0x6FB6: 'chán',  # 澶
    0x6FB7: 'màn',  # 澷
    0x6FB8: 'gǎn',  # 澸
    0x6FB9: 'dàn,tán',  # 澹
    0x6FBA: 'yì',  # 澺
    0x6FBB: 'suì',  # 澻
    0x6FBC: 'pì',  # 澼
    0x6FBD: 'jù',  # 澽
    0x6FBE: 'tà',  # 澾
    0x6FBF: 'qín',  # 澿
    0x6FC0: 'jī',  # 激
    0x6FC1: 'zhuó',  # 濁
    0x6FC2: 'lián',  # 濂
    0x6FC3: 'nóng',  # 濃
    0x6FC4: 'guō,wō',  # 濄
    0x6FC5: 'jìn',  # 濅
    0x6FC6: 'fén,pēn',  # 濆
    0x6FC7: 'sè',  # 濇
    0x6FC8: 'jí,shà',  # 濈
    0x6FC9: 'suī',  # 濉
    0x6FCA: 'huì,huò',  # 濊
    0x6FCB: 'chǔ',  # 濋
    0x6FCC: 'tà',  # 濌
    0x6FCD: 'sōng',  # 濍
    0x6FCE: 'dǐng,tìng',  # 濎
    0x6FCF: 'sè',  # 濏
    0x6FD0: 'zhǔ',  # 濐
    0x6FD1: 'lài',  # 濑
    0x6FD2: 'bīn',  # 濒
    0x6FD3: 'lián',  # 濓
    0x6FD4: 'mǐ,nǐ',  # 濔
    0x6FD5: 'shī',  # 濕
    0x6FD6: 'shù',  # 濖
    0x6FD7: 'mì',  # 濗
    0x6FD8: 'nìng',  # 濘
    0x6FD9: 'yíng',  # 濙
    0x6FDA: 'yíng',  # 濚
    0x6FDB: 'méng',  # 濛
    0x6FDC: 'jìn',  # 濜
    0x6FDD: 'qí',  # 濝
    0x6FDE: 'bì,pì',  # 濞
    0x6FDF: 'jì,jǐ',  # 濟
    0x6FE0: 'háo',  # 濠
    0x6FE1: 'rú',  # 濡
    0x6FE2: 'cuì,zuǐ',  # 濢
    0x6FE3: 'wò',  # 濣
    0x6FE4: 'tāo',  # 濤
    0x6FE5: 'yǐn',  # 濥
    0x6FE6: 'yīn',  # 濦
    0x6FE7: 'duì',  # 濧
    0x6FE8: 'cí',  # 濨
    0x6FE9: 'huò,hù',  # 濩
    0x6FEA: 'qìng',  # 濪
    0x6FEB: 'làn',  # 濫
    0x6FEC: 'jùn,xùn',  # 濬
    0x6FED: 'ǎi,kài,kè',  # 濭
    0x6FEE: 'pú',  # 濮
    0x6FEF: 'zhuó,zhào',  # 濯
    0x6FF0: 'wéi',  # 濰
    0x6FF1: 'bīn',  # 濱
    0x6FF2: 'gǔ',  # 濲
    0x6FF3: 'qián',  # 濳
    0x6FF4: 'yíng',  # 濴
    0x6FF5: 'bīn',  # 濵
    0x6FF6: 'kuò',  # 濶
    0x6FF7: 'fèi',  # 濷
    0x6FF8: 'cāng',  # 濸
    0x6FF9: 'mè',  # 濹
    0x6FFA: 'jiàn,jiān',  # 濺
    0x6FFB: 'wěi,duì',  # 濻
    0x6FFC: 'luò,pō',  # 濼
    0x6FFD: 'zàn,cuán',  # 濽
    0x6FFE: 'lǜ',  # 濾
    0x6FFF: 'lì',  # 濿
    0x7000: 'yōu',  # 瀀
    0x7001: 'yǎng,yàng',  # 瀁
    0x7002: 'lǔ',  # 瀂
    0x7003: 'sì',  # 瀃
    0x7004: 'zhì',  # 瀄
    0x7005: 'yíng',  # 瀅
    0x7006: 'dú,dòu',  # 瀆
    0x7007: 'wǎng,wāng',  # 瀇
    0x7008: 'huī',  # 瀈
    0x7009: 'xiè',  # 瀉
    0x700A: 'pán',  # 瀊
    0x700B: 'shěn',  # 瀋
    0x700C: 'biāo',  # 瀌
    0x700D: 'chán',  # 瀍
    0x700E: 'miè,mò',  # 瀎
    0x700F: 'liú',  # 瀏
    0x7010: 'jiān',  # 瀐
    0x7011: 'pù,bào',  # 瀑
    0x7012: 'sè',  # 瀒
    0x7013: 'chéng,dèng',  # 瀓
    0x7014: 'gǔ',  # 瀔
    0x7015: 'bīn',  # 瀕
    0x7016: 'huò',  # 瀖
    0x7017: 'xiàn',  # 瀗
    0x7018: 'lú',  # 瀘
    0x7019: 'qìn',  # 瀙
    0x701A: 'hàn',  # 瀚
    0x701B: 'yíng',  # 瀛
    0x701C: 'róng',  # 瀜
    0x701D: 'lì',  # 瀝
    0x701E: 'jìng',  # 瀞
    0x701F: 'xiāo',  # 瀟
    0x7020: 'yíng',  # 瀠
    0x7021: 'suǐ',  # 瀡
    0x7022: 'wěi,duì',  # 瀢
    0x7023: 'xiè',  # 瀣
    0x7024: 'huái,wāi',  # 瀤
    0x7025: 'xuè',  # 瀥
    0x7026: 'zhū',  # 瀦
    0x7027: 'lóng,shuāng',  # 瀧
    0x7028: 'lài',  # 瀨
    0x7029: 'duì',  # 瀩
    0x702A: 'fàn',  # 瀪
    0x702B: 'hú',  # 瀫
    0x702C: 'lài',  # 瀬
    0x702D: 'shū',  # 瀭
    0x702E: 'lián',  # 瀮
    0x702F: 'yíng',  # 瀯
    0x7030: 'mí',  # 瀰
    0x7031: 'jì',  # 瀱
    0x7032: 'liàn',  # 瀲
    0x7033: 'jiàn,zùn',  # 瀳
    0x7034: 'yīng,yǐng,yìng',  # 瀴
    0x7035: 'fèn',  # 瀵
    0x7036: 'lín',  # 瀶
    0x7037: 'yì',  # 瀷
    0x7038: 'jiān',  # 瀸
    0x7039: 'yuè',  # 瀹
    0x703A: 'chán',  # 瀺
    0x703B: 'dài',  # 瀻
    0x703C: 'ráng,nǎng',  # 瀼
    0x703D: 'jiǎn',  # 瀽
    0x703E: 'lán',  # 瀾
    0x703F: 'fán',  # 瀿
    0x7040: 'shuàng',  # 灀
    0x7041: 'yuān',  # 灁
    0x7042: 'zhuó,jiào,zé',  # 灂
    0x7043: 'fēng',  # 灃
    0x7044: 'shè',  # 灄
    0x7045: 'lěi',  # 灅
    0x7046: 'lán',  # 灆
    0x7047: 'cóng',  # 灇
    0x7048: 'qú',  # 灈
    0x7049: 'yōng',  # 灉
    0x704A: 'qián',  # 灊
    0x704B: 'fǎ',  # 灋
    0x704C: 'guàn',  # 灌
    0x704D: 'jué',  # 灍
    0x704E: 'yàn',  # 灎
    0x704F: 'hào',  # 灏
    0x7050: 'yíng',  # 灐
    0x7051: 'sǎ',  # 灑
    0x7052: 'zàn,cuán',  # 灒
    0x7053: 'luán,luàn',  # 灓
    0x7054: 'yàn',  # 灔
    0x7055: 'lí',  # 灕
    0x7056: 'mǐ',  # 灖
    0x7057: 'shàn',  # 灗
    0x7058: 'tān',  # 灘
    0x7059: 'dǎng,tǎng',  # 灙
    0x705A: 'jiǎo',  # 灚
    0x705B: 'chǎn',  # 灛
    0x705C: 'yíng',  # 灜
    0x705D: 'hào',  # 灝
    0x705E: 'bà',  # 灞
    0x705F: 'zhú',  # 灟
    0x7060: 'lǎn',  # 灠
    0x7061: 'lán',  # 灡
    0x7062: 'nǎng',  # 灢
    0x7063: 'wān',  # 灣
    0x7064: 'luán',  # 灤
    0x7065: 'xún,quán,quàn',  # 灥
    0x7066: 'xiǎn',  # 灦
    0x7067: 'yàn',  # 灧
    0x7068: 'gàn',  # 灨
    0x7069: 'yàn',  # 灩
    0x706A: 'yù',  # 灪
    0x706B: 'huǒ',  # 火
    0x706C: 'huǒ,biāo',  # 灬
    0x706D: 'miè',  # 灭
    0x706E: 'guāng',  # 灮
    0x706F: 'dēng',  # 灯
    0x7070: 'huī',  # 灰
    0x7071: 'xiāo',  # 灱
    0x7072: 'xiāo',  # 灲
    0x7073: 'huī',  # 灳
    0x7074: 'hōng',  # 灴
    0x7075: 'líng',  # 灵
    0x7076: 'zào',  # 灶
    0x7077: 'zhuàn',  # 灷
    0x7078: 'jiǔ',  # 灸
    0x7079: 'zhà,yù',  # 灹
    0x707A: 'xiè',  # 灺
    0x707B: 'chì',  # 灻
    0x707C: 'zhuó',  # 灼
    0x707D: 'zāi',  # 災
    0x707E: 'zāi',  # 灾
    0x707F: 'càn',  # 灿
    0x7080: 'yáng',  # 炀
    0x7081: 'qì',  # 炁
    0x7082: 'zhōng',  # 炂
    0x7083: 'fén,bèn',  # 炃
    0x7084: 'niǔ',  # 炄
    0x7085: 'jiǒng,guì',  # 炅
    0x7086: 'wén',  # 炆
    0x7087: 'pū',  # 炇
    0x7088: 'yì',  # 炈
    0x7089: 'lú',  # 炉
    0x708A: 'chuī',  # 炊
    0x708B: 'pī',  # 炋
    0x708C: 'kài',  # 炌
    0x708D: 'pàn',  # 炍
    0x708E: 'yán',  # 炎
    0x708F: 'yán',  # 炏
    0x7090: 'pàng,fēng',  # 炐
    0x7091: 'mù',  # 炑
    0x7092: 'chǎo',  # 炒
    0x7093: 'liào',  # 炓
    0x7094: 'quē',  # 炔
    0x7095: 'kàng',  # 炕
    0x7096: 'dùn',  # 炖
    0x7097: 'guāng',  # 炗
    0x7098: 'xìn',  # 炘
    0x7099: 'zhì',  # 炙
    0x709A: 'guāng',  # 炚
    0x709B: 'guāng',  # 炛
    0x709C: 'wěi',  # 炜
    0x709D: 'qiàng',  # 炝
    0x709E: 'biān',  # 炞
    0x709F: 'dá',  # 炟
    0x70A0: 'xiá',  # 炠
    0x70A1: 'zhēng',  # 炡
    0x70A2: 'zhú',  # 炢
    0x70A3: 'kě',  # 炣
    0x70A4: 'zhào,zhāo',  # 炤
    0x70A5: 'fú',  # 炥
    0x70A6: 'bá',  # 炦
    0x70A7: 'xiè',  # 炧
    0x70A8: 'xiè',  # 炨
    0x70A9: 'lìng',  # 炩
    0x70AA: 'zhuō,chù',  # 炪
    0x70AB: 'xuàn',  # 炫
    0x70AC: 'jù',  # 炬
    0x70AD: 'tàn',  # 炭
    0x70AE: 'páo,bāo,pào',  # 炮
    0x70AF: 'jiǒng',  # 炯
    0x70B0: 'páo,fǒu',  # 炰
    0x70B1: 'tái',  # 炱
    0x70B2: 'tái',  # 炲
    0x70B3: 'bǐng',  # 炳
    0x70B4: 'yǎng',  # 炴
    0x70B5: 'tōng',  # 炵
    0x70B6: 'shǎn,qián,shān',  # 炶
    0x70B7: 'zhù',  # 炷
    0x70B8: 'zhà,zhá',  # 炸
    0x70B9: 'diǎn',  # 点
    0x70BA: 'wéi,wèi',  # 為
    0x70BB: 'shí',  # 炻
    0x70BC: 'liàn',  # 炼
    0x70BD: 'chì',  # 炽
    0x70BE: 'huǎng',  # 炾
    0x70BF: 'zhōu',  # 炿
    0x70C0: 'hū',  # 烀
    0x70C1: 'shuò',  # 烁
    0x70C2: 'làn',  # 烂
    0x70C3: 'tīng',  # 烃
    0x70C4: 'jiǎo,yào',  # 烄
    0x70C5: 'xù',  # 烅
    0x70C6: 'héng',  # 烆
    0x70C7: 'quǎn',  # 烇
    0x70C8: 'liè',  # 烈
    0x70C9: 'huàn',  # 烉
    0x70CA: 'yáng,yàng',  # 烊
    0x70CB: 'xiāo',  # 烋
    0x70CC: 'xiū',  # 烌
    0x70CD: 'xiǎn',  # 烍
    0x70CE: 'yín',  # 烎
    0x70CF: 'wū',  # 烏
    0x70D0: 'zhōu',  # 烐
    0x70D1: 'yáo',  # 烑
    0x70D2: 'shì',  # 烒
    0x70D3: 'wēi',  # 烓
    0x70D4: 'tóng,dòng',  # 烔
    0x70D5: 'miè',  # 烕
    0x70D6: 'zāi',  # 烖
    0x70D7: 'kài',  # 烗
    0x70D8: 'hōng',  # 烘
    0x70D9: 'lào,luò',  # 烙
    0x70DA: 'xiá',  # 烚
    0x70DB: 'zhú',  # 烛
    0x70DC: 'xuǎn',  # 烜
    0x70DD: 'zhēng',  # 烝
    0x70DE: 'pò',  # 烞
    0x70DF: 'yān',  # 烟
    0x70E0: 'huí,huǐ',  # 烠
    0x70E1: 'guāng',  # 烡
    0x70E2: 'chè',  # 烢
    0x70E3: 'huī',  # 烣
    0x70E4: 'kǎo',  # 烤
    0x70E5: 'jù',  # 烥
    0x70E6: 'fán',  # 烦
    0x70E7: 'shāo',  # 烧
    0x70E8: 'yè',  # 烨
    0x70E9: 'huì',  # 烩
    # 0x70EA: '',  # 烪
    0x70EB: 'tàng',  # 烫
    0x70EC: 'jìn',  # 烬
    0x70ED: 'rè',  # 热
    0x70EE: 'liè',  # 烮
    0x70EF: 'xī',  # 烯
    0x70F0: 'fú,páo',  # 烰
    0x70F1: 'jiǒng',  # 烱
    0x70F2: 'xiè,chè',  # 烲
    0x70F3: 'pǔ',  # 烳
    0x70F4: 'tīng',  # 烴
    0x70F5: 'zhuó',  # 烵
    0x70F6: 'tǐng',  # 烶
    0x70F7: 'wán',  # 烷
    0x70F8: 'hǎi',  # 烸
    0x70F9: 'pēng',  # 烹
    0x70FA: 'lǎng',  # 烺
    0x70FB: 'yàn',  # 烻
    0x70FC: 'xù',  # 烼
    0x70FD: 'fēng',  # 烽
    0x70FE: 'chì',  # 烾
    0x70FF: 'róng',  # 烿
    0x7100: 'hú',  # 焀
    0x7101: 'xī',  # 焁
    0x7102: 'shū',  # 焂
    0x7103: 'hè',  # 焃
    0x7104: 'xūn,hūn',  # 焄
    0x7105: 'kù',  # 焅
    0x7106: 'juān,yè',  # 焆
    0x7107: 'xiāo',  # 焇
    0x7108: 'xī',  # 焈
    0x7109: 'yān',  # 焉
    0x710A: 'hàn',  # 焊
    0x710B: 'zhuàng',  # 焋
    0x710C: 'qū,jùn',  # 焌
    0x710D: 'dì',  # 焍
    0x710E: 'xiè,chè',  # 焎
    0x710F: 'jí,qì',  # 焏
    0x7110: 'wù',  # 焐
    0x7111: 'yān',  # 焑
    0x7112: 'lǚ',  # 焒
    0x7113: 'hán',  # 焓
    0x7114: 'yàn',  # 焔
    0x7115: 'huàn',  # 焕
    0x7116: 'mèn',  # 焖
    0x7117: 'jú',  # 焗
    0x7118: 'dào',  # 焘
    0x7119: 'bèi',  # 焙
    0x711A: 'fén',  # 焚
    0x711B: 'lìn',  # 焛
    0x711C: 'kūn',  # 焜
    0x711D: 'hùn',  # 焝
    0x711E: 'tūn',  # 焞
    0x711F: 'xī',  # 焟
    0x7120: 'cuì',  # 焠
    0x7121: 'wú',  # 無
    0x7122: 'hōng',  # 焢
    0x7123: 'chǎo,jù',  # 焣
    0x7124: 'fǔ',  # 焤
    0x7125: 'wò,ài',  # 焥
    0x7126: 'jiāo',  # 焦
    0x7127: 'zǒng,cōng',  # 焧
    0x7128: 'fèng',  # 焨
    0x7129: 'píng',  # 焩
    0x712A: 'qióng',  # 焪
    0x712B: 'ruò',  # 焫
    0x712C: 'xī,yì',  # 焬
    0x712D: 'qióng',  # 焭
    0x712E: 'xìn',  # 焮
    0x712F: 'zhuō,chāo',  # 焯
    0x7130: 'yàn',  # 焰
    0x7131: 'yàn',  # 焱
    0x7132: 'yì',  # 焲
    0x7133: 'jué',  # 焳
    0x7134: 'yù',  # 焴
    0x7135: 'gàng',  # 焵
    0x7136: 'rán',  # 然
    0x7137: 'pí',  # 焷
    0x7138: 'xiǒng,yīng',  # 焸
    0x7139: 'gàng',  # 焹
    0x713A: 'shēng',  # 焺
    0x713B: 'chàng',  # 焻
    0x713C: 'shāo',  # 焼
    0x713D: 'xiǒng,yīng',  # 焽
    0x713E: 'niǎn',  # 焾
    0x713F: 'gēng',  # 焿
    0x7140: 'qū',  # 煀
    0x7141: 'chén',  # 煁
    0x7142: 'hè',  # 煂
    0x7143: 'kuǐ',  # 煃
    0x7144: 'zhǒng',  # 煄
    0x7145: 'duàn',  # 煅
    0x7146: 'xiā',  # 煆
    0x7147: 'huī,yùn,xūn',  # 煇
    0x7148: 'fèng',  # 煈
    0x7149: 'liàn',  # 煉
    0x714A: 'xuān',  # 煊
    0x714B: 'xīng',  # 煋
    0x714C: 'huáng',  # 煌
    0x714D: 'jiǎo,qiāo',  # 煍
    0x714E: 'jiān',  # 煎
    0x714F: 'bì',  # 煏
    0x7150: 'yīng',  # 煐
    0x7151: 'zhǔ',  # 煑
    0x7152: 'wěi',  # 煒
    0x7153: 'tuān',  # 煓
    0x7154: 'shǎn,qián,shān',  # 煔
    0x7155: 'xī,yí',  # 煕
    0x7156: 'nuǎn',  # 煖
    0x7157: 'nuǎn',  # 煗
    0x7158: 'chán',  # 煘
    0x7159: 'yān',  # 煙
    0x715A: 'jiǒng',  # 煚
    0x715B: 'jiǒng',  # 煛
    0x715C: 'yù',  # 煜
    0x715D: 'mèi',  # 煝
    0x715E: 'shā,shà',  # 煞
    0x715F: 'wèi',  # 煟
    0x7160: 'yè,zhá',  # 煠
    0x7161: 'jìn',  # 煡
    0x7162: 'qióng',  # 煢
    0x7163: 'róu',  # 煣
    0x7164: 'méi',  # 煤
    0x7165: 'huàn',  # 煥
    0x7166: 'xù',  # 煦
    0x7167: 'zhào',  # 照
    0x7168: 'wēi',  # 煨
    0x7169: 'fán',  # 煩
    0x716A: 'qiú',  # 煪
    0x716B: 'suì',  # 煫
    0x716C: 'yáng,yàng',  # 煬
    0x716D: 'liè',  # 煭
    0x716E: 'zhǔ',  # 煮
    0x716F: 'jiē',  # 煯
    0x7170: 'zào',  # 煰
    0x7171: 'guā',  # 煱
    0x7172: 'bāo',  # 煲
    0x7173: 'hú',  # 煳
    0x7174: 'yūn,yǔn',  # 煴
    0x7175: 'nǎn',  # 煵
    0x7176: 'shì',  # 煶
    0x7177: 'huǒ',  # 煷
    0x7178: 'biān',  # 煸
    0x7179: 'gòu',  # 煹
    0x717A: 'tuì',  # 煺
    0x717B: 'táng',  # 煻
    0x717C: 'chǎo',  # 煼
    0x717D: 'shān',  # 煽
    0x717E: 'ēn,yūn',  # 煾
    0x717F: 'bó',  # 煿
    0x7180: 'huǎng',  # 熀
    0x7181: 'xié',  # 熁
    0x7182: 'xì',  # 熂
    0x7183: 'wù',  # 熃
    0x7184: 'xī',  # 熄
    0x7185: 'yūn,yǔn',  # 熅
    0x7186: 'hé',  # 熆
    0x7187: 'hè,xiāo',  # 熇
    0x7188: 'xī',  # 熈
    0x7189: 'yún',  # 熉
    0x718A: 'xióng',  # 熊
    0x718B: 'xióng',  # 熋
    0x718C: 'shǎn',  # 熌
    0x718D: 'qióng',  # 熍
    0x718E: 'yào',  # 熎
    0x718F: 'xūn,xùn',  # 熏
    0x7190: 'mì',  # 熐
    0x7191: 'lián',  # 熑
    0x7192: 'yíng',  # 熒
    0x7193: 'wǔ',  # 熓
    0x7194: 'róng',  # 熔
    0x7195: 'gòng',  # 熕
    0x7196: 'yàn',  # 熖
    0x7197: 'qiàng',  # 熗
    0x7198: 'liū',  # 熘
    0x7199: 'xī',  # 熙
    0x719A: 'bì',  # 熚
    0x719B: 'biāo',  # 熛
    0x719C: 'cōng,zǒng',  # 熜
    0x719D: 'lù,āo',  # 熝
    0x719E: 'jiān',  # 熞
    0x719F: 'shú',  # 熟
    0x71A0: 'yì',  # 熠
    0x71A1: 'lóu',  # 熡
    0x71A2: 'péng,fēng',  # 熢
    0x71A3: 'suī,cuǐ',  # 熣
    0x71A4: 'yì',  # 熤
    0x71A5: 'tēng',  # 熥
    0x71A6: 'jué',  # 熦
    0x71A7: 'zōng',  # 熧
    0x71A8: 'yùn,yù',  # 熨
    0x71A9: 'hù',  # 熩
    0x71AA: 'yí',  # 熪
    0x71AB: 'zhì',  # 熫
    0x71AC: 'āo,áo',  # 熬
    0x71AD: 'wèi',  # 熭
    0x71AE: 'liǔ',  # 熮
    0x71AF: 'hàn,rǎn',  # 熯
    0x71B0: 'ōu,ǒu',  # 熰
    0x71B1: 'rè',  # 熱
    0x71B2: 'jiǒng',  # 熲
    0x71B3: 'màn',  # 熳
    0x71B4: 'kūn',  # 熴
    0x71B5: 'shāng',  # 熵
    0x71B6: 'cuàn',  # 熶
    0x71B7: 'zèng',  # 熷
    0x71B8: 'jiān',  # 熸
    0x71B9: 'xī',  # 熹
    0x71BA: 'xī',  # 熺
    0x71BB: 'xī',  # 熻
    0x71BC: 'yì',  # 熼
    0x71BD: 'xiào',  # 熽
    0x71BE: 'chì',  # 熾
    0x71BF: 'huáng,huǎng',  # 熿
    0x71C0: 'chǎn,dǎn,chàn',  # 燀
    0x71C1: 'yè',  # 燁
    0x71C2: 'tán',  # 燂
    0x71C3: 'rán',  # 燃
    0x71C4: 'yàn',  # 燄
    0x71C5: 'xún',  # 燅
    0x71C6: 'qiāo',  # 燆
    0x71C7: 'jùn',  # 燇
    0x71C8: 'dēng',  # 燈
    0x71C9: 'dùn',  # 燉
    0x71CA: 'shēn',  # 燊
    0x71CB: 'jiāo,qiáo,jué,zhuó',  # 燋
    0x71CC: 'fén',  # 燌
    0x71CD: 'sī',  # 燍
    0x71CE: 'liáo,liǎo',  # 燎
    0x71CF: 'yù',  # 燏
    0x71D0: 'lín',  # 燐
    0x71D1: 'tóng,dòng',  # 燑
    0x71D2: 'shāo',  # 燒
    0x71D3: 'fén',  # 燓
    0x71D4: 'fán',  # 燔
    0x71D5: 'yàn,yān',  # 燕
    0x71D6: 'xún',  # 燖
    0x71D7: 'làn',  # 燗
    0x71D8: 'měi',  # 燘
    0x71D9: 'tàng',  # 燙
    0x71DA: 'yì',  # 燚
    0x71DB: 'jiǒng',  # 燛
    0x71DC: 'mèn',  # 燜
    0x71DD: 'zhǔ',  # 燝
    0x71DE: 'jiǎo',  # 燞
    0x71DF: 'yíng',  # 營
    0x71E0: 'yù',  # 燠
    0x71E1: 'yì',  # 燡
    0x71E2: 'xué',  # 燢
    0x71E3: 'lán',  # 燣
    0x71E4: 'tài,liè',  # 燤
    0x71E5: 'zào',  # 燥
    0x71E6: 'càn',  # 燦
    0x71E7: 'suì',  # 燧
    0x71E8: 'xī',  # 燨
    0x71E9: 'què',  # 燩
    0x71EA: 'zǒng',  # 燪
    0x71EB: 'lián',  # 燫
    0x71EC: 'huǐ',  # 燬
    0x71ED: 'zhú',  # 燭
    0x71EE: 'xiè',  # 燮
    0x71EF: 'líng',  # 燯
    0x71F0: 'wēi',  # 燰
    0x71F1: 'yì',  # 燱
    0x71F2: 'xié',  # 燲
    0x71F3: 'zhào',  # 燳
    0x71F4: 'huì',  # 燴
    0x71F5: 'dá',  # 燵
    0x71F6: 'nóng',  # 燶
    0x71F7: 'lán',  # 燷
    0x71F8: 'xū',  # 燸
    0x71F9: 'xiǎn',  # 燹
    0x71FA: 'hè',  # 燺
    0x71FB: 'xūn',  # 燻
    0x71FC: 'jìn',  # 燼
    0x71FD: 'chóu',  # 燽
    0x71FE: 'dào',  # 燾
    0x71FF: 'yào',  # 燿
    0x7200: 'hè',  # 爀
    0x7201: 'làn',  # 爁
    0x7202: 'biāo',  # 爂
    0x7203: 'róng,yíng',  # 爃
    0x7204: 'lì,liè',  # 爄
    0x7205: 'mò',  # 爅
    0x7206: 'bào',  # 爆
    0x7207: 'ruò',  # 爇
    0x7208: 'lǜ',  # 爈
    0x7209: 'là,liè',  # 爉
    0x720A: 'āo',  # 爊
    0x720B: 'xūn,xùn',  # 爋
    0x720C: 'kuàng,huǎng',  # 爌
    0x720D: 'shuò',  # 爍
    0x720E: 'liáo,liǎo',  # 爎
    0x720F: 'lì',  # 爏
    0x7210: 'lú',  # 爐
    0x7211: 'jué',  # 爑
    0x7212: 'liáo,liǎo',  # 爒
    0x7213: 'yàn,xún',  # 爓
    0x7214: 'xī',  # 爔
    0x7215: 'xiè',  # 爕
    0x7216: 'lóng',  # 爖
    0x7217: 'yè',  # 爗
    0x7218: 'cān',  # 爘
    0x7219: 'rǎng',  # 爙
    0x721A: 'yuè',  # 爚
    0x721B: 'làn',  # 爛
    0x721C: 'cóng',  # 爜
    0x721D: 'jué',  # 爝
    0x721E: 'chóng',  # 爞
    0x721F: 'guàn',  # 爟
    0x7220: 'qú',  # 爠
    0x7221: 'chè',  # 爡
    0x7222: 'mí',  # 爢
    0x7223: 'tǎng',  # 爣
    0x7224: 'làn',  # 爤
    0x7225: 'zhú',  # 爥
    0x7226: 'lǎn,làn',  # 爦
    0x7227: 'líng',  # 爧
    0x7228: 'cuàn',  # 爨
    0x7229: 'yù',  # 爩
    0x722A: 'zhǎo,zhuǎ',  # 爪
    0x722B: 'zhǎo,zhuǎ',  # 爫
    0x722C: 'pá',  # 爬
    0x722D: 'zhēng',  # 爭
    0x722E: 'páo',  # 爮
    0x722F: 'chēng,chèn',  # 爯
    0x7230: 'yuán',  # 爰
    0x7231: 'ài',  # 爱
    0x7232: 'wéi,wèi',  # 爲
    0x7233: 'han',  # 爳
    0x7234: 'jué',  # 爴
    0x7235: 'jué',  # 爵
    0x7236: 'fù,fǔ',  # 父
    0x7237: 'yé',  # 爷
    0x7238: 'bà',  # 爸
    0x7239: 'diē',  # 爹
    0x723A: 'yé',  # 爺
    0x723B: 'yáo',  # 爻
    0x723C: 'zǔ',  # 爼
    0x723D: 'shuǎng',  # 爽
    0x723E: 'ěr',  # 爾
    0x723F: 'pán',  # 爿
    0x7240: 'chuáng',  # 牀
    0x7241: 'kē',  # 牁
    0x7242: 'zāng',  # 牂
    0x7243: 'dié',  # 牃
    0x7244: 'qiāng',  # 牄
    0x7245: 'yōng',  # 牅
    0x7246: 'qiáng',  # 牆
    0x7247: 'piàn,piān',  # 片
    0x7248: 'bǎn',  # 版
    0x7249: 'pàn',  # 牉
    0x724A: 'cháo',  # 牊
    0x724B: 'jiān',  # 牋
    0x724C: 'pái',  # 牌
    0x724D: 'dú',  # 牍
    0x724E: 'chuāng',  # 牎
    0x724F: 'yú',  # 牏
    0x7250: 'zhá',  # 牐
    0x7251: 'biān,miàn',  # 牑
    0x7252: 'dié',  # 牒
    0x7253: 'bǎng',  # 牓
    0x7254: 'bó',  # 牔
    0x7255: 'chuāng',  # 牕
    0x7256: 'yǒu',  # 牖
    0x7257: 'yǒu,yōng',  # 牗
    0x7258: 'dú',  # 牘
    0x7259: 'yá',  # 牙
    0x725A: 'chēng,chèng',  # 牚
    0x725B: 'niú',  # 牛
    0x725C: 'niú',  # 牜
    0x725D: 'pìn',  # 牝
    0x725E: 'jiū,lè',  # 牞
    0x725F: 'móu,mù',  # 牟
    0x7260: 'tā',  # 牠
    0x7261: 'mǔ',  # 牡
    0x7262: 'láo',  # 牢
    0x7263: 'rèn',  # 牣
    0x7264: 'māng',  # 牤
    0x7265: 'fāng',  # 牥
    0x7266: 'máo',  # 牦
    0x7267: 'mù',  # 牧
    0x7268: 'gāng',  # 牨
    0x7269: 'wù',  # 物
    0x726A: 'yàn',  # 牪
    0x726B: 'gē,qiú',  # 牫
    0x726C: 'bèi',  # 牬
    0x726D: 'sì',  # 牭
    0x726E: 'jiàn',  # 牮
    0x726F: 'gǔ',  # 牯
    0x7270: 'yòu,chōu',  # 牰
    0x7271: 'kē',  # 牱
    0x7272: 'shēng',  # 牲
    0x7273: 'mǔ',  # 牳
    0x7274: 'dǐ',  # 牴
    0x7275: 'qiān',  # 牵
    0x7276: 'quàn',  # 牶
    0x7277: 'quán',  # 牷
    0x7278: 'zì',  # 牸
    0x7279: 'tè',  # 特
    0x727A: 'xī',  # 牺
    0x727B: 'máng',  # 牻
    0x727C: 'kēng',  # 牼
    0x727D: 'qiān',  # 牽
    0x727E: 'wǔ',  # 牾
    0x727F: 'gù',  # 牿
    0x7280: 'xī',  # 犀
    0x7281: 'lí',  # 犁
    0x7282: 'lí',  # 犂
    0x7283: 'pǒu',  # 犃
    0x7284: 'jī',  # 犄
    0x7285: 'gāng',  # 犅
    0x7286: 'zhí,tè',  # 犆
    0x7287: 'bēn',  # 犇
    0x7288: 'quán',  # 犈
    0x7289: 'chún',  # 犉
    0x728A: 'dú',  # 犊
    0x728B: 'jù',  # 犋
    0x728C: 'jiā',  # 犌
    0x728D: 'jiān,qián',  # 犍
    0x728E: 'fēng',  # 犎
    0x728F: 'piān',  # 犏
    0x7290: 'kē',  # 犐
    0x7291: 'jú',  # 犑
    0x7292: 'kào',  # 犒
    0x7293: 'chú',  # 犓
    0x7294: 'xì',  # 犔
    0x7295: 'bèi',  # 犕
    0x7296: 'luò',  # 犖
    0x7297: 'jiè',  # 犗
    0x7298: 'má',  # 犘
    0x7299: 'sān',  # 犙
    0x729A: 'wèi',  # 犚
    0x729B: 'máo,lí',  # 犛
    0x729C: 'dūn',  # 犜
    0x729D: 'tóng',  # 犝
    0x729E: 'qiáo',  # 犞
    0x729F: 'jiàng',  # 犟
    0x72A0: 'xī',  # 犠
    0x72A1: 'lì',  # 犡
    0x72A2: 'dú',  # 犢
    0x72A3: 'liè',  # 犣
    0x72A4: 'pái',  # 犤
    0x72A5: 'piāo',  # 犥
    0x72A6: 'bào',  # 犦
    0x72A7: 'xī',  # 犧
    0x72A8: 'chōu',  # 犨
    0x72A9: 'wéi',  # 犩
    0x72AA: 'kuí',  # 犪
    0x72AB: 'chōu',  # 犫
    0x72AC: 'quǎn',  # 犬
    0x72AD: 'quǎn',  # 犭
    0x72AE: 'quǎn,bá',  # 犮
    0x72AF: 'fàn',  # 犯
    0x72B0: 'qiú',  # 犰
    0x72B1: 'jǐ',  # 犱
    0x72B2: 'chái',  # 犲
    0x72B3: 'zhuó,bào',  # 犳
    0x72B4: 'hān,àn',  # 犴
    0x72B5: 'gē',  # 犵
    0x72B6: 'zhuàng',  # 状
    0x72B7: 'guǎng',  # 犷
    0x72B8: 'mǎ',  # 犸
    0x72B9: 'yóu',  # 犹
    0x72BA: 'kàng,gǎng',  # 犺
    0x72BB: 'pèi,fèi',  # 犻
    0x72BC: 'hǒu',  # 犼
    0x72BD: 'yà',  # 犽
    0x72BE: 'yín',  # 犾
    0x72BF: 'huān,fān',  # 犿
    0x72C0: 'zhuàng',  # 狀
    0x72C1: 'yǔn',  # 狁
    0x72C2: 'kuáng',  # 狂
    0x72C3: 'niǔ',  # 狃
    0x72C4: 'dí',  # 狄
    0x72C5: 'kuáng',  # 狅
    0x72C6: 'zhòng',  # 狆
    0x72C7: 'mù',  # 狇
    0x72C8: 'bèi',  # 狈
    0x72C9: 'pī',  # 狉
    0x72CA: 'jú',  # 狊
    0x72CB: 'yí,quán,chí',  # 狋
    0x72CC: 'shēng,xīng',  # 狌
    0x72CD: 'páo',  # 狍
    0x72CE: 'xiá',  # 狎
    0x72CF: 'tuó,yí',  # 狏
    0x72D0: 'hú',  # 狐
    0x72D1: 'líng',  # 狑
    0x72D2: 'fèi',  # 狒
    0x72D3: 'pī',  # 狓
    0x72D4: 'nǐ',  # 狔
    0x72D5: 'yǎo',  # 狕
    0x72D6: 'yòu',  # 狖
    0x72D7: 'gǒu',  # 狗
    0x72D8: 'xuè',  # 狘
    0x72D9: 'jū',  # 狙
    0x72DA: 'dàn',  # 狚
    0x72DB: 'bó',  # 狛
    0x72DC: 'kǔ',  # 狜
    0x72DD: 'xiǎn',  # 狝
    0x72DE: 'níng',  # 狞
    0x72DF: 'huán,huān',  # 狟
    0x72E0: 'hěn',  # 狠
    0x72E1: 'jiǎo',  # 狡
    0x72E2: 'hé,mò',  # 狢
    0x72E3: 'zhào',  # 狣
    0x72E4: 'jié',  # 狤
    0x72E5: 'xùn',  # 狥
    0x72E6: 'shān',  # 狦
    0x72E7: 'tà,shì',  # 狧
    0x72E8: 'róng',  # 狨
    0x72E9: 'shòu',  # 狩
    0x72EA: 'tóng,dòng',  # 狪
    0x72EB: 'lǎo',  # 狫
    0x72EC: 'dú',  # 独
    0x72ED: 'xiá',  # 狭
    0x72EE: 'shī',  # 狮
    0x72EF: 'kuài',  # 狯
    0x72F0: 'zhēng',  # 狰
    0x72F1: 'yù',  # 狱
    0x72F2: 'sūn',  # 狲
    0x72F3: 'yú',  # 狳
    0x72F4: 'bì',  # 狴
    0x72F5: 'máng,dòu',  # 狵
    0x72F6: 'xī,shǐ',  # 狶
    0x72F7: 'juàn',  # 狷
    0x72F8: 'lí',  # 狸
    0x72F9: 'xiá',  # 狹
    0x72FA: 'yín',  # 狺
    0x72FB: 'suān',  # 狻
    0x72FC: 'láng',  # 狼
    0x72FD: 'bèi',  # 狽
    0x72FE: 'zhì',  # 狾
    0x72FF: 'yán',  # 狿
    0x7300: 'shā',  # 猀
    0x7301: 'lì',  # 猁
    0x7302: 'hàn',  # 猂
    0x7303: 'xiǎn',  # 猃
    0x7304: 'jīng',  # 猄
    0x7305: 'pái',  # 猅
    0x7306: 'fēi',  # 猆
    0x7307: 'xiāo',  # 猇
    0x7308: 'bài,pí',  # 猈
    0x7309: 'qí',  # 猉
    0x730A: 'ní',  # 猊
    0x730B: 'biāo',  # 猋
    0x730C: 'yìn',  # 猌
    0x730D: 'lái',  # 猍
    0x730E: 'liè',  # 猎
    0x730F: 'jiān,yàn',  # 猏
    0x7310: 'qiāng',  # 猐
    0x7311: 'kūn',  # 猑
    0x7312: 'yàn',  # 猒
    0x7313: 'guō',  # 猓
    0x7314: 'zòng',  # 猔
    0x7315: 'mí',  # 猕
    0x7316: 'chāng',  # 猖
    0x7317: 'yī,yǐ',  # 猗
    0x7318: 'zhì',  # 猘
    0x7319: 'zhēng',  # 猙
    0x731A: 'yá,wèi',  # 猚
    0x731B: 'měng',  # 猛
    0x731C: 'cāi',  # 猜
    0x731D: 'cù',  # 猝
    0x731E: 'shē',  # 猞
    0x731F: 'liè',  # 猟
    0x7320: 'ceon',  # 猠
    0x7321: 'luó',  # 猡
    0x7322: 'hú',  # 猢
    0x7323: 'zōng',  # 猣
    0x7324: 'guì',  # 猤
    0x7325: 'wěi',  # 猥
    0x7326: 'fēng',  # 猦
    0x7327: 'wō',  # 猧
    0x7328: 'yuán',  # 猨
    0x7329: 'xīng',  # 猩
    0x732A: 'zhū',  # 猪
    0x732B: 'māo,máo',  # 猫
    0x732C: 'wèi',  # 猬
    0x732D: 'chuàn,chuān',  # 猭
    0x732E: 'xiàn',  # 献
    0x732F: 'tuān,tuàn',  # 猯
    0x7330: 'yà,jiá,qiè',  # 猰
    0x7331: 'náo',  # 猱
    0x7332: 'xiē,hè,gé,hài',  # 猲
    0x7333: 'jiā',  # 猳
    0x7334: 'hóu',  # 猴
    0x7335: 'biān,piàn',  # 猵
    0x7336: 'yóu',  # 猶
    0x7337: 'yóu',  # 猷
    0x7338: 'méi',  # 猸
    0x7339: 'chá',  # 猹
    0x733A: 'yáo',  # 猺
    0x733B: 'sūn',  # 猻
    0x733C: 'bó,pò',  # 猼
    0x733D: 'míng',  # 猽
    0x733E: 'huá',  # 猾
    0x733F: 'yuán',  # 猿
    0x7340: 'sōu',  # 獀
    0x7341: 'mǎ',  # 獁
    0x7342: 'huán',  # 獂
    0x7343: 'dāi',  # 獃
    0x7344: 'yù',  # 獄
    0x7345: 'shī',  # 獅
    0x7346: 'háo',  # 獆
    0x7347: 'qiāng',  # 獇
    0x7348: 'yì',  # 獈
    0x7349: 'zhēn',  # 獉
    0x734A: 'cāng',  # 獊
    0x734B: 'háo,gāo',  # 獋
    0x734C: 'màn',  # 獌
    0x734D: 'jìng',  # 獍
    0x734E: 'jiǎng',  # 獎
    0x734F: 'mò',  # 獏
    0x7350: 'zhāng',  # 獐
    0x7351: 'chán',  # 獑
    0x7352: 'áo',  # 獒
    0x7353: 'áo',  # 獓
    0x7354: 'háo',  # 獔
    0x7355: 'suǒ',  # 獕
    0x7356: 'fén,fèn',  # 獖
    0x7357: 'jué',  # 獗
    0x7358: 'bì',  # 獘
    0x7359: 'bì',  # 獙
    0x735A: 'huáng',  # 獚
    0x735B: 'pú',  # 獛
    0x735C: 'lín,lìn',  # 獜
    0x735D: 'xù',  # 獝
    0x735E: 'tóng',  # 獞
    0x735F: 'yào,xiāo',  # 獟
    0x7360: 'liáo',  # 獠
    0x7361: 'shuò,xī',  # 獡
    0x7362: 'xiāo',  # 獢
    0x7363: 'shòu',  # 獣
    0x7364: 'dūn',  # 獤
    0x7365: 'jiào',  # 獥
    0x7366: 'gé,liè,xiē',  # 獦
    0x7367: 'juàn',  # 獧
    0x7368: 'dú',  # 獨
    0x7369: 'huì',  # 獩
    0x736A: 'kuài',  # 獪
    0x736B: 'xiǎn',  # 獫
    0x736C: 'xiè',  # 獬
    0x736D: 'tǎ',  # 獭
    0x736E: 'xiǎn',  # 獮
    0x736F: 'xūn',  # 獯
    0x7370: 'níng',  # 獰
    0x7371: 'biān,piàn',  # 獱
    0x7372: 'huò',  # 獲
    0x7373: 'nòu,rú',  # 獳
    0x7374: 'méng',  # 獴
    0x7375: 'liè',  # 獵
    0x7376: 'náo,nǎo,yōu',  # 獶
    0x7377: 'guǎng',  # 獷
    0x7378: 'shòu',  # 獸
    0x7379: 'lú',  # 獹
    0x737A: 'tǎ',  # 獺
    0x737B: 'xiàn',  # 獻
    0x737C: 'mí',  # 獼
    0x737D: 'ráng',  # 獽
    0x737E: 'huān',  # 獾
    0x737F: 'náo,yōu',  # 獿
    0x7380: 'luó',  # 玀
    0x7381: 'xiǎn',  # 玁
    0x7382: 'qí',  # 玂
    0x7383: 'jué',  # 玃
    0x7384: 'xuán',  # 玄
    0x7385: 'miào',  # 玅
    0x7386: 'zī',  # 玆
    0x7387: 'shuài,lǜ',  # 率
    0x7388: 'lú',  # 玈
    0x7389: 'yù',  # 玉
    0x738A: 'sù',  # 玊
    0x738B: 'wáng,wàng',  # 王
    0x738C: 'qiú',  # 玌
    0x738D: 'gǎ',  # 玍
    0x738E: 'dīng',  # 玎
    0x738F: 'lè',  # 玏
    0x7390: 'bā',  # 玐
    0x7391: 'jī',  # 玑
    0x7392: 'hóng',  # 玒
    0x7393: 'dì',  # 玓
    0x7394: 'chuàn',  # 玔
    0x7395: 'gān',  # 玕
    0x7396: 'jiǔ',  # 玖
    0x7397: 'yú',  # 玗
    0x7398: 'qǐ',  # 玘
    0x7399: 'yú',  # 玙
    0x739A: 'chàng,yáng',  # 玚
    0x739B: 'mǎ',  # 玛
    0x739C: 'hóng',  # 玜
    0x739D: 'wǔ',  # 玝
    0x739E: 'fū',  # 玞
    0x739F: 'mín,wén',  # 玟
    0x73A0: 'jiè',  # 玠
    0x73A1: 'yà',  # 玡
    0x73A2: 'bīn,fēn',  # 玢
    0x73A3: 'biàn',  # 玣
    0x73A4: 'bàng',  # 玤
    0x73A5: 'yuè',  # 玥
    0x73A6: 'jué',  # 玦
    0x73A7: 'mén,yǔn',  # 玧
    0x73A8: 'jué',  # 玨
    0x73A9: 'wán',  # 玩
    0x73AA: 'jiān,qián',  # 玪
    0x73AB: 'méi',  # 玫
    0x73AC: 'dǎn',  # 玬
    0x73AD: 'pín',  # 玭
    0x73AE: 'wěi',  # 玮
    0x73AF: 'huán',  # 环
    0x73B0: 'xiàn',  # 现
    0x73B1: 'qiāng,cāng',  # 玱
    0x73B2: 'líng',  # 玲
    0x73B3: 'dài',  # 玳
    0x73B4: 'yì',  # 玴
    0x73B5: 'án,gān',  # 玵
    0x73B6: 'píng',  # 玶
    0x73B7: 'diàn',  # 玷
    0x73B8: 'fú',  # 玸
    0x73B9: 'xuán,xián',  # 玹
    0x73BA: 'xǐ',  # 玺
    0x73BB: 'bō',  # 玻
    0x73BC: 'cī,cǐ',  # 玼
    0x73BD: 'gǒu',  # 玽
    0x73BE: 'jiǎ',  # 玾
    0x73BF: 'sháo',  # 玿
    0x73C0: 'pò',  # 珀
    0x73C1: 'cí',  # 珁
    0x73C2: 'kē',  # 珂
    0x73C3: 'rǎn',  # 珃
    0x73C4: 'shēng',  # 珄
    0x73C5: 'shēn',  # 珅
    0x73C6: 'yí,tāi',  # 珆
    0x73C7: 'zǔ,jù',  # 珇
    0x73C8: 'jiā',  # 珈
    0x73C9: 'mín',  # 珉
    0x73CA: 'shān',  # 珊
    0x73CB: 'liǔ',  # 珋
    0x73CC: 'bì',  # 珌
    0x73CD: 'zhēn',  # 珍
    0x73CE: 'zhēn',  # 珎
    0x73CF: 'jué',  # 珏
    0x73D0: 'fà',  # 珐
    0x73D1: 'lóng',  # 珑
    0x73D2: 'jīn',  # 珒
    0x73D3: 'jiào',  # 珓
    0x73D4: 'jiàn',  # 珔
    0x73D5: 'lì',  # 珕
    0x73D6: 'guāng',  # 珖
    0x73D7: 'xiān',  # 珗
    0x73D8: 'zhōu',  # 珘
    0x73D9: 'gǒng',  # 珙
    0x73DA: 'yān',  # 珚
    0x73DB: 'xiù',  # 珛
    0x73DC: 'yáng',  # 珜
    0x73DD: 'xǔ',  # 珝
    0x73DE: 'luò',  # 珞
    0x73DF: 'sù',  # 珟
    0x73E0: 'zhū',  # 珠
    0x73E1: 'qín',  # 珡
    0x73E2: 'yín,kèn',  # 珢
    0x73E3: 'xún',  # 珣
    0x73E4: 'bǎo',  # 珤
    0x73E5: 'ěr',  # 珥
    0x73E6: 'xiàng',  # 珦
    0x73E7: 'yáo',  # 珧
    0x73E8: 'xiá',  # 珨
    0x73E9: 'héng',  # 珩
    0x73EA: 'guī',  # 珪
    0x73EB: 'chōng',  # 珫
    0x73EC: 'xù',  # 珬
    0x73ED: 'bān',  # 班
    0x73EE: 'pèi',  # 珮
    0x73EF: 'lǎo',  # 珯
    0x73F0: 'dāng',  # 珰
    0x73F1: 'yīng',  # 珱
    0x73F2: 'hún,huī',  # 珲
    0x73F3: 'wén',  # 珳
    0x73F4: 'é',  # 珴
    0x73F5: 'chéng',  # 珵
    0x73F6: 'dì,tí',  # 珶
    0x73F7: 'wǔ',  # 珷
    0x73F8: 'wú',  # 珸
    0x73F9: 'chéng',  # 珹
    0x73FA: 'jùn',  # 珺
    0x73FB: 'méi',  # 珻
    0x73FC: 'bèi',  # 珼
    0x73FD: 'tǐng',  # 珽
    0x73FE: 'xiàn',  # 現
    0x73FF: 'chù',  # 珿
    0x7400: 'hán',  # 琀
    0x7401: 'xuán,qióng',  # 琁
    0x7402: 'yán',  # 琂
    0x7403: 'qiú',  # 球
    0x7404: 'xuàn',  # 琄
    0x7405: 'láng',  # 琅
    0x7406: 'lǐ',  # 理
    0x7407: 'xiù',  # 琇
    0x7408: 'fú,fū',  # 琈
    0x7409: 'liú',  # 琉
    0x740A: 'yá',  # 琊
    0x740B: 'xī',  # 琋
    0x740C: 'líng',  # 琌
    0x740D: 'lí',  # 琍
    0x740E: 'jīn',  # 琎
    0x740F: 'liǎn',  # 琏
    0x7410: 'suǒ',  # 琐
    0x7411: 'suǒ',  # 琑
    0x7412: 'fēng',  # 琒
    0x7413: 'wán',  # 琓
    0x7414: 'diàn',  # 琔
    0x7415: 'pín,bǐng',  # 琕
    0x7416: 'zhǎn',  # 琖
    0x7417: 'cuì,sè',  # 琗
    0x7418: 'mín',  # 琘
    0x7419: 'yù',  # 琙
    0x741A: 'jū',  # 琚
    0x741B: 'chēn',  # 琛
    0x741C: 'lái',  # 琜
    0x741D: 'mín',  # 琝
    0x741E: 'shèng',  # 琞
    0x741F: 'wéi,yù',  # 琟
    0x7420: 'tiǎn,tiàn',  # 琠
    0x7421: 'shū',  # 琡
    0x7422: 'zhuó,zuó',  # 琢
    0x7423: 'běng,pěi',  # 琣
    0x7424: 'chēng',  # 琤
    0x7425: 'hǔ',  # 琥
    0x7426: 'qí',  # 琦
    0x7427: 'è',  # 琧
    0x7428: 'kūn',  # 琨
    0x7429: 'chāng',  # 琩
    0x742A: 'qí',  # 琪
    0x742B: 'běng',  # 琫
    0x742C: 'wǎn',  # 琬
    0x742D: 'lù',  # 琭
    0x742E: 'cóng',  # 琮
    0x742F: 'guǎn',  # 琯
    0x7430: 'yǎn',  # 琰
    0x7431: 'diāo',  # 琱
    0x7432: 'bèi',  # 琲
    0x7433: 'lín',  # 琳
    0x7434: 'qín',  # 琴
    0x7435: 'pí',  # 琵
    0x7436: 'pá',  # 琶
    0x7437: 'què',  # 琷
    0x7438: 'zhuó',  # 琸
    0x7439: 'qín',  # 琹
    0x743A: 'fà',  # 琺
    0x743B: 'jīn',  # 琻
    0x743C: 'qióng',  # 琼
    0x743D: 'dǔ',  # 琽
    0x743E: 'jiè',  # 琾
    0x743F: 'hún,huī',  # 琿
    0x7440: 'yǔ',  # 瑀
    0x7441: 'mào',  # 瑁
    0x7442: 'méi',  # 瑂
    0x7443: 'chūn',  # 瑃
    0x7444: 'xuān',  # 瑄
    0x7445: 'tí',  # 瑅
    0x7446: 'xīng',  # 瑆
    0x7447: 'dài',  # 瑇
    0x7448: 'róu',  # 瑈
    0x7449: 'mín',  # 瑉
    0x744A: 'jiān',  # 瑊
    0x744B: 'wěi',  # 瑋
    0x744C: 'ruǎn',  # 瑌
    0x744D: 'huàn',  # 瑍
    0x744E: 'xié,jiē',  # 瑎
    0x744F: 'chuān',  # 瑏
    0x7450: 'jiǎn',  # 瑐
    0x7451: 'zhuàn',  # 瑑
    0x7452: 'chàng,yáng',  # 瑒
    0x7453: 'liàn',  # 瑓
    0x7454: 'quán',  # 瑔
    0x7455: 'xiá',  # 瑕
    0x7456: 'duàn',  # 瑖
    0x7457: 'yuàn',  # 瑗
    0x7458: 'yé',  # 瑘
    0x7459: 'nǎo',  # 瑙
    0x745A: 'hú',  # 瑚
    0x745B: 'yīng',  # 瑛
    0x745C: 'yú',  # 瑜
    0x745D: 'huáng',  # 瑝
    0x745E: 'ruì',  # 瑞
    0x745F: 'sè',  # 瑟
    0x7460: 'liú',  # 瑠
    0x7461: 'shī',  # 瑡
    0x7462: 'róng',  # 瑢
    0x7463: 'suǒ',  # 瑣
    0x7464: 'yáo',  # 瑤
    0x7465: 'wēn',  # 瑥
    0x7466: 'wǔ',  # 瑦
    0x7467: 'zhēn',  # 瑧
    0x7468: 'jìn',  # 瑨
    0x7469: 'yíng',  # 瑩
    0x746A: 'mǎ',  # 瑪
    0x746B: 'tāo',  # 瑫
    0x746C: 'liú',  # 瑬
    0x746D: 'táng',  # 瑭
    0x746E: 'lì',  # 瑮
    0x746F: 'láng',  # 瑯
    0x7470: 'guī',  # 瑰
    0x7471: 'tiàn,tián,zhèn',  # 瑱
    0x7472: 'qiāng,cāng',  # 瑲
    0x7473: 'cuō',  # 瑳
    0x7474: 'jué',  # 瑴
    0x7475: 'zhǎo',  # 瑵
    0x7476: 'yáo',  # 瑶
    0x7477: 'ài',  # 瑷
    0x7478: 'bīn,pián',  # 瑸
    0x7479: 'tú,shū',  # 瑹
    0x747A: 'cháng',  # 瑺
    0x747B: 'kūn',  # 瑻
    0x747C: 'zhuān',  # 瑼
    0x747D: 'cōng',  # 瑽
    0x747E: 'jǐn',  # 瑾
    0x747F: 'yī',  # 瑿
    0x7480: 'cuǐ',  # 璀
    0x7481: 'cōng',  # 璁
    0x7482: 'qí',  # 璂
    0x7483: 'lí',  # 璃
    0x7484: 'jǐng',  # 璄
    0x7485: 'zǎo,suǒ',  # 璅
    0x7486: 'qiú',  # 璆
    0x7487: 'xuán',  # 璇
    0x7488: 'áo',  # 璈
    0x7489: 'liǎn',  # 璉
    0x748A: 'mén',  # 璊
    0x748B: 'zhāng',  # 璋
    0x748C: 'yín',  # 璌
    0x748D: 'yè',  # 璍
    0x748E: 'yīng',  # 璎
    0x748F: 'zhì',  # 璏
    0x7490: 'lù',  # 璐
    0x7491: 'wú',  # 璑
    0x7492: 'dēng',  # 璒
    0x7493: 'xiù',  # 璓
    0x7494: 'zēng',  # 璔
    0x7495: 'xún',  # 璕
    0x7496: 'qú',  # 璖
    0x7497: 'dàng',  # 璗
    0x7498: 'lín',  # 璘
    0x7499: 'liáo',  # 璙
    0x749A: 'qióng,jué',  # 璚
    0x749B: 'sù',  # 璛
    0x749C: 'huáng',  # 璜
    0x749D: 'guī',  # 璝
    0x749E: 'pú',  # 璞
    0x749F: 'jǐng',  # 璟
    0x74A0: 'fán',  # 璠
    0x74A1: 'jīn',  # 璡
    0x74A2: 'liú',  # 璢
    0x74A3: 'jī',  # 璣
    0x74A4: 'huì',  # 璤
    0x74A5: 'jǐng',  # 璥
    0x74A6: 'ài',  # 璦
    0x74A7: 'bì',  # 璧
    0x74A8: 'càn',  # 璨
    0x74A9: 'qú',  # 璩
    0x74AA: 'zǎo',  # 璪
    0x74AB: 'dāng',  # 璫
    0x74AC: 'jiǎo',  # 璬
    0x74AD: 'guǎn',  # 璭
    0x74AE: 'tǎn',  # 璮
    0x74AF: 'huì,kuài',  # 璯
    0x74B0: 'huán',  # 環
    0x74B1: 'sè',  # 璱
    0x74B2: 'suì',  # 璲
    0x74B3: 'tián',  # 璳
    0x74B4: 'chǔ',  # 璴
    0x74B5: 'yú',  # 璵
    0x74B6: 'jìn',  # 璶
    0x74B7: 'lú,fū',  # 璷
    0x74B8: 'bīn,pián',  # 璸
    0x74B9: 'shú',  # 璹
    0x74BA: 'wèn',  # 璺
    0x74BB: 'zuǐ',  # 璻
    0x74BC: 'lán',  # 璼
    0x74BD: 'xǐ',  # 璽
    0x74BE: 'jì,zī',  # 璾
    0x74BF: 'xuán',  # 璿
    0x74C0: 'ruǎn',  # 瓀
    0x74C1: 'wò',  # 瓁
    0x74C2: 'gài',  # 瓂
    0x74C3: 'léi',  # 瓃
    0x74C4: 'dú',  # 瓄
    0x74C5: 'lì',  # 瓅
    0x74C6: 'zhì',  # 瓆
    0x74C7: 'róu',  # 瓇
    0x74C8: 'lí',  # 瓈
    0x74C9: 'zàn',  # 瓉
    0x74CA: 'qióng',  # 瓊
    0x74CB: 'tì',  # 瓋
    0x74CC: 'guī',  # 瓌
    0x74CD: 'suí',  # 瓍
    0x74CE: 'là',  # 瓎
    0x74CF: 'lóng',  # 瓏
    0x74D0: 'lú',  # 瓐
    0x74D1: 'lì',  # 瓑
    0x74D2: 'zàn',  # 瓒
    0x74D3: 'làn',  # 瓓
    0x74D4: 'yīng',  # 瓔
    0x74D5: 'mí,xǐ',  # 瓕
    0x74D6: 'xiāng',  # 瓖
    0x74D7: 'qióng,wěi,wèi',  # 瓗
    0x74D8: 'guàn',  # 瓘
    0x74D9: 'dào',  # 瓙
    0x74DA: 'zàn',  # 瓚
    0x74DB: 'huán,yè,yà',  # 瓛
    0x74DC: 'guā',  # 瓜
    0x74DD: 'bó',  # 瓝
    0x74DE: 'dié',  # 瓞
    0x74DF: 'bó,páo',  # 瓟
    0x74E0: 'hù',  # 瓠
    0x74E1: 'zhí,hú',  # 瓡
    0x74E2: 'piáo',  # 瓢
    0x74E3: 'bàn',  # 瓣
    0x74E4: 'ráng',  # 瓤
    0x74E5: 'lì',  # 瓥
    0x74E6: 'wǎ,wà',  # 瓦
    0x74E7: 'shíwǎ',  # 瓧
    0x74E8: 'xiáng,hóng',  # 瓨
    0x74E9: 'qiānwǎ',  # 瓩
    0x74EA: 'bǎn',  # 瓪
    0x74EB: 'pén',  # 瓫
    0x74EC: 'fǎng',  # 瓬
    0x74ED: 'dǎn',  # 瓭
    0x74EE: 'wèng',  # 瓮
    0x74EF: 'ōu',  # 瓯
    0x74F0: 'fēnwǎ',  # 瓰
    0x74F1: 'máowǎ',  # 瓱
    0x74F2: 'túnwǎ',  # 瓲
    0x74F3: 'hú',  # 瓳
    0x74F4: 'líng',  # 瓴
    0x74F5: 'yí',  # 瓵
    0x74F6: 'píng',  # 瓶
    0x74F7: 'cí',  # 瓷
    0x74F8: 'bǎi,wǎ',  # 瓸
    0x74F9: 'juàn,juān',  # 瓹
    0x74FA: 'cháng',  # 瓺
    0x74FB: 'chī',  # 瓻
    0x74FC: 'lǐwǎ',  # 瓼
    0x74FD: 'dàng',  # 瓽
    0x74FE: 'wā',  # 瓾
    0x74FF: 'bù',  # 瓿
    0x7500: 'zhuì',  # 甀
    0x7501: 'píng',  # 甁
    0x7502: 'biān',  # 甂
    0x7503: 'zhòu',  # 甃
    0x7504: 'zhēn',  # 甄
    0x7505: 'líwǎ',  # 甅
    0x7506: 'cí',  # 甆
    0x7507: 'yīng',  # 甇
    0x7508: 'qì',  # 甈
    0x7509: 'xián',  # 甉
    0x750A: 'lǒu',  # 甊
    0x750B: 'dì',  # 甋
    0x750C: 'ōu',  # 甌
    0x750D: 'méng',  # 甍
    0x750E: 'zhuān',  # 甎
    0x750F: 'bèng',  # 甏
    0x7510: 'lìn',  # 甐
    0x7511: 'zèng',  # 甑
    0x7512: 'wǔ',  # 甒
    0x7513: 'pì',  # 甓
    0x7514: 'dān',  # 甔
    0x7515: 'wèng',  # 甕
    0x7516: 'yīng',  # 甖
    0x7517: 'yǎn',  # 甗
    0x7518: 'gān',  # 甘
    0x7519: 'dài',  # 甙
    0x751A: 'shèn,shén',  # 甚
    0x751B: 'tián',  # 甛
    0x751C: 'tián',  # 甜
    0x751D: 'hán',  # 甝
    0x751E: 'cháng',  # 甞
    0x751F: 'shēng',  # 生
    0x7520: 'qíng',  # 甠
    0x7521: 'shēn',  # 甡
    0x7522: 'chǎn',  # 產
    0x7523: 'chǎn',  # 産
    0x7524: 'ruí',  # 甤
    0x7525: 'shēng',  # 甥
    0x7526: 'sū',  # 甦
    0x7527: 'shēn',  # 甧
    0x7528: 'yòng',  # 用
    0x7529: 'shuǎi',  # 甩
    0x752A: 'lù',  # 甪
    0x752B: 'fǔ',  # 甫
    0x752C: 'yǒng',  # 甬
    0x752D: 'béng',  # 甭
    0x752E: 'béng',  # 甮
    0x752F: 'níng,nìng',  # 甯
    0x7530: 'tián',  # 田
    0x7531: 'yóu',  # 由
    0x7532: 'jiǎ',  # 甲
    0x7533: 'shēn',  # 申
    0x7534: 'yóu,zhá',  # 甴
    0x7535: 'diàn',  # 电
    0x7536: 'fú',  # 甶
    0x7537: 'nán',  # 男
    0x7538: 'diàn,tián,shèng',  # 甸
    0x7539: 'pīng',  # 甹
    0x753A: 'tǐng,dīng',  # 町
    0x753B: 'huà',  # 画
    0x753C: 'tǐng,dīng',  # 甼
    0x753D: 'zhèn',  # 甽
    0x753E: 'zāi,zī',  # 甾
    0x753F: 'méng',  # 甿
    0x7540: 'bì',  # 畀
    0x7541: 'bì,qí',  # 畁
    0x7542: 'mǔ',  # 畂
    0x7543: 'xún',  # 畃
    0x7544: 'liú',  # 畄
    0x7545: 'chàng',  # 畅
    0x7546: 'mǔ',  # 畆
    0x7547: 'yún',  # 畇
    0x7548: 'fàn',  # 畈
    0x7549: 'fú',  # 畉
    0x754A: 'gēng',  # 畊
    0x754B: 'tián',  # 畋
    0x754C: 'jiè',  # 界
    0x754D: 'jiè',  # 畍
    0x754E: 'quǎn',  # 畎
    0x754F: 'wèi',  # 畏
    0x7550: 'fú,bì',  # 畐
    0x7551: 'tián',  # 畑
    0x7552: 'mǔ',  # 畒
    0x7553: 'duō',  # 畓
    0x7554: 'pàn',  # 畔
    0x7555: 'jiāng',  # 畕
    0x7556: 'wā',  # 畖
    0x7557: 'dá,fú',  # 畗
    0x7558: 'nán',  # 畘
    0x7559: 'liú',  # 留
    0x755A: 'běn',  # 畚
    0x755B: 'zhěn',  # 畛
    0x755C: 'xù,chù',  # 畜
    0x755D: 'mǔ',  # 畝
    0x755E: 'mǔ',  # 畞
    0x755F: 'cè,jì',  # 畟
    0x7560: 'zāi,zī',  # 畠
    0x7561: 'gāi',  # 畡
    0x7562: 'bì',  # 畢
    0x7563: 'dá',  # 畣
    0x7564: 'zhì,chóu,shì',  # 畤
    0x7565: 'lüè',  # 略
    0x7566: 'qí',  # 畦
    0x7567: 'lüè',  # 畧
    0x7568: 'fān,pān',  # 畨
    0x7569: 'yī',  # 畩
    0x756A: 'fān,pān',  # 番
    0x756B: 'huà',  # 畫
    0x756C: 'shē,yú',  # 畬
    0x756D: 'shē',  # 畭
    0x756E: 'mǔ',  # 畮
    0x756F: 'jùn',  # 畯
    0x7570: 'yì',  # 異
    0x7571: 'liú',  # 畱
    0x7572: 'shē',  # 畲
    0x7573: 'dié',  # 畳
    0x7574: 'chóu',  # 畴
    0x7575: 'huà',  # 畵
    0x7576: 'dāng,dàng,dǎng',  # 當
    0x7577: 'zhuì',  # 畷
    0x7578: 'jī',  # 畸
    0x7579: 'wǎn',  # 畹
    0x757A: 'jiāng,jiàng',  # 畺
    0x757B: 'chéng',  # 畻
    0x757C: 'chàng',  # 畼
    0x757D: 'tuǎn',  # 畽
    0x757E: 'léi',  # 畾
    0x757F: 'jī',  # 畿
    0x7580: 'chā',  # 疀
    0x7581: 'liú',  # 疁
    0x7582: 'dié',  # 疂
    0x7583: 'tuǎn',  # 疃
    0x7584: 'lín,lìn',  # 疄
    0x7585: 'jiāng',  # 疅
    0x7586: 'jiāng,qiáng',  # 疆
    0x7587: 'chóu',  # 疇
    0x7588: 'pì',  # 疈
    0x7589: 'dié',  # 疉
    0x758A: 'dié',  # 疊
    0x758B: 'pǐ,yǎ,shū',  # 疋
    0x758C: 'jié,qiè',  # 疌
    0x758D: 'dàn',  # 疍
    0x758E: 'shū',  # 疎
    0x758F: 'shū',  # 疏
    0x7590: 'zhì,dì',  # 疐
    0x7591: 'yí,nǐ',  # 疑
    0x7592: 'nè',  # 疒
    0x7593: 'nǎi',  # 疓
    0x7594: 'dīng',  # 疔
    0x7595: 'bǐ',  # 疕
    0x7596: 'jiē',  # 疖
    0x7597: 'liáo',  # 疗
    0x7598: 'gāng',  # 疘
    0x7599: 'gē,yì',  # 疙
    0x759A: 'jiù',  # 疚
    0x759B: 'zhǒu',  # 疛
    0x759C: 'xià',  # 疜
    0x759D: 'shàn',  # 疝
    0x759E: 'xū',  # 疞
    0x759F: 'nüè,yào',  # 疟
    0x75A0: 'lì,lài',  # 疠
    0x75A1: 'yáng',  # 疡
    0x75A2: 'chèn',  # 疢
    0x75A3: 'yóu',  # 疣
    0x75A4: 'bā',  # 疤
    0x75A5: 'jiè',  # 疥
    0x75A6: 'jué,xuè',  # 疦
    0x75A7: 'qí',  # 疧
    0x75A8: 'yǎ,xiā',  # 疨
    0x75A9: 'cuì',  # 疩
    0x75AA: 'bì',  # 疪
    0x75AB: 'yì',  # 疫
    0x75AC: 'lì',  # 疬
    0x75AD: 'zòng',  # 疭
    0x75AE: 'chuāng',  # 疮
    0x75AF: 'fēng',  # 疯
    0x75B0: 'zhù',  # 疰
    0x75B1: 'pào',  # 疱
    0x75B2: 'pí',  # 疲
    0x75B3: 'gān',  # 疳
    0x75B4: 'kē',  # 疴
    0x75B5: 'cī',  # 疵
    0x75B6: 'xuē',  # 疶
    0x75B7: 'zhī',  # 疷
    0x75B8: 'dǎn',  # 疸
    0x75B9: 'zhěn',  # 疹
    0x75BA: 'fá,biǎn',  # 疺
    0x75BB: 'zhǐ',  # 疻
    0x75BC: 'téng',  # 疼
    0x75BD: 'jū',  # 疽
    0x75BE: 'jí',  # 疾
    0x75BF: 'fèi,féi',  # 疿
    0x75C0: 'gōu',  # 痀
    0x75C1: 'shān,diàn',  # 痁
    0x75C2: 'jiā',  # 痂
    0x75C3: 'xuán',  # 痃
    0x75C4: 'zhà',  # 痄
    0x75C5: 'bìng',  # 病
    0x75C6: 'niè',  # 痆
    0x75C7: 'zhèng,zhēng',  # 症
    0x75C8: 'yōng',  # 痈
    0x75C9: 'jìng',  # 痉
    0x75CA: 'quán',  # 痊
    0x75CB: 'téng,chóng',  # 痋
    0x75CC: 'tōng,tóng',  # 痌
    0x75CD: 'yí',  # 痍
    0x75CE: 'jiē',  # 痎
    0x75CF: 'wěi,yòu,yù',  # 痏
    0x75D0: 'huí',  # 痐
    0x75D1: 'tān,shǐ',  # 痑
    0x75D2: 'yǎng',  # 痒
    0x75D3: 'zhì',  # 痓
    0x75D4: 'zhì',  # 痔
    0x75D5: 'hén',  # 痕
    0x75D6: 'yǎ',  # 痖
    0x75D7: 'mèi',  # 痗
    0x75D8: 'dòu',  # 痘
    0x75D9: 'jìng',  # 痙
    0x75DA: 'xiāo',  # 痚
    0x75DB: 'tòng',  # 痛
    0x75DC: 'tū',  # 痜
    0x75DD: 'máng',  # 痝
    0x75DE: 'pǐ',  # 痞
    0x75DF: 'xiāo',  # 痟
    0x75E0: 'suān',  # 痠
    0x75E1: 'pū,pù',  # 痡
    0x75E2: 'lì',  # 痢
    0x75E3: 'zhì',  # 痣
    0x75E4: 'cuó',  # 痤
    0x75E5: 'duó',  # 痥
    0x75E6: 'wù',  # 痦
    0x75E7: 'shā',  # 痧
    0x75E8: 'láo',  # 痨
    0x75E9: 'shòu',  # 痩
    0x75EA: 'huàn',  # 痪
    0x75EB: 'xián',  # 痫
    0x75EC: 'yì',  # 痬
    0x75ED: 'bēng,péng',  # 痭
    0x75EE: 'zhàng',  # 痮
    0x75EF: 'guǎn',  # 痯
    0x75F0: 'tán',  # 痰
    0x75F1: 'fèi,féi',  # 痱
    0x75F2: 'má',  # 痲
    0x75F3: 'má,lìn',  # 痳
    0x75F4: 'chī',  # 痴
    0x75F5: 'jì',  # 痵
    0x75F6: 'tiǎn,diàn',  # 痶
    0x75F7: 'ān,yè,è',  # 痷
    0x75F8: 'chì',  # 痸
    0x75F9: 'bì',  # 痹
    0x75FA: 'bì',  # 痺
    0x75FB: 'mín',  # 痻
    0x75FC: 'gù',  # 痼
    0x75FD: 'duī',  # 痽
    0x75FE: 'kē,ē',  # 痾
    0x75FF: 'wěi',  # 痿
    0x7600: 'yū',  # 瘀
    0x7601: 'cuì',  # 瘁
    0x7602: 'yǎ',  # 瘂
    0x7603: 'zhú',  # 瘃
    0x7604: 'cù',  # 瘄
    0x7605: 'dàn,dān',  # 瘅
    0x7606: 'shèn',  # 瘆
    0x7607: 'zhǒng',  # 瘇
    0x7608: 'zhì,chì',  # 瘈
    0x7609: 'yù',  # 瘉
    0x760A: 'hóu',  # 瘊
    0x760B: 'fēng',  # 瘋
    0x760C: 'là',  # 瘌
    0x760D: 'yáng',  # 瘍
    0x760E: 'chén',  # 瘎
    0x760F: 'tú',  # 瘏
    0x7610: 'yǔ',  # 瘐
    0x7611: 'guō',  # 瘑
    0x7612: 'wén',  # 瘒
    0x7613: 'huàn',  # 瘓
    0x7614: 'kù',  # 瘔
    0x7615: 'jiǎ,xiá,xiā',  # 瘕
    0x7616: 'yīn',  # 瘖
    0x7617: 'yì',  # 瘗
    0x7618: 'lòu',  # 瘘
    0x7619: 'sào',  # 瘙
    0x761A: 'jué',  # 瘚
    0x761B: 'chì',  # 瘛
    0x761C: 'xī',  # 瘜
    0x761D: 'guān',  # 瘝
    0x761E: 'yì',  # 瘞
    0x761F: 'wēn',  # 瘟
    0x7620: 'jí',  # 瘠
    0x7621: 'chuāng',  # 瘡
    0x7622: 'bān',  # 瘢
    0x7623: 'huì,lěi',  # 瘣
    0x7624: 'liú',  # 瘤
    0x7625: 'chài,cuó',  # 瘥
    0x7626: 'shòu',  # 瘦
    0x7627: 'nüè,yào',  # 瘧
    0x7628: 'diān,chēn',  # 瘨
    0x7629: 'dá,da',  # 瘩
    0x762A: 'biē,biě',  # 瘪
    0x762B: 'tān',  # 瘫
    0x762C: 'zhàng',  # 瘬
    0x762D: 'biāo',  # 瘭
    0x762E: 'shèn',  # 瘮
    0x762F: 'cù',  # 瘯
    0x7630: 'luǒ',  # 瘰
    0x7631: 'yì',  # 瘱
    0x7632: 'zòng',  # 瘲
    0x7633: 'chōu',  # 瘳
    0x7634: 'zhàng',  # 瘴
    0x7635: 'zhài',  # 瘵
    0x7636: 'sòu',  # 瘶
    0x7637: 'sè',  # 瘷
    0x7638: 'qué',  # 瘸
    0x7639: 'diào',  # 瘹
    0x763A: 'lòu',  # 瘺
    0x763B: 'lòu',  # 瘻
    0x763C: 'mò',  # 瘼
    0x763D: 'qín',  # 瘽
    0x763E: 'yǐn',  # 瘾
    0x763F: 'yǐng',  # 瘿
    0x7640: 'huáng',  # 癀
    0x7641: 'fú',  # 癁
    0x7642: 'liáo',  # 療
    0x7643: 'lóng',  # 癃
    0x7644: 'qiáo,jiào',  # 癄
    0x7645: 'liú',  # 癅
    0x7646: 'láo',  # 癆
    0x7647: 'xián',  # 癇
    0x7648: 'fèi',  # 癈
    0x7649: 'dàn,dān',  # 癉
    0x764A: 'yìn',  # 癊
    0x764B: 'hè',  # 癋
    0x764C: 'ái',  # 癌
    0x764D: 'bān',  # 癍
    0x764E: 'xián',  # 癎
    0x764F: 'guān',  # 癏
    0x7650: 'guì,wēi',  # 癐
    0x7651: 'nòng,nóng',  # 癑
    0x7652: 'yù',  # 癒
    0x7653: 'wēi',  # 癓
    0x7654: 'yì',  # 癔
    0x7655: 'yōng',  # 癕
    0x7656: 'pǐ',  # 癖
    0x7657: 'lěi',  # 癗
    0x7658: 'lì,lài',  # 癘
    0x7659: 'shǔ',  # 癙
    0x765A: 'dàn',  # 癚
    0x765B: 'lǐn',  # 癛
    0x765C: 'diàn',  # 癜
    0x765D: 'lǐn',  # 癝
    0x765E: 'lài',  # 癞
    0x765F: 'biē,biě',  # 癟
    0x7660: 'jì',  # 癠
    0x7661: 'chī',  # 癡
    0x7662: 'yǎng',  # 癢
    0x7663: 'xuǎn',  # 癣
    0x7664: 'jiē',  # 癤
    0x7665: 'zhēng',  # 癥
    0x7666: 'mèng',  # 癦
    0x7667: 'lì',  # 癧
    0x7668: 'huò',  # 癨
    0x7669: 'lài',  # 癩
    0x766A: 'jī',  # 癪
    0x766B: 'diān',  # 癫
    0x766C: 'xuǎn',  # 癬
    0x766D: 'yǐng',  # 癭
    0x766E: 'yǐn',  # 癮
    0x766F: 'qú',  # 癯
    0x7670: 'yōng',  # 癰
    0x7671: 'tān',  # 癱
    0x7672: 'diān',  # 癲
    0x7673: 'luǒ',  # 癳
    0x7674: 'luán',  # 癴
    0x7675: 'luán',  # 癵
    0x7676: 'bō',  # 癶
    0x7677: 'bō,bǒ',  # 癷
    0x7678: 'guǐ',  # 癸
    0x7679: 'bá',  # 癹
    0x767A: 'fā',  # 発
    0x767B: 'dēng',  # 登
    0x767C: 'fā',  # 發
    0x767D: 'bái',  # 白
    0x767E: 'bǎi',  # 百
    0x767F: 'qié',  # 癿
    0x7680: 'jí,bī',  # 皀
    0x7681: 'zào',  # 皁
    0x7682: 'zào',  # 皂
    0x7683: 'mào',  # 皃
    0x7684: 'dí,dì,de',  # 的
    0x7685: 'pā,bà',  # 皅
    0x7686: 'jiē',  # 皆
    0x7687: 'huáng',  # 皇
    0x7688: 'guī',  # 皈
    0x7689: 'cǐ',  # 皉
    0x768A: 'líng',  # 皊
    0x768B: 'gāo,háo',  # 皋
    0x768C: 'mò',  # 皌
    0x768D: 'jí',  # 皍
    0x768E: 'jiǎo',  # 皎
    0x768F: 'pěng',  # 皏
    0x7690: 'gāo,yáo',  # 皐
    0x7691: 'ái',  # 皑
    0x7692: 'é',  # 皒
    0x7693: 'hào',  # 皓
    0x7694: 'hàn',  # 皔
    0x7695: 'bì',  # 皕
    0x7696: 'wǎn',  # 皖
    0x7697: 'chóu',  # 皗
    0x7698: 'qiàn',  # 皘
    0x7699: 'xī',  # 皙
    0x769A: 'ái',  # 皚
    0x769B: 'xiǎo',  # 皛
    0x769C: 'hào',  # 皜
    0x769D: 'huàng',  # 皝
    0x769E: 'hào',  # 皞
    0x769F: 'zé',  # 皟
    0x76A0: 'cuǐ',  # 皠
    0x76A1: 'hào',  # 皡
    0x76A2: 'xiǎo',  # 皢
    0x76A3: 'yè',  # 皣
    0x76A4: 'pó',  # 皤
    0x76A5: 'hào',  # 皥
    0x76A6: 'jiǎo',  # 皦
    0x76A7: 'ài',  # 皧
    0x76A8: 'xīng',  # 皨
    0x76A9: 'huàng',  # 皩
    0x76AA: 'lì,luò,bō',  # 皪
    0x76AB: 'piǎo',  # 皫
    0x76AC: 'hé',  # 皬
    0x76AD: 'jiào',  # 皭
    0x76AE: 'pí',  # 皮
    0x76AF: 'gǎn',  # 皯
    0x76B0: 'pào',  # 皰
    0x76B1: 'zhòu',  # 皱
    0x76B2: 'jūn',  # 皲
    0x76B3: 'qiú',  # 皳
    0x76B4: 'cūn',  # 皴
    0x76B5: 'què',  # 皵
    0x76B6: 'zhā',  # 皶
    0x76B7: 'gǔ',  # 皷
    0x76B8: 'jūn',  # 皸
    0x76B9: 'jūn',  # 皹
    0x76BA: 'zhòu',  # 皺
    0x76BB: 'zhā,cǔ',  # 皻
    0x76BC: 'gǔ',  # 皼
    0x76BD: 'zhāo,zhǎn,dǎn',  # 皽
    0x76BE: 'dú',  # 皾
    0x76BF: 'mǐn',  # 皿
    0x76C0: 'qǐ',  # 盀
    0x76C1: 'yíng',  # 盁
    0x76C2: 'yú',  # 盂
    0x76C3: 'bēi',  # 盃
    0x76C4: 'diào',  # 盄
    0x76C5: 'zhōng',  # 盅
    0x76C6: 'pén',  # 盆
    0x76C7: 'hé',  # 盇
    0x76C8: 'yíng',  # 盈
    0x76C9: 'hé',  # 盉
    0x76CA: 'yì',  # 益
    0x76CB: 'bō',  # 盋
    0x76CC: 'wǎn',  # 盌
    0x76CD: 'hé',  # 盍
    0x76CE: 'àng',  # 盎
    0x76CF: 'zhǎn',  # 盏
    0x76D0: 'yán',  # 盐
    0x76D1: 'jiān,jiàn',  # 监
    0x76D2: 'hé',  # 盒
    0x76D3: 'yū',  # 盓
    0x76D4: 'kuī',  # 盔
    0x76D5: 'fàn',  # 盕
    0x76D6: 'gài,gě,hé',  # 盖
    0x76D7: 'dào',  # 盗
    0x76D8: 'pán',  # 盘
    0x76D9: 'fǔ',  # 盙
    0x76DA: 'qiú',  # 盚
    0x76DB: 'shèng,chéng',  # 盛
    0x76DC: 'dào',  # 盜
    0x76DD: 'lù',  # 盝
    0x76DE: 'zhǎn',  # 盞
    0x76DF: 'méng',  # 盟
    0x76E0: 'lí',  # 盠
    0x76E1: 'jìn',  # 盡
    0x76E2: 'xù',  # 盢
    0x76E3: 'jiān,jiàn',  # 監
    0x76E4: 'pán',  # 盤
    0x76E5: 'guàn',  # 盥
    0x76E6: 'ān',  # 盦
    0x76E7: 'lú',  # 盧
    0x76E8: 'xǔ',  # 盨
    0x76E9: 'zhōu,chóu',  # 盩
    0x76EA: 'dàng',  # 盪
    0x76EB: 'ān',  # 盫
    0x76EC: 'gǔ',  # 盬
    0x76ED: 'lì',  # 盭
    0x76EE: 'mù',  # 目
    0x76EF: 'dīng',  # 盯
    0x76F0: 'gàn',  # 盰
    0x76F1: 'xū',  # 盱
    0x76F2: 'máng',  # 盲
    0x76F3: 'máng,wàng',  # 盳
    0x76F4: 'zhí',  # 直
    0x76F5: 'qì',  # 盵
    0x76F6: 'yuǎn',  # 盶
    0x76F7: 'xián,tián',  # 盷
    0x76F8: 'xiāng,xiàng',  # 相
    0x76F9: 'dǔn',  # 盹
    0x76FA: 'xīn',  # 盺
    0x76FB: 'xì,pǎn',  # 盻
    0x76FC: 'pàn',  # 盼
    0x76FD: 'fēng',  # 盽
    0x76FE: 'dùn',  # 盾
    0x76FF: 'mín',  # 盿
    0x7700: 'míng',  # 眀
    0x7701: 'shěng,xǐng',  # 省
    0x7702: 'shì',  # 眂
    0x7703: 'yún,hùn',  # 眃
    0x7704: 'miǎn',  # 眄
    0x7705: 'pān',  # 眅
    0x7706: 'fǎng',  # 眆
    0x7707: 'miǎo',  # 眇
    0x7708: 'dān',  # 眈
    0x7709: 'méi',  # 眉
    0x770A: 'mào',  # 眊
    0x770B: 'kàn,kān',  # 看
    0x770C: 'xiàn',  # 県
    0x770D: 'kōu',  # 眍
    0x770E: 'shì',  # 眎
    0x770F: 'yāng,yǎng,yìng',  # 眏
    0x7710: 'zhēng',  # 眐
    0x7711: 'yǎo,āo,ǎo',  # 眑
    0x7712: 'shēn',  # 眒
    0x7713: 'huò',  # 眓
    0x7714: 'dà',  # 眔
    0x7715: 'zhěn',  # 眕
    0x7716: 'kuàng',  # 眖
    0x7717: 'jū,xū,kōu',  # 眗
    0x7718: 'shèn',  # 眘
    0x7719: 'yí,chì',  # 眙
    0x771A: 'shěng',  # 眚
    0x771B: 'mèi',  # 眛
    0x771C: 'mò,miè',  # 眜
    0x771D: 'zhù',  # 眝
    0x771E: 'zhēn',  # 眞
    0x771F: 'zhēn',  # 真
    0x7720: 'mián',  # 眠
    0x7721: 'shì',  # 眡
    0x7722: 'yuān',  # 眢
    0x7723: 'dié,tì',  # 眣
    0x7724: 'nì',  # 眤
    0x7725: 'zì',  # 眥
    0x7726: 'zì',  # 眦
    0x7727: 'chǎo',  # 眧
    0x7728: 'zhǎ',  # 眨
    0x7729: 'xuàn',  # 眩
    0x772A: 'bǐng,fǎng',  # 眪
    0x772B: 'pàng,pán',  # 眫
    0x772C: 'lóng',  # 眬
    0x772D: 'guì,suī',  # 眭
    0x772E: 'tóng',  # 眮
    0x772F: 'mī,mí',  # 眯
    0x7730: 'dié,zhì',  # 眰
    0x7731: 'dì',  # 眱
    0x7732: 'nè',  # 眲
    0x7733: 'míng',  # 眳
    0x7734: 'xuàn,shùn,xún',  # 眴
    0x7735: 'chī',  # 眵
    0x7736: 'kuàng',  # 眶
    0x7737: 'juàn',  # 眷
    0x7738: 'móu',  # 眸
    0x7739: 'zhèn',  # 眹
    0x773A: 'tiào',  # 眺
    0x773B: 'yáng',  # 眻
    0x773C: 'yǎn',  # 眼
    0x773D: 'mò',  # 眽
    0x773E: 'zhòng',  # 眾
    0x773F: 'mò',  # 眿
    0x7740: 'zhuó,zháo,zhāo,zhe',  # 着
    0x7741: 'zhēng',  # 睁
    0x7742: 'méi',  # 睂
    0x7743: 'suō',  # 睃
    0x7744: 'qiáo,shào,xiāo',  # 睄
    0x7745: 'hàn',  # 睅
    0x7746: 'huǎn',  # 睆
    0x7747: 'dì',  # 睇
    0x7748: 'chěng',  # 睈
    0x7749: 'cuó,zhuài',  # 睉
    0x774A: 'juàn',  # 睊
    0x774B: 'é',  # 睋
    0x774C: 'miǎn',  # 睌
    0x774D: 'xiàn',  # 睍
    0x774E: 'xī',  # 睎
    0x774F: 'kùn',  # 睏
    0x7750: 'lài',  # 睐
    0x7751: 'jiǎn',  # 睑
    0x7752: 'shǎn',  # 睒
    0x7753: 'tiǎn',  # 睓
    0x7754: 'gùn',  # 睔
    0x7755: 'wān',  # 睕
    0x7756: 'lèng',  # 睖
    0x7757: 'shì',  # 睗
    0x7758: 'qióng',  # 睘
    0x7759: 'lì',  # 睙
    0x775A: 'yá',  # 睚
    0x775B: 'jīng',  # 睛
    0x775C: 'zhēng',  # 睜
    0x775D: 'lí',  # 睝
    0x775E: 'lài',  # 睞
    0x775F: 'suì,zuì',  # 睟
    0x7760: 'juàn',  # 睠
    0x7761: 'shuì',  # 睡
    0x7762: 'huī,suī',  # 睢
    0x7763: 'dū',  # 督
    0x7764: 'bì',  # 睤
    0x7765: 'bì,pì',  # 睥
    0x7766: 'mù',  # 睦
    0x7767: 'hūn',  # 睧
    0x7768: 'nì',  # 睨
    0x7769: 'lù',  # 睩
    0x776A: 'yì,zé,gāo',  # 睪
    0x776B: 'jié',  # 睫
    0x776C: 'cǎi',  # 睬
    0x776D: 'zhǒu',  # 睭
    0x776E: 'yú',  # 睮
    0x776F: 'hūn',  # 睯
    0x7770: 'mà',  # 睰
    0x7771: 'xià',  # 睱
    0x7772: 'xǐng,xìng',  # 睲
    0x7773: 'huī',  # 睳
    0x7774: 'hùn',  # 睴
    0x7775: 'zāi',  # 睵
    0x7776: 'chǔn',  # 睶
    0x7777: 'jiān',  # 睷
    0x7778: 'mèi',  # 睸
    0x7779: 'dǔ',  # 睹
    0x777A: 'hóu',  # 睺
    0x777B: 'xuān',  # 睻
    0x777C: 'tí',  # 睼
    0x777D: 'kuí',  # 睽
    0x777E: 'gāo',  # 睾
    0x777F: 'ruì',  # 睿
    0x7780: 'mào',  # 瞀
    0x7781: 'xù',  # 瞁
    0x7782: 'fá',  # 瞂
    0x7783: 'wò',  # 瞃
    0x7784: 'miáo',  # 瞄
    0x7785: 'chǒu',  # 瞅
    0x7786: 'guì,wèi,kuì',  # 瞆
    0x7787: 'mī,mí',  # 瞇
    0x7788: 'wěng',  # 瞈
    0x7789: 'kòu,jì',  # 瞉
    0x778A: 'dàng',  # 瞊
    0x778B: 'chēn',  # 瞋
    0x778C: 'kē',  # 瞌
    0x778D: 'sǒu',  # 瞍
    0x778E: 'xiā',  # 瞎
    0x778F: 'qióng,huán',  # 瞏
    0x7790: 'mò',  # 瞐
    0x7791: 'míng',  # 瞑
    0x7792: 'mán,mén',  # 瞒
    0x7793: 'fèn',  # 瞓
    0x7794: 'zé',  # 瞔
    0x7795: 'zhàng',  # 瞕
    0x7796: 'yì',  # 瞖
    0x7797: 'diāo,dōu',  # 瞗
    0x7798: 'kōu',  # 瞘
    0x7799: 'mò',  # 瞙
    0x779A: 'shùn',  # 瞚
    0x779B: 'cōng',  # 瞛
    0x779C: 'lóu,lǘ,lou',  # 瞜
    0x779D: 'chī',  # 瞝
    0x779E: 'mán,mén',  # 瞞
    0x779F: 'piǎo',  # 瞟
    0x77A0: 'chēng',  # 瞠
    0x77A1: 'guī',  # 瞡
    0x77A2: 'méng,měng',  # 瞢
    0x77A3: 'wàn',  # 瞣
    0x77A4: 'rún,shùn',  # 瞤
    0x77A5: 'piē',  # 瞥
    0x77A6: 'xī',  # 瞦
    0x77A7: 'qiáo',  # 瞧
    0x77A8: 'pú',  # 瞨
    0x77A9: 'zhǔ',  # 瞩
    0x77AA: 'dèng',  # 瞪
    0x77AB: 'shěn',  # 瞫
    0x77AC: 'shùn',  # 瞬
    0x77AD: 'liǎo,liào',  # 瞭
    0x77AE: 'chè',  # 瞮
    0x77AF: 'xián,jiàn',  # 瞯
    0x77B0: 'kàn',  # 瞰
    0x77B1: 'yè',  # 瞱
    0x77B2: 'xuè',  # 瞲
    0x77B3: 'tóng',  # 瞳
    0x77B4: 'wǔ,mí',  # 瞴
    0x77B5: 'lín',  # 瞵
    0x77B6: 'guì,kuì',  # 瞶
    0x77B7: 'jiàn',  # 瞷
    0x77B8: 'yè',  # 瞸
    0x77B9: 'ài',  # 瞹
    0x77BA: 'huì',  # 瞺
    0x77BB: 'zhān',  # 瞻
    0x77BC: 'jiǎn',  # 瞼
    0x77BD: 'gǔ',  # 瞽
    0x77BE: 'zhào',  # 瞾
    0x77BF: 'qú,jù',  # 瞿
    0x77C0: 'wéi',  # 矀
    0x77C1: 'chǒu',  # 矁
    0x77C2: 'sào',  # 矂
    0x77C3: 'nǐng,chēng',  # 矃
    0x77C4: 'xūn',  # 矄
    0x77C5: 'yào',  # 矅
    0x77C6: 'huò,yuè',  # 矆
    0x77C7: 'mēng',  # 矇
    0x77C8: 'mián',  # 矈
    0x77C9: 'pín',  # 矉
    0x77CA: 'mián',  # 矊
    0x77CB: 'lěi',  # 矋
    0x77CC: 'kuàng,guō',  # 矌
    0x77CD: 'jué',  # 矍
    0x77CE: 'xuān',  # 矎
    0x77CF: 'mián',  # 矏
    0x77D0: 'huò',  # 矐
    0x77D1: 'lú',  # 矑
    0x77D2: 'méng,měng',  # 矒
    0x77D3: 'lóng',  # 矓
    0x77D4: 'guàn,quán',  # 矔
    0x77D5: 'mǎn,mán',  # 矕
    0x77D6: 'xǐ',  # 矖
    0x77D7: 'chù',  # 矗
    0x77D8: 'tǎng',  # 矘
    0x77D9: 'kàn',  # 矙
    0x77DA: 'zhǔ',  # 矚
    0x77DB: 'máo',  # 矛
    0x77DC: 'jīn,qín,guān',  # 矜
    0x77DD: 'jīn,qín,guān',  # 矝
    0x77DE: 'yù,xù,jué',  # 矞
    0x77DF: 'shuò',  # 矟
    0x77E0: 'zé',  # 矠
    0x77E1: 'jué',  # 矡
    0x77E2: 'shǐ',  # 矢
    0x77E3: 'yǐ',  # 矣
    0x77E4: 'shěn',  # 矤
    0x77E5: 'zhī,zhì',  # 知
    0x77E6: 'hóu,hòu',  # 矦
    0x77E7: 'shěn',  # 矧
    0x77E8: 'yǐng',  # 矨
    0x77E9: 'jǔ',  # 矩
    0x77EA: 'zhōu',  # 矪
    0x77EB: 'jiǎo,jiáo',  # 矫
    0x77EC: 'cuó',  # 矬
    0x77ED: 'duǎn',  # 短
    0x77EE: 'ǎi',  # 矮
    0x77EF: 'jiǎo,jiáo',  # 矯
    0x77F0: 'zēng',  # 矰
    0x77F1: 'yuē',  # 矱
    0x77F2: 'bà',  # 矲
    0x77F3: 'shí,dàn',  # 石
    0x77F4: 'dìng',  # 矴
    0x77F5: 'qì',  # 矵
    0x77F6: 'jī',  # 矶
    0x77F7: 'zǐ',  # 矷
    0x77F8: 'gān',  # 矸
    0x77F9: 'wù',  # 矹
    0x77FA: 'zhé',  # 矺
    0x77FB: 'kū',  # 矻
    0x77FC: 'gāng,qiāng,kòng',  # 矼
    0x77FD: 'xī',  # 矽
    0x77FE: 'fán',  # 矾
    0x77FF: 'kuàng',  # 矿
    0x7800: 'dàng',  # 砀
    0x7801: 'mǎ',  # 码
    0x7802: 'shā',  # 砂
    0x7803: 'dān',  # 砃
    0x7804: 'jué',  # 砄
    0x7805: 'lì',  # 砅
    0x7806: 'fū',  # 砆
    0x7807: 'mín',  # 砇
    0x7808: 'è',  # 砈
    0x7809: 'xū,huā',  # 砉
    0x780A: 'kāng',  # 砊
    0x780B: 'zhǐ',  # 砋
    0x780C: 'qì,qiè',  # 砌
    0x780D: 'kǎn',  # 砍
    0x780E: 'jiè',  # 砎
    0x780F: 'pīn,bīn,fēn',  # 砏
    0x7810: 'è',  # 砐
    0x7811: 'yà',  # 砑
    0x7812: 'pī',  # 砒
    0x7813: 'zhé',  # 砓
    0x7814: 'yán,yàn',  # 研
    0x7815: 'suì',  # 砕
    0x7816: 'zhuān',  # 砖
    0x7817: 'chē',  # 砗
    0x7818: 'dùn',  # 砘
    0x7819: 'wǎ',  # 砙
    0x781A: 'yàn',  # 砚
    0x781B: 'jīn',  # 砛
    0x781C: 'fēng',  # 砜
    0x781D: 'fǎ',  # 砝
    0x781E: 'mò',  # 砞
    0x781F: 'zhǎ',  # 砟
    0x7820: 'jū',  # 砠
    0x7821: 'yù',  # 砡
    0x7822: 'kē,luǒ',  # 砢
    0x7823: 'tuó',  # 砣
    0x7824: 'tuó',  # 砤
    0x7825: 'dǐ',  # 砥
    0x7826: 'zhài',  # 砦
    0x7827: 'zhēn',  # 砧
    0x7828: 'ě',  # 砨
    0x7829: 'fú,fèi',  # 砩
    0x782A: 'mǔ',  # 砪
    0x782B: 'zhù,zhǔ',  # 砫
    0x782C: 'lì,lā,lá',  # 砬
    0x782D: 'biān',  # 砭
    0x782E: 'nǔ',  # 砮
    0x782F: 'pīng',  # 砯
    0x7830: 'pēng',  # 砰
    0x7831: 'líng',  # 砱
    0x7832: 'pào',  # 砲
    0x7833: 'lè',  # 砳
    0x7834: 'pò',  # 破
    0x7835: 'bō',  # 砵
    0x7836: 'pò',  # 砶
    0x7837: 'shēn',  # 砷
    0x7838: 'zá',  # 砸
    0x7839: 'ài',  # 砹
    0x783A: 'lì',  # 砺
    0x783B: 'lóng',  # 砻
    0x783C: 'tóng',  # 砼
    0x783D: 'yòng',  # 砽
    0x783E: 'lì',  # 砾
    0x783F: 'kuàng',  # 砿
    0x7840: 'chǔ',  # 础
    0x7841: 'kēng',  # 硁
    0x7842: 'quán',  # 硂
    0x7843: 'zhū',  # 硃
    0x7844: 'kuāng,guāng',  # 硄
    0x7845: 'guī',  # 硅
    0x7846: 'è',  # 硆
    0x7847: 'náo',  # 硇
    0x7848: 'qià',  # 硈
    0x7849: 'lù',  # 硉
    0x784A: 'wěi,guì',  # 硊
    0x784B: 'ài',  # 硋
    0x784C: 'luò,gè',  # 硌
    0x784D: 'kèn,xiàn,gǔn,yǐn',  # 硍
    0x784E: 'xíng',  # 硎
    0x784F: 'yán,yàn',  # 硏
    0x7850: 'dòng',  # 硐
    0x7851: 'pēng,píng',  # 硑
    0x7852: 'xī',  # 硒
    0x7853: 'lǎo',  # 硓
    0x7854: 'hóng',  # 硔
    0x7855: 'shuò,shí',  # 硕
    0x7856: 'xiá',  # 硖
    0x7857: 'qiāo',  # 硗
    0x7858: 'qíng',  # 硘
    0x7859: 'wéi,wèi',  # 硙
    0x785A: 'qiáo',  # 硚
    0x785B: 'ceok',  # 硛
    0x785C: 'kēng',  # 硜
    0x785D: 'xiāo',  # 硝
    0x785E: 'què,kè,kù',  # 硞
    0x785F: 'chàn',  # 硟
    0x7860: 'láng',  # 硠
    0x7861: 'hōng',  # 硡
    0x7862: 'yù',  # 硢
    0x7863: 'xiāo',  # 硣
    0x7864: 'xiá',  # 硤
    0x7865: 'mǎng,bàng',  # 硥
    0x7866: 'luò,lòng',  # 硦
    0x7867: 'yǒng,tóng',  # 硧
    0x7868: 'chē',  # 硨
    0x7869: 'chè',  # 硩
    0x786A: 'wò',  # 硪
    0x786B: 'liú',  # 硫
    0x786C: 'yìng',  # 硬
    0x786D: 'máng',  # 硭
    0x786E: 'què',  # 确
    0x786F: 'yàn',  # 硯
    0x7870: 'shā',  # 硰
    0x7871: 'kǔn',  # 硱
    0x7872: 'yù',  # 硲
    0x7873: 'ceok',  # 硳
    0x7874: 'huā',  # 硴
    0x7875: 'lǔ',  # 硵
    0x7876: 'chěn',  # 硶
    0x7877: 'jiǎn',  # 硷
    0x7878: 'nüè',  # 硸
    0x7879: 'sōng',  # 硹
    0x787A: 'zhuó',  # 硺
    0x787B: 'kēng,kěng',  # 硻
    0x787C: 'péng',  # 硼
    0x787D: 'yān,yǎn',  # 硽
    0x787E: 'zhuì,chuí,duǒ',  # 硾
    0x787F: 'kōng',  # 硿
    0x7880: 'chēng',  # 碀
    0x7881: 'qí',  # 碁
    0x7882: 'zòng,cóng',  # 碂
    0x7883: 'qìng',  # 碃
    0x7884: 'lín',  # 碄
    0x7885: 'jūn',  # 碅
    0x7886: 'bō',  # 碆
    0x7887: 'dìng',  # 碇
    0x7888: 'mín',  # 碈
    0x7889: 'diāo',  # 碉
    0x788A: 'jiān,zhàn',  # 碊
    0x788B: 'hè',  # 碋
    0x788C: 'lù,liù',  # 碌
    0x788D: 'ài',  # 碍
    0x788E: 'suì',  # 碎
    0x788F: 'què,xī',  # 碏
    0x7890: 'léng',  # 碐
    0x7891: 'bēi',  # 碑
    0x7892: 'yín',  # 碒
    0x7893: 'duì',  # 碓
    0x7894: 'wǔ',  # 碔
    0x7895: 'qí',  # 碕
    0x7896: 'lún,lǔn,lùn',  # 碖
    0x7897: 'wǎn',  # 碗
    0x7898: 'diǎn',  # 碘
    0x7899: 'náo,gāng',  # 碙
    0x789A: 'bèi',  # 碚
    0x789B: 'qì',  # 碛
    0x789C: 'chěn',  # 碜
    0x789D: 'ruǎn',  # 碝
    0x789E: 'yán',  # 碞
    0x789F: 'dié',  # 碟
    0x78A0: 'dìng',  # 碠
    0x78A1: 'zhóu',  # 碡
    0x78A2: 'tuó',  # 碢
    0x78A3: 'jié,yà',  # 碣
    0x78A4: 'yīng',  # 碤
    0x78A5: 'biǎn',  # 碥
    0x78A6: 'kè',  # 碦
    0x78A7: 'bì',  # 碧
    0x78A8: 'wěi,wèi',  # 碨
    0x78A9: 'shuò,shí',  # 碩
    0x78AA: 'zhēn',  # 碪
    0x78AB: 'duàn',  # 碫
    0x78AC: 'xiá',  # 碬
    0x78AD: 'dàng',  # 碭
    0x78AE: 'tí,dī',  # 碮
    0x78AF: 'nǎo',  # 碯
    0x78B0: 'pèng',  # 碰
    0x78B1: 'jiǎn',  # 碱
    0x78B2: 'dì',  # 碲
    0x78B3: 'tàn',  # 碳
    0x78B4: 'chá,chā',  # 碴
    0x78B5: 'tián',  # 碵
    0x78B6: 'qì',  # 碶
    0x78B7: 'dùn',  # 碷
    0x78B8: 'fēng',  # 碸
    0x78B9: 'xuàn',  # 碹
    0x78BA: 'què',  # 確
    0x78BB: 'què,qiāo',  # 碻
    0x78BC: 'mǎ',  # 碼
    0x78BD: 'gōng',  # 碽
    0x78BE: 'niǎn',  # 碾
    0x78BF: 'sù,xiè',  # 碿
    0x78C0: 'é',  # 磀
    0x78C1: 'cí',  # 磁
    0x78C2: 'liú,liù',  # 磂
    0x78C3: 'sī,tí',  # 磃
    0x78C4: 'táng',  # 磄
    0x78C5: 'bàng,páng',  # 磅
    0x78C6: 'huá,kě,gū',  # 磆
    0x78C7: 'pī',  # 磇
    0x78C8: 'kuǐ,wěi',  # 磈
    0x78C9: 'sǎng',  # 磉
    0x78CA: 'lěi',  # 磊
    0x78CB: 'cuō',  # 磋
    0x78CC: 'tián',  # 磌
    0x78CD: 'xiá,qià,yà',  # 磍
    0x78CE: 'xī',  # 磎
    0x78CF: 'lián,qiān',  # 磏
    0x78D0: 'pán',  # 磐
    0x78D1: 'ái,wèi',  # 磑
    0x78D2: 'yǔn',  # 磒
    0x78D3: 'duī',  # 磓
    0x78D4: 'zhé',  # 磔
    0x78D5: 'kē',  # 磕
    0x78D6: 'lá,lā',  # 磖
    0x78D7: 'zhuān',  # 磗
    0x78D8: 'yáo',  # 磘
    0x78D9: 'gǔn',  # 磙
    0x78DA: 'zhuān',  # 磚
    0x78DB: 'chán',  # 磛
    0x78DC: 'qì',  # 磜
    0x78DD: 'áo,qiāo',  # 磝
    0x78DE: 'pēng,pèng',  # 磞
    0x78DF: 'liù',  # 磟
    0x78E0: 'lǔ',  # 磠
    0x78E1: 'kàn',  # 磡
    0x78E2: 'chuǎng',  # 磢
    0x78E3: 'chěn',  # 磣
    0x78E4: 'yīn,yǐn',  # 磤
    0x78E5: 'lěi,léi',  # 磥
    0x78E6: 'biāo',  # 磦
    0x78E7: 'qì',  # 磧
    0x78E8: 'mó,mò',  # 磨
    0x78E9: 'qì,zhú',  # 磩
    0x78EA: 'cuī',  # 磪
    0x78EB: 'zōng',  # 磫
    0x78EC: 'qìng',  # 磬
    0x78ED: 'chuò',  # 磭
    0x78EE: 'lún',  # 磮
    0x78EF: 'jī',  # 磯
    0x78F0: 'shàn',  # 磰
    0x78F1: 'láo,luò',  # 磱
    0x78F2: 'qú',  # 磲
    0x78F3: 'zēng',  # 磳
    0x78F4: 'dèng',  # 磴
    0x78F5: 'jiàn',  # 磵
    0x78F6: 'xì',  # 磶
    0x78F7: 'lín',  # 磷
    0x78F8: 'dìng',  # 磸
    0x78F9: 'diàn',  # 磹
    0x78FA: 'huáng',  # 磺
    0x78FB: 'pán,bō',  # 磻
    0x78FC: 'jí,shé',  # 磼
    0x78FD: 'qiāo',  # 磽
    0x78FE: 'dī',  # 磾
    0x78FF: 'lì',  # 磿
    0x7900: 'jiàn',  # 礀
    0x7901: 'jiāo',  # 礁
    0x7902: 'xī',  # 礂
    0x7903: 'zhǎng',  # 礃
    0x7904: 'qiáo',  # 礄
    0x7905: 'dūn',  # 礅
    0x7906: 'jiǎn',  # 礆
    0x7907: 'yù',  # 礇
    0x7908: 'zhuì',  # 礈
    0x7909: 'hé,qiāo,qiào',  # 礉
    0x790A: 'kè,huò',  # 礊
    0x790B: 'zé',  # 礋
    0x790C: 'léi,lěi',  # 礌
    0x790D: 'jié',  # 礍
    0x790E: 'chǔ',  # 礎
    0x790F: 'yè',  # 礏
    0x7910: 'què,hú',  # 礐
    0x7911: 'dàng',  # 礑
    0x7912: 'yǐ',  # 礒
    0x7913: 'jiāng',  # 礓
    0x7914: 'pī',  # 礔
    0x7915: 'pī',  # 礕
    0x7916: 'yù',  # 礖
    0x7917: 'pīn',  # 礗
    0x7918: 'è,qì',  # 礘
    0x7919: 'ài',  # 礙
    0x791A: 'kē',  # 礚
    0x791B: 'jiān',  # 礛
    0x791C: 'yù',  # 礜
    0x791D: 'ruǎn',  # 礝
    0x791E: 'méng',  # 礞
    0x791F: 'pào',  # 礟
    0x7920: 'cí',  # 礠
    0x7921: 'bō',  # 礡
    0x7922: 'yǎng',  # 礢
    0x7923: 'miè',  # 礣
    0x7924: 'cǎ',  # 礤
    0x7925: 'xián,xín',  # 礥
    0x7926: 'kuàng',  # 礦
    0x7927: 'léi,lěi,lèi',  # 礧
    0x7928: 'lěi',  # 礨
    0x7929: 'zhì',  # 礩
    0x792A: 'lì',  # 礪
    0x792B: 'lì',  # 礫
    0x792C: 'fán',  # 礬
    0x792D: 'què',  # 礭
    0x792E: 'pào',  # 礮
    0x792F: 'yīng',  # 礯
    0x7930: 'lì',  # 礰
    0x7931: 'lóng',  # 礱
    0x7932: 'lóng',  # 礲
    0x7933: 'mò',  # 礳
    0x7934: 'bó',  # 礴
    0x7935: 'shuāng',  # 礵
    0x7936: 'guàn',  # 礶
    0x7937: 'jiān',  # 礷
    0x7938: 'cǎ',  # 礸
    0x7939: 'yán,yǎn',  # 礹
    0x793A: 'shì',  # 示
    0x793B: 'shì',  # 礻
    0x793C: 'lǐ',  # 礼
    0x793D: 'réng',  # 礽
    0x793E: 'shè',  # 社
    0x793F: 'yuè',  # 礿
    0x7940: 'sì',  # 祀
    0x7941: 'qí',  # 祁
    0x7942: 'tā',  # 祂
    0x7943: 'mà',  # 祃
    0x7944: 'xiè',  # 祄
    0x7945: 'yāo',  # 祅
    0x7946: 'xiān',  # 祆
    0x7947: 'zhǐ,qí',  # 祇
    0x7948: 'qí',  # 祈
    0x7949: 'zhǐ',  # 祉
    0x794A: 'bēng,fāng',  # 祊
    0x794B: 'duì',  # 祋
    0x794C: 'zhòng',  # 祌
    0x794D: 'rèn',  # 祍
    0x794E: 'yī',  # 祎
    0x794F: 'shí',  # 祏
    0x7950: 'yòu',  # 祐
    0x7951: 'zhì',  # 祑
    0x7952: 'tiáo',  # 祒
    0x7953: 'fú',  # 祓
    0x7954: 'fù',  # 祔
    0x7955: 'mì,bì',  # 祕
    0x7956: 'zǔ',  # 祖
    0x7957: 'zhī',  # 祗
    0x7958: 'suàn',  # 祘
    0x7959: 'mèi',  # 祙
    0x795A: 'zuò',  # 祚
    0x795B: 'qū',  # 祛
    0x795C: 'hù',  # 祜
    0x795D: 'zhù',  # 祝
    0x795E: 'shén',  # 神
    0x795F: 'suì',  # 祟
    0x7960: 'cí',  # 祠
    0x7961: 'chái',  # 祡
    0x7962: 'mí',  # 祢
    0x7963: 'lǚ',  # 祣
    0x7964: 'yǔ',  # 祤
    0x7965: 'xiáng',  # 祥
    0x7966: 'wú',  # 祦
    0x7967: 'tiāo',  # 祧
    0x7968: 'piào,piāo',  # 票
    0x7969: 'zhù',  # 祩
    0x796A: 'guǐ',  # 祪
    0x796B: 'xiá',  # 祫
    0x796C: 'zhī',  # 祬
    0x796D: 'jì,zhài',  # 祭
    0x796E: 'gào',  # 祮
    0x796F: 'zhēn',  # 祯
    0x7970: 'gào',  # 祰
    0x7971: 'shuì,lèi',  # 祱
    0x7972: 'jìn',  # 祲
    0x7973: 'shèn',  # 祳
    0x7974: 'gāi',  # 祴
    0x7975: 'kǔn',  # 祵
    0x7976: 'dì',  # 祶
    0x7977: 'dǎo',  # 祷
    0x7978: 'huò',  # 祸
    0x7979: 'táo',  # 祹
    0x797A: 'qí',  # 祺
    0x797B: 'gù',  # 祻
    0x797C: 'guàn',  # 祼
    0x797D: 'zuì',  # 祽
    0x797E: 'líng',  # 祾
    0x797F: 'lù',  # 祿
    0x7980: 'bǐng',  # 禀
    0x7981: 'jīn,jìn',  # 禁
    0x7982: 'dǎo',  # 禂
    0x7983: 'zhí',  # 禃
    0x7984: 'lù',  # 禄
    0x7985: 'chán,shàn',  # 禅
    0x7986: 'bì,pí',  # 禆
    0x7987: 'chǔ',  # 禇
    0x7988: 'huī',  # 禈
    0x7989: 'yǒu',  # 禉
    0x798A: 'xì',  # 禊
    0x798B: 'yīn',  # 禋
    0x798C: 'zī',  # 禌
    0x798D: 'huò',  # 禍
    0x798E: 'zhēn',  # 禎
    0x798F: 'fú',  # 福
    0x7990: 'yuàn',  # 禐
    0x7991: 'xú',  # 禑
    0x7992: 'xiǎn',  # 禒
    0x7993: 'shāng,yáng',  # 禓
    0x7994: 'tí,zhǐ',  # 禔
    0x7995: 'yī',  # 禕
    0x7996: 'méi',  # 禖
    0x7997: 'sī',  # 禗
    0x7998: 'dì',  # 禘
    0x7999: 'bèi',  # 禙
    0x799A: 'zhuó',  # 禚
    0x799B: 'zhēn',  # 禛
    0x799C: 'yíng',  # 禜
    0x799D: 'jì',  # 禝
    0x799E: 'gào',  # 禞
    0x799F: 'táng',  # 禟
    0x79A0: 'sī',  # 禠
    0x79A1: 'mà',  # 禡
    0x79A2: 'tà',  # 禢
    0x79A3: 'fù',  # 禣
    0x79A4: 'xuān',  # 禤
    0x79A5: 'qí',  # 禥
    0x79A6: 'yù',  # 禦
    0x79A7: 'xǐ',  # 禧
    0x79A8: 'jī,jì',  # 禨
    0x79A9: 'sì',  # 禩
    0x79AA: 'shàn,chán',  # 禪
    0x79AB: 'dàn',  # 禫
    0x79AC: 'guì',  # 禬
    0x79AD: 'suì',  # 禭
    0x79AE: 'lǐ',  # 禮
    0x79AF: 'nóng',  # 禯
    0x79B0: 'mí',  # 禰
    0x79B1: 'dǎo',  # 禱
    0x79B2: 'lì',  # 禲
    0x79B3: 'ráng',  # 禳
    0x79B4: 'yuè',  # 禴
    0x79B5: 'tí',  # 禵
    0x79B6: 'zàn',  # 禶
    0x79B7: 'lèi',  # 禷
    0x79B8: 'róu',  # 禸
    0x79B9: 'yǔ',  # 禹
    0x79BA: 'yú,yù,ǒu',  # 禺
    0x79BB: 'lí',  # 离
    0x79BC: 'xiè',  # 禼
    0x79BD: 'qín',  # 禽
    0x79BE: 'hé',  # 禾
    0x79BF: 'tū',  # 禿
    0x79C0: 'xiù',  # 秀
    0x79C1: 'sī',  # 私
    0x79C2: 'rén',  # 秂
    0x79C3: 'tū',  # 秃
    0x79C4: 'zǐ,zì',  # 秄
    0x79C5: 'chá,ná',  # 秅
    0x79C6: 'gǎn',  # 秆
    0x79C7: 'yì,zhí',  # 秇
    0x79C8: 'xiān',  # 秈
    0x79C9: 'bǐng',  # 秉
    0x79CA: 'nián',  # 秊
    0x79CB: 'qiū',  # 秋
    0x79CC: 'qiū',  # 秌
    0x79CD: 'zhǒng,zhòng,chóng',  # 种
    0x79CE: 'fèn',  # 秎
    0x79CF: 'hào,mào',  # 秏
    0x79D0: 'yún',  # 秐
    0x79D1: 'kē',  # 科
    0x79D2: 'miǎo',  # 秒
    0x79D3: 'zhī',  # 秓
    0x79D4: 'jīng',  # 秔
    0x79D5: 'bǐ',  # 秕
    0x79D6: 'zhǐ',  # 秖
    0x79D7: 'yù',  # 秗
    0x79D8: 'mì,bì',  # 秘
    0x79D9: 'kù,kū',  # 秙
    0x79DA: 'bàn',  # 秚
    0x79DB: 'pī',  # 秛
    0x79DC: 'ní,nì',  # 秜
    0x79DD: 'lì',  # 秝
    0x79DE: 'yóu',  # 秞
    0x79DF: 'zū',  # 租
    0x79E0: 'pī',  # 秠
    0x79E1: 'bó',  # 秡
    0x79E2: 'líng',  # 秢
    0x79E3: 'mò',  # 秣
    0x79E4: 'chèng',  # 秤
    0x79E5: 'nián',  # 秥
    0x79E6: 'qín',  # 秦
    0x79E7: 'yāng',  # 秧
    0x79E8: 'zuó',  # 秨
    0x79E9: 'zhì',  # 秩
    0x79EA: 'dī',  # 秪
    0x79EB: 'shú',  # 秫
    0x79EC: 'jù',  # 秬
    0x79ED: 'zǐ',  # 秭
    0x79EE: 'huó,kuò',  # 秮
    0x79EF: 'jī',  # 积
    0x79F0: 'chēng,chèn,chèng',  # 称
    0x79F1: 'tóng',  # 秱
    0x79F2: 'shì,zhì',  # 秲
    0x79F3: 'huó,kuò',  # 秳
    0x79F4: 'huō',  # 秴
    0x79F5: 'yīn',  # 秵
    0x79F6: 'zī',  # 秶
    0x79F7: 'zhì',  # 秷
    0x79F8: 'jiē',  # 秸
    0x79F9: 'rěn',  # 秹
    0x79FA: 'dù',  # 秺
    0x79FB: 'yí',  # 移
    0x79FC: 'zhū',  # 秼
    0x79FD: 'huì',  # 秽
    0x79FE: 'nóng',  # 秾
    0x79FF: 'fù,pū',  # 秿
    0x7A00: 'xī',  # 稀
    0x7A01: 'gǎo',  # 稁
    0x7A02: 'láng',  # 稂
    0x7A03: 'fū',  # 稃
    0x7A04: 'xùn,zè',  # 稄
    0x7A05: 'shuì',  # 稅
    0x7A06: 'lǚ',  # 稆
    0x7A07: 'kǔn',  # 稇
    0x7A08: 'gǎn',  # 稈
    0x7A09: 'jīng',  # 稉
    0x7A0A: 'tí',  # 稊
    0x7A0B: 'chéng',  # 程
    0x7A0C: 'tú,shǔ',  # 稌
    0x7A0D: 'shāo,shào',  # 稍
    0x7A0E: 'shuì',  # 税
    0x7A0F: 'yà',  # 稏
    0x7A10: 'lǔn',  # 稐
    0x7A11: 'lù',  # 稑
    0x7A12: 'gū',  # 稒
    0x7A13: 'zuó',  # 稓
    0x7A14: 'rěn',  # 稔
    0x7A15: 'zhùn,zhǔn',  # 稕
    0x7A16: 'bàng',  # 稖
    0x7A17: 'bài',  # 稗
    0x7A18: 'jī,qí',  # 稘
    0x7A19: 'zhī',  # 稙
    0x7A1A: 'zhì',  # 稚
    0x7A1B: 'kǔn',  # 稛
    0x7A1C: 'léng,lēng,líng',  # 稜
    0x7A1D: 'péng',  # 稝
    0x7A1E: 'kē',  # 稞
    0x7A1F: 'bǐng',  # 稟
    0x7A20: 'chóu',  # 稠
    0x7A21: 'zuì,zú,sū',  # 稡
    0x7A22: 'yù',  # 稢
    0x7A23: 'sū',  # 稣
    0x7A24: 'lüè',  # 稤
    0x7A25: 'xiāng',  # 稥
    0x7A26: 'yī',  # 稦
    0x7A27: 'xì,qiè',  # 稧
    0x7A28: 'biǎn',  # 稨
    0x7A29: 'jì',  # 稩
    0x7A2A: 'fú',  # 稪
    0x7A2B: 'pì,bì',  # 稫
    0x7A2C: 'nuò',  # 稬
    0x7A2D: 'jiē',  # 稭
    0x7A2E: 'zhǒng,zhòng',  # 種
    0x7A2F: 'zōng,zǒng',  # 稯
    0x7A30: 'xǔ,xū',  # 稰
    0x7A31: 'chēng,chèn,chèng',  # 稱
    0x7A32: 'dào',  # 稲
    0x7A33: 'wěn',  # 稳
    0x7A34: 'xián,jiān,liàn',  # 稴
    0x7A35: 'zī,jiū',  # 稵
    0x7A36: 'yù',  # 稶
    0x7A37: 'jì',  # 稷
    0x7A38: 'xù',  # 稸
    0x7A39: 'zhěn',  # 稹
    0x7A3A: 'zhì',  # 稺
    0x7A3B: 'dào',  # 稻
    0x7A3C: 'jià',  # 稼
    0x7A3D: 'jī,qǐ',  # 稽
    0x7A3E: 'gǎo',  # 稾
    0x7A3F: 'gǎo',  # 稿
    0x7A40: 'gǔ',  # 穀
    0x7A41: 'róng',  # 穁
    0x7A42: 'suì',  # 穂
    0x7A43: 'ròng',  # 穃
    0x7A44: 'jì',  # 穄
    0x7A45: 'kāng',  # 穅
    0x7A46: 'mù',  # 穆
    0x7A47: 'cǎn,shān,cēn',  # 穇
    0x7A48: 'mén,méi',  # 穈
    0x7A49: 'zhì',  # 穉
    0x7A4A: 'jì',  # 穊
    0x7A4B: 'lù',  # 穋
    0x7A4C: 'sū',  # 穌
    0x7A4D: 'jī',  # 積
    0x7A4E: 'yǐng',  # 穎
    0x7A4F: 'wěn',  # 穏
    0x7A50: 'qiū',  # 穐
    0x7A51: 'sè',  # 穑
    0x7A52: 'kweok',  # 穒
    0x7A53: 'yì',  # 穓
    0x7A54: 'huáng',  # 穔
    0x7A55: 'qiè',  # 穕
    0x7A56: 'jǐ,jì',  # 穖
    0x7A57: 'suì',  # 穗
    0x7A58: 'xiāo,rào',  # 穘
    0x7A59: 'pú',  # 穙
    0x7A5A: 'jiāo',  # 穚
    0x7A5B: 'zhuō,bó',  # 穛
    0x7A5C: 'tóng,zhǒng',  # 穜
    0x7A5D: 'zuō',  # 穝
    0x7A5E: 'lǔ',  # 穞
    0x7A5F: 'suì',  # 穟
    0x7A60: 'nóng',  # 穠
    0x7A61: 'sè',  # 穡
    0x7A62: 'huì',  # 穢
    0x7A63: 'ráng',  # 穣
    0x7A64: 'nuò',  # 穤
    0x7A65: 'yǔ',  # 穥
    0x7A66: 'pīn',  # 穦
    0x7A67: 'jì',  # 穧
    0x7A68: 'tuí',  # 穨
    0x7A69: 'wěn',  # 穩
    0x7A6A: 'chēng,chèn,chèng',  # 穪
    0x7A6B: 'huò',  # 穫
    0x7A6C: 'kuàng',  # 穬
    0x7A6D: 'lǚ',  # 穭
    0x7A6E: 'biāo,pāo',  # 穮
    0x7A6F: 'sè',  # 穯
    0x7A70: 'ráng',  # 穰
    0x7A71: 'zhuō,jué',  # 穱
    0x7A72: 'lí',  # 穲
    0x7A73: 'cuán,zàn',  # 穳
    0x7A74: 'xué',  # 穴
    0x7A75: 'wā',  # 穵
    0x7A76: 'jiū',  # 究
    0x7A77: 'qióng',  # 穷
    0x7A78: 'xī',  # 穸
    0x7A79: 'qióng',  # 穹
    0x7A7A: 'kōng,kòng,kǒng',  # 空
    0x7A7B: 'yū,yǔ',  # 穻
    0x7A7C: 'shēn',  # 穼
    0x7A7D: 'jǐng',  # 穽
    0x7A7E: 'yào',  # 穾
    0x7A7F: 'chuān',  # 穿
    0x7A80: 'zhūn',  # 窀
    0x7A81: 'tū',  # 突
    0x7A82: 'láo',  # 窂
    0x7A83: 'qiè',  # 窃
    0x7A84: 'zhǎi',  # 窄
    0x7A85: 'yǎo',  # 窅
    0x7A86: 'biǎn',  # 窆
    0x7A87: 'báo',  # 窇
    0x7A88: 'yǎo',  # 窈
    0x7A89: 'bìng',  # 窉
    0x7A8A: 'wā',  # 窊
    0x7A8B: 'zhú,kū',  # 窋
    0x7A8C: 'jiào,liáo,liù',  # 窌
    0x7A8D: 'qiào',  # 窍
    0x7A8E: 'diào',  # 窎
    0x7A8F: 'wū',  # 窏
    0x7A90: 'wā,guī',  # 窐
    0x7A91: 'yáo',  # 窑
    0x7A92: 'zhì',  # 窒
    0x7A93: 'chuāng',  # 窓
    0x7A94: 'yào',  # 窔
    0x7A95: 'tiǎo,yáo',  # 窕
    0x7A96: 'jiào',  # 窖
    0x7A97: 'chuāng',  # 窗
    0x7A98: 'jiǒng',  # 窘
    0x7A99: 'xiāo',  # 窙
    0x7A9A: 'chéng',  # 窚
    0x7A9B: 'kòu',  # 窛
    0x7A9C: 'cuàn',  # 窜
    0x7A9D: 'wō',  # 窝
    0x7A9E: 'dàn',  # 窞
    0x7A9F: 'kū',  # 窟
    0x7AA0: 'kē',  # 窠
    0x7AA1: 'zhuó',  # 窡
    0x7AA2: 'huò',  # 窢
    0x7AA3: 'sū',  # 窣
    0x7AA4: 'guān',  # 窤
    0x7AA5: 'kuī',  # 窥
    0x7AA6: 'dòu',  # 窦
    0x7AA7: 'zhuō',  # 窧
    0x7AA8: 'yìn,xūn',  # 窨
    0x7AA9: 'wō',  # 窩
    0x7AAA: 'wā',  # 窪
    0x7AAB: 'yà,yē',  # 窫
    0x7AAC: 'yú',  # 窬
    0x7AAD: 'jù',  # 窭
    0x7AAE: 'qióng',  # 窮
    0x7AAF: 'yáo',  # 窯
    0x7AB0: 'yáo',  # 窰
    0x7AB1: 'tiǎo',  # 窱
    0x7AB2: 'cháo',  # 窲
    0x7AB3: 'yǔ',  # 窳
    0x7AB4: 'tián,diān,yǎn',  # 窴
    0x7AB5: 'diào',  # 窵
    0x7AB6: 'jù',  # 窶
    0x7AB7: 'liào',  # 窷
    0x7AB8: 'xī',  # 窸
    0x7AB9: 'wù',  # 窹
    0x7ABA: 'kuī',  # 窺
    0x7ABB: 'chuāng',  # 窻
    0x7ABC: 'chāo,kē',  # 窼
    0x7ABD: 'kuǎn,cuàn',  # 窽
    0x7ABE: 'kuǎn,cuàn',  # 窾
    0x7ABF: 'lóng',  # 窿
    0x7AC0: 'chēng,chèng',  # 竀
    0x7AC1: 'cuì',  # 竁
    0x7AC2: 'liáo',  # 竂
    0x7AC3: 'zào',  # 竃
    0x7AC4: 'cuàn',  # 竄
    0x7AC5: 'qiào',  # 竅
    0x7AC6: 'qióng',  # 竆
    0x7AC7: 'dòu',  # 竇
    0x7AC8: 'zào',  # 竈
    0x7AC9: 'lǒng',  # 竉
    0x7ACA: 'qiè',  # 竊
    0x7ACB: 'lì',  # 立
    0x7ACC: 'chù',  # 竌
    0x7ACD: 'shí',  # 竍
    0x7ACE: 'fù',  # 竎
    0x7ACF: 'qiān',  # 竏
    0x7AD0: 'chù,qì',  # 竐
    0x7AD1: 'hóng',  # 竑
    0x7AD2: 'qí',  # 竒
    0x7AD3: 'háo',  # 竓
    0x7AD4: 'shēng',  # 竔
    0x7AD5: 'fēn',  # 竕
    0x7AD6: 'shù',  # 竖
    0x7AD7: 'miào',  # 竗
    0x7AD8: 'qǔ,kǒu',  # 竘
    0x7AD9: 'zhàn',  # 站
    0x7ADA: 'zhù',  # 竚
    0x7ADB: 'líng',  # 竛
    0x7ADC: 'lóng',  # 竜
    0x7ADD: 'bìng',  # 竝
    0x7ADE: 'jìng',  # 竞
    0x7ADF: 'jìng',  # 竟
    0x7AE0: 'zhāng',  # 章
    0x7AE1: 'bǎi',  # 竡
    0x7AE2: 'sì',  # 竢
    0x7AE3: 'jùn',  # 竣
    0x7AE4: 'hóng',  # 竤
    0x7AE5: 'tóng',  # 童
    0x7AE6: 'sǒng',  # 竦
    0x7AE7: 'jìng,zhěn',  # 竧
    0x7AE8: 'diào',  # 竨
    0x7AE9: 'yì',  # 竩
    0x7AEA: 'shù',  # 竪
    0x7AEB: 'jìng',  # 竫
    0x7AEC: 'qǔ',  # 竬
    0x7AED: 'jié',  # 竭
    0x7AEE: 'píng',  # 竮
    0x7AEF: 'duān',  # 端
    0x7AF0: 'lí',  # 竰
    0x7AF1: 'zhuǎn',  # 竱
    0x7AF2: 'céng,zēng',  # 竲
    0x7AF3: 'dēng',  # 竳
    0x7AF4: 'cūn',  # 竴
    0x7AF5: 'wāi',  # 竵
    0x7AF6: 'jìng',  # 競
    0x7AF7: 'kǎn,kàn',  # 竷
    0x7AF8: 'jìng',  # 竸
    0x7AF9: 'zhú',  # 竹
    0x7AFA: 'zhú,dǔ',  # 竺
    0x7AFB: 'lè,jīn',  # 竻
    0x7AFC: 'péng',  # 竼
    0x7AFD: 'yú',  # 竽
    0x7AFE: 'chí',  # 竾
    0x7AFF: 'gān',  # 竿
    0x7B00: 'máng',  # 笀
    0x7B01: 'zhú',  # 笁
    0x7B02: 'wán',  # 笂
    0x7B03: 'dǔ',  # 笃
    0x7B04: 'jī',  # 笄
    0x7B05: 'jiǎo,jiào',  # 笅
    0x7B06: 'bā',  # 笆
    0x7B07: 'suàn',  # 笇
    0x7B08: 'jí',  # 笈
    0x7B09: 'qǐn',  # 笉
    0x7B0A: 'zhào',  # 笊
    0x7B0B: 'sǔn',  # 笋
    0x7B0C: 'yá',  # 笌
    0x7B0D: 'zhuì,ruì',  # 笍
    0x7B0E: 'yuán',  # 笎
    0x7B0F: 'hù',  # 笏
    0x7B10: 'háng,hàng',  # 笐
    0x7B11: 'xiào',  # 笑
    0x7B12: 'cén,jìn,hán',  # 笒
    0x7B13: 'pí,bì',  # 笓
    0x7B14: 'bǐ',  # 笔
    0x7B15: 'jiǎn',  # 笕
    0x7B16: 'yǐ',  # 笖
    0x7B17: 'dōng',  # 笗
    0x7B18: 'shān',  # 笘
    0x7B19: 'shēng',  # 笙
    0x7B1A: 'dā,xiá,nà',  # 笚
    0x7B1B: 'dí',  # 笛
    0x7B1C: 'zhú',  # 笜
    0x7B1D: 'nà',  # 笝
    0x7B1E: 'chī',  # 笞
    0x7B1F: 'gū',  # 笟
    0x7B20: 'lì',  # 笠
    0x7B21: 'qiè',  # 笡
    0x7B22: 'mǐn',  # 笢
    0x7B23: 'bāo',  # 笣
    0x7B24: 'tiáo',  # 笤
    0x7B25: 'sì',  # 笥
    0x7B26: 'fú',  # 符
    0x7B27: 'cè',  # 笧
    0x7B28: 'bèn',  # 笨
    0x7B29: 'fá',  # 笩
    0x7B2A: 'dá',  # 笪
    0x7B2B: 'zǐ',  # 笫
    0x7B2C: 'dì',  # 第
    0x7B2D: 'líng',  # 笭
    0x7B2E: 'zuó,zé',  # 笮
    0x7B2F: 'nú',  # 笯
    0x7B30: 'fú,fèi',  # 笰
    0x7B31: 'gǒu',  # 笱
    0x7B32: 'fán',  # 笲
    0x7B33: 'jiā',  # 笳
    0x7B34: 'gě',  # 笴
    0x7B35: 'fàn',  # 笵
    0x7B36: 'shǐ',  # 笶
    0x7B37: 'mǎo',  # 笷
    0x7B38: 'pǒ',  # 笸
    0x7B39: 'tì',  # 笹
    0x7B3A: 'jiān',  # 笺
    0x7B3B: 'qióng',  # 笻
    0x7B3C: 'lóng,lǒng',  # 笼
    0x7B3D: 'mǐn',  # 笽
    0x7B3E: 'biān',  # 笾
    0x7B3F: 'luò',  # 笿
    0x7B40: 'guì',  # 筀
    0x7B41: 'qū',  # 筁
    0x7B42: 'chí',  # 筂
    0x7B43: 'yīn',  # 筃
    0x7B44: 'yào',  # 筄
    0x7B45: 'xiǎn',  # 筅
    0x7B46: 'bǐ',  # 筆
    0x7B47: 'qióng',  # 筇
    0x7B48: 'kuò',  # 筈
    0x7B49: 'děng',  # 等
    0x7B4A: 'jiǎo,jiào',  # 筊
    0x7B4B: 'jīn',  # 筋
    0x7B4C: 'quán',  # 筌
    0x7B4D: 'sǔn',  # 筍
    0x7B4E: 'rú',  # 筎
    0x7B4F: 'fá',  # 筏
    0x7B50: 'kuāng',  # 筐
    0x7B51: 'zhù,zhú',  # 筑
    0x7B52: 'tǒng',  # 筒
    0x7B53: 'jī',  # 筓
    0x7B54: 'dá,dā',  # 答
    0x7B55: 'háng',  # 筕
    0x7B56: 'cè',  # 策
    0x7B57: 'zhòng',  # 筗
    0x7B58: 'kòu',  # 筘
    0x7B59: 'lái',  # 筙
    0x7B5A: 'bì',  # 筚
    0x7B5B: 'shāi',  # 筛
    0x7B5C: 'dāng',  # 筜
    0x7B5D: 'zhēng',  # 筝
    0x7B5E: 'cè',  # 筞
    0x7B5F: 'fū',  # 筟
    0x7B60: 'yún,jūn',  # 筠
    0x7B61: 'tú',  # 筡
    0x7B62: 'pá',  # 筢
    0x7B63: 'lí',  # 筣
    0x7B64: 'láng,làng',  # 筤
    0x7B65: 'jǔ',  # 筥
    0x7B66: 'guǎn',  # 筦
    0x7B67: 'jiǎn',  # 筧
    0x7B68: 'hán',  # 筨
    0x7B69: 'tǒng',  # 筩
    0x7B6A: 'xiá',  # 筪
    0x7B6B: 'zhì,zhǐ',  # 筫
    0x7B6C: 'chéng',  # 筬
    0x7B6D: 'suàn',  # 筭
    0x7B6E: 'shì',  # 筮
    0x7B6F: 'zhù',  # 筯
    0x7B70: 'zuó',  # 筰
    0x7B71: 'xiǎo',  # 筱
    0x7B72: 'shāo',  # 筲
    0x7B73: 'tíng',  # 筳
    0x7B74: 'cè',  # 筴
    0x7B75: 'yán',  # 筵
    0x7B76: 'gào',  # 筶
    0x7B77: 'kuài',  # 筷
    0x7B78: 'gān',  # 筸
    0x7B79: 'chóu',  # 筹
    0x7B7A: 'kuāng',  # 筺
    0x7B7B: 'gàng',  # 筻
    0x7B7C: 'yún',  # 筼
    0x7B7D: 'o',  # 筽
    0x7B7E: 'qiān',  # 签
    0x7B7F: 'xiǎo',  # 筿
    0x7B80: 'jiǎn',  # 简
    0x7B81: 'póu,bù,fú,pú',  # 箁
    0x7B82: 'lái',  # 箂
    0x7B83: 'zōu',  # 箃
    0x7B84: 'pái,bēi',  # 箄
    0x7B85: 'bì',  # 箅
    0x7B86: 'bì',  # 箆
    0x7B87: 'gè',  # 箇
    0x7B88: 'tái,chí',  # 箈
    0x7B89: 'guǎi,dài',  # 箉
    0x7B8A: 'yū',  # 箊
    0x7B8B: 'jiān',  # 箋
    0x7B8C: 'zhào,dào',  # 箌
    0x7B8D: 'gū',  # 箍
    0x7B8E: 'chí',  # 箎
    0x7B8F: 'zhēng',  # 箏
    0x7B90: 'qìng,jīng',  # 箐
    0x7B91: 'shà',  # 箑
    0x7B92: 'zhǒu',  # 箒
    0x7B93: 'lù',  # 箓
    0x7B94: 'bó',  # 箔
    0x7B95: 'jī',  # 箕
    0x7B96: 'lín,lǐn',  # 箖
    0x7B97: 'suàn',  # 算
    0x7B98: 'jùn,qūn',  # 箘
    0x7B99: 'fú',  # 箙
    0x7B9A: 'zhá',  # 箚
    0x7B9B: 'gū',  # 箛
    0x7B9C: 'kōng',  # 箜
    0x7B9D: 'qián',  # 箝
    0x7B9E: 'quān',  # 箞
    0x7B9F: 'jùn',  # 箟
    0x7BA0: 'chuí',  # 箠
    0x7BA1: 'guǎn',  # 管
    0x7BA2: 'wǎn,yuān',  # 箢
    0x7BA3: 'cè',  # 箣
    0x7BA4: 'zú',  # 箤
    0x7BA5: 'pǒ',  # 箥
    0x7BA6: 'zé',  # 箦
    0x7BA7: 'qiè',  # 箧
    0x7BA8: 'tuò',  # 箨
    0x7BA9: 'luó',  # 箩
    0x7BAA: 'dān',  # 箪
    0x7BAB: 'xiāo',  # 箫
    0x7BAC: 'ruò',  # 箬
    0x7BAD: 'jiàn',  # 箭
    0x7BAE: 'xuān',  # 箮
    0x7BAF: 'biān',  # 箯
    0x7BB0: 'sǔn',  # 箰
    0x7BB1: 'xiāng',  # 箱
    0x7BB2: 'xiǎn',  # 箲
    0x7BB3: 'píng',  # 箳
    0x7BB4: 'zhēn',  # 箴
    0x7BB5: 'xīng',  # 箵
    0x7BB6: 'hú',  # 箶
    0x7BB7: 'shī,yí',  # 箷
    0x7BB8: 'zhù',  # 箸
    0x7BB9: 'yuē,yào,chuò',  # 箹
    0x7BBA: 'chūn',  # 箺
    0x7BBB: 'lǜ',  # 箻
    0x7BBC: 'wū',  # 箼
    0x7BBD: 'dǒng',  # 箽
    0x7BBE: 'shuò,xiāo,qiào',  # 箾
    0x7BBF: 'jí',  # 箿
    0x7BC0: 'jié',  # 節
    0x7BC1: 'huáng',  # 篁
    0x7BC2: 'xīng',  # 篂
    0x7BC3: 'mèi',  # 篃
    0x7BC4: 'fàn',  # 範
    0x7BC5: 'chuán',  # 篅
    0x7BC6: 'zhuàn',  # 篆
    0x7BC7: 'piān',  # 篇
    0x7BC8: 'fēng',  # 篈
    0x7BC9: 'zhù,zhú',  # 築
    0x7BCA: 'hóng',  # 篊
    0x7BCB: 'qiè',  # 篋
    0x7BCC: 'hóu',  # 篌
    0x7BCD: 'qiū',  # 篍
    0x7BCE: 'miǎo',  # 篎
    0x7BCF: 'qiàn',  # 篏
    0x7BD0: 'gū',  # 篐
    0x7BD1: 'kuì',  # 篑
    0x7BD2: 'yì',  # 篒
    0x7BD3: 'lǒu',  # 篓
    0x7BD4: 'yún',  # 篔
    0x7BD5: 'hé',  # 篕
    0x7BD6: 'táng',  # 篖
    0x7BD7: 'yuè',  # 篗
    0x7BD8: 'chōu',  # 篘
    0x7BD9: 'gāo',  # 篙
    0x7BDA: 'fěi',  # 篚
    0x7BDB: 'ruò',  # 篛
    0x7BDC: 'zhēng',  # 篜
    0x7BDD: 'gōu',  # 篝
    0x7BDE: 'niè',  # 篞
    0x7BDF: 'qiàn',  # 篟
    0x7BE0: 'xiǎo',  # 篠
    0x7BE1: 'cuàn',  # 篡
    0x7BE2: 'gōng,gǎn,lǒng',  # 篢
    0x7BE3: 'péng,páng',  # 篣
    0x7BE4: 'dǔ',  # 篤
    0x7BE5: 'lì',  # 篥
    0x7BE6: 'bì',  # 篦
    0x7BE7: 'zhuó,huò',  # 篧
    0x7BE8: 'chú',  # 篨
    0x7BE9: 'shāi',  # 篩
    0x7BEA: 'chí',  # 篪
    0x7BEB: 'zhù',  # 篫
    0x7BEC: 'qiāng,cāng',  # 篬
    0x7BED: 'lóng,lǒng',  # 篭
    0x7BEE: 'lán',  # 篮
    0x7BEF: 'jiǎn,jiān',  # 篯
    0x7BF0: 'bù',  # 篰
    0x7BF1: 'lí',  # 篱
    0x7BF2: 'huì',  # 篲
    0x7BF3: 'bì',  # 篳
    0x7BF4: 'zhú,dí',  # 篴
    0x7BF5: 'cōng',  # 篵
    0x7BF6: 'yān',  # 篶
    0x7BF7: 'péng',  # 篷
    0x7BF8: 'cēn,zān,cǎn',  # 篸
    0x7BF9: 'zhuàn,zuàn,suǎn',  # 篹
    0x7BFA: 'pí',  # 篺
    0x7BFB: 'piǎo,biāo',  # 篻
    0x7BFC: 'dōu',  # 篼
    0x7BFD: 'yù',  # 篽
    0x7BFE: 'miè',  # 篾
    0x7BFF: 'tuán,zhuān',  # 篿
    0x7C00: 'zé',  # 簀
    0x7C01: 'shāi',  # 簁
    0x7C02: 'guó,guì',  # 簂
    0x7C03: 'yí',  # 簃
    0x7C04: 'hù',  # 簄
    0x7C05: 'chǎn',  # 簅
    0x7C06: 'kòu',  # 簆
    0x7C07: 'cù',  # 簇
    0x7C08: 'píng',  # 簈
    0x7C09: 'zào',  # 簉
    0x7C0A: 'jī',  # 簊
    0x7C0B: 'guǐ',  # 簋
    0x7C0C: 'sù',  # 簌
    0x7C0D: 'lǒu',  # 簍
    0x7C0E: 'cè,jí',  # 簎
    0x7C0F: 'lù',  # 簏
    0x7C10: 'niǎn',  # 簐
    0x7C11: 'suō',  # 簑
    0x7C12: 'cuàn',  # 簒
    0x7C13: 'diāo',  # 簓
    0x7C14: 'suō',  # 簔
    0x7C15: 'lè',  # 簕
    0x7C16: 'duàn',  # 簖
    0x7C17: 'zhù',  # 簗
    0x7C18: 'xiāo',  # 簘
    0x7C19: 'bó',  # 簙
    0x7C1A: 'mì,miè',  # 簚
    0x7C1B: 'shāi',  # 簛
    0x7C1C: 'dàng',  # 簜
    0x7C1D: 'liáo',  # 簝
    0x7C1E: 'dān',  # 簞
    0x7C1F: 'diàn',  # 簟
    0x7C20: 'fǔ',  # 簠
    0x7C21: 'jiǎn',  # 簡
    0x7C22: 'mǐn',  # 簢
    0x7C23: 'kuì',  # 簣
    0x7C24: 'dài',  # 簤
    0x7C25: 'jiāo',  # 簥
    0x7C26: 'dēng',  # 簦
    0x7C27: 'huáng',  # 簧
    0x7C28: 'sǔn,zhuàn',  # 簨
    0x7C29: 'láo',  # 簩
    0x7C2A: 'zān',  # 簪
    0x7C2B: 'xiāo',  # 簫
    0x7C2C: 'lù',  # 簬
    0x7C2D: 'shì',  # 簭
    0x7C2E: 'zān',  # 簮
    0x7C2F: 'qí',  # 簯
    0x7C30: 'pái',  # 簰
    0x7C31: 'qí',  # 簱
    0x7C32: 'pái',  # 簲
    0x7C33: 'gǎn,gàn',  # 簳
    0x7C34: 'jù',  # 簴
    0x7C35: 'lù',  # 簵
    0x7C36: 'lù',  # 簶
    0x7C37: 'yán',  # 簷
    0x7C38: 'bò,bǒ',  # 簸
    0x7C39: 'dāng',  # 簹
    0x7C3A: 'sài',  # 簺
    0x7C3B: 'zhuā',  # 簻
    0x7C3C: 'gōu',  # 簼
    0x7C3D: 'qiān',  # 簽
    0x7C3E: 'lián',  # 簾
    0x7C3F: 'bù,bó',  # 簿
    0x7C40: 'zhòu',  # 籀
    0x7C41: 'lài',  # 籁
    0x7C42: 'shi',  # 籂
    0x7C43: 'lán',  # 籃
    0x7C44: 'kuì',  # 籄
    0x7C45: 'yú',  # 籅
    0x7C46: 'yuè',  # 籆
    0x7C47: 'háo',  # 籇
    0x7C48: 'zhēn,jiān',  # 籈
    0x7C49: 'tái',  # 籉
    0x7C4A: 'tì',  # 籊
    0x7C4B: 'niè',  # 籋
    0x7C4C: 'chóu',  # 籌
    0x7C4D: 'jí',  # 籍
    0x7C4E: 'yí',  # 籎
    0x7C4F: 'qí',  # 籏
    0x7C50: 'téng',  # 籐
    0x7C51: 'zhuàn',  # 籑
    0x7C52: 'zhòu',  # 籒
    0x7C53: 'fān,pān,biān',  # 籓
    0x7C54: 'sǒu,shǔ',  # 籔
    0x7C55: 'zhòu',  # 籕
    0x7C56: 'qiān',  # 籖
    0x7C57: 'zhuó',  # 籗
    0x7C58: 'téng',  # 籘
    0x7C59: 'lù',  # 籙
    0x7C5A: 'lú',  # 籚
    0x7C5B: 'jiǎn,jiān',  # 籛
    0x7C5C: 'tuò',  # 籜
    0x7C5D: 'yíng',  # 籝
    0x7C5E: 'yù',  # 籞
    0x7C5F: 'lài',  # 籟
    0x7C60: 'lóng,lǒng',  # 籠
    0x7C61: 'qiè',  # 籡
    0x7C62: 'lián',  # 籢
    0x7C63: 'lán',  # 籣
    0x7C64: 'qiān',  # 籤
    0x7C65: 'yuè',  # 籥
    0x7C66: 'zhōng',  # 籦
    0x7C67: 'qú',  # 籧
    0x7C68: 'lián',  # 籨
    0x7C69: 'biān',  # 籩
    0x7C6A: 'duàn',  # 籪
    0x7C6B: 'zuǎn',  # 籫
    0x7C6C: 'lí',  # 籬
    0x7C6D: 'shāi',  # 籭
    0x7C6E: 'luó',  # 籮
    0x7C6F: 'yíng',  # 籯
    0x7C70: 'yuè',  # 籰
    0x7C71: 'zhuó',  # 籱
    0x7C72: 'yù',  # 籲
    0x7C73: 'mǐ',  # 米
    0x7C74: 'dí',  # 籴
    0x7C75: 'fán',  # 籵
    0x7C76: 'shēn',  # 籶
    0x7C77: 'zhé',  # 籷
    0x7C78: 'shēn',  # 籸
    0x7C79: 'nǚ',  # 籹
    0x7C7A: 'hé',  # 籺
    0x7C7B: 'lèi',  # 类
    0x7C7C: 'xiān',  # 籼
    0x7C7D: 'zǐ',  # 籽
    0x7C7E: 'ní',  # 籾
    0x7C7F: 'cùn',  # 籿
    0x7C80: 'zhàng',  # 粀
    0x7C81: 'qiān',  # 粁
    0x7C82: 'zhāi',  # 粂
    0x7C83: 'bǐ',  # 粃
    0x7C84: 'bǎn',  # 粄
    0x7C85: 'wù',  # 粅
    0x7C86: 'shā,chǎo',  # 粆
    0x7C87: 'kāng,jīng',  # 粇
    0x7C88: 'róu',  # 粈
    0x7C89: 'fěn',  # 粉
    0x7C8A: 'bì',  # 粊
    0x7C8B: 'cuì',  # 粋
    0x7C8C: 'yǐn',  # 粌
    0x7C8D: 'zhé',  # 粍
    0x7C8E: 'mǐ',  # 粎
    0x7C8F: 'tà',  # 粏
    0x7C90: 'hù',  # 粐
    0x7C91: 'bā',  # 粑
    0x7C92: 'lì',  # 粒
    0x7C93: 'gān',  # 粓
    0x7C94: 'jù',  # 粔
    0x7C95: 'pò',  # 粕
    0x7C96: 'yù',  # 粖
    0x7C97: 'cū',  # 粗
    0x7C98: 'nián,zhān',  # 粘
    0x7C99: 'zhòu',  # 粙
    0x7C9A: 'chī',  # 粚
    0x7C9B: 'sù',  # 粛
    0x7C9C: 'tiào',  # 粜
    0x7C9D: 'lì',  # 粝
    0x7C9E: 'xī',  # 粞
    0x7C9F: 'sù',  # 粟
    0x7CA0: 'hóng',  # 粠
    0x7CA1: 'tóng',  # 粡
    0x7CA2: 'zī,cí',  # 粢
    0x7CA3: 'cè,sè',  # 粣
    0x7CA4: 'yuè',  # 粤
    0x7CA5: 'zhōu,yù',  # 粥
    0x7CA6: 'lín',  # 粦
    0x7CA7: 'zhuāng',  # 粧
    0x7CA8: 'bǎi',  # 粨
    0x7CA9: 'lāo',  # 粩
    0x7CAA: 'fèn',  # 粪
    0x7CAB: 'ér',  # 粫
    0x7CAC: 'qū',  # 粬
    0x7CAD: 'hé',  # 粭
    0x7CAE: 'liáng',  # 粮
    0x7CAF: 'xiàn',  # 粯
    0x7CB0: 'fū,fú',  # 粰
    0x7CB1: 'liáng',  # 粱
    0x7CB2: 'càn',  # 粲
    0x7CB3: 'jīng',  # 粳
    0x7CB4: 'lǐ',  # 粴
    0x7CB5: 'yuè',  # 粵
    0x7CB6: 'lù',  # 粶
    0x7CB7: 'jú',  # 粷
    0x7CB8: 'qí',  # 粸
    0x7CB9: 'cuì',  # 粹
    0x7CBA: 'bài',  # 粺
    0x7CBB: 'zhāng',  # 粻
    0x7CBC: 'lín',  # 粼
    0x7CBD: 'zòng',  # 粽
    0x7CBE: 'jīng',  # 精
    0x7CBF: 'guǒ',  # 粿
    0x7CC0: 'huā',  # 糀
    0x7CC1: 'sǎn,shēn',  # 糁
    0x7CC2: 'shēn',  # 糂
    0x7CC3: 'táng',  # 糃
    0x7CC4: 'biān,biǎn',  # 糄
    0x7CC5: 'róu',  # 糅
    0x7CC6: 'miàn',  # 糆
    0x7CC7: 'hóu',  # 糇
    0x7CC8: 'xǔ',  # 糈
    0x7CC9: 'zòng',  # 糉
    0x7CCA: 'hū,hú,hù',  # 糊
    0x7CCB: 'jiàn',  # 糋
    0x7CCC: 'zān',  # 糌
    0x7CCD: 'cí',  # 糍
    0x7CCE: 'lí',  # 糎
    0x7CCF: 'xiè',  # 糏
    0x7CD0: 'fū',  # 糐
    0x7CD1: 'nuò',  # 糑
    0x7CD2: 'bèi',  # 糒
    0x7CD3: 'gǔ,gòu',  # 糓
    0x7CD4: 'xiǔ',  # 糔
    0x7CD5: 'gāo',  # 糕
    0x7CD6: 'táng',  # 糖
    0x7CD7: 'qiǔ',  # 糗
    0x7CD8: 'jiā',  # 糘
    0x7CD9: 'cāo',  # 糙
    0x7CDA: 'zhuāng',  # 糚
    0x7CDB: 'táng',  # 糛
    0x7CDC: 'mí,méi',  # 糜
    0x7CDD: 'sǎn,shēn',  # 糝
    0x7CDE: 'fèn',  # 糞
    0x7CDF: 'zāo',  # 糟
    0x7CE0: 'kāng',  # 糠
    0x7CE1: 'jiàng',  # 糡
    0x7CE2: 'mó',  # 糢
    0x7CE3: 'sǎn,shēn',  # 糣
    0x7CE4: 'sǎn',  # 糤
    0x7CE5: 'nuò',  # 糥
    0x7CE6: 'xī',  # 糦
    0x7CE7: 'liáng',  # 糧
    0x7CE8: 'jiàng',  # 糨
    0x7CE9: 'kuài',  # 糩
    0x7CEA: 'bó',  # 糪
    0x7CEB: 'huán',  # 糫
    0x7CEC: 'shǔ',  # 糬
    0x7CED: 'zòng',  # 糭
    0x7CEE: 'xiàn',  # 糮
    0x7CEF: 'nuò',  # 糯
    0x7CF0: 'tuán',  # 糰
    0x7CF1: 'niè',  # 糱
    0x7CF2: 'lì',  # 糲
    0x7CF3: 'zuò',  # 糳
    0x7CF4: 'dí',  # 糴
    0x7CF5: 'niè',  # 糵
    0x7CF6: 'tiào',  # 糶
    0x7CF7: 'làn',  # 糷
    0x7CF8: 'mì,sī',  # 糸
    0x7CF9: 'sī',  # 糹
    0x7CFA: 'jiū,jiǔ',  # 糺
    0x7CFB: 'xì,jì',  # 系
    0x7CFC: 'gōng',  # 糼
    0x7CFD: 'zhēng,zhěng',  # 糽
    0x7CFE: 'jiū',  # 糾
    0x7CFF: 'gōng',  # 糿
    0x7D00: 'jì',  # 紀
    0x7D01: 'chà,chǎ',  # 紁
    0x7D02: 'zhòu',  # 紂
    0x7D03: 'xún',  # 紃
    0x7D04: 'yuē,yāo',  # 約
    0x7D05: 'hóng,gōng',  # 紅
    0x7D06: 'yū',  # 紆
    0x7D07: 'hé,gē',  # 紇
    0x7D08: 'wán',  # 紈
    0x7D09: 'rèn',  # 紉
    0x7D0A: 'wěn',  # 紊
    0x7D0B: 'wén,wèn',  # 紋
    0x7D0C: 'qiú',  # 紌
    0x7D0D: 'nà',  # 納
    0x7D0E: 'zī',  # 紎
    0x7D0F: 'tǒu',  # 紏
    0x7D10: 'niǔ',  # 紐
    0x7D11: 'fóu',  # 紑
    0x7D12: 'jì,jié,jiè',  # 紒
    0x7D13: 'shū',  # 紓
    0x7D14: 'chún',  # 純
    0x7D15: 'pī,pí,bǐ',  # 紕
    0x7D16: 'zhèn',  # 紖
    0x7D17: 'shā',  # 紗
    0x7D18: 'hóng',  # 紘
    0x7D19: 'zhǐ',  # 紙
    0x7D1A: 'jí',  # 級
    0x7D1B: 'fēn',  # 紛
    0x7D1C: 'yún',  # 紜
    0x7D1D: 'rèn',  # 紝
    0x7D1E: 'dǎn',  # 紞
    0x7D1F: 'jīn,jìn',  # 紟
    0x7D20: 'sù',  # 素
    0x7D21: 'fǎng',  # 紡
    0x7D22: 'suǒ',  # 索
    0x7D23: 'cuì',  # 紣
    0x7D24: 'jiǔ',  # 紤
    0x7D25: 'zhā,zā',  # 紥
    0x7D26: 'hā',  # 紦
    0x7D27: 'jǐn',  # 紧
    0x7D28: 'fū,fù',  # 紨
    0x7D29: 'zhì',  # 紩
    0x7D2A: 'qī',  # 紪
    0x7D2B: 'zǐ',  # 紫
    0x7D2C: 'chōu,chóu',  # 紬
    0x7D2D: 'hóng',  # 紭
    0x7D2E: 'zhā,zā',  # 紮
    0x7D2F: 'léi,lěi,lèi',  # 累
    0x7D30: 'xì',  # 細
    0x7D31: 'fú',  # 紱
    0x7D32: 'xiè',  # 紲
    0x7D33: 'shēn',  # 紳
    0x7D34: 'bō,bì',  # 紴
    0x7D35: 'zhù',  # 紵
    0x7D36: 'qū,qǔ',  # 紶
    0x7D37: 'líng',  # 紷
    0x7D38: 'zhù',  # 紸
    0x7D39: 'shào',  # 紹
    0x7D3A: 'gàn',  # 紺
    0x7D3B: 'yǎng',  # 紻
    0x7D3C: 'fú',  # 紼
    0x7D3D: 'tuó',  # 紽
    0x7D3E: 'zhěn,tiǎn',  # 紾
    0x7D3F: 'dài',  # 紿
    0x7D40: 'chù',  # 絀
    0x7D41: 'shī',  # 絁
    0x7D42: 'zhōng',  # 終
    0x7D43: 'xián',  # 絃
    0x7D44: 'zǔ',  # 組
    0x7D45: 'jiōng,jiǒng',  # 絅
    0x7D46: 'bàn',  # 絆
    0x7D47: 'qú',  # 絇
    0x7D48: 'mò',  # 絈
    0x7D49: 'shù',  # 絉
    0x7D4A: 'zuì',  # 絊
    0x7D4B: 'kuàng',  # 絋
    0x7D4C: 'jīng',  # 経
    0x7D4D: 'rèn',  # 絍
    0x7D4E: 'háng',  # 絎
    0x7D4F: 'xiè',  # 絏
    0x7D50: 'jié,jiē',  # 結
    0x7D51: 'zhū',  # 絑
    0x7D52: 'chóu',  # 絒
    0x7D53: 'guà,kuā',  # 絓
    0x7D54: 'bǎi,mò',  # 絔
    0x7D55: 'jué',  # 絕
    0x7D56: 'kuàng',  # 絖
    0x7D57: 'hú',  # 絗
    0x7D58: 'cì',  # 絘
    0x7D59: 'huán,gēng',  # 絙
    0x7D5A: 'gēng',  # 絚
    0x7D5B: 'tāo',  # 絛
    0x7D5C: 'xié,jié',  # 絜
    0x7D5D: 'kù',  # 絝
    0x7D5E: 'jiǎo',  # 絞
    0x7D5F: 'quán,shuān',  # 絟
    0x7D60: 'gǎi,ǎi',  # 絠
    0x7D61: 'luò,lào',  # 絡
    0x7D62: 'xuàn',  # 絢
    0x7D63: 'bēng,bīng,pēng',  # 絣
    0x7D64: 'xiàn',  # 絤
    0x7D65: 'fú',  # 絥
    0x7D66: 'gěi,jǐ',  # 給
    0x7D67: 'tōng,tóng,dòng',  # 絧
    0x7D68: 'róng',  # 絨
    0x7D69: 'tiào,diào,dào',  # 絩
    0x7D6A: 'yīn',  # 絪
    0x7D6B: 'lěi,lèi,léi',  # 絫
    0x7D6C: 'xiè',  # 絬
    0x7D6D: 'juàn',  # 絭
    0x7D6E: 'xù',  # 絮
    0x7D6F: 'gāi,hài',  # 絯
    0x7D70: 'dié',  # 絰
    0x7D71: 'tǒng',  # 統
    0x7D72: 'sī',  # 絲
    0x7D73: 'jiàng',  # 絳
    0x7D74: 'xiáng',  # 絴
    0x7D75: 'huì',  # 絵
    0x7D76: 'jué',  # 絶
    0x7D77: 'zhí',  # 絷
    0x7D78: 'jiǎn',  # 絸
    0x7D79: 'juàn',  # 絹
    0x7D7A: 'chī,zhǐ',  # 絺
    0x7D7B: 'miǎn,wèn,mán,wàn',  # 絻
    0x7D7C: 'zhèn',  # 絼
    0x7D7D: 'lǚ',  # 絽
    0x7D7E: 'chéng',  # 絾
    0x7D7F: 'qiú',  # 絿
    0x7D80: 'shū',  # 綀
    0x7D81: 'bǎng',  # 綁
    0x7D82: 'tǒng',  # 綂
    0x7D83: 'xiāo',  # 綃
    0x7D84: 'huán,huàn,wàn',  # 綄
    0x7D85: 'qīn,xiān',  # 綅
    0x7D86: 'gěng',  # 綆
    0x7D87: 'xū',  # 綇
    0x7D88: 'tí,tì',  # 綈
    0x7D89: 'xiù',  # 綉
    0x7D8A: 'xié',  # 綊
    0x7D8B: 'hóng',  # 綋
    0x7D8C: 'xì',  # 綌
    0x7D8D: 'fú',  # 綍
    0x7D8E: 'tīng',  # 綎
    0x7D8F: 'suí',  # 綏
    0x7D90: 'duì',  # 綐
    0x7D91: 'kǔn',  # 綑
    0x7D92: 'fū',  # 綒
    0x7D93: 'jīng',  # 經
    0x7D94: 'hù',  # 綔
    0x7D95: 'zhī',  # 綕
    0x7D96: 'yán,xiàn',  # 綖
    0x7D97: 'jiǒng',  # 綗
    0x7D98: 'féng',  # 綘
    0x7D99: 'jì',  # 継
    0x7D9A: 'xù',  # 続
    0x7D9B: 'rěn',  # 綛
    0x7D9C: 'zōng,zèng',  # 綜
    0x7D9D: 'lín,chēn',  # 綝
    0x7D9E: 'duǒ',  # 綞
    0x7D9F: 'lì,liè',  # 綟
    0x7DA0: 'lǜ',  # 綠
    0x7DA1: 'jīng',  # 綡
    0x7DA2: 'chóu',  # 綢
    0x7DA3: 'quǎn',  # 綣
    0x7DA4: 'shào',  # 綤
    0x7DA5: 'qí',  # 綥
    0x7DA6: 'qí',  # 綦
    0x7DA7: 'zhǔn,zhùn',  # 綧
    0x7DA8: 'jī,qí',  # 綨
    0x7DA9: 'wǎn',  # 綩
    0x7DAA: 'qiàn,qīng,zhēng',  # 綪
    0x7DAB: 'xiàn',  # 綫
    0x7DAC: 'shòu',  # 綬
    0x7DAD: 'wéi',  # 維
    0x7DAE: 'qìng,qǐ',  # 綮
    0x7DAF: 'táo',  # 綯
    0x7DB0: 'wǎn',  # 綰
    0x7DB1: 'gāng',  # 綱
    0x7DB2: 'wǎng',  # 網
    0x7DB3: 'bēng,běng,bèng',  # 綳
    0x7DB4: 'zhuì',  # 綴
    0x7DB5: 'cǎi',  # 綵
    0x7DB6: 'guǒ',  # 綶
    0x7DB7: 'cuì',  # 綷
    0x7DB8: 'lún,guān',  # 綸
    0x7DB9: 'liǔ',  # 綹
    0x7DBA: 'qǐ',  # 綺
    0x7DBB: 'zhàn',  # 綻
    0x7DBC: 'bì',  # 綼
    0x7DBD: 'chuò,chāo',  # 綽
    0x7DBE: 'líng',  # 綾
    0x7DBF: 'mián',  # 綿
    0x7DC0: 'qī',  # 緀
    0x7DC1: 'jī',  # 緁
    0x7DC2: 'tián,tǎn,chān',  # 緂
    0x7DC3: 'zōng',  # 緃
    0x7DC4: 'gǔn',  # 緄
    0x7DC5: 'zōu',  # 緅
    0x7DC6: 'xī',  # 緆
    0x7DC7: 'zī',  # 緇
    0x7DC8: 'xìng',  # 緈
    0x7DC9: 'liǎng',  # 緉
    0x7DCA: 'jǐn',  # 緊
    0x7DCB: 'fēi',  # 緋
    0x7DCC: 'ruí',  # 緌
    0x7DCD: 'mín',  # 緍
    0x7DCE: 'yù',  # 緎
    0x7DCF: 'zǒng',  # 総
    0x7DD0: 'fán',  # 緐
    0x7DD1: 'lǜ,lù',  # 緑
    0x7DD2: 'xù',  # 緒
    0x7DD3: 'yīng',  # 緓
    0x7DD4: 'shàng',  # 緔
    0x7DD5: 'zī',  # 緕
    0x7DD6: 'xù',  # 緖
    0x7DD7: 'xiāng',  # 緗
    0x7DD8: 'jiān',  # 緘
    0x7DD9: 'kè',  # 緙
    0x7DDA: 'xiàn',  # 線
    0x7DDB: 'ruǎn,ruàn',  # 緛
    0x7DDC: 'mián',  # 緜
    0x7DDD: 'jī,qī',  # 緝
    0x7DDE: 'duàn',  # 緞
    0x7DDF: 'chóng,zhòng',  # 緟
    0x7DE0: 'dì',  # 締
    0x7DE1: 'mín',  # 緡
    0x7DE2: 'miáo,máo',  # 緢
    0x7DE3: 'yuán',  # 緣
    0x7DE4: 'xiè,yè',  # 緤
    0x7DE5: 'bǎo',  # 緥
    0x7DE6: 'sī',  # 緦
    0x7DE7: 'qiū',  # 緧
    0x7DE8: 'biān',  # 編
    0x7DE9: 'huǎn',  # 緩
    0x7DEA: 'gēng,gèng',  # 緪
    0x7DEB: 'zǒng',  # 緫
    0x7DEC: 'miǎn',  # 緬
    0x7DED: 'wèi',  # 緭
    0x7DEE: 'fù',  # 緮
    0x7DEF: 'wěi',  # 緯
    0x7DF0: 'tōu,xū,shū',  # 緰
    0x7DF1: 'gōu',  # 緱
    0x7DF2: 'miǎo',  # 緲
    0x7DF3: 'xié',  # 緳
    0x7DF4: 'liàn',  # 練
    0x7DF5: 'zōng,zòng',  # 緵
    0x7DF6: 'biàn,pián',  # 緶
    0x7DF7: 'gǔn,yùn',  # 緷
    0x7DF8: 'yīn',  # 緸
    0x7DF9: 'tí',  # 緹
    0x7DFA: 'guā,wō',  # 緺
    0x7DFB: 'zhì',  # 緻
    0x7DFC: 'yùn,yūn,wēn',  # 緼
    0x7DFD: 'chēng',  # 緽
    0x7DFE: 'chán',  # 緾
    0x7DFF: 'dài',  # 緿
    0x7E00: 'xié',  # 縀
    0x7E01: 'yuán',  # 縁
    0x7E02: 'zǒng',  # 縂
    0x7E03: 'xū',  # 縃
    0x7E04: 'shéng',  # 縄
    0x7E05: 'wēi',  # 縅
    0x7E06: 'gēng,gèng',  # 縆
    0x7E07: 'seon',  # 縇
    0x7E08: 'yíng',  # 縈
    0x7E09: 'jìn',  # 縉
    0x7E0A: 'yì',  # 縊
    0x7E0B: 'zhuì',  # 縋
    0x7E0C: 'nì',  # 縌
    0x7E0D: 'bāng,bàng',  # 縍
    0x7E0E: 'gǔ,hú',  # 縎
    0x7E0F: 'pán',  # 縏
    0x7E10: 'zhòu',  # 縐
    0x7E11: 'jiān',  # 縑
    0x7E12: 'cī,cuò,suǒ',  # 縒
    0x7E13: 'quán',  # 縓
    0x7E14: 'shuǎng',  # 縔
    0x7E15: 'yùn,yūn,wēn',  # 縕
    0x7E16: 'xiá',  # 縖
    0x7E17: 'cuī,suī,shuāi',  # 縗
    0x7E18: 'xì',  # 縘
    0x7E19: 'róng,rǒng,ròng',  # 縙
    0x7E1A: 'tāo',  # 縚
    0x7E1B: 'fù',  # 縛
    0x7E1C: 'yún',  # 縜
    0x7E1D: 'zhěn',  # 縝
    0x7E1E: 'gǎo',  # 縞
    0x7E1F: 'rù',  # 縟
    0x7E20: 'hú',  # 縠
    0x7E21: 'zài,zēng',  # 縡
    0x7E22: 'téng',  # 縢
    0x7E23: 'xiàn,xuán',  # 縣
    0x7E24: 'sù',  # 縤
    0x7E25: 'zhěn',  # 縥
    0x7E26: 'zòng',  # 縦
    0x7E27: 'tāo',  # 縧
    0x7E28: 'huǎng',  # 縨
    0x7E29: 'cài',  # 縩
    0x7E2A: 'bì',  # 縪
    0x7E2B: 'féng,fèng',  # 縫
    0x7E2C: 'cù',  # 縬
    0x7E2D: 'lí',  # 縭
    0x7E2E: 'suō,sù',  # 縮
    0x7E2F: 'yǎn,yǐn',  # 縯
    0x7E30: 'xǐ',  # 縰
    0x7E31: 'zòng,zǒng',  # 縱
    0x7E32: 'léi',  # 縲
    0x7E33: 'zhuàn,juàn',  # 縳
    0x7E34: 'qiàn',  # 縴
    0x7E35: 'màn',  # 縵
    0x7E36: 'zhí',  # 縶
    0x7E37: 'lǚ',  # 縷
    0x7E38: 'mù,mò',  # 縸
    0x7E39: 'piǎo,piāo',  # 縹
    0x7E3A: 'lián',  # 縺
    0x7E3B: 'mí',  # 縻
    0x7E3C: 'xuàn',  # 縼
    0x7E3D: 'zǒng',  # 總
    0x7E3E: 'jì',  # 績
    0x7E3F: 'shān',  # 縿
    0x7E40: 'suì',  # 繀
    0x7E41: 'fán,pó',  # 繁
    0x7E42: 'lǜ',  # 繂
    0x7E43: 'bēng,běng,bèng',  # 繃
    0x7E44: 'yī',  # 繄
    0x7E45: 'sāo',  # 繅
    0x7E46: 'móu,miù,miào,mù,liǎo',  # 繆
    0x7E47: 'yáo,yóu,zhòu',  # 繇
    0x7E48: 'qiǎng',  # 繈
    0x7E49: 'shéng',  # 繉
    0x7E4A: 'xiān',  # 繊
    0x7E4B: 'jì',  # 繋
    0x7E4C: 'zōng,zòng',  # 繌
    0x7E4D: 'xiù',  # 繍
    0x7E4E: 'rán',  # 繎
    0x7E4F: 'xuàn',  # 繏
    0x7E50: 'suì',  # 繐
    0x7E51: 'qiāo',  # 繑
    0x7E52: 'zēng,zèng',  # 繒
    0x7E53: 'zuǒ',  # 繓
    0x7E54: 'zhī,zhì',  # 織
    0x7E55: 'shàn',  # 繕
    0x7E56: 'sǎn',  # 繖
    0x7E57: 'lín',  # 繗
    0x7E58: 'jú,jué',  # 繘
    0x7E59: 'fān',  # 繙
    0x7E5A: 'liáo',  # 繚
    0x7E5B: 'chuō,chuò',  # 繛
    0x7E5C: 'zūn,zǔn',  # 繜
    0x7E5D: 'jiàn',  # 繝
    0x7E5E: 'rào',  # 繞
    0x7E5F: 'chǎn,chán',  # 繟
    0x7E60: 'ruǐ',  # 繠
    0x7E61: 'xiù',  # 繡
    0x7E62: 'huì,huí',  # 繢
    0x7E63: 'huà',  # 繣
    0x7E64: 'zuǎn',  # 繤
    0x7E65: 'xī',  # 繥
    0x7E66: 'qiǎng',  # 繦
    0x7E67: 'wén',  # 繧
    0x7E68: 'da',  # 繨
    0x7E69: 'shéng',  # 繩
    0x7E6A: 'huì',  # 繪
    0x7E6B: 'xì,jì',  # 繫
    0x7E6C: 'sè',  # 繬
    0x7E6D: 'jiǎn',  # 繭
    0x7E6E: 'jiāng',  # 繮
    0x7E6F: 'huán',  # 繯
    0x7E70: 'qiāo,sāo',  # 繰
    0x7E71: 'cōng',  # 繱
    0x7E72: 'xiè',  # 繲
    0x7E73: 'jiǎo,zhuó',  # 繳
    0x7E74: 'bì',  # 繴
    0x7E75: 'dàn,tán,chán',  # 繵
    0x7E76: 'yì',  # 繶
    0x7E77: 'nǒng',  # 繷
    0x7E78: 'suì',  # 繸
    0x7E79: 'yì',  # 繹
    0x7E7A: 'shā',  # 繺
    0x7E7B: 'rú',  # 繻
    0x7E7C: 'jì',  # 繼
    0x7E7D: 'bīn',  # 繽
    0x7E7E: 'qiǎn',  # 繾
    0x7E7F: 'lán',  # 繿
    0x7E80: 'pú,fú',  # 纀
    0x7E81: 'xūn',  # 纁
    0x7E82: 'zuǎn',  # 纂
    0x7E83: 'zī',  # 纃
    0x7E84: 'péng',  # 纄
    0x7E85: 'yào,lì',  # 纅
    0x7E86: 'mò',  # 纆
    0x7E87: 'lèi',  # 纇
    0x7E88: 'xiè',  # 纈
    0x7E89: 'zuǎn',  # 纉
    0x7E8A: 'kuàng',  # 纊
    0x7E8B: 'yōu',  # 纋
    0x7E8C: 'xù',  # 續
    0x7E8D: 'léi',  # 纍
    0x7E8E: 'xiān',  # 纎
    0x7E8F: 'chán',  # 纏
    0x7E90: 'jiǎo',  # 纐
    0x7E91: 'lú',  # 纑
    0x7E92: 'chán',  # 纒
    0x7E93: 'yīng',  # 纓
    0x7E94: 'cái',  # 纔
    0x7E95: 'xiāng,rǎng',  # 纕
    0x7E96: 'xiān',  # 纖
    0x7E97: 'zuī',  # 纗
    0x7E98: 'zuǎn',  # 纘
    0x7E99: 'luò',  # 纙
    0x7E9A: 'lí,xǐ,lǐ,sǎ',  # 纚
    0x7E9B: 'dào',  # 纛
    0x7E9C: 'lǎn',  # 纜
    0x7E9D: 'léi',  # 纝
    0x7E9E: 'liàn',  # 纞
    0x7E9F: 'sī',  # 纟
    0x7EA0: 'jiū',  # 纠
    0x7EA1: 'yū',  # 纡
    0x7EA2: 'hóng,gōng',  # 红
    0x7EA3: 'zhòu',  # 纣
    0x7EA4: 'xiān,qiàn',  # 纤
    0x7EA5: 'hé,gē',  # 纥
    0x7EA6: 'yuē,yāo',  # 约
    0x7EA7: 'jí',  # 级
    0x7EA8: 'wán',  # 纨
    0x7EA9: 'kuàng',  # 纩
    0x7EAA: 'jì,jǐ',  # 纪
    0x7EAB: 'rèn',  # 纫
    0x7EAC: 'wěi',  # 纬
    0x7EAD: 'yún',  # 纭
    0x7EAE: 'hóng',  # 纮
    0x7EAF: 'chún',  # 纯
    0x7EB0: 'pī,pí,bǐ',  # 纰
    0x7EB1: 'shā',  # 纱
    0x7EB2: 'gāng',  # 纲
    0x7EB3: 'nà',  # 纳
    0x7EB4: 'rèn',  # 纴
    0x7EB5: 'zòng,zǒng',  # 纵
    0x7EB6: 'lún,guān',  # 纶
    0x7EB7: 'fēn',  # 纷
    0x7EB8: 'zhǐ',  # 纸
    0x7EB9: 'wén,wèn',  # 纹
    0x7EBA: 'fǎng',  # 纺
    0x7EBB: 'zhù',  # 纻
    0x7EBC: 'zhèn',  # 纼
    0x7EBD: 'niǔ',  # 纽
    0x7EBE: 'shū',  # 纾
    0x7EBF: 'xiàn',  # 线
    0x7EC0: 'gàn',  # 绀
    0x7EC1: 'xiè',  # 绁
    0x7EC2: 'fú',  # 绂
    0x7EC3: 'liàn',  # 练
    0x7EC4: 'zǔ',  # 组
    0x7EC5: 'shēn',  # 绅
    0x7EC6: 'xì',  # 细
    0x7EC7: 'zhī,zhì',  # 织
    0x7EC8: 'zhōng',  # 终
    0x7EC9: 'zhòu',  # 绉
    0x7ECA: 'bàn',  # 绊
    0x7ECB: 'fú',  # 绋
    0x7ECC: 'chù',  # 绌
    0x7ECD: 'shào',  # 绍
    0x7ECE: 'yì',  # 绎
    0x7ECF: 'jīng',  # 经
    0x7ED0: 'dài',  # 绐
    0x7ED1: 'bǎng',  # 绑
    0x7ED2: 'róng',  # 绒
    0x7ED3: 'jié,jiē',  # 结
    0x7ED4: 'kù',  # 绔
    0x7ED5: 'rào',  # 绕
    0x7ED6: 'dié',  # 绖
    0x7ED7: 'háng',  # 绗
    0x7ED8: 'huì',  # 绘
    0x7ED9: 'gěi,jǐ',  # 给
    0x7EDA: 'xuàn',  # 绚
    0x7EDB: 'jiàng',  # 绛
    0x7EDC: 'luò,lào',  # 络
    0x7EDD: 'jué',  # 绝
    0x7EDE: 'jiǎo',  # 绞
    0x7EDF: 'tǒng',  # 统
    0x7EE0: 'gěng',  # 绠
    0x7EE1: 'xiāo',  # 绡
    0x7EE2: 'juàn',  # 绢
    0x7EE3: 'xiù',  # 绣
    0x7EE4: 'xì',  # 绤
    0x7EE5: 'suí',  # 绥
    0x7EE6: 'tāo',  # 绦
    0x7EE7: 'jì',  # 继
    0x7EE8: 'tí,tì',  # 绨
    0x7EE9: 'jì',  # 绩
    0x7EEA: 'xù',  # 绪
    0x7EEB: 'líng',  # 绫
    0x7EEC: 'yīng',  # 绬
    0x7EED: 'xù',  # 续
    0x7EEE: 'qǐ',  # 绮
    0x7EEF: 'fēi',  # 绯
    0x7EF0: 'chuò,chāo',  # 绰
    0x7EF1: 'shàng',  # 绱
    0x7EF2: 'gǔn',  # 绲
    0x7EF3: 'shéng',  # 绳
    0x7EF4: 'wéi',  # 维
    0x7EF5: 'mián',  # 绵
    0x7EF6: 'shòu',  # 绶
    0x7EF7: 'bēng,běng,bèng',  # 绷
    0x7EF8: 'chóu',  # 绸
    0x7EF9: 'táo',  # 绹
    0x7EFA: 'liǔ',  # 绺
    0x7EFB: 'quǎn',  # 绻
    0x7EFC: 'zōng,zèng',  # 综
    0x7EFD: 'zhàn',  # 绽
    0x7EFE: 'wǎn',  # 绾
    0x7EFF: 'lǜ,lù',  # 绿
    0x7F00: 'zhuì',  # 缀
    0x7F01: 'zī',  # 缁
    0x7F02: 'kè',  # 缂
    0x7F03: 'xiāng',  # 缃
    0x7F04: 'jiān',  # 缄
    0x7F05: 'miǎn',  # 缅
    0x7F06: 'lǎn',  # 缆
    0x7F07: 'tí',  # 缇
    0x7F08: 'miǎo',  # 缈
    0x7F09: 'jī,qī',  # 缉
    0x7F0A: 'yùn,yūn,wēn',  # 缊
    0x7F0B: 'huì,huí',  # 缋
    0x7F0C: 'sī',  # 缌
    0x7F0D: 'duǒ',  # 缍
    0x7F0E: 'duàn',  # 缎
    0x7F0F: 'biàn,pián',  # 缏
    0x7F10: 'xiàn',  # 缐
    0x7F11: 'gōu',  # 缑
    0x7F12: 'zhuì',  # 缒
    0x7F13: 'huǎn',  # 缓
    0x7F14: 'dì',  # 缔
    0x7F15: 'lǚ',  # 缕
    0x7F16: 'biān',  # 编
    0x7F17: 'mín',  # 缗
    0x7F18: 'yuán',  # 缘
    0x7F19: 'jìn',  # 缙
    0x7F1A: 'fù',  # 缚
    0x7F1B: 'rù',  # 缛
    0x7F1C: 'zhěn',  # 缜
    0x7F1D: 'féng,fèng',  # 缝
    0x7F1E: 'cuī,suī,shuāi',  # 缞
    0x7F1F: 'gǎo',  # 缟
    0x7F20: 'chán',  # 缠
    0x7F21: 'lí',  # 缡
    0x7F22: 'yì',  # 缢
    0x7F23: 'jiān',  # 缣
    0x7F24: 'bīn',  # 缤
    0x7F25: 'piǎo,piāo',  # 缥
    0x7F26: 'màn',  # 缦
    0x7F27: 'léi',  # 缧
    0x7F28: 'yīng',  # 缨
    0x7F29: 'suō,sù',  # 缩
    0x7F2A: 'móu,miù,miào,mù,liǎo',  # 缪
    0x7F2B: 'sāo',  # 缫
    0x7F2C: 'xié',  # 缬
    0x7F2D: 'liáo',  # 缭
    0x7F2E: 'shàn',  # 缮
    0x7F2F: 'zēng,zèng',  # 缯
    0x7F30: 'jiāng',  # 缰
    0x7F31: 'qiǎn',  # 缱
    0x7F32: 'qiāo,sāo',  # 缲
    0x7F33: 'huán',  # 缳
    0x7F34: 'jiǎo,zhuó',  # 缴
    0x7F35: 'zuǎn',  # 缵
    0x7F36: 'fǒu',  # 缶
    0x7F37: 'xiè',  # 缷
    0x7F38: 'gāng',  # 缸
    0x7F39: 'fǒu',  # 缹
    0x7F3A: 'quē',  # 缺
    0x7F3B: 'fǒu',  # 缻
    0x7F3C: 'quē',  # 缼
    0x7F3D: 'bō',  # 缽
    0x7F3E: 'píng',  # 缾
    0x7F3F: 'xiàng',  # 缿
    0x7F40: 'zhào',  # 罀
    0x7F41: 'gāng',  # 罁
    0x7F42: 'yīng',  # 罂
    0x7F43: 'yīng',  # 罃
    0x7F44: 'qìng',  # 罄
    0x7F45: 'xià',  # 罅
    0x7F46: 'guàn',  # 罆
    0x7F47: 'zūn',  # 罇
    0x7F48: 'tán',  # 罈
    0x7F49: 'chēng',  # 罉
    0x7F4A: 'qì',  # 罊
    0x7F4B: 'wèng',  # 罋
    0x7F4C: 'yīng',  # 罌
    0x7F4D: 'léi',  # 罍
    0x7F4E: 'tán',  # 罎
    0x7F4F: 'lú',  # 罏
    0x7F50: 'guàn',  # 罐
    0x7F51: 'wǎng',  # 网
    0x7F52: 'wǎng',  # 罒
    0x7F53: 'wǎng',  # 罓
    0x7F54: 'wǎng',  # 罔
    0x7F55: 'hǎn',  # 罕
    0x7F56: 'wǎng,ra',  # 罖
    0x7F57: 'luó',  # 罗
    0x7F58: 'fú',  # 罘
    0x7F59: 'shēn',  # 罙
    0x7F5A: 'fá',  # 罚
    0x7F5B: 'gū',  # 罛
    0x7F5C: 'zhǔ',  # 罜
    0x7F5D: 'jū',  # 罝
    0x7F5E: 'máo',  # 罞
    0x7F5F: 'gǔ',  # 罟
    0x7F60: 'mín',  # 罠
    0x7F61: 'gāng',  # 罡
    0x7F62: 'bà,ba,pí',  # 罢
    0x7F63: 'guà',  # 罣
    0x7F64: 'tí',  # 罤
    0x7F65: 'juàn',  # 罥
    0x7F66: 'fú',  # 罦
    0x7F67: 'shēn',  # 罧
    0x7F68: 'yǎn',  # 罨
    0x7F69: 'zhào',  # 罩
    0x7F6A: 'zuì',  # 罪
    0x7F6B: 'guǎi,guà',  # 罫
    0x7F6C: 'zhuó',  # 罬
    0x7F6D: 'yù',  # 罭
    0x7F6E: 'zhì',  # 置
    0x7F6F: 'ǎn',  # 罯
    0x7F70: 'fá',  # 罰
    0x7F71: 'lǎn',  # 罱
    0x7F72: 'shǔ',  # 署
    0x7F73: 'sī',  # 罳
    0x7F74: 'pí',  # 罴
    0x7F75: 'mà',  # 罵
    0x7F76: 'liǔ',  # 罶
    0x7F77: 'bà,ba,pí',  # 罷
    0x7F78: 'fá',  # 罸
    0x7F79: 'lí',  # 罹
    0x7F7A: 'cháo',  # 罺
    0x7F7B: 'wèi',  # 罻
    0x7F7C: 'bì',  # 罼
    0x7F7D: 'jì',  # 罽
    0x7F7E: 'zēng',  # 罾
    0x7F7F: 'chōng',  # 罿
    0x7F80: 'liǔ',  # 羀
    0x7F81: 'jī',  # 羁
    0x7F82: 'juàn',  # 羂
    0x7F83: 'mì',  # 羃
    0x7F84: 'zhào',  # 羄
    0x7F85: 'luó',  # 羅
    0x7F86: 'pí',  # 羆
    0x7F87: 'jī',  # 羇
    0x7F88: 'jī',  # 羈
    0x7F89: 'luán',  # 羉
    0x7F8A: 'yáng,xiáng',  # 羊
    0x7F8B: 'mǐ',  # 羋
    0x7F8C: 'qiāng',  # 羌
    0x7F8D: 'dá',  # 羍
    0x7F8E: 'měi',  # 美
    0x7F8F: 'yáng,xiáng',  # 羏
    0x7F90: 'líng',  # 羐
    0x7F91: 'yǒu',  # 羑
    0x7F92: 'fén',  # 羒
    0x7F93: 'bā',  # 羓
    0x7F94: 'gāo',  # 羔
    0x7F95: 'yàng',  # 羕
    0x7F96: 'gǔ',  # 羖
    0x7F97: 'qiāng',  # 羗
    0x7F98: 'zāng',  # 羘
    0x7F99: 'měi,gāo',  # 羙
    0x7F9A: 'líng',  # 羚
    0x7F9B: 'yì,xī',  # 羛
    0x7F9C: 'zhù',  # 羜
    0x7F9D: 'dī',  # 羝
    0x7F9E: 'xiū',  # 羞
    0x7F9F: 'qiǎng',  # 羟
    0x7FA0: 'yí',  # 羠
    0x7FA1: 'xiàn',  # 羡
    0x7FA2: 'róng',  # 羢
    0x7FA3: 'qún',  # 羣
    0x7FA4: 'qún',  # 群
    0x7FA5: 'qiǎng',  # 羥
    0x7FA6: 'huán',  # 羦
    0x7FA7: 'suō',  # 羧
    0x7FA8: 'xiàn',  # 羨
    0x7FA9: 'yì',  # 義
    0x7FAA: 'yōu',  # 羪
    0x7FAB: 'qiāng,kòng',  # 羫
    0x7FAC: 'qián,xián,yán',  # 羬
    0x7FAD: 'yú',  # 羭
    0x7FAE: 'gēng',  # 羮
    0x7FAF: 'jié',  # 羯
    0x7FB0: 'tāng',  # 羰
    0x7FB1: 'yuán',  # 羱
    0x7FB2: 'xī',  # 羲
    0x7FB3: 'fán',  # 羳
    0x7FB4: 'shān',  # 羴
    0x7FB5: 'fén',  # 羵
    0x7FB6: 'shān',  # 羶
    0x7FB7: 'liǎn',  # 羷
    0x7FB8: 'léi',  # 羸
    0x7FB9: 'gēng',  # 羹
    0x7FBA: 'nóu',  # 羺
    0x7FBB: 'qiàng',  # 羻
    0x7FBC: 'chàn',  # 羼
    0x7FBD: 'yǔ',  # 羽
    0x7FBE: 'hóng,gòng',  # 羾
    0x7FBF: 'yì',  # 羿
    0x7FC0: 'chōng',  # 翀
    0x7FC1: 'wēng',  # 翁
    0x7FC2: 'fēn',  # 翂
    0x7FC3: 'hóng',  # 翃
    0x7FC4: 'chì',  # 翄
    0x7FC5: 'chì',  # 翅
    0x7FC6: 'cuì',  # 翆
    0x7FC7: 'fú',  # 翇
    0x7FC8: 'xiá',  # 翈
    0x7FC9: 'běn',  # 翉
    0x7FCA: 'yì',  # 翊
    0x7FCB: 'là',  # 翋
    0x7FCC: 'yì',  # 翌
    0x7FCD: 'pī,bì,pō',  # 翍
    0x7FCE: 'líng',  # 翎
    0x7FCF: 'liù',  # 翏
    0x7FD0: 'zhì',  # 翐
    0x7FD1: 'qú,yù',  # 翑
    0x7FD2: 'xí',  # 習
    0x7FD3: 'xié',  # 翓
    0x7FD4: 'xiáng',  # 翔
    0x7FD5: 'xī',  # 翕
    0x7FD6: 'xī',  # 翖
    0x7FD7: 'ké',  # 翗
    0x7FD8: 'qiáo,qiào',  # 翘
    0x7FD9: 'huì',  # 翙
    0x7FDA: 'huī',  # 翚
    0x7FDB: 'xiāo',  # 翛
    0x7FDC: 'shà',  # 翜
    0x7FDD: 'hóng',  # 翝
    0x7FDE: 'jiāng',  # 翞
    0x7FDF: 'dí,zhái',  # 翟
    0x7FE0: 'cuì',  # 翠
    0x7FE1: 'fěi',  # 翡
    0x7FE2: 'dào,zhōu',  # 翢
    0x7FE3: 'shà',  # 翣
    0x7FE4: 'chì',  # 翤
    0x7FE5: 'zhù',  # 翥
    0x7FE6: 'jiǎn',  # 翦
    0x7FE7: 'xuān',  # 翧
    0x7FE8: 'chì',  # 翨
    0x7FE9: 'piān',  # 翩
    0x7FEA: 'zōng',  # 翪
    0x7FEB: 'wán',  # 翫
    0x7FEC: 'huī',  # 翬
    0x7FED: 'hóu',  # 翭
    0x7FEE: 'hé',  # 翮
    0x7FEF: 'hè',  # 翯
    0x7FF0: 'hàn',  # 翰
    0x7FF1: 'áo',  # 翱
    0x7FF2: 'piāo',  # 翲
    0x7FF3: 'yì',  # 翳
    0x7FF4: 'lián',  # 翴
    0x7FF5: 'hóu,qú',  # 翵
    0x7FF6: 'áo',  # 翶
    0x7FF7: 'lín',  # 翷
    0x7FF8: 'pěn',  # 翸
    0x7FF9: 'qiáo,qiào',  # 翹
    0x7FFA: 'áo',  # 翺
    0x7FFB: 'fān',  # 翻
    0x7FFC: 'yì',  # 翼
    0x7FFD: 'huì',  # 翽
    0x7FFE: 'xuān',  # 翾
    0x7FFF: 'dào',  # 翿
    0x8000: 'yào',  # 耀
    0x8001: 'lǎo',  # 老
    0x8002: 'lǎo',  # 耂
    0x8003: 'kǎo',  # 考
    0x8004: 'mào',  # 耄
    0x8005: 'zhě',  # 者
    0x8006: 'qí,shì',  # 耆
    0x8007: 'gǒu',  # 耇
    0x8008: 'gǒu',  # 耈
    0x8009: 'gǒu',  # 耉
    0x800A: 'dié',  # 耊
    0x800B: 'dié',  # 耋
    0x800C: 'ér',  # 而
    0x800D: 'shuǎ',  # 耍
    0x800E: 'ruǎn,nuò',  # 耎
    0x800F: 'ér,nài',  # 耏
    0x8010: 'nài',  # 耐
    0x8011: 'duān,zhuān',  # 耑
    0x8012: 'lěi',  # 耒
    0x8013: 'tīng',  # 耓
    0x8014: 'zǐ',  # 耔
    0x8015: 'gēng',  # 耕
    0x8016: 'chào',  # 耖
    0x8017: 'hào',  # 耗
    0x8018: 'yún',  # 耘
    0x8019: 'bà,pá',  # 耙
    0x801A: 'pī',  # 耚
    0x801B: 'sì,chí',  # 耛
    0x801C: 'sì',  # 耜
    0x801D: 'qù,chú',  # 耝
    0x801E: 'jiā',  # 耞
    0x801F: 'jù',  # 耟
    0x8020: 'huō',  # 耠
    0x8021: 'chú',  # 耡
    0x8022: 'lào',  # 耢
    0x8023: 'lún,lǔn',  # 耣
    0x8024: 'jí,jiè',  # 耤
    0x8025: 'tǎng',  # 耥
    0x8026: 'ǒu',  # 耦
    0x8027: 'lóu',  # 耧
    0x8028: 'nòu',  # 耨
    0x8029: 'jiǎng',  # 耩
    0x802A: 'pǎng',  # 耪
    0x802B: 'zhá,zé',  # 耫
    0x802C: 'lóu',  # 耬
    0x802D: 'jī',  # 耭
    0x802E: 'lào',  # 耮
    0x802F: 'huò',  # 耯
    0x8030: 'yōu',  # 耰
    0x8031: 'mò',  # 耱
    0x8032: 'huái',  # 耲
    0x8033: 'ěr',  # 耳
    0x8034: 'yì',  # 耴
    0x8035: 'dīng',  # 耵
    0x8036: 'yé,yē',  # 耶
    0x8037: 'dā',  # 耷
    0x8038: 'sǒng',  # 耸
    0x8039: 'qín',  # 耹
    0x803A: 'yún,yíng',  # 耺
    0x803B: 'chǐ',  # 耻
    0x803C: 'dān',  # 耼
    0x803D: 'dān',  # 耽
    0x803E: 'hóng',  # 耾
    0x803F: 'gěng',  # 耿
    0x8040: 'zhí',  # 聀
    0x8041: 'pàn',  # 聁
    0x8042: 'niè',  # 聂
    0x8043: 'dān',  # 聃
    0x8044: 'zhěn',  # 聄
    0x8045: 'chè',  # 聅
    0x8046: 'líng',  # 聆
    0x8047: 'zhēng',  # 聇
    0x8048: 'yǒu',  # 聈
    0x8049: 'wà,tuǐ,zhuó',  # 聉
    0x804A: 'liáo',  # 聊
    0x804B: 'lóng',  # 聋
    0x804C: 'zhí',  # 职
    0x804D: 'níng',  # 聍
    0x804E: 'tiāo',  # 聎
    0x804F: 'ér,nǜ',  # 聏
    0x8050: 'yà',  # 聐
    0x8051: 'tiē,zhé',  # 聑
    0x8052: 'guō',  # 聒
    0x8053: 'xù',  # 聓
    0x8054: 'lián',  # 联
    0x8055: 'hào',  # 聕
    0x8056: 'shèng',  # 聖
    0x8057: 'liè',  # 聗
    0x8058: 'pìn',  # 聘
    0x8059: 'jīng',  # 聙
    0x805A: 'jù',  # 聚
    0x805B: 'bǐ',  # 聛
    0x805C: 'dǐ,zhì',  # 聜
    0x805D: 'guó',  # 聝
    0x805E: 'wén',  # 聞
    0x805F: 'xù',  # 聟
    0x8060: 'pīng',  # 聠
    0x8061: 'cōng',  # 聡
    0x8062: 'dìng',  # 聢
    0x8063: 'ní',  # 聣
    0x8064: 'tíng',  # 聤
    0x8065: 'jǔ',  # 聥
    0x8066: 'cōng',  # 聦
    0x8067: 'kuī',  # 聧
    0x8068: 'lián',  # 聨
    0x8069: 'kuì',  # 聩
    0x806A: 'cōng',  # 聪
    0x806B: 'lián',  # 聫
    0x806C: 'wēng',  # 聬
    0x806D: 'kuì',  # 聭
    0x806E: 'lián',  # 聮
    0x806F: 'lián',  # 聯
    0x8070: 'cōng',  # 聰
    0x8071: 'áo',  # 聱
    0x8072: 'shēng',  # 聲
    0x8073: 'sǒng',  # 聳
    0x8074: 'tīng',  # 聴
    0x8075: 'kuì',  # 聵
    0x8076: 'niè',  # 聶
    0x8077: 'zhí',  # 職
    0x8078: 'dān',  # 聸
    0x8079: 'níng',  # 聹
    0x807A: 'qié',  # 聺
    0x807B: 'nǐ,jiàn',  # 聻
    0x807C: 'tīng',  # 聼
    0x807D: 'tīng',  # 聽
    0x807E: 'lóng',  # 聾
    0x807F: 'yù',  # 聿
    0x8080: 'yù',  # 肀
    0x8081: 'zhào',  # 肁
    0x8082: 'sì',  # 肂
    0x8083: 'sù',  # 肃
    0x8084: 'yì',  # 肄
    0x8085: 'sù',  # 肅
    0x8086: 'sì',  # 肆
    0x8087: 'zhào',  # 肇
    0x8088: 'zhào',  # 肈
    0x8089: 'ròu',  # 肉
    0x808A: 'yì',  # 肊
    0x808B: 'lèi,lē',  # 肋
    0x808C: 'jī',  # 肌
    0x808D: 'qiú',  # 肍
    0x808E: 'kěn',  # 肎
    0x808F: 'cào',  # 肏
    0x8090: 'gē',  # 肐
    0x8091: 'bó,dí',  # 肑
    0x8092: 'huàn',  # 肒
    0x8093: 'huāng',  # 肓
    0x8094: 'chǐ',  # 肔
    0x8095: 'rèn',  # 肕
    0x8096: 'xiāo,xiào',  # 肖
    0x8097: 'rǔ',  # 肗
    0x8098: 'zhǒu',  # 肘
    0x8099: 'yuān',  # 肙
    0x809A: 'dù,dǔ',  # 肚
    0x809B: 'gāng',  # 肛
    0x809C: 'róng,chēn',  # 肜
    0x809D: 'gān',  # 肝
    0x809E: 'chāi',  # 肞
    0x809F: 'wò',  # 肟
    0x80A0: 'cháng',  # 肠
    0x80A1: 'gǔ',  # 股
    0x80A2: 'zhī',  # 肢
    0x80A3: 'qín,hán,hàn',  # 肣
    0x80A4: 'fū',  # 肤
    0x80A5: 'féi',  # 肥
    0x80A6: 'bān',  # 肦
    0x80A7: 'pēi',  # 肧
    0x80A8: 'pàng,pán,pàn',  # 肨
    0x80A9: 'jiān',  # 肩
    0x80AA: 'fáng',  # 肪
    0x80AB: 'zhūn,chún',  # 肫
    0x80AC: 'yóu',  # 肬
    0x80AD: 'nà',  # 肭
    0x80AE: 'āng',  # 肮
    0x80AF: 'kěn',  # 肯
    0x80B0: 'rán',  # 肰
    0x80B1: 'gōng',  # 肱
    0x80B2: 'yù',  # 育
    0x80B3: 'wěn',  # 肳
    0x80B4: 'yáo',  # 肴
    0x80B5: 'qí',  # 肵
    0x80B6: 'pí,bǐ,bì',  # 肶
    0x80B7: 'qiǎn',  # 肷
    0x80B8: 'xī',  # 肸
    0x80B9: 'xī',  # 肹
    0x80BA: 'fèi',  # 肺
    0x80BB: 'kěn',  # 肻
    0x80BC: 'jǐng',  # 肼
    0x80BD: 'tài',  # 肽
    0x80BE: 'shèn',  # 肾
    0x80BF: 'zhǒng',  # 肿
    0x80C0: 'zhàng',  # 胀
    0x80C1: 'xié',  # 胁
    0x80C2: 'shèn',  # 胂
    0x80C3: 'wèi',  # 胃
    0x80C4: 'zhòu',  # 胄
    0x80C5: 'dié',  # 胅
    0x80C6: 'dǎn',  # 胆
    0x80C7: 'fèi,bì',  # 胇
    0x80C8: 'bá',  # 胈
    0x80C9: 'bó',  # 胉
    0x80CA: 'qú',  # 胊
    0x80CB: 'tián',  # 胋
    0x80CC: 'bèi,bēi',  # 背
    0x80CD: 'guā',  # 胍
    0x80CE: 'tāi',  # 胎
    0x80CF: 'zǐ,fèi',  # 胏
    0x80D0: 'fěi,kū',  # 胐
    0x80D1: 'zhī',  # 胑
    0x80D2: 'nì',  # 胒
    0x80D3: 'píng,pēng',  # 胓
    0x80D4: 'zì',  # 胔
    0x80D5: 'fū,fú,zhǒu',  # 胕
    0x80D6: 'pàng,pán,pàn',  # 胖
    0x80D7: 'zhēn',  # 胗
    0x80D8: 'xián',  # 胘
    0x80D9: 'zuò',  # 胙
    0x80DA: 'pēi',  # 胚
    0x80DB: 'jiǎ',  # 胛
    0x80DC: 'shèng',  # 胜
    0x80DD: 'zhī',  # 胝
    0x80DE: 'bāo',  # 胞
    0x80DF: 'mǔ',  # 胟
    0x80E0: 'qū',  # 胠
    0x80E1: 'hú',  # 胡
    0x80E2: 'qià',  # 胢
    0x80E3: 'chǐ',  # 胣
    0x80E4: 'yìn',  # 胤
    0x80E5: 'xū',  # 胥
    0x80E6: 'yāng',  # 胦
    0x80E7: 'lóng',  # 胧
    0x80E8: 'dòng',  # 胨
    0x80E9: 'kǎ',  # 胩
    0x80EA: 'lú',  # 胪
    0x80EB: 'jìng',  # 胫
    0x80EC: 'nǔ',  # 胬
    0x80ED: 'yān',  # 胭
    0x80EE: 'pāng',  # 胮
    0x80EF: 'kuà',  # 胯
    0x80F0: 'yí',  # 胰
    0x80F1: 'guāng',  # 胱
    0x80F2: 'hǎi',  # 胲
    0x80F3: 'gē,gé',  # 胳
    0x80F4: 'dòng',  # 胴
    0x80F5: 'chī',  # 胵
    0x80F6: 'jiāo',  # 胶
    0x80F7: 'xiōng',  # 胷
    0x80F8: 'xiōng',  # 胸
    0x80F9: 'ér',  # 胹
    0x80FA: 'àn',  # 胺
    0x80FB: 'héng',  # 胻
    0x80FC: 'pián',  # 胼
    0x80FD: 'néng,nài',  # 能
    0x80FE: 'zì',  # 胾
    0x80FF: 'guī,kuì',  # 胿
    0x8100: 'zhēng',  # 脀
    0x8101: 'tiǎo',  # 脁
    0x8102: 'zhī',  # 脂
    0x8103: 'cuì',  # 脃
    0x8104: 'méi',  # 脄
    0x8105: 'xié',  # 脅
    0x8106: 'cuì',  # 脆
    0x8107: 'xié',  # 脇
    0x8108: 'mài',  # 脈
    0x8109: 'mài,mò',  # 脉
    0x810A: 'jǐ',  # 脊
    0x810B: 'xié',  # 脋
    0x810C: 'nín',  # 脌
    0x810D: 'kuài',  # 脍
    0x810E: 'sà',  # 脎
    0x810F: 'zàng',  # 脏
    0x8110: 'qí',  # 脐
    0x8111: 'nǎo',  # 脑
    0x8112: 'mǐ',  # 脒
    0x8113: 'nóng',  # 脓
    0x8114: 'luán',  # 脔
    0x8115: 'wàn',  # 脕
    0x8116: 'bó',  # 脖
    0x8117: 'wěn',  # 脗
    0x8118: 'wǎn',  # 脘
    0x8119: 'xiū',  # 脙
    0x811A: 'jiǎo',  # 脚
    0x811B: 'jìng',  # 脛
    0x811C: 'róu',  # 脜
    0x811D: 'hēng',  # 脝
    0x811E: 'cuǒ',  # 脞
    0x811F: 'liè',  # 脟
    0x8120: 'shān',  # 脠
    0x8121: 'tǐng',  # 脡
    0x8122: 'méi',  # 脢
    0x8123: 'chún',  # 脣
    0x8124: 'shèn',  # 脤
    0x8125: 'jiá',  # 脥
    0x8126: 'tè',  # 脦
    0x8127: 'juān',  # 脧
    0x8128: 'cù',  # 脨
    0x8129: 'xiū',  # 脩
    0x812A: 'xìn',  # 脪
    0x812B: 'tuō',  # 脫
    0x812C: 'pāo',  # 脬
    0x812D: 'chéng',  # 脭
    0x812E: 'něi',  # 脮
    0x812F: 'fǔ',  # 脯
    0x8130: 'dòu',  # 脰
    0x8131: 'tuō',  # 脱
    0x8132: 'niào',  # 脲
    0x8133: 'nǎo',  # 脳
    0x8134: 'pǐ',  # 脴
    0x8135: 'gǔ',  # 脵
    0x8136: 'luó',  # 脶
    0x8137: 'lì',  # 脷
    0x8138: 'liǎn',  # 脸
    0x8139: 'zhàng',  # 脹
    0x813A: 'cuī',  # 脺
    0x813B: 'jiē',  # 脻
    0x813C: 'liǎng',  # 脼
    0x813D: 'shuí',  # 脽
    0x813E: 'pí',  # 脾
    0x813F: 'biāo',  # 脿
    0x8140: 'lún',  # 腀
    0x8141: 'pián',  # 腁
    0x8142: 'guò',  # 腂
    0x8143: 'juàn',  # 腃
    0x8144: 'chuí',  # 腄
    0x8145: 'dàn',  # 腅
    0x8146: 'tiǎn',  # 腆
    0x8147: 'něi',  # 腇
    0x8148: 'jīng',  # 腈
    0x8149: 'nái',  # 腉
    0x814A: 'là,xī',  # 腊
    0x814B: 'yè',  # 腋
    0x814C: 'ā,yān',  # 腌
    0x814D: 'rèn',  # 腍
    0x814E: 'shèn',  # 腎
    0x814F: 'zhuì',  # 腏
    0x8150: 'fǔ',  # 腐
    0x8151: 'fǔ',  # 腑
    0x8152: 'jū',  # 腒
    0x8153: 'féi',  # 腓
    0x8154: 'qiāng',  # 腔
    0x8155: 'wàn',  # 腕
    0x8156: 'dòng',  # 腖
    0x8157: 'pí',  # 腗
    0x8158: 'guó',  # 腘
    0x8159: 'zōng',  # 腙
    0x815A: 'dìng',  # 腚
    0x815B: 'wò',  # 腛
    0x815C: 'méi',  # 腜
    0x815D: 'ruǎn',  # 腝
    0x815E: 'zhuàn',  # 腞
    0x815F: 'chì',  # 腟
    0x8160: 'còu',  # 腠
    0x8161: 'luó',  # 腡
    0x8162: 'ǒu',  # 腢
    0x8163: 'dì',  # 腣
    0x8164: 'ān',  # 腤
    0x8165: 'xīng',  # 腥
    0x8166: 'nǎo',  # 腦
    0x8167: 'shù',  # 腧
    0x8168: 'shuàn',  # 腨
    0x8169: 'nǎn',  # 腩
    0x816A: 'yùn',  # 腪
    0x816B: 'zhǒng',  # 腫
    0x816C: 'róu',  # 腬
    0x816D: 'è',  # 腭
    0x816E: 'sāi',  # 腮
    0x816F: 'tú',  # 腯
    0x8170: 'yāo',  # 腰
    0x8171: 'jiàn',  # 腱
    0x8172: 'wěi',  # 腲
    0x8173: 'jiǎo',  # 腳
    0x8174: 'yú',  # 腴
    0x8175: 'jiā',  # 腵
    0x8176: 'duàn',  # 腶
    0x8177: 'bì',  # 腷
    0x8178: 'cháng',  # 腸
    0x8179: 'fù',  # 腹
    0x817A: 'xiàn',  # 腺
    0x817B: 'nì',  # 腻
    0x817C: 'miǎn',  # 腼
    0x817D: 'wà',  # 腽
    0x817E: 'téng',  # 腾
    0x817F: 'tuǐ',  # 腿
    0x8180: 'bǎng,páng',  # 膀
    0x8181: 'qiǎn',  # 膁
    0x8182: 'lǚ',  # 膂
    0x8183: 'wà',  # 膃
    0x8184: 'shòu',  # 膄
    0x8185: 'táng',  # 膅
    0x8186: 'sù',  # 膆
    0x8187: 'zhuì',  # 膇
    0x8188: 'gé',  # 膈
    0x8189: 'yì',  # 膉
    0x818A: 'bó',  # 膊
    0x818B: 'liáo',  # 膋
    0x818C: 'jí',  # 膌
    0x818D: 'pí',  # 膍
    0x818E: 'xié',  # 膎
    0x818F: 'gāo,gào',  # 膏
    0x8190: 'lǚ',  # 膐
    0x8191: 'bìn',  # 膑
    0x8192: 'ōu',  # 膒
    0x8193: 'cháng',  # 膓
    0x8194: 'lù,biāo',  # 膔
    0x8195: 'guó',  # 膕
    0x8196: 'pāng',  # 膖
    0x8197: 'chuái',  # 膗
    0x8198: 'biāo',  # 膘
    0x8199: 'jiǎng',  # 膙
    0x819A: 'fū',  # 膚
    0x819B: 'táng',  # 膛
    0x819C: 'mó',  # 膜
    0x819D: 'xī',  # 膝
    0x819E: 'zhuān,chuán,chún,zhuǎn',  # 膞
    0x819F: 'lǜ',  # 膟
    0x81A0: 'jiāo',  # 膠
    0x81A1: 'yìng',  # 膡
    0x81A2: 'lǘ',  # 膢
    0x81A3: 'zhì',  # 膣
    0x81A4: 'xuě',  # 膤
    0x81A5: 'cūn',  # 膥
    0x81A6: 'lìn',  # 膦
    0x81A7: 'tóng',  # 膧
    0x81A8: 'péng',  # 膨
    0x81A9: 'nì',  # 膩
    0x81AA: 'chuài',  # 膪
    0x81AB: 'liáo',  # 膫
    0x81AC: 'cuì',  # 膬
    0x81AD: 'kuì',  # 膭
    0x81AE: 'xiāo',  # 膮
    0x81AF: 'tēng',  # 膯
    0x81B0: 'fán,pán',  # 膰
    0x81B1: 'zhí',  # 膱
    0x81B2: 'jiāo',  # 膲
    0x81B3: 'shàn',  # 膳
    0x81B4: 'hū,wǔ',  # 膴
    0x81B5: 'cuì',  # 膵
    0x81B6: 'rùn',  # 膶
    0x81B7: 'xiāng',  # 膷
    0x81B8: 'suǐ',  # 膸
    0x81B9: 'fèn',  # 膹
    0x81BA: 'yīng',  # 膺
    0x81BB: 'shān,dàn',  # 膻
    0x81BC: 'zhuā',  # 膼
    0x81BD: 'dǎn',  # 膽
    0x81BE: 'kuài',  # 膾
    0x81BF: 'nóng',  # 膿
    0x81C0: 'tún',  # 臀
    0x81C1: 'lián',  # 臁
    0x81C2: 'bì,bei',  # 臂
    0x81C3: 'yōng',  # 臃
    0x81C4: 'jué',  # 臄
    0x81C5: 'chù',  # 臅
    0x81C6: 'yì',  # 臆
    0x81C7: 'juǎn',  # 臇
    0x81C8: 'là,gé',  # 臈
    0x81C9: 'liǎn',  # 臉
    0x81CA: 'sāo,sào',  # 臊
    0x81CB: 'tún',  # 臋
    0x81CC: 'gǔ',  # 臌
    0x81CD: 'qí',  # 臍
    0x81CE: 'cuì',  # 臎
    0x81CF: 'bìn',  # 臏
    0x81D0: 'xūn',  # 臐
    0x81D1: 'nào',  # 臑
    0x81D2: 'wò,yuè',  # 臒
    0x81D3: 'zàng',  # 臓
    0x81D4: 'xiàn',  # 臔
    0x81D5: 'biāo',  # 臕
    0x81D6: 'xìng',  # 臖
    0x81D7: 'kuān',  # 臗
    0x81D8: 'là',  # 臘
    0x81D9: 'yān',  # 臙
    0x81DA: 'lú',  # 臚
    0x81DB: 'huò',  # 臛
    0x81DC: 'zā',  # 臜
    0x81DD: 'luǒ',  # 臝
    0x81DE: 'qú',  # 臞
    0x81DF: 'zàng',  # 臟
    0x81E0: 'luán',  # 臠
    0x81E1: 'ní,luán',  # 臡
    0x81E2: 'zā',  # 臢
    0x81E3: 'chén',  # 臣
    0x81E4: 'qiān,xián',  # 臤
    0x81E5: 'wò',  # 臥
    0x81E6: 'guàng,jiǒng',  # 臦
    0x81E7: 'zāng,zàng,cáng',  # 臧
    0x81E8: 'lín',  # 臨
    0x81E9: 'guǎng,jiǒng',  # 臩
    0x81EA: 'zì',  # 自
    0x81EB: 'jiǎo',  # 臫
    0x81EC: 'niè',  # 臬
    0x81ED: 'chòu,xiù',  # 臭
    0x81EE: 'jì',  # 臮
    0x81EF: 'gāo',  # 臯
    0x81F0: 'chòu',  # 臰
    0x81F1: 'mián,biān',  # 臱
    0x81F2: 'niè',  # 臲
    0x81F3: 'zhì',  # 至
    0x81F4: 'zhì',  # 致
    0x81F5: 'gé',  # 臵
    0x81F6: 'jiàn',  # 臶
    0x81F7: 'dié,zhí',  # 臷
    0x81F8: 'zhī,jìn',  # 臸
    0x81F9: 'xiū',  # 臹
    0x81FA: 'tái',  # 臺
    0x81FB: 'zhēn',  # 臻
    0x81FC: 'jiù',  # 臼
    0x81FD: 'xiàn',  # 臽
    0x81FE: 'yú',  # 臾
    0x81FF: 'chā',  # 臿
    0x8200: 'yǎo',  # 舀
    0x8201: 'yú',  # 舁
    0x8202: 'chōng',  # 舂
    0x8203: 'xì',  # 舃
    0x8204: 'xì',  # 舄
    0x8205: 'jiù',  # 舅
    0x8206: 'yú',  # 舆
    0x8207: 'yǔ',  # 與
    0x8208: 'xīng',  # 興
    0x8209: 'jǔ',  # 舉
    0x820A: 'jiù',  # 舊
    0x820B: 'xìn',  # 舋
    0x820C: 'shé',  # 舌
    0x820D: 'shě,shè',  # 舍
    0x820E: 'shè',  # 舎
    0x820F: 'jiǔ',  # 舏
    0x8210: 'shì',  # 舐
    0x8211: 'tān',  # 舑
    0x8212: 'shū',  # 舒
    0x8213: 'shì',  # 舓
    0x8214: 'tiǎn',  # 舔
    0x8215: 'tàn',  # 舕
    0x8216: 'pù',  # 舖
    0x8217: 'pù',  # 舗
    0x8218: 'guǎn',  # 舘
    0x8219: 'huà',  # 舙
    0x821A: 'tiàn',  # 舚
    0x821B: 'chuǎn',  # 舛
    0x821C: 'shùn',  # 舜
    0x821D: 'xiá',  # 舝
    0x821E: 'wǔ',  # 舞
    0x821F: 'zhōu',  # 舟
    0x8220: 'dāo',  # 舠
    0x8221: 'chuán',  # 舡
    0x8222: 'shān',  # 舢
    0x8223: 'yǐ',  # 舣
    0x8224: 'fán',  # 舤
    0x8225: 'pā',  # 舥
    0x8226: 'tài',  # 舦
    0x8227: 'fán',  # 舧
    0x8228: 'bǎn',  # 舨
    0x8229: 'chuán',  # 舩
    0x822A: 'háng',  # 航
    0x822B: 'fǎng',  # 舫
    0x822C: 'bān',  # 般
    0x822D: 'bǐ',  # 舭
    0x822E: 'lú',  # 舮
    0x822F: 'zhōng',  # 舯
    0x8230: 'jiàn',  # 舰
    0x8231: 'cāng',  # 舱
    0x8232: 'líng',  # 舲
    0x8233: 'zhú',  # 舳
    0x8234: 'zé',  # 舴
    0x8235: 'duò',  # 舵
    0x8236: 'bó',  # 舶
    0x8237: 'xián',  # 舷
    0x8238: 'gě',  # 舸
    0x8239: 'chuán',  # 船
    0x823A: 'xiá',  # 舺
    0x823B: 'lú',  # 舻
    0x823C: 'qióng',  # 舼
    0x823D: 'páng',  # 舽
    0x823E: 'xī',  # 舾
    0x823F: 'kuā',  # 舿
    0x8240: 'fú',  # 艀
    0x8241: 'zào',  # 艁
    0x8242: 'féng',  # 艂
    0x8243: 'lí',  # 艃
    0x8244: 'shāo',  # 艄
    0x8245: 'yú',  # 艅
    0x8246: 'láng',  # 艆
    0x8247: 'tǐng',  # 艇
    0x8248: 'yù',  # 艈
    0x8249: 'wěi',  # 艉
    0x824A: 'bó',  # 艊
    0x824B: 'měng',  # 艋
    0x824C: 'niàn',  # 艌
    0x824D: 'jū',  # 艍
    0x824E: 'huáng',  # 艎
    0x824F: 'shǒu',  # 艏
    0x8250: 'kè',  # 艐
    0x8251: 'biàn',  # 艑
    0x8252: 'mù',  # 艒
    0x8253: 'dié',  # 艓
    0x8254: 'dào',  # 艔
    0x8255: 'bàng',  # 艕
    0x8256: 'chā',  # 艖
    0x8257: 'yì',  # 艗
    0x8258: 'sōu',  # 艘
    0x8259: 'cāng',  # 艙
    0x825A: 'cáo',  # 艚
    0x825B: 'lóu',  # 艛
    0x825C: 'dài',  # 艜
    0x825D: 'xuě',  # 艝
    0x825E: 'yào',  # 艞
    0x825F: 'chōng',  # 艟
    0x8260: 'dēng',  # 艠
    0x8261: 'dāng',  # 艡
    0x8262: 'qiáng',  # 艢
    0x8263: 'lǔ',  # 艣
    0x8264: 'yǐ',  # 艤
    0x8265: 'jí',  # 艥
    0x8266: 'jiàn',  # 艦
    0x8267: 'huò',  # 艧
    0x8268: 'méng',  # 艨
    0x8269: 'qí',  # 艩
    0x826A: 'lǔ',  # 艪
    0x826B: 'lú',  # 艫
    0x826C: 'chán',  # 艬
    0x826D: 'shuāng',  # 艭
    0x826E: 'gèn',  # 艮
    0x826F: 'liáng',  # 良
    0x8270: 'jiān',  # 艰
    0x8271: 'jiān',  # 艱
    0x8272: 'sè',  # 色
    0x8273: 'yàn',  # 艳
    0x8274: 'fú',  # 艴
    0x8275: 'pīng',  # 艵
    0x8276: 'yàn',  # 艶
    0x8277: 'yàn',  # 艷
    0x8278: 'cǎo',  # 艸
    0x8279: 'ǎo',  # 艹
    0x827A: 'yì',  # 艺
    0x827B: 'lè',  # 艻
    0x827C: 'dǐng',  # 艼
    0x827D: 'jiāo,qiú',  # 艽
    0x827E: 'ài,yì',  # 艾
    0x827F: 'nǎi',  # 艿
    0x8280: 'tiáo',  # 芀
    0x8281: 'qiú',  # 芁
    0x8282: 'jié,jiē',  # 节
    0x8283: 'péng',  # 芃
    0x8284: 'wán',  # 芄
    0x8285: 'yì',  # 芅
    0x8286: 'chāi,chā',  # 芆
    0x8287: 'mián',  # 芇
    0x8288: 'mǐ',  # 芈
    0x8289: 'gǎn',  # 芉
    0x828A: 'qiān',  # 芊
    0x828B: 'yù',  # 芋
    0x828C: 'yù',  # 芌
    0x828D: 'sháo',  # 芍
    0x828E: 'xiōng',  # 芎
    0x828F: 'dù',  # 芏
    0x8290: 'hù,xià',  # 芐
    0x8291: 'qǐ',  # 芑
    0x8292: 'máng',  # 芒
    0x8293: 'zì,zǐ',  # 芓
    0x8294: 'huì,hū',  # 芔
    0x8295: 'suī',  # 芕
    0x8296: 'zhì',  # 芖
    0x8297: 'xiāng',  # 芗
    0x8298: 'bì,pí',  # 芘
    0x8299: 'fú',  # 芙
    0x829A: 'tún,chūn',  # 芚
    0x829B: 'wěi',  # 芛
    0x829C: 'wú',  # 芜
    0x829D: 'zhī',  # 芝
    0x829E: 'qì',  # 芞
    0x829F: 'shān',  # 芟
    0x82A0: 'wén',  # 芠
    0x82A1: 'qiàn',  # 芡
    0x82A2: 'rén',  # 芢
    0x82A3: 'fú',  # 芣
    0x82A4: 'kōu',  # 芤
    0x82A5: 'jiè,gài',  # 芥
    0x82A6: 'lú',  # 芦
    0x82A7: 'xù,zhù',  # 芧
    0x82A8: 'jī',  # 芨
    0x82A9: 'qín',  # 芩
    0x82AA: 'qí',  # 芪
    0x82AB: 'yuán,yán',  # 芫
    0x82AC: 'fēn',  # 芬
    0x82AD: 'bā',  # 芭
    0x82AE: 'ruì',  # 芮
    0x82AF: 'xīn,xìn',  # 芯
    0x82B0: 'jì',  # 芰
    0x82B1: 'huā',  # 花
    0x82B2: 'lún,huā',  # 芲
    0x82B3: 'fāng',  # 芳
    0x82B4: 'wù,hū',  # 芴
    0x82B5: 'jué',  # 芵
    0x82B6: 'gōu,gǒu',  # 芶
    0x82B7: 'zhǐ',  # 芷
    0x82B8: 'yún',  # 芸
    0x82B9: 'qín',  # 芹
    0x82BA: 'ǎo',  # 芺
    0x82BB: 'chú',  # 芻
    0x82BC: 'máo,mào',  # 芼
    0x82BD: 'yá',  # 芽
    0x82BE: 'fèi,fú',  # 芾
    0x82BF: 'réng',  # 芿
    0x82C0: 'háng',  # 苀
    0x82C1: 'cōng',  # 苁
    0x82C2: 'chán,yín',  # 苂
    0x82C3: 'yǒu',  # 苃
    0x82C4: 'biàn',  # 苄
    0x82C5: 'yì',  # 苅
    0x82C6: 'qiē',  # 苆
    0x82C7: 'wěi',  # 苇
    0x82C8: 'lì',  # 苈
    0x82C9: 'pǐ',  # 苉
    0x82CA: 'è',  # 苊
    0x82CB: 'xiàn',  # 苋
    0x82CC: 'cháng',  # 苌
    0x82CD: 'cāng',  # 苍
    0x82CE: 'zhù',  # 苎
    0x82CF: 'sū,sù',  # 苏
    0x82D0: 'dì,tí',  # 苐
    0x82D1: 'yuàn',  # 苑
    0x82D2: 'rǎn',  # 苒
    0x82D3: 'líng',  # 苓
    0x82D4: 'tái,tāi',  # 苔
    0x82D5: 'tiáo,sháo',  # 苕
    0x82D6: 'dí',  # 苖
    0x82D7: 'miáo',  # 苗
    0x82D8: 'qǐng',  # 苘
    0x82D9: 'lì,jī',  # 苙
    0x82DA: 'yòng',  # 苚
    0x82DB: 'kē,hē',  # 苛
    0x82DC: 'mù',  # 苜
    0x82DD: 'bèi',  # 苝
    0x82DE: 'bāo',  # 苞
    0x82DF: 'gǒu',  # 苟
    0x82E0: 'mín',  # 苠
    0x82E1: 'yǐ',  # 苡
    0x82E2: 'yǐ',  # 苢
    0x82E3: 'jù,qǔ',  # 苣
    0x82E4: 'piě',  # 苤
    0x82E5: 'ruò,rě',  # 若
    0x82E6: 'kǔ',  # 苦
    0x82E7: 'zhù,níng',  # 苧
    0x82E8: 'nǐ',  # 苨
    0x82E9: 'pā,bó',  # 苩
    0x82EA: 'bǐng',  # 苪
    0x82EB: 'shān,shàn',  # 苫
    0x82EC: 'xiú',  # 苬
    0x82ED: 'yǎo',  # 苭
    0x82EE: 'xiān',  # 苮
    0x82EF: 'běn',  # 苯
    0x82F0: 'hóng',  # 苰
    0x82F1: 'yīng',  # 英
    0x82F2: 'zuó,zhǎ',  # 苲
    0x82F3: 'dōng',  # 苳
    0x82F4: 'jū,chá',  # 苴
    0x82F5: 'dié',  # 苵
    0x82F6: 'nié',  # 苶
    0x82F7: 'gān',  # 苷
    0x82F8: 'hū',  # 苸
    0x82F9: 'píng,pēng',  # 苹
    0x82FA: 'méi',  # 苺
    0x82FB: 'fú',  # 苻
    0x82FC: 'shēng,ruí',  # 苼
    0x82FD: 'gū',  # 苽
    0x82FE: 'bì',  # 苾
    0x82FF: 'wèi',  # 苿
    0x8300: 'fú',  # 茀
    0x8301: 'zhuó',  # 茁
    0x8302: 'mào',  # 茂
    0x8303: 'fàn',  # 范
    0x8304: 'qié',  # 茄
    0x8305: 'máo',  # 茅
    0x8306: 'máo',  # 茆
    0x8307: 'bá',  # 茇
    0x8308: 'zǐ',  # 茈
    0x8309: 'mò',  # 茉
    0x830A: 'zī',  # 茊
    0x830B: 'zhǐ',  # 茋
    0x830C: 'chí',  # 茌
    0x830D: 'jì',  # 茍
    0x830E: 'jīng',  # 茎
    0x830F: 'lóng',  # 茏
    0x8310: 'cōng',  # 茐
    0x8311: 'niǎo',  # 茑
    0x8312: 'yuán',  # 茒
    0x8313: 'xué',  # 茓
    0x8314: 'yíng',  # 茔
    0x8315: 'qióng',  # 茕
    0x8316: 'gè',  # 茖
    0x8317: 'míng',  # 茗
    0x8318: 'lì',  # 茘
    0x8319: 'róng',  # 茙
    0x831A: 'yìn',  # 茚
    0x831B: 'gèn',  # 茛
    0x831C: 'qiàn',  # 茜
    0x831D: 'chǎi',  # 茝
    0x831E: 'chén',  # 茞
    0x831F: 'yù',  # 茟
    0x8320: 'hāo',  # 茠
    0x8321: 'zì',  # 茡
    0x8322: 'liè',  # 茢
    0x8323: 'wú',  # 茣
    0x8324: 'jì',  # 茤
    0x8325: 'guī',  # 茥
    0x8326: 'cì',  # 茦
    0x8327: 'jiǎn',  # 茧
    0x8328: 'cí',  # 茨
    0x8329: 'hòu',  # 茩
    0x832A: 'guāng',  # 茪
    0x832B: 'máng',  # 茫
    0x832C: 'chá',  # 茬
    0x832D: 'jiāo',  # 茭
    0x832E: 'jiāo',  # 茮
    0x832F: 'fú',  # 茯
    0x8330: 'yú',  # 茰
    0x8331: 'zhū',  # 茱
    0x8332: 'zī',  # 茲
    0x8333: 'jiāng',  # 茳
    0x8334: 'huí',  # 茴
    0x8335: 'yīn',  # 茵
    0x8336: 'chá',  # 茶
    0x8337: 'fá',  # 茷
    0x8338: 'róng',  # 茸
    0x8339: 'rú',  # 茹
    0x833A: 'chōng',  # 茺
    0x833B: 'mǎng',  # 茻
    0x833C: 'tóng',  # 茼
    0x833D: 'zhòng',  # 茽
    0x833E: 'qiān',  # 茾
    0x833F: 'zhú',  # 茿
    0x8340: 'xún',  # 荀
    0x8341: 'huán',  # 荁
    0x8342: 'fū',  # 荂
    0x8343: 'quán',  # 荃
    0x8344: 'gāi',  # 荄
    0x8345: 'dá',  # 荅
    0x8346: 'jīng',  # 荆
    0x8347: 'xìng',  # 荇
    0x8348: 'chuǎn',  # 荈
    0x8349: 'cǎo',  # 草
    0x834A: 'jīng',  # 荊
    0x834B: 'ér',  # 荋
    0x834C: 'àn',  # 荌
    0x834D: 'qiáo',  # 荍
    0x834E: 'chí',  # 荎
    0x834F: 'rěn',  # 荏
    0x8350: 'jiàn',  # 荐
    0x8351: 'yí,tí',  # 荑
    0x8352: 'huāng',  # 荒
    0x8353: 'píng',  # 荓
    0x8354: 'lì',  # 荔
    0x8355: 'jīn',  # 荕
    0x8356: 'lǎo',  # 荖
    0x8357: 'shù',  # 荗
    0x8358: 'zhuāng',  # 荘
    0x8359: 'dá',  # 荙
    0x835A: 'jiá',  # 荚
    0x835B: 'ráo',  # 荛
    0x835C: 'bì',  # 荜
    0x835D: 'cè',  # 荝
    0x835E: 'qiáo',  # 荞
    0x835F: 'huì',  # 荟
    0x8360: 'jì,qí',  # 荠
    0x8361: 'dàng',  # 荡
    0x8362: 'zì',  # 荢
    0x8363: 'róng',  # 荣
    0x8364: 'hūn',  # 荤
    0x8365: 'xíng,yīng',  # 荥
    0x8366: 'luò',  # 荦
    0x8367: 'yíng',  # 荧
    0x8368: 'qián,xún',  # 荨
    0x8369: 'jìn',  # 荩
    0x836A: 'sūn',  # 荪
    0x836B: 'yīn,yìn',  # 荫
    0x836C: 'mǎi',  # 荬
    0x836D: 'hóng',  # 荭
    0x836E: 'zhòu',  # 荮
    0x836F: 'yào',  # 药
    0x8370: 'dù',  # 荰
    0x8371: 'wěi',  # 荱
    0x8372: 'lí',  # 荲
    0x8373: 'dòu',  # 荳
    0x8374: 'fū',  # 荴
    0x8375: 'rěn',  # 荵
    0x8376: 'yín',  # 荶
    0x8377: 'hé',  # 荷
    0x8378: 'bí',  # 荸
    0x8379: 'bù',  # 荹
    0x837A: 'yǔn',  # 荺
    0x837B: 'dí',  # 荻
    0x837C: 'tú',  # 荼
    0x837D: 'suī',  # 荽
    0x837E: 'suī',  # 荾
    0x837F: 'chéng',  # 荿
    0x8380: 'chén',  # 莀
    0x8381: 'wú',  # 莁
    0x8382: 'bié',  # 莂
    0x8383: 'xī',  # 莃
    0x8384: 'gěng',  # 莄
    0x8385: 'lì',  # 莅
    0x8386: 'pú',  # 莆
    0x8387: 'zhù',  # 莇
    0x8388: 'mò',  # 莈
    0x8389: 'lì',  # 莉
    0x838A: 'zhuāng',  # 莊
    0x838B: 'zuó',  # 莋
    0x838C: 'tuō',  # 莌
    0x838D: 'qiú',  # 莍
    0x838E: 'suō,shā',  # 莎
    0x838F: 'suō',  # 莏
    0x8390: 'chén',  # 莐
    0x8391: 'péng,fēng',  # 莑
    0x8392: 'jǔ',  # 莒
    0x8393: 'méi',  # 莓
    0x8394: 'méng',  # 莔
    0x8395: 'xìng',  # 莕
    0x8396: 'jìng',  # 莖
    0x8397: 'chē',  # 莗
    0x8398: 'shēn,xīn',  # 莘
    0x8399: 'jūn',  # 莙
    0x839A: 'yán',  # 莚
    0x839B: 'tíng',  # 莛
    0x839C: 'yóu',  # 莜
    0x839D: 'cuò',  # 莝
    0x839E: 'guān,guǎn,wǎn',  # 莞
    0x839F: 'hàn',  # 莟
    0x83A0: 'yǒu',  # 莠
    0x83A1: 'cuò',  # 莡
    0x83A2: 'jiá',  # 莢
    0x83A3: 'wáng',  # 莣
    0x83A4: 'sù,yóu',  # 莤
    0x83A5: 'niǔ',  # 莥
    0x83A6: 'shāo,xiāo',  # 莦
    0x83A7: 'xiàn',  # 莧
    0x83A8: 'làng,liáng',  # 莨
    0x83A9: 'fú,piǎo',  # 莩
    0x83AA: 'é',  # 莪
    0x83AB: 'mò,mù',  # 莫
    0x83AC: 'wèn,wǎn,miǎn',  # 莬
    0x83AD: 'jié',  # 莭
    0x83AE: 'nán',  # 莮
    0x83AF: 'mù',  # 莯
    0x83B0: 'kǎn',  # 莰
    0x83B1: 'lái',  # 莱
    0x83B2: 'lián',  # 莲
    0x83B3: 'shì,shí',  # 莳
    0x83B4: 'wō',  # 莴
    0x83B5: 'tù,tú',  # 莵
    0x83B6: 'xiān,liǎn',  # 莶
    0x83B7: 'huò',  # 获
    0x83B8: 'yóu',  # 莸
    0x83B9: 'yíng',  # 莹
    0x83BA: 'yīng',  # 莺
    0x83BB: 'neus',  # 莻
    0x83BC: 'chún',  # 莼
    0x83BD: 'mǎng',  # 莽
    0x83BE: 'mǎng',  # 莾
    0x83BF: 'cì',  # 莿
    0x83C0: 'wǎn,yùn',  # 菀
    0x83C1: 'jīng',  # 菁
    0x83C2: 'dì',  # 菂
    0x83C3: 'qú',  # 菃
    0x83C4: 'dōng',  # 菄
    0x83C5: 'jiān',  # 菅
    0x83C6: 'zōu,chù',  # 菆
    0x83C7: 'gū',  # 菇
    0x83C8: 'lā',  # 菈
    0x83C9: 'lù',  # 菉
    0x83CA: 'jú',  # 菊
    0x83CB: 'wèi',  # 菋
    0x83CC: 'jūn,jùn',  # 菌
    0x83CD: 'niè,rěn',  # 菍
    0x83CE: 'kūn',  # 菎
    0x83CF: 'hé',  # 菏
    0x83D0: 'pú',  # 菐
    0x83D1: 'zī,zì,zāi',  # 菑
    0x83D2: 'gǎo',  # 菒
    0x83D3: 'guǒ',  # 菓
    0x83D4: 'fú',  # 菔
    0x83D5: 'lún',  # 菕
    0x83D6: 'chāng',  # 菖
    0x83D7: 'chóu',  # 菗
    0x83D8: 'sōng',  # 菘
    0x83D9: 'chuí',  # 菙
    0x83DA: 'zhàn',  # 菚
    0x83DB: 'mén',  # 菛
    0x83DC: 'cài',  # 菜
    0x83DD: 'bá',  # 菝
    0x83DE: 'lí',  # 菞
    0x83DF: 'tù,tú',  # 菟
    0x83E0: 'bō',  # 菠
    0x83E1: 'hàn',  # 菡
    0x83E2: 'bào',  # 菢
    0x83E3: 'qìn',  # 菣
    0x83E4: 'juǎn',  # 菤
    0x83E5: 'xī',  # 菥
    0x83E6: 'qín',  # 菦
    0x83E7: 'dǐ',  # 菧
    0x83E8: 'jiē,shà',  # 菨
    0x83E9: 'pú',  # 菩
    0x83EA: 'dàng',  # 菪
    0x83EB: 'jǐn',  # 菫
    0x83EC: 'qiáo,zhǎo',  # 菬
    0x83ED: 'tái,zhī,chí',  # 菭
    0x83EE: 'gēng',  # 菮
    0x83EF: 'huá,huà,huā',  # 華
    0x83F0: 'gū',  # 菰
    0x83F1: 'líng',  # 菱
    0x83F2: 'fēi,fěi',  # 菲
    0x83F3: 'qín,qīn,jīn',  # 菳
    0x83F4: 'ān',  # 菴
    0x83F5: 'wǎng',  # 菵
    0x83F6: 'běng',  # 菶
    0x83F7: 'zhǒu',  # 菷
    0x83F8: 'yān',  # 菸
    0x83F9: 'zū',  # 菹
    0x83FA: 'jiān',  # 菺
    0x83FB: 'lǐn,má',  # 菻
    0x83FC: 'tǎn',  # 菼
    0x83FD: 'shū',  # 菽
    0x83FE: 'tián,tiàn',  # 菾
    0x83FF: 'dào',  # 菿
    0x8400: 'hǔ',  # 萀
    0x8401: 'qí',  # 萁
    0x8402: 'hé',  # 萂
    0x8403: 'cuì',  # 萃
    0x8404: 'táo',  # 萄
    0x8405: 'chūn',  # 萅
    0x8406: 'bì',  # 萆
    0x8407: 'cháng',  # 萇
    0x8408: 'huán',  # 萈
    0x8409: 'fèi',  # 萉
    0x840A: 'lái',  # 萊
    0x840B: 'qī',  # 萋
    0x840C: 'méng',  # 萌
    0x840D: 'píng',  # 萍
    0x840E: 'wěi',  # 萎
    0x840F: 'dàn',  # 萏
    0x8410: 'shà',  # 萐
    0x8411: 'huán',  # 萑
    0x8412: 'yǎn',  # 萒
    0x8413: 'yí',  # 萓
    0x8414: 'tiáo',  # 萔
    0x8415: 'qí',  # 萕
    0x8416: 'wǎn',  # 萖
    0x8417: 'cè',  # 萗
    0x8418: 'nài',  # 萘
    0x8419: 'zhěn',  # 萙
    0x841A: 'tuò',  # 萚
    0x841B: 'jiū',  # 萛
    0x841C: 'tiē',  # 萜
    0x841D: 'luó',  # 萝
    0x841E: 'bì',  # 萞
    0x841F: 'yì',  # 萟
    0x8420: 'pān',  # 萠
    0x8421: 'bó',  # 萡
    0x8422: 'pāo',  # 萢
    0x8423: 'dìng',  # 萣
    0x8424: 'yíng',  # 萤
    0x8425: 'yíng',  # 营
    0x8426: 'yíng',  # 萦
    0x8427: 'xiāo',  # 萧
    0x8428: 'sà',  # 萨
    0x8429: 'qiū',  # 萩
    0x842A: 'kē',  # 萪
    0x842B: 'xiāng',  # 萫
    0x842C: 'wàn',  # 萬
    0x842D: 'yǔ',  # 萭
    0x842E: 'yú',  # 萮
    0x842F: 'fù',  # 萯
    0x8430: 'liàn',  # 萰
    0x8431: 'xuān',  # 萱
    0x8432: 'xuān',  # 萲
    0x8433: 'nǎn',  # 萳
    0x8434: 'cè',  # 萴
    0x8435: 'wō',  # 萵
    0x8436: 'chǔn',  # 萶
    0x8437: 'shāo',  # 萷
    0x8438: 'yú',  # 萸
    0x8439: 'biān',  # 萹
    0x843A: 'mào',  # 萺
    0x843B: 'ān',  # 萻
    0x843C: 'è',  # 萼
    0x843D: 'là,luò,lào',  # 落
    0x843E: 'yíng',  # 萾
    0x843F: 'kuò',  # 萿
    0x8440: 'kuò',  # 葀
    0x8441: 'jiāng',  # 葁
    0x8442: 'miǎn',  # 葂
    0x8443: 'zuò',  # 葃
    0x8444: 'zuò',  # 葄
    0x8445: 'zū',  # 葅
    0x8446: 'bǎo',  # 葆
    0x8447: 'róu',  # 葇
    0x8448: 'xǐ',  # 葈
    0x8449: 'yè',  # 葉
    0x844A: 'ān',  # 葊
    0x844B: 'qú',  # 葋
    0x844C: 'jiān',  # 葌
    0x844D: 'fú',  # 葍
    0x844E: 'lǜ',  # 葎
    0x844F: 'jīng',  # 葏
    0x8450: 'pén',  # 葐
    0x8451: 'fēng',  # 葑
    0x8452: 'hóng',  # 葒
    0x8453: 'hóng',  # 葓
    0x8454: 'hóu',  # 葔
    0x8455: 'xìng',  # 葕
    0x8456: 'tū',  # 葖
    0x8457: 'zhù,zhuó,zhe',  # 著
    0x8458: 'zī',  # 葘
    0x8459: 'xiāng',  # 葙
    0x845A: 'shèn',  # 葚
    0x845B: 'gé,gě',  # 葛
    0x845C: 'qiā',  # 葜
    0x845D: 'qíng',  # 葝
    0x845E: 'mǐ',  # 葞
    0x845F: 'huáng',  # 葟
    0x8460: 'shēn',  # 葠
    0x8461: 'pú',  # 葡
    0x8462: 'gài',  # 葢
    0x8463: 'dǒng',  # 董
    0x8464: 'zhòu',  # 葤
    0x8465: 'qián',  # 葥
    0x8466: 'wěi',  # 葦
    0x8467: 'bó',  # 葧
    0x8468: 'wēi',  # 葨
    0x8469: 'pā',  # 葩
    0x846A: 'jì',  # 葪
    0x846B: 'hú',  # 葫
    0x846C: 'zàng',  # 葬
    0x846D: 'jiā',  # 葭
    0x846E: 'duàn',  # 葮
    0x846F: 'yào',  # 葯
    0x8470: 'jùn',  # 葰
    0x8471: 'cōng',  # 葱
    0x8472: 'quán',  # 葲
    0x8473: 'wēi',  # 葳
    0x8474: 'zhēn',  # 葴
    0x8475: 'kuí',  # 葵
    0x8476: 'tíng',  # 葶
    0x8477: 'hūn',  # 葷
    0x8478: 'xǐ',  # 葸
    0x8479: 'shī',  # 葹
    0x847A: 'qì',  # 葺
    0x847B: 'lán',  # 葻
    0x847C: 'zōng',  # 葼
    0x847D: 'yāo',  # 葽
    0x847E: 'yuān',  # 葾
    0x847F: 'méi',  # 葿
    0x8480: 'yūn',  # 蒀
    0x8481: 'shù',  # 蒁
    0x8482: 'dì',  # 蒂
    0x8483: 'zhuàn',  # 蒃
    0x8484: 'guān',  # 蒄
    0x8485: 'rǎn',  # 蒅
    0x8486: 'xuē',  # 蒆
    0x8487: 'chǎn',  # 蒇
    0x8488: 'kǎi',  # 蒈
    0x8489: 'kuì,kuài',  # 蒉
    0x848A: 'huā',  # 蒊
    0x848B: 'jiǎng',  # 蒋
    0x848C: 'lóu',  # 蒌
    0x848D: 'wěi',  # 蒍
    0x848E: 'pài',  # 蒎
    0x848F: 'yòng',  # 蒏
    0x8490: 'sōu',  # 蒐
    0x8491: 'yīn',  # 蒑
    0x8492: 'shī',  # 蒒
    0x8493: 'chún',  # 蒓
    0x8494: 'shì,shí',  # 蒔
    0x8495: 'yūn',  # 蒕
    0x8496: 'zhēn',  # 蒖
    0x8497: 'làng',  # 蒗
    0x8498: 'rú,ná',  # 蒘
    0x8499: 'mēng,méng,měng',  # 蒙
    0x849A: 'lì',  # 蒚
    0x849B: 'quē',  # 蒛
    0x849C: 'suàn',  # 蒜
    0x849D: 'yuán,huán',  # 蒝
    0x849E: 'lì',  # 蒞
    0x849F: 'jǔ',  # 蒟
    0x84A0: 'xī',  # 蒠
    0x84A1: 'bàng',  # 蒡
    0x84A2: 'chú',  # 蒢
    0x84A3: 'xú,shú',  # 蒣
    0x84A4: 'tú',  # 蒤
    0x84A5: 'liú',  # 蒥
    0x84A6: 'huò',  # 蒦
    0x84A7: 'diǎn',  # 蒧
    0x84A8: 'qiàn',  # 蒨
    0x84A9: 'zū,jù',  # 蒩
    0x84AA: 'pò',  # 蒪
    0x84AB: 'cuó',  # 蒫
    0x84AC: 'yuān',  # 蒬
    0x84AD: 'chú',  # 蒭
    0x84AE: 'yù',  # 蒮
    0x84AF: 'kuǎi',  # 蒯
    0x84B0: 'pán',  # 蒰
    0x84B1: 'pú',  # 蒱
    0x84B2: 'pú',  # 蒲
    0x84B3: 'nà',  # 蒳
    0x84B4: 'shuò',  # 蒴
    0x84B5: 'xí,xì',  # 蒵
    0x84B6: 'fén',  # 蒶
    0x84B7: 'yún',  # 蒷
    0x84B8: 'zhēng',  # 蒸
    0x84B9: 'jiān',  # 蒹
    0x84BA: 'jí',  # 蒺
    0x84BB: 'ruò',  # 蒻
    0x84BC: 'cāng',  # 蒼
    0x84BD: 'ēn',  # 蒽
    0x84BE: 'mí',  # 蒾
    0x84BF: 'hāo',  # 蒿
    0x84C0: 'sūn',  # 蓀
    0x84C1: 'zhēn',  # 蓁
    0x84C2: 'míng',  # 蓂
    0x84C3: 'sōu,sǒu',  # 蓃
    0x84C4: 'xù',  # 蓄
    0x84C5: 'liú',  # 蓅
    0x84C6: 'xí',  # 蓆
    0x84C7: 'gū',  # 蓇
    0x84C8: 'láng',  # 蓈
    0x84C9: 'róng',  # 蓉
    0x84CA: 'wěng',  # 蓊
    0x84CB: 'gài,gě,hé',  # 蓋
    0x84CC: 'cuò',  # 蓌
    0x84CD: 'shī',  # 蓍
    0x84CE: 'táng',  # 蓎
    0x84CF: 'luǒ',  # 蓏
    0x84D0: 'rù',  # 蓐
    0x84D1: 'suō',  # 蓑
    0x84D2: 'xuān',  # 蓒
    0x84D3: 'bèi',  # 蓓
    0x84D4: 'yǎo,zhuó',  # 蓔
    0x84D5: 'guì',  # 蓕
    0x84D6: 'bì',  # 蓖
    0x84D7: 'zǒng',  # 蓗
    0x84D8: 'gǔn',  # 蓘
    0x84D9: 'zuò',  # 蓙
    0x84DA: 'tiáo',  # 蓚
    0x84DB: 'cè',  # 蓛
    0x84DC: 'pèi',  # 蓜
    0x84DD: 'lán',  # 蓝
    0x84DE: 'dàn',  # 蓞
    0x84DF: 'jì',  # 蓟
    0x84E0: 'lí',  # 蓠
    0x84E1: 'shēn',  # 蓡
    0x84E2: 'lǎng',  # 蓢
    0x84E3: 'yù',  # 蓣
    0x84E4: 'líng',  # 蓤
    0x84E5: 'yíng',  # 蓥
    0x84E6: 'mò',  # 蓦
    0x84E7: 'diào,tiáo,dí',  # 蓧
    0x84E8: 'tiáo',  # 蓨
    0x84E9: 'mǎo',  # 蓩
    0x84EA: 'tōng',  # 蓪
    0x84EB: 'zhú',  # 蓫
    0x84EC: 'péng',  # 蓬
    0x84ED: 'ān',  # 蓭
    0x84EE: 'lián',  # 蓮
    0x84EF: 'cōng',  # 蓯
    0x84F0: 'xǐ',  # 蓰
    0x84F1: 'píng',  # 蓱
    0x84F2: 'qiū,xū,fū',  # 蓲
    0x84F3: 'jǐn',  # 蓳
    0x84F4: 'chún',  # 蓴
    0x84F5: 'jié',  # 蓵
    0x84F6: 'wéi',  # 蓶
    0x84F7: 'tuī',  # 蓷
    0x84F8: 'cáo',  # 蓸
    0x84F9: 'yù',  # 蓹
    0x84FA: 'yì',  # 蓺
    0x84FB: 'zí,jú',  # 蓻
    0x84FC: 'liǎo,lù',  # 蓼
    0x84FD: 'bì',  # 蓽
    0x84FE: 'lǔ',  # 蓾
    0x84FF: 'xù',  # 蓿
    0x8500: 'bù',  # 蔀
    0x8501: 'zhāng',  # 蔁
    0x8502: 'léi',  # 蔂
    0x8503: 'qiáng',  # 蔃
    0x8504: 'màn',  # 蔄
    0x8505: 'yán',  # 蔅
    0x8506: 'líng',  # 蔆
    0x8507: 'jì',  # 蔇
    0x8508: 'biāo',  # 蔈
    0x8509: 'gǔn',  # 蔉
    0x850A: 'hàn',  # 蔊
    0x850B: 'dí',  # 蔋
    0x850C: 'sù',  # 蔌
    0x850D: 'lù',  # 蔍
    0x850E: 'shè',  # 蔎
    0x850F: 'shāng',  # 蔏
    0x8510: 'dí',  # 蔐
    0x8511: 'miè',  # 蔑
    0x8512: 'hūn',  # 蔒
    0x8513: 'màn,wàn',  # 蔓
    0x8514: 'bo',  # 蔔
    0x8515: 'dì',  # 蔕
    0x8516: 'cuó',  # 蔖
    0x8517: 'zhè',  # 蔗
    0x8518: 'shēn',  # 蔘
    0x8519: 'xuàn',  # 蔙
    0x851A: 'wèi',  # 蔚
    0x851B: 'hú',  # 蔛
    0x851C: 'áo',  # 蔜
    0x851D: 'mǐ',  # 蔝
    0x851E: 'lóu',  # 蔞
    0x851F: 'cù',  # 蔟
    0x8520: 'zhōng',  # 蔠
    0x8521: 'cài',  # 蔡
    0x8522: 'pó',  # 蔢
    0x8523: 'jiǎng',  # 蔣
    0x8524: 'mì',  # 蔤
    0x8525: 'cōng',  # 蔥
    0x8526: 'niǎo',  # 蔦
    0x8527: 'huì',  # 蔧
    0x8528: 'juàn',  # 蔨
    0x8529: 'yín',  # 蔩
    0x852A: 'jiān',  # 蔪
    0x852B: 'niān',  # 蔫
    0x852C: 'shū',  # 蔬
    0x852D: 'yīn',  # 蔭
    0x852E: 'guó',  # 蔮
    0x852F: 'chén',  # 蔯
    0x8530: 'hù',  # 蔰
    0x8531: 'shā',  # 蔱
    0x8532: 'kòu',  # 蔲
    0x8533: 'qiàn',  # 蔳
    0x8534: 'má',  # 蔴
    0x8535: 'zàng',  # 蔵
    0x8536: 'zé',  # 蔶
    0x8537: 'qiáng',  # 蔷
    0x8538: 'dōu',  # 蔸
    0x8539: 'liǎn',  # 蔹
    0x853A: 'lìn',  # 蔺
    0x853B: 'kòu',  # 蔻
    0x853C: 'ǎi',  # 蔼
    0x853D: 'bì',  # 蔽
    0x853E: 'lí',  # 蔾
    0x853F: 'wěi',  # 蔿
    0x8540: 'jí',  # 蕀
    0x8541: 'qián,xún',  # 蕁
    0x8542: 'shèng',  # 蕂
    0x8543: 'fán',  # 蕃
    0x8544: 'méng',  # 蕄
    0x8545: 'ǒu',  # 蕅
    0x8546: 'chǎn',  # 蕆
    0x8547: 'diǎn',  # 蕇
    0x8548: 'xùn',  # 蕈
    0x8549: 'jiāo',  # 蕉
    0x854A: 'ruǐ',  # 蕊
    0x854B: 'ruǐ',  # 蕋
    0x854C: 'lěi',  # 蕌
    0x854D: 'yú',  # 蕍
    0x854E: 'qiáo',  # 蕎
    0x854F: 'zhū',  # 蕏
    0x8550: 'huá',  # 蕐
    0x8551: 'jiān',  # 蕑
    0x8552: 'mǎi',  # 蕒
    0x8553: 'yún',  # 蕓
    0x8554: 'bāo',  # 蕔
    0x8555: 'yóu',  # 蕕
    0x8556: 'qú',  # 蕖
    0x8557: 'lù',  # 蕗
    0x8558: 'ráo',  # 蕘
    0x8559: 'huì',  # 蕙
    0x855A: 'è',  # 蕚
    0x855B: 'tí',  # 蕛
    0x855C: 'fěi',  # 蕜
    0x855D: 'jué',  # 蕝
    0x855E: 'zuì',  # 蕞
    0x855F: 'fà',  # 蕟
    0x8560: 'rú',  # 蕠
    0x8561: 'fén',  # 蕡
    0x8562: 'kuì',  # 蕢
    0x8563: 'shùn',  # 蕣
    0x8564: 'ruí',  # 蕤
    0x8565: 'yǎ',  # 蕥
    0x8566: 'xū',  # 蕦
    0x8567: 'fù',  # 蕧
    0x8568: 'jué',  # 蕨
    0x8569: 'dàng',  # 蕩
    0x856A: 'wú',  # 蕪
    0x856B: 'dǒng',  # 蕫
    0x856C: 'sī',  # 蕬
    0x856D: 'xiāo',  # 蕭
    0x856E: 'xì',  # 蕮
    0x856F: 'sà',  # 蕯
    0x8570: 'yùn',  # 蕰
    0x8571: 'shāo',  # 蕱
    0x8572: 'qí',  # 蕲
    0x8573: 'jiān',  # 蕳
    0x8574: 'yùn',  # 蕴
    0x8575: 'sūn',  # 蕵
    0x8576: 'líng',  # 蕶
    0x8577: 'yù',  # 蕷
    0x8578: 'xiá',  # 蕸
    0x8579: 'wèng',  # 蕹
    0x857A: 'jí',  # 蕺
    0x857B: 'hòng',  # 蕻
    0x857C: 'sì',  # 蕼
    0x857D: 'nóng',  # 蕽
    0x857E: 'lěi',  # 蕾
    0x857F: 'xuān',  # 蕿
    0x8580: 'yùn',  # 薀
    0x8581: 'yù',  # 薁
    0x8582: 'xí,xiào',  # 薂
    0x8583: 'hào',  # 薃
    0x8584: 'báo,bó,bò',  # 薄
    0x8585: 'hāo',  # 薅
    0x8586: 'ài',  # 薆
    0x8587: 'wēi',  # 薇
    0x8588: 'huì',  # 薈
    0x8589: 'huì',  # 薉
    0x858A: 'jì',  # 薊
    0x858B: 'cí,zī',  # 薋
    0x858C: 'xiāng',  # 薌
    0x858D: 'wàn,luàn',  # 薍
    0x858E: 'miè',  # 薎
    0x858F: 'yì',  # 薏
    0x8590: 'léng',  # 薐
    0x8591: 'jiāng',  # 薑
    0x8592: 'càn',  # 薒
    0x8593: 'shēn',  # 薓
    0x8594: 'qiáng,sè',  # 薔
    0x8595: 'lián',  # 薕
    0x8596: 'kē',  # 薖
    0x8597: 'yuán',  # 薗
    0x8598: 'dá',  # 薘
    0x8599: 'tì',  # 薙
    0x859A: 'tāng',  # 薚
    0x859B: 'xuē',  # 薛
    0x859C: 'bì',  # 薜
    0x859D: 'zhān',  # 薝
    0x859E: 'sūn',  # 薞
    0x859F: 'xiān,liǎn',  # 薟
    0x85A0: 'fán',  # 薠
    0x85A1: 'dǐng',  # 薡
    0x85A2: 'xiè',  # 薢
    0x85A3: 'gǔ',  # 薣
    0x85A4: 'xiè',  # 薤
    0x85A5: 'shǔ',  # 薥
    0x85A6: 'jiàn',  # 薦
    0x85A7: 'hāo,kǎo',  # 薧
    0x85A8: 'hōng',  # 薨
    0x85A9: 'sà',  # 薩
    0x85AA: 'xīn',  # 薪
    0x85AB: 'xūn',  # 薫
    0x85AC: 'yào',  # 薬
    0x85AD: 'bài',  # 薭
    0x85AE: 'sǒu',  # 薮
    0x85AF: 'shǔ',  # 薯
    0x85B0: 'xūn',  # 薰
    0x85B1: 'duì',  # 薱
    0x85B2: 'pín',  # 薲
    0x85B3: 'yuǎn,wěi',  # 薳
    0x85B4: 'níng',  # 薴
    0x85B5: 'chóu,zhòu',  # 薵
    0x85B6: 'mái,wō',  # 薶
    0x85B7: 'rú',  # 薷
    0x85B8: 'piáo',  # 薸
    0x85B9: 'tái',  # 薹
    0x85BA: 'jì,qí',  # 薺
    0x85BB: 'zǎo',  # 薻
    0x85BC: 'chén',  # 薼
    0x85BD: 'zhēn',  # 薽
    0x85BE: 'ěr',  # 薾
    0x85BF: 'nǐ',  # 薿
    0x85C0: 'yíng',  # 藀
    0x85C1: 'gǎo',  # 藁
    0x85C2: 'cóng',  # 藂
    0x85C3: 'xiāo,hào',  # 藃
    0x85C4: 'qí',  # 藄
    0x85C5: 'fá',  # 藅
    0x85C6: 'jiǎn',  # 藆
    0x85C7: 'xù,yù,xū',  # 藇
    0x85C8: 'kuí',  # 藈
    0x85C9: 'jiè,jí',  # 藉
    0x85CA: 'biǎn',  # 藊
    0x85CB: 'diào,zhuó',  # 藋
    0x85CC: 'mí',  # 藌
    0x85CD: 'lán',  # 藍
    0x85CE: 'jìn',  # 藎
    0x85CF: 'cáng,zàng',  # 藏
    0x85D0: 'miǎo',  # 藐
    0x85D1: 'qióng',  # 藑
    0x85D2: 'qì',  # 藒
    0x85D3: 'xiǎn',  # 藓
    0x85D4: 'liáo',  # 藔
    0x85D5: 'ǒu',  # 藕
    0x85D6: 'xián',  # 藖
    0x85D7: 'sù',  # 藗
    0x85D8: 'lǘ',  # 藘
    0x85D9: 'yì',  # 藙
    0x85DA: 'xù',  # 藚
    0x85DB: 'xiě',  # 藛
    0x85DC: 'lí',  # 藜
    0x85DD: 'yì',  # 藝
    0x85DE: 'lǎ',  # 藞
    0x85DF: 'lěi',  # 藟
    0x85E0: 'jiào',  # 藠
    0x85E1: 'dí',  # 藡
    0x85E2: 'zhǐ',  # 藢
    0x85E3: 'bēi',  # 藣
    0x85E4: 'téng',  # 藤
    0x85E5: 'yào',  # 藥
    0x85E6: 'mò',  # 藦
    0x85E7: 'huàn',  # 藧
    0x85E8: 'biāo,pāo',  # 藨
    0x85E9: 'fān',  # 藩
    0x85EA: 'sǒu',  # 藪
    0x85EB: 'tán',  # 藫
    0x85EC: 'tuī',  # 藬
    0x85ED: 'qióng',  # 藭
    0x85EE: 'qiáo',  # 藮
    0x85EF: 'wèi',  # 藯
    0x85F0: 'liú,liǔ',  # 藰
    0x85F1: 'huì,huí',  # 藱
    0x85F2: 'ōu',  # 藲
    0x85F3: 'gǎo',  # 藳
    0x85F4: 'yùn',  # 藴
    0x85F5: 'bǎo',  # 藵
    0x85F6: 'lì',  # 藶
    0x85F7: 'shǔ',  # 藷
    0x85F8: 'zhū,chú',  # 藸
    0x85F9: 'ǎi',  # 藹
    0x85FA: 'lìn',  # 藺
    0x85FB: 'zǎo',  # 藻
    0x85FC: 'xuān',  # 藼
    0x85FD: 'qìn',  # 藽
    0x85FE: 'lài',  # 藾
    0x85FF: 'huò',  # 藿
    0x8600: 'tuò',  # 蘀
    0x8601: 'wù',  # 蘁
    0x8602: 'ruǐ',  # 蘂
    0x8603: 'ruǐ',  # 蘃
    0x8604: 'qí',  # 蘄
    0x8605: 'héng',  # 蘅
    0x8606: 'lú',  # 蘆
    0x8607: 'sū',  # 蘇
    0x8608: 'tuí',  # 蘈
    0x8609: 'máng',  # 蘉
    0x860A: 'yùn',  # 蘊
    0x860B: 'pín,píng',  # 蘋
    0x860C: 'yù',  # 蘌
    0x860D: 'xūn',  # 蘍
    0x860E: 'jì',  # 蘎
    0x860F: 'jiōng',  # 蘏
    0x8610: 'xuān',  # 蘐
    0x8611: 'mó',  # 蘑
    0x8612: 'qiū',  # 蘒
    0x8613: 'sū',  # 蘓
    0x8614: 'jiōng',  # 蘔
    0x8615: 'péng',  # 蘕
    0x8616: 'niè',  # 蘖
    0x8617: 'bò',  # 蘗
    0x8618: 'ráng',  # 蘘
    0x8619: 'yì',  # 蘙
    0x861A: 'xiǎn',  # 蘚
    0x861B: 'yú',  # 蘛
    0x861C: 'jú',  # 蘜
    0x861D: 'liǎn',  # 蘝
    0x861E: 'liǎn',  # 蘞
    0x861F: 'yǐn',  # 蘟
    0x8620: 'qiáng',  # 蘠
    0x8621: 'yīng',  # 蘡
    0x8622: 'lóng',  # 蘢
    0x8623: 'tǒu',  # 蘣
    0x8624: 'huā',  # 蘤
    0x8625: 'yuè',  # 蘥
    0x8626: 'lìng',  # 蘦
    0x8627: 'qú',  # 蘧
    0x8628: 'yáo',  # 蘨
    0x8629: 'fán',  # 蘩
    0x862A: 'mí',  # 蘪
    0x862B: 'lán',  # 蘫
    0x862C: 'guī',  # 蘬
    0x862D: 'lán',  # 蘭
    0x862E: 'jì',  # 蘮
    0x862F: 'dàng',  # 蘯
    0x8630: 'màn',  # 蘰
    0x8631: 'lèi',  # 蘱
    0x8632: 'léi',  # 蘲
    0x8633: 'huī',  # 蘳
    0x8634: 'fēng',  # 蘴
    0x8635: 'zhī',  # 蘵
    0x8636: 'wèi',  # 蘶
    0x8637: 'kuí',  # 蘷
    0x8638: 'zhàn',  # 蘸
    0x8639: 'huái',  # 蘹
    0x863A: 'lí',  # 蘺
    0x863B: 'jì',  # 蘻
    0x863C: 'mí',  # 蘼
    0x863D: 'lěi',  # 蘽
    0x863E: 'huài',  # 蘾
    0x863F: 'luó',  # 蘿
    0x8640: 'jī',  # 虀
    0x8641: 'kuí',  # 虁
    0x8642: 'lù',  # 虂
    0x8643: 'jiān',  # 虃
    0x8644: 'sal',  # 虄
    0x8645: 'téng',  # 虅
    0x8646: 'léi',  # 虆
    0x8647: 'quǎn',  # 虇
    0x8648: 'xiāo',  # 虈
    0x8649: 'yì',  # 虉
    0x864A: 'luán',  # 虊
    0x864B: 'mén',  # 虋
    0x864C: 'biē',  # 虌
    0x864D: 'hū',  # 虍
    0x864E: 'hǔ',  # 虎
    0x864F: 'lǔ',  # 虏
    0x8650: 'nüè',  # 虐
    0x8651: 'lǜ',  # 虑
    0x8652: 'sī',  # 虒
    0x8653: 'xiāo',  # 虓
    0x8654: 'qián',  # 虔
    0x8655: 'chǔ',  # 處
    0x8656: 'hū',  # 虖
    0x8657: 'xū',  # 虗
    0x8658: 'cuó',  # 虘
    0x8659: 'fú',  # 虙
    0x865A: 'xū',  # 虚
    0x865B: 'xū',  # 虛
    0x865C: 'lǔ',  # 虜
    0x865D: 'hǔ',  # 虝
    0x865E: 'yú',  # 虞
    0x865F: 'hào,háo',  # 號
    0x8660: 'jiāo',  # 虠
    0x8661: 'jù',  # 虡
    0x8662: 'guó',  # 虢
    0x8663: 'bào',  # 虣
    0x8664: 'yán',  # 虤
    0x8665: 'zhàn',  # 虥
    0x8666: 'zhàn',  # 虦
    0x8667: 'kuī',  # 虧
    0x8668: 'bīn',  # 虨
    0x8669: 'xì',  # 虩
    0x866A: 'shù',  # 虪
    0x866B: 'chóng',  # 虫
    0x866C: 'qiú',  # 虬
    0x866D: 'diāo',  # 虭
    0x866E: 'jǐ',  # 虮
    0x866F: 'qiú',  # 虯
    0x8670: 'dīng',  # 虰
    0x8671: 'shī',  # 虱
    0x8672: 'xiā',  # 虲
    0x8673: 'jué',  # 虳
    0x8674: 'zhé',  # 虴
    0x8675: 'shé',  # 虵
    0x8676: 'yú',  # 虶
    0x8677: 'hán',  # 虷
    0x8678: 'zǐ',  # 虸
    0x8679: 'hóng',  # 虹
    0x867A: 'huǐ,huī',  # 虺
    0x867B: 'méng',  # 虻
    0x867C: 'gè',  # 虼
    0x867D: 'suī',  # 虽
    0x867E: 'xiā,hā',  # 虾
    0x867F: 'chài',  # 虿
    0x8680: 'shí',  # 蚀
    0x8681: 'yǐ',  # 蚁
    0x8682: 'mǎ,mā,mà',  # 蚂
    0x8683: 'xiǎng',  # 蚃
    0x8684: 'fāng,bàng',  # 蚄
    0x8685: 'è',  # 蚅
    0x8686: 'bā',  # 蚆
    0x8687: 'chǐ',  # 蚇
    0x8688: 'qiān',  # 蚈
    0x8689: 'wén',  # 蚉
    0x868A: 'wén',  # 蚊
    0x868B: 'ruì',  # 蚋
    0x868C: 'bàng,bèng',  # 蚌
    0x868D: 'pí',  # 蚍
    0x868E: 'yuè',  # 蚎
    0x868F: 'yuè',  # 蚏
    0x8690: 'jūn',  # 蚐
    0x8691: 'qí',  # 蚑
    0x8692: 'tóng',  # 蚒
    0x8693: 'yǐn',  # 蚓
    0x8694: 'qí,zhǐ',  # 蚔
    0x8695: 'cán',  # 蚕
    0x8696: 'yuán,wán',  # 蚖
    0x8697: 'jué,quē',  # 蚗
    0x8698: 'huí',  # 蚘
    0x8699: 'qín,qián',  # 蚙
    0x869A: 'qí',  # 蚚
    0x869B: 'zhòng',  # 蚛
    0x869C: 'yá',  # 蚜
    0x869D: 'háo',  # 蚝
    0x869E: 'mù',  # 蚞
    0x869F: 'wáng',  # 蚟
    0x86A0: 'fén',  # 蚠
    0x86A1: 'fén',  # 蚡
    0x86A2: 'háng',  # 蚢
    0x86A3: 'gōng,zhōng',  # 蚣
    0x86A4: 'zǎo',  # 蚤
    0x86A5: 'fù,fǔ',  # 蚥
    0x86A6: 'rán',  # 蚦
    0x86A7: 'jiè',  # 蚧
    0x86A8: 'fú',  # 蚨
    0x86A9: 'chī',  # 蚩
    0x86AA: 'dǒu',  # 蚪
    0x86AB: 'bào',  # 蚫
    0x86AC: 'xiǎn',  # 蚬
    0x86AD: 'ní',  # 蚭
    0x86AE: 'dài,dé',  # 蚮
    0x86AF: 'qiū',  # 蚯
    0x86B0: 'yóu',  # 蚰
    0x86B1: 'zhà',  # 蚱
    0x86B2: 'píng',  # 蚲
    0x86B3: 'chí',  # 蚳
    0x86B4: 'yòu',  # 蚴
    0x86B5: 'kē',  # 蚵
    0x86B6: 'hān',  # 蚶
    0x86B7: 'jù',  # 蚷
    0x86B8: 'lì',  # 蚸
    0x86B9: 'fù',  # 蚹
    0x86BA: 'rán',  # 蚺
    0x86BB: 'zhá',  # 蚻
    0x86BC: 'gǒu,qú,xù',  # 蚼
    0x86BD: 'pí',  # 蚽
    0x86BE: 'pí,bǒ',  # 蚾
    0x86BF: 'xián',  # 蚿
    0x86C0: 'zhù',  # 蛀
    0x86C1: 'diāo',  # 蛁
    0x86C2: 'bié',  # 蛂
    0x86C3: 'bīng',  # 蛃
    0x86C4: 'gū',  # 蛄
    0x86C5: 'zhān',  # 蛅
    0x86C6: 'qū',  # 蛆
    0x86C7: 'shé,yí',  # 蛇
    0x86C8: 'tiě',  # 蛈
    0x86C9: 'líng',  # 蛉
    0x86CA: 'gǔ',  # 蛊
    0x86CB: 'dàn',  # 蛋
    0x86CC: 'tún',  # 蛌
    0x86CD: 'yíng',  # 蛍
    0x86CE: 'lì',  # 蛎
    0x86CF: 'chēng',  # 蛏
    0x86D0: 'qū',  # 蛐
    0x86D1: 'móu',  # 蛑
    0x86D2: 'gé,luò',  # 蛒
    0x86D3: 'cì',  # 蛓
    0x86D4: 'huí',  # 蛔
    0x86D5: 'huí',  # 蛕
    0x86D6: 'máng,bàng',  # 蛖
    0x86D7: 'fù',  # 蛗
    0x86D8: 'yáng',  # 蛘
    0x86D9: 'wā',  # 蛙
    0x86DA: 'liè',  # 蛚
    0x86DB: 'zhū',  # 蛛
    0x86DC: 'yī',  # 蛜
    0x86DD: 'xián',  # 蛝
    0x86DE: 'kuò',  # 蛞
    0x86DF: 'jiāo',  # 蛟
    0x86E0: 'lì',  # 蛠
    0x86E1: 'yì,xǔ',  # 蛡
    0x86E2: 'píng',  # 蛢
    0x86E3: 'jié',  # 蛣
    0x86E4: 'gé,há',  # 蛤
    0x86E5: 'shé',  # 蛥
    0x86E6: 'yí',  # 蛦
    0x86E7: 'wǎng',  # 蛧
    0x86E8: 'mò',  # 蛨
    0x86E9: 'qióng',  # 蛩
    0x86EA: 'qiè,ní',  # 蛪
    0x86EB: 'guǐ',  # 蛫
    0x86EC: 'qióng',  # 蛬
    0x86ED: 'zhì',  # 蛭
    0x86EE: 'mán',  # 蛮
    0x86EF: 'lǎo',  # 蛯
    0x86F0: 'zhé',  # 蛰
    0x86F1: 'jiá',  # 蛱
    0x86F2: 'náo',  # 蛲
    0x86F3: 'sī',  # 蛳
    0x86F4: 'qí',  # 蛴
    0x86F5: 'xíng',  # 蛵
    0x86F6: 'jiè',  # 蛶
    0x86F7: 'qiú',  # 蛷
    0x86F8: 'xiāo',  # 蛸
    0x86F9: 'yǒng',  # 蛹
    0x86FA: 'jiá',  # 蛺
    0x86FB: 'tuì',  # 蛻
    0x86FC: 'chē',  # 蛼
    0x86FD: 'bèi',  # 蛽
    0x86FE: 'é,yǐ',  # 蛾
    0x86FF: 'hàn',  # 蛿
    0x8700: 'shǔ',  # 蜀
    0x8701: 'xuán',  # 蜁
    0x8702: 'fēng',  # 蜂
    0x8703: 'shèn',  # 蜃
    0x8704: 'shèn',  # 蜄
    0x8705: 'fǔ',  # 蜅
    0x8706: 'xiǎn',  # 蜆
    0x8707: 'zhé',  # 蜇
    0x8708: 'wú',  # 蜈
    0x8709: 'fú',  # 蜉
    0x870A: 'lì',  # 蜊
    0x870B: 'láng',  # 蜋
    0x870C: 'bì',  # 蜌
    0x870D: 'chú',  # 蜍
    0x870E: 'yuān',  # 蜎
    0x870F: 'yǒu',  # 蜏
    0x8710: 'jié',  # 蜐
    0x8711: 'dàn',  # 蜑
    0x8712: 'yán',  # 蜒
    0x8713: 'tíng',  # 蜓
    0x8714: 'diàn',  # 蜔
    0x8715: 'tuì',  # 蜕
    0x8716: 'huí',  # 蜖
    0x8717: 'wō',  # 蜗
    0x8718: 'zhī',  # 蜘
    0x8719: 'zhōng',  # 蜙
    0x871A: 'fēi',  # 蜚
    0x871B: 'jū',  # 蜛
    0x871C: 'mì',  # 蜜
    0x871D: 'qí',  # 蜝
    0x871E: 'qí',  # 蜞
    0x871F: 'yù',  # 蜟
    0x8720: 'jùn',  # 蜠
    0x8721: 'là',  # 蜡
    0x8722: 'měng',  # 蜢
    0x8723: 'qiāng',  # 蜣
    0x8724: 'sī',  # 蜤
    0x8725: 'xī',  # 蜥
    0x8726: 'lún',  # 蜦
    0x8727: 'lì',  # 蜧
    0x8728: 'dié',  # 蜨
    0x8729: 'tiáo',  # 蜩
    0x872A: 'táo',  # 蜪
    0x872B: 'kūn',  # 蜫
    0x872C: 'hán',  # 蜬
    0x872D: 'hàn',  # 蜭
    0x872E: 'yù',  # 蜮
    0x872F: 'bàng',  # 蜯
    0x8730: 'féi',  # 蜰
    0x8731: 'pí',  # 蜱
    0x8732: 'wēi',  # 蜲
    0x8733: 'dūn',  # 蜳
    0x8734: 'yì',  # 蜴
    0x8735: 'yuān',  # 蜵
    0x8736: 'suò',  # 蜶
    0x8737: 'quán',  # 蜷
    0x8738: 'qiǎn',  # 蜸
    0x8739: 'ruì',  # 蜹
    0x873A: 'ní',  # 蜺
    0x873B: 'qīng',  # 蜻
    0x873C: 'wèi',  # 蜼
    0x873D: 'liǎng',  # 蜽
    0x873E: 'guǒ',  # 蜾
    0x873F: 'wān',  # 蜿
    0x8740: 'dōng',  # 蝀
    0x8741: 'è',  # 蝁
    0x8742: 'bǎn',  # 蝂
    0x8743: 'dì',  # 蝃
    0x8744: 'wǎng',  # 蝄
    0x8745: 'cán',  # 蝅
    0x8746: 'yǎng',  # 蝆
    0x8747: 'yíng',  # 蝇
    0x8748: 'guō',  # 蝈
    0x8749: 'chán',  # 蝉
    0x874A: 'dìng',  # 蝊
    0x874B: 'là',  # 蝋
    0x874C: 'kē',  # 蝌
    0x874D: 'jí',  # 蝍
    0x874E: 'xiē',  # 蝎
    0x874F: 'tíng',  # 蝏
    0x8750: 'mào',  # 蝐
    0x8751: 'xū',  # 蝑
    0x8752: 'mián',  # 蝒
    0x8753: 'yú',  # 蝓
    0x8754: 'jiē',  # 蝔
    0x8755: 'shí',  # 蝕
    0x8756: 'xuān',  # 蝖
    0x8757: 'huáng',  # 蝗
    0x8758: 'yǎn',  # 蝘
    0x8759: 'biān',  # 蝙
    0x875A: 'róu',  # 蝚
    0x875B: 'wēi',  # 蝛
    0x875C: 'fù',  # 蝜
    0x875D: 'yuán',  # 蝝
    0x875E: 'mèi',  # 蝞
    0x875F: 'wèi',  # 蝟
    0x8760: 'fú',  # 蝠
    0x8761: 'rú',  # 蝡
    0x8762: 'xié',  # 蝢
    0x8763: 'yóu',  # 蝣
    0x8764: 'qiú',  # 蝤
    0x8765: 'máo',  # 蝥
    0x8766: 'xiā,hā',  # 蝦
    0x8767: 'yīng',  # 蝧
    0x8768: 'shī',  # 蝨
    0x8769: 'chóng',  # 蝩
    0x876A: 'tāng',  # 蝪
    0x876B: 'zhū',  # 蝫
    0x876C: 'zōng',  # 蝬
    0x876D: 'dì',  # 蝭
    0x876E: 'fù',  # 蝮
    0x876F: 'yuán',  # 蝯
    0x8770: 'kuí',  # 蝰
    0x8771: 'méng',  # 蝱
    0x8772: 'là',  # 蝲
    0x8773: 'dài',  # 蝳
    0x8774: 'hú',  # 蝴
    0x8775: 'qiū',  # 蝵
    0x8776: 'dié',  # 蝶
    0x8777: 'lì',  # 蝷
    0x8778: 'wō',  # 蝸
    0x8779: 'yūn',  # 蝹
    0x877A: 'qǔ',  # 蝺
    0x877B: 'nǎn',  # 蝻
    0x877C: 'lóu',  # 蝼
    0x877D: 'chūn',  # 蝽
    0x877E: 'róng',  # 蝾
    0x877F: 'yíng',  # 蝿
    0x8780: 'jiāng',  # 螀
    0x8781: 'tuì',  # 螁
    0x8782: 'láng',  # 螂
    0x8783: 'páng',  # 螃
    0x8784: 'sī',  # 螄
    0x8785: 'xī',  # 螅
    0x8786: 'cì',  # 螆
    0x8787: 'xī,qī',  # 螇
    0x8788: 'yuán',  # 螈
    0x8789: 'wēng',  # 螉
    0x878A: 'lián',  # 螊
    0x878B: 'sōu',  # 螋
    0x878C: 'bān',  # 螌
    0x878D: 'róng',  # 融
    0x878E: 'róng',  # 螎
    0x878F: 'jí',  # 螏
    0x8790: 'wū',  # 螐
    0x8791: 'xiù',  # 螑
    0x8792: 'hàn',  # 螒
    0x8793: 'qín',  # 螓
    0x8794: 'yí',  # 螔
    0x8795: 'bī,pí',  # 螕
    0x8796: 'huá',  # 螖
    0x8797: 'táng',  # 螗
    0x8798: 'yǐ',  # 螘
    0x8799: 'dù',  # 螙
    0x879A: 'nài,něng',  # 螚
    0x879B: 'hé,xiá',  # 螛
    0x879C: 'hú',  # 螜
    0x879D: 'guì,huǐ',  # 螝
    0x879E: 'mǎ,mā,mà',  # 螞
    0x879F: 'míng',  # 螟
    0x87A0: 'yì',  # 螠
    0x87A1: 'wén',  # 螡
    0x87A2: 'yíng',  # 螢
    0x87A3: 'téng',  # 螣
    0x87A4: 'zhōng',  # 螤
    0x87A5: 'cāng',  # 螥
    0x87A6: 'sāo',  # 螦
    0x87A7: 'qí',  # 螧
    0x87A8: 'mǎn',  # 螨
    0x87A9: 'dāo',  # 螩
    0x87AA: 'shāng',  # 螪
    0x87AB: 'shì,zhē',  # 螫
    0x87AC: 'cáo',  # 螬
    0x87AD: 'chī',  # 螭
    0x87AE: 'dì',  # 螮
    0x87AF: 'áo',  # 螯
    0x87B0: 'lù',  # 螰
    0x87B1: 'wèi',  # 螱
    0x87B2: 'dié,zhì',  # 螲
    0x87B3: 'táng',  # 螳
    0x87B4: 'chén',  # 螴
    0x87B5: 'piāo',  # 螵
    0x87B6: 'qú,jù',  # 螶
    0x87B7: 'pí',  # 螷
    0x87B8: 'yú',  # 螸
    0x87B9: 'chán,jiàn',  # 螹
    0x87BA: 'luó',  # 螺
    0x87BB: 'lóu',  # 螻
    0x87BC: 'qǐn',  # 螼
    0x87BD: 'zhōng',  # 螽
    0x87BE: 'yǐn',  # 螾
    0x87BF: 'jiāng',  # 螿
    0x87C0: 'shuài',  # 蟀
    0x87C1: 'wén',  # 蟁
    0x87C2: 'xiāo',  # 蟂
    0x87C3: 'wàn',  # 蟃
    0x87C4: 'zhé',  # 蟄
    0x87C5: 'zhè',  # 蟅
    0x87C6: 'má,mò',  # 蟆
    0x87C7: 'má',  # 蟇
    0x87C8: 'guō',  # 蟈
    0x87C9: 'liú',  # 蟉
    0x87CA: 'máo',  # 蟊
    0x87CB: 'xī',  # 蟋
    0x87CC: 'cōng',  # 蟌
    0x87CD: 'lí',  # 蟍
    0x87CE: 'mǎn',  # 蟎
    0x87CF: 'xiāo',  # 蟏
    0x87D0: 'chán',  # 蟐
    0x87D1: 'zhāng',  # 蟑
    0x87D2: 'mǎng,měng',  # 蟒
    0x87D3: 'xiàng',  # 蟓
    0x87D4: 'mò',  # 蟔
    0x87D5: 'zuī',  # 蟕
    0x87D6: 'sī',  # 蟖
    0x87D7: 'qiū',  # 蟗
    0x87D8: 'tè',  # 蟘
    0x87D9: 'zhí',  # 蟙
    0x87DA: 'péng',  # 蟚
    0x87DB: 'péng',  # 蟛
    0x87DC: 'jiǎo',  # 蟜
    0x87DD: 'qú',  # 蟝
    0x87DE: 'biē,bié',  # 蟞
    0x87DF: 'liáo',  # 蟟
    0x87E0: 'pán',  # 蟠
    0x87E1: 'guǐ',  # 蟡
    0x87E2: 'xǐ',  # 蟢
    0x87E3: 'jǐ',  # 蟣
    0x87E4: 'zhuān',  # 蟤
    0x87E5: 'huáng',  # 蟥
    0x87E6: 'fèi,bēn',  # 蟦
    0x87E7: 'láo,liáo',  # 蟧
    0x87E8: 'jué',  # 蟨
    0x87E9: 'jué',  # 蟩
    0x87EA: 'huì',  # 蟪
    0x87EB: 'yín,xún',  # 蟫
    0x87EC: 'chán',  # 蟬
    0x87ED: 'jiāo',  # 蟭
    0x87EE: 'shàn',  # 蟮
    0x87EF: 'náo',  # 蟯
    0x87F0: 'xiāo',  # 蟰
    0x87F1: 'wú',  # 蟱
    0x87F2: 'chóng',  # 蟲
    0x87F3: 'xún',  # 蟳
    0x87F4: 'sī',  # 蟴
    0x87F5: 'chú',  # 蟵
    0x87F6: 'chēng',  # 蟶
    0x87F7: 'dāng',  # 蟷
    0x87F8: 'lí',  # 蟸
    0x87F9: 'xiè',  # 蟹
    0x87FA: 'shàn',  # 蟺
    0x87FB: 'yǐ',  # 蟻
    0x87FC: 'jǐng',  # 蟼
    0x87FD: 'dá',  # 蟽
    0x87FE: 'chán',  # 蟾
    0x87FF: 'qì',  # 蟿
    0x8800: 'cī',  # 蠀
    0x8801: 'xiǎng',  # 蠁
    0x8802: 'shè',  # 蠂
    0x8803: 'luǒ',  # 蠃
    0x8804: 'qín',  # 蠄
    0x8805: 'yíng',  # 蠅
    0x8806: 'chài',  # 蠆
    0x8807: 'lì',  # 蠇
    0x8808: 'zéi',  # 蠈
    0x8809: 'xuān',  # 蠉
    0x880A: 'lián',  # 蠊
    0x880B: 'zhú',  # 蠋
    0x880C: 'zé',  # 蠌
    0x880D: 'xiē',  # 蠍
    0x880E: 'mǎng',  # 蠎
    0x880F: 'xiè',  # 蠏
    0x8810: 'qí',  # 蠐
    0x8811: 'róng',  # 蠑
    0x8812: 'jiǎn',  # 蠒
    0x8813: 'měng',  # 蠓
    0x8814: 'háo',  # 蠔
    0x8815: 'rú',  # 蠕
    0x8816: 'huò',  # 蠖
    0x8817: 'zhuó',  # 蠗
    0x8818: 'jié',  # 蠘
    0x8819: 'pín',  # 蠙
    0x881A: 'hē',  # 蠚
    0x881B: 'miè',  # 蠛
    0x881C: 'fán',  # 蠜
    0x881D: 'lěi',  # 蠝
    0x881E: 'jié',  # 蠞
    0x881F: 'là',  # 蠟
    0x8820: 'mǐn',  # 蠠
    0x8821: 'lǐ',  # 蠡
    0x8822: 'chǔn',  # 蠢
    0x8823: 'lì',  # 蠣
    0x8824: 'qiū',  # 蠤
    0x8825: 'niè',  # 蠥
    0x8826: 'lú',  # 蠦
    0x8827: 'dù',  # 蠧
    0x8828: 'xiāo',  # 蠨
    0x8829: 'zhū',  # 蠩
    0x882A: 'lóng',  # 蠪
    0x882B: 'lí',  # 蠫
    0x882C: 'lóng',  # 蠬
    0x882D: 'fēng',  # 蠭
    0x882E: 'yē',  # 蠮
    0x882F: 'pí',  # 蠯
    0x8830: 'náng',  # 蠰
    0x8831: 'gǔ',  # 蠱
    0x8832: 'juān',  # 蠲
    0x8833: 'yīng',  # 蠳
    0x8834: 'shǔ',  # 蠴
    0x8835: 'xī',  # 蠵
    0x8836: 'cán',  # 蠶
    0x8837: 'qú',  # 蠷
    0x8838: 'quán',  # 蠸
    0x8839: 'dù',  # 蠹
    0x883A: 'cán',  # 蠺
    0x883B: 'mán',  # 蠻
    0x883C: 'qú',  # 蠼
    0x883D: 'jié',  # 蠽
    0x883E: 'zhú',  # 蠾
    0x883F: 'zhuó',  # 蠿
    0x8840: 'xiě,xuè',  # 血
    0x8841: 'huāng',  # 衁
    0x8842: 'nǜ',  # 衂
    0x8843: 'pēi',  # 衃
    0x8844: 'nǜ',  # 衄
    0x8845: 'xìn',  # 衅
    0x8846: 'zhòng',  # 衆
    0x8847: 'mài',  # 衇
    0x8848: 'ěr',  # 衈
    0x8849: 'kè',  # 衉
    0x884A: 'miè',  # 衊
    0x884B: 'xì',  # 衋
    0x884C: 'háng,xíng',  # 行
    0x884D: 'yǎn',  # 衍
    0x884E: 'kàn',  # 衎
    0x884F: 'yuàn',  # 衏
    0x8850: 'qú',  # 衐
    0x8851: 'líng',  # 衑
    0x8852: 'xuàn',  # 衒
    0x8853: 'shù',  # 術
    0x8854: 'xián',  # 衔
    0x8855: 'tòng',  # 衕
    0x8856: 'xiàng',  # 衖
    0x8857: 'jiē',  # 街
    0x8858: 'xián',  # 衘
    0x8859: 'yá',  # 衙
    0x885A: 'hú',  # 衚
    0x885B: 'wèi',  # 衛
    0x885C: 'dào',  # 衜
    0x885D: 'chōng',  # 衝
    0x885E: 'wèi',  # 衞
    0x885F: 'dào',  # 衟
    0x8860: 'zhūn',  # 衠
    0x8861: 'héng',  # 衡
    0x8862: 'qú',  # 衢
    0x8863: 'yī',  # 衣
    0x8864: 'yī',  # 衤
    0x8865: 'bǔ',  # 补
    0x8866: 'gǎn',  # 衦
    0x8867: 'yú',  # 衧
    0x8868: 'biǎo',  # 表
    0x8869: 'chà',  # 衩
    0x886A: 'yì',  # 衪
    0x886B: 'shān',  # 衫
    0x886C: 'chèn',  # 衬
    0x886D: 'fū',  # 衭
    0x886E: 'gǔn',  # 衮
    0x886F: 'fēn',  # 衯
    0x8870: 'shuāi,cuī',  # 衰
    0x8871: 'jié',  # 衱
    0x8872: 'nà',  # 衲
    0x8873: 'zhōng',  # 衳
    0x8874: 'dǎn',  # 衴
    0x8875: 'rì',  # 衵
    0x8876: 'zhòng',  # 衶
    0x8877: 'zhōng',  # 衷
    0x8878: 'jiè',  # 衸
    0x8879: 'zhǐ',  # 衹
    0x887A: 'xié',  # 衺
    0x887B: 'rán',  # 衻
    0x887C: 'zhī',  # 衼
    0x887D: 'rèn',  # 衽
    0x887E: 'qīn',  # 衾
    0x887F: 'jīn',  # 衿
    0x8880: 'jūn',  # 袀
    0x8881: 'yuán',  # 袁
    0x8882: 'mèi',  # 袂
    0x8883: 'chài',  # 袃
    0x8884: 'ǎo',  # 袄
    0x8885: 'niǎo',  # 袅
    0x8886: 'huī',  # 袆
    0x8887: 'rán',  # 袇
    0x8888: 'jiā',  # 袈
    0x8889: 'tuó,tuō',  # 袉
    0x888A: 'lǐng,líng',  # 袊
    0x888B: 'dài',  # 袋
    0x888C: 'bào,páo,pào',  # 袌
    0x888D: 'páo',  # 袍
    0x888E: 'yào',  # 袎
    0x888F: 'zuò',  # 袏
    0x8890: 'bì',  # 袐
    0x8891: 'shào',  # 袑
    0x8892: 'tǎn',  # 袒
    0x8893: 'jù,jiē',  # 袓
    0x8894: 'hè,kè',  # 袔
    0x8895: 'xué',  # 袕
    0x8896: 'xiù',  # 袖
    0x8897: 'zhěn',  # 袗
    0x8898: 'yí,yì',  # 袘
    0x8899: 'pà',  # 袙
    0x889A: 'fú',  # 袚
    0x889B: 'dī',  # 袛
    0x889C: 'wà',  # 袜
    0x889D: 'fù',  # 袝
    0x889E: 'gǔn',  # 袞
    0x889F: 'zhì',  # 袟
    0x88A0: 'zhì',  # 袠
    0x88A1: 'rán',  # 袡
    0x88A2: 'pàn',  # 袢
    0x88A3: 'yì',  # 袣
    0x88A4: 'mào',  # 袤
    0x88A5: 'tuō',  # 袥
    0x88A6: 'nà,jué',  # 袦
    0x88A7: 'gōu',  # 袧
    0x88A8: 'xuàn',  # 袨
    0x88A9: 'zhé',  # 袩
    0x88AA: 'qū',  # 袪
    0x88AB: 'bèi,pī',  # 被
    0x88AC: 'yù',  # 袬
    0x88AD: 'xí',  # 袭
    0x88AE: 'mí',  # 袮
    0x88AF: 'bó',  # 袯
    0x88B0: 'bō',  # 袰
    0x88B1: 'fú',  # 袱
    0x88B2: 'chǐ,nuǒ',  # 袲
    0x88B3: 'chǐ,qǐ,duǒ,nuǒ',  # 袳
    0x88B4: 'kù',  # 袴
    0x88B5: 'rèn',  # 袵
    0x88B6: 'péng',  # 袶
    0x88B7: 'jiá,jié,qiā',  # 袷
    0x88B8: 'jiàn,zùn',  # 袸
    0x88B9: 'bó,mò',  # 袹
    0x88BA: 'jié',  # 袺
    0x88BB: 'ér',  # 袻
    0x88BC: 'gē',  # 袼
    0x88BD: 'rú',  # 袽
    0x88BE: 'zhū',  # 袾
    0x88BF: 'guī,guà',  # 袿
    0x88C0: 'yīn',  # 裀
    0x88C1: 'cái',  # 裁
    0x88C2: 'liè,liě',  # 裂
    0x88C3: 'kǎ',  # 裃
    0x88C4: 'háng',  # 裄
    0x88C5: 'zhuāng',  # 装
    0x88C6: 'dāng',  # 裆
    0x88C7: 'xū',  # 裇
    0x88C8: 'kūn',  # 裈
    0x88C9: 'kèn',  # 裉
    0x88CA: 'niǎo',  # 裊
    0x88CB: 'shù',  # 裋
    0x88CC: 'jiá',  # 裌
    0x88CD: 'kǔn',  # 裍
    0x88CE: 'chéng,chěng',  # 裎
    0x88CF: 'lǐ',  # 裏
    0x88D0: 'juān',  # 裐
    0x88D1: 'shēn',  # 裑
    0x88D2: 'póu',  # 裒
    0x88D3: 'gé,jiē',  # 裓
    0x88D4: 'yì',  # 裔
    0x88D5: 'yù',  # 裕
    0x88D6: 'zhěn',  # 裖
    0x88D7: 'liú',  # 裗
    0x88D8: 'qiú',  # 裘
    0x88D9: 'qún',  # 裙
    0x88DA: 'jì',  # 裚
    0x88DB: 'yì',  # 裛
    0x88DC: 'bǔ',  # 補
    0x88DD: 'zhuāng',  # 裝
    0x88DE: 'shuì',  # 裞
    0x88DF: 'shā',  # 裟
    0x88E0: 'qún',  # 裠
    0x88E1: 'lǐ',  # 裡
    0x88E2: 'lián',  # 裢
    0x88E3: 'liǎn',  # 裣
    0x88E4: 'kù',  # 裤
    0x88E5: 'jiǎn',  # 裥
    0x88E6: 'bāo',  # 裦
    0x88E7: 'chān',  # 裧
    0x88E8: 'bì,pí',  # 裨
    0x88E9: 'kūn',  # 裩
    0x88EA: 'táo',  # 裪
    0x88EB: 'yuàn',  # 裫
    0x88EC: 'líng',  # 裬
    0x88ED: 'chǐ',  # 裭
    0x88EE: 'chāng',  # 裮
    0x88EF: 'chóu,dāo',  # 裯
    0x88F0: 'duō',  # 裰
    0x88F1: 'biǎo',  # 裱
    0x88F2: 'liǎng',  # 裲
    0x88F3: 'cháng,shang',  # 裳
    0x88F4: 'péi',  # 裴
    0x88F5: 'péi',  # 裵
    0x88F6: 'fēi',  # 裶
    0x88F7: 'yuān,gǔn',  # 裷
    0x88F8: 'luǒ',  # 裸
    0x88F9: 'guǒ',  # 裹
    0x88FA: 'yǎn,ān',  # 裺
    0x88FB: 'dú',  # 裻
    0x88FC: 'xī,tì',  # 裼
    0x88FD: 'zhì',  # 製
    0x88FE: 'jū',  # 裾
    0x88FF: 'yǐ',  # 裿
    0x8900: 'qí',  # 褀
    0x8901: 'guǒ',  # 褁
    0x8902: 'guà',  # 褂
    0x8903: 'kèn',  # 褃
    0x8904: 'qī',  # 褄
    0x8905: 'tì',  # 褅
    0x8906: 'tí',  # 褆
    0x8907: 'fù',  # 複
    0x8908: 'chóng',  # 褈
    0x8909: 'xiè',  # 褉
    0x890A: 'biǎn',  # 褊
    0x890B: 'dié',  # 褋
    0x890C: 'kūn',  # 褌
    0x890D: 'duān',  # 褍
    0x890E: 'xiù',  # 褎
    0x890F: 'xiù',  # 褏
    0x8910: 'hè',  # 褐
    0x8911: 'yuàn',  # 褑
    0x8912: 'bāo',  # 褒
    0x8913: 'bǎo',  # 褓
    0x8914: 'fù,fú',  # 褔
    0x8915: 'yú',  # 褕
    0x8916: 'tuàn',  # 褖
    0x8917: 'yǎn',  # 褗
    0x8918: 'huī',  # 褘
    0x8919: 'bèi',  # 褙
    0x891A: 'zhǔ,chǔ',  # 褚
    0x891B: 'lǚ',  # 褛
    0x891C: 'páo',  # 褜
    0x891D: 'dān',  # 褝
    0x891E: 'yùn',  # 褞
    0x891F: 'tā',  # 褟
    0x8920: 'gōu',  # 褠
    0x8921: 'dā',  # 褡
    0x8922: 'huái',  # 褢
    0x8923: 'róng',  # 褣
    0x8924: 'yuán',  # 褤
    0x8925: 'rù',  # 褥
    0x8926: 'nài',  # 褦
    0x8927: 'jiǒng',  # 褧
    0x8928: 'suǒ',  # 褨
    0x8929: 'bān',  # 褩
    0x892A: 'tuì,tùn',  # 褪
    0x892B: 'chǐ',  # 褫
    0x892C: 'sǎng',  # 褬
    0x892D: 'niǎo',  # 褭
    0x892E: 'yīng',  # 褮
    0x892F: 'jiè',  # 褯
    0x8930: 'qiān',  # 褰
    0x8931: 'huái',  # 褱
    0x8932: 'kù',  # 褲
    0x8933: 'lián',  # 褳
    0x8934: 'lán',  # 褴
    0x8935: 'lí',  # 褵
    0x8936: 'zhě',  # 褶
    0x8937: 'shī',  # 褷
    0x8938: 'lǚ',  # 褸
    0x8939: 'yì',  # 褹
    0x893A: 'diē',  # 褺
    0x893B: 'xiè',  # 褻
    0x893C: 'xiān',  # 褼
    0x893D: 'wèi',  # 褽
    0x893E: 'biǎo',  # 褾
    0x893F: 'cáo',  # 褿
    0x8940: 'jì',  # 襀
    0x8941: 'qiǎng',  # 襁
    0x8942: 'sēn',  # 襂
    0x8943: 'bāo',  # 襃
    0x8944: 'xiāng',  # 襄
    0x8945: 'bì',  # 襅
    0x8946: 'fú',  # 襆
    0x8947: 'jiǎn',  # 襇
    0x8948: 'zhuàn',  # 襈
    0x8949: 'jiǎn',  # 襉
    0x894A: 'cuì',  # 襊
    0x894B: 'jí',  # 襋
    0x894C: 'dān',  # 襌
    0x894D: 'zá',  # 襍
    0x894E: 'fán',  # 襎
    0x894F: 'bó',  # 襏
    0x8950: 'xiàng',  # 襐
    0x8951: 'xín',  # 襑
    0x8952: 'bié',  # 襒
    0x8953: 'ráo',  # 襓
    0x8954: 'mǎn',  # 襔
    0x8955: 'lán',  # 襕
    0x8956: 'ǎo',  # 襖
    0x8957: 'zé',  # 襗
    0x8958: 'guì',  # 襘
    0x8959: 'cào',  # 襙
    0x895A: 'suì',  # 襚
    0x895B: 'nóng',  # 襛
    0x895C: 'chān',  # 襜
    0x895D: 'liǎn',  # 襝
    0x895E: 'bì',  # 襞
    0x895F: 'jīn',  # 襟
    0x8960: 'dāng',  # 襠
    0x8961: 'shǔ',  # 襡
    0x8962: 'tǎn',  # 襢
    0x8963: 'bì',  # 襣
    0x8964: 'lán',  # 襤
    0x8965: 'fú',  # 襥
    0x8966: 'rú',  # 襦
    0x8967: 'zhǐ',  # 襧
    0x8968: 'tae',  # 襨
    0x8969: 'shǔ',  # 襩
    0x896A: 'wà',  # 襪
    0x896B: 'shì',  # 襫
    0x896C: 'bǎi',  # 襬
    0x896D: 'xié',  # 襭
    0x896E: 'bó',  # 襮
    0x896F: 'chèn',  # 襯
    0x8970: 'lǎi',  # 襰
    0x8971: 'lóng',  # 襱
    0x8972: 'xí',  # 襲
    0x8973: 'xiān',  # 襳
    0x8974: 'lán',  # 襴
    0x8975: 'zhě',  # 襵
    0x8976: 'dài',  # 襶
    0x8977: 'jǔ',  # 襷
    0x8978: 'zàn',  # 襸
    0x8979: 'shī',  # 襹
    0x897A: 'jiǎn',  # 襺
    0x897B: 'pàn',  # 襻
    0x897C: 'yì',  # 襼
    0x897D: 'lán',  # 襽
    0x897E: 'yà',  # 襾
    0x897F: 'xī',  # 西
    0x8980: 'yà',  # 覀
    0x8981: 'yào,yāo',  # 要
    0x8982: 'fěng',  # 覂
    0x8983: 'tán,qín',  # 覃
    0x8984: 'fù',  # 覄
    0x8985: 'fiào',  # 覅
    0x8986: 'fù',  # 覆
    0x8987: 'bà',  # 覇
    0x8988: 'hé',  # 覈
    0x8989: 'jī',  # 覉
    0x898A: 'jī',  # 覊
    0x898B: 'jiàn,xiàn',  # 見
    0x898C: 'guān,guàn',  # 覌
    0x898D: 'biàn',  # 覍
    0x898E: 'yàn',  # 覎
    0x898F: 'guī',  # 規
    0x8990: 'jué,jiào',  # 覐
    0x8991: 'piǎn',  # 覑
    0x8992: 'mào',  # 覒
    0x8993: 'mì',  # 覓
    0x8994: 'mì',  # 覔
    0x8995: 'piē,miè',  # 覕
    0x8996: 'shì',  # 視
    0x8997: 'sì',  # 覗
    0x8998: 'chān',  # 覘
    0x8999: 'zhěn',  # 覙
    0x899A: 'jué,jiào',  # 覚
    0x899B: 'mì',  # 覛
    0x899C: 'tiào',  # 覜
    0x899D: 'lián',  # 覝
    0x899E: 'yào',  # 覞
    0x899F: 'zhì',  # 覟
    0x89A0: 'jūn',  # 覠
    0x89A1: 'xī',  # 覡
    0x89A2: 'shǎn',  # 覢
    0x89A3: 'wēi',  # 覣
    0x89A4: 'xì',  # 覤
    0x89A5: 'tiǎn',  # 覥
    0x89A6: 'yú',  # 覦
    0x89A7: 'lǎn',  # 覧
    0x89A8: 'è',  # 覨
    0x89A9: 'dǔ',  # 覩
    0x89AA: 'qīn,qìng',  # 親
    0x89AB: 'pǎng',  # 覫
    0x89AC: 'jì',  # 覬
    0x89AD: 'míng',  # 覭
    0x89AE: 'yíng,yǐng',  # 覮
    0x89AF: 'gòu',  # 覯
    0x89B0: 'qū,qù',  # 覰
    0x89B1: 'zhàn,zhān',  # 覱
    0x89B2: 'jìn',  # 覲
    0x89B3: 'guān,guàn',  # 観
    0x89B4: 'dèng',  # 覴
    0x89B5: 'jiàn,biǎn',  # 覵
    0x89B6: 'luó,luǎn',  # 覶
    0x89B7: 'qù,qū',  # 覷
    0x89B8: 'jiàn',  # 覸
    0x89B9: 'wéi',  # 覹
    0x89BA: 'jué,jiào',  # 覺
    0x89BB: 'qù,qū',  # 覻
    0x89BC: 'luó',  # 覼
    0x89BD: 'lǎn',  # 覽
    0x89BE: 'shěn',  # 覾
    0x89BF: 'dí',  # 覿
    0x89C0: 'guān,guàn',  # 觀
    0x89C1: 'jiàn,xiàn',  # 见
    0x89C2: 'guān,guàn',  # 观
    0x89C3: 'yàn',  # 觃
    0x89C4: 'guī',  # 规
    0x89C5: 'mì',  # 觅
    0x89C6: 'shì',  # 视
    0x89C7: 'chān',  # 觇
    0x89C8: 'lǎn',  # 览
    0x89C9: 'jué,jiào',  # 觉
    0x89CA: 'jì',  # 觊
    0x89CB: 'xí',  # 觋
    0x89CC: 'dí',  # 觌
    0x89CD: 'tiǎn',  # 觍
    0x89CE: 'yú',  # 觎
    0x89CF: 'gòu',  # 觏
    0x89D0: 'jìn',  # 觐
    0x89D1: 'qù,qū',  # 觑
    0x89D2: 'jiǎo,jué',  # 角
    0x89D3: 'qiú',  # 觓
    0x89D4: 'jīn',  # 觔
    0x89D5: 'cū',  # 觕
    0x89D6: 'jué',  # 觖
    0x89D7: 'zhì',  # 觗
    0x89D8: 'chào',  # 觘
    0x89D9: 'jí',  # 觙
    0x89DA: 'gū',  # 觚
    0x89DB: 'dàn',  # 觛
    0x89DC: 'zī,zuǐ',  # 觜
    0x89DD: 'dǐ',  # 觝
    0x89DE: 'shāng',  # 觞
    0x89DF: 'huà,xiè',  # 觟
    0x89E0: 'quán',  # 觠
    0x89E1: 'gé',  # 觡
    0x89E2: 'shì',  # 觢
    0x89E3: 'jiě,jiè,xiè',  # 解
    0x89E4: 'guǐ',  # 觤
    0x89E5: 'gōng',  # 觥
    0x89E6: 'chù',  # 触
    0x89E7: 'jiě,jiè,xiè',  # 觧
    0x89E8: 'hùn',  # 觨
    0x89E9: 'qiú',  # 觩
    0x89EA: 'xīng',  # 觪
    0x89EB: 'sù',  # 觫
    0x89EC: 'ní',  # 觬
    0x89ED: 'jī,qí',  # 觭
    0x89EE: 'jué',  # 觮
    0x89EF: 'zhì',  # 觯
    0x89F0: 'zhā',  # 觰
    0x89F1: 'bì',  # 觱
    0x89F2: 'xīng',  # 觲
    0x89F3: 'hú',  # 觳
    0x89F4: 'shāng',  # 觴
    0x89F5: 'gōng',  # 觵
    0x89F6: 'zhì',  # 觶
    0x89F7: 'xué,hù',  # 觷
    0x89F8: 'chù',  # 觸
    0x89F9: 'xī',  # 觹
    0x89FA: 'yí',  # 觺
    0x89FB: 'lì,lù',  # 觻
    0x89FC: 'jué',  # 觼
    0x89FD: 'xī',  # 觽
    0x89FE: 'yàn',  # 觾
    0x89FF: 'xī',  # 觿
    0x8A00: 'yán',  # 言
    0x8A01: 'yán',  # 訁
    0x8A02: 'dìng',  # 訂
    0x8A03: 'fù',  # 訃
    0x8A04: 'qiú',  # 訄
    0x8A05: 'qiú',  # 訅
    0x8A06: 'jiào',  # 訆
    0x8A07: 'hōng',  # 訇
    0x8A08: 'jì',  # 計
    0x8A09: 'fàn',  # 訉
    0x8A0A: 'xùn',  # 訊
    0x8A0B: 'diào',  # 訋
    0x8A0C: 'hòng',  # 訌
    0x8A0D: 'chài',  # 訍
    0x8A0E: 'tǎo',  # 討
    0x8A0F: 'xū',  # 訏
    0x8A10: 'jié',  # 訐
    0x8A11: 'dàn',  # 訑
    0x8A12: 'rèn',  # 訒
    0x8A13: 'xùn',  # 訓
    0x8A14: 'yín',  # 訔
    0x8A15: 'shàn',  # 訕
    0x8A16: 'qì',  # 訖
    0x8A17: 'tuō',  # 託
    0x8A18: 'jì',  # 記
    0x8A19: 'xùn',  # 訙
    0x8A1A: 'yín',  # 訚
    0x8A1B: 'é',  # 訛
    0x8A1C: 'fēn',  # 訜
    0x8A1D: 'yà',  # 訝
    0x8A1E: 'yāo',  # 訞
    0x8A1F: 'sòng',  # 訟
    0x8A20: 'shěn',  # 訠
    0x8A21: 'yín',  # 訡
    0x8A22: 'xīn',  # 訢
    0x8A23: 'jué',  # 訣
    0x8A24: 'xiáo',  # 訤
    0x8A25: 'nè',  # 訥
    0x8A26: 'chén',  # 訦
    0x8A27: 'yóu',  # 訧
    0x8A28: 'zhǐ',  # 訨
    0x8A29: 'xiōng',  # 訩
    0x8A2A: 'fǎng',  # 訪
    0x8A2B: 'xìn',  # 訫
    0x8A2C: 'chāo',  # 訬
    0x8A2D: 'shè',  # 設
    0x8A2E: 'yán',  # 訮
    0x8A2F: 'sǎ',  # 訯
    0x8A30: 'zhùn',  # 訰
    0x8A31: 'xū',  # 許
    0x8A32: 'yì',  # 訲
    0x8A33: 'yì',  # 訳
    0x8A34: 'sù',  # 訴
    0x8A35: 'chī',  # 訵
    0x8A36: 'hē',  # 訶
    0x8A37: 'shēn',  # 訷
    0x8A38: 'hé',  # 訸
    0x8A39: 'xù',  # 訹
    0x8A3A: 'zhěn',  # 診
    0x8A3B: 'zhù',  # 註
    0x8A3C: 'zhèng',  # 証
    0x8A3D: 'gòu',  # 訽
    0x8A3E: 'zī',  # 訾
    0x8A3F: 'zǐ',  # 訿
    0x8A40: 'zhān',  # 詀
    0x8A41: 'gǔ',  # 詁
    0x8A42: 'fù',  # 詂
    0x8A43: 'jiǎn',  # 詃
    0x8A44: 'dié',  # 詄
    0x8A45: 'líng',  # 詅
    0x8A46: 'dǐ',  # 詆
    0x8A47: 'yàng',  # 詇
    0x8A48: 'lì',  # 詈
    0x8A49: 'náo',  # 詉
    0x8A4A: 'pàn',  # 詊
    0x8A4B: 'zhòu',  # 詋
    0x8A4C: 'gàn',  # 詌
    0x8A4D: 'yì',  # 詍
    0x8A4E: 'jù',  # 詎
    0x8A4F: 'yào',  # 詏
    0x8A50: 'zhà',  # 詐
    0x8A51: 'tuó',  # 詑
    0x8A52: 'yí,dài',  # 詒
    0x8A53: 'qǔ',  # 詓
    0x8A54: 'zhào',  # 詔
    0x8A55: 'píng',  # 評
    0x8A56: 'bì',  # 詖
    0x8A57: 'xiòng',  # 詗
    0x8A58: 'qū',  # 詘
    0x8A59: 'bá',  # 詙
    0x8A5A: 'dá',  # 詚
    0x8A5B: 'zǔ',  # 詛
    0x8A5C: 'tāo',  # 詜
    0x8A5D: 'zhǔ',  # 詝
    0x8A5E: 'cí',  # 詞
    0x8A5F: 'zhé',  # 詟
    0x8A60: 'yǒng',  # 詠
    0x8A61: 'xǔ',  # 詡
    0x8A62: 'xún',  # 詢
    0x8A63: 'yì',  # 詣
    0x8A64: 'huǎng',  # 詤
    0x8A65: 'hé',  # 詥
    0x8A66: 'shì',  # 試
    0x8A67: 'chá',  # 詧
    0x8A68: 'xiào',  # 詨
    0x8A69: 'shī',  # 詩
    0x8A6A: 'hěn',  # 詪
    0x8A6B: 'chà',  # 詫
    0x8A6C: 'gòu',  # 詬
    0x8A6D: 'guǐ',  # 詭
    0x8A6E: 'quán',  # 詮
    0x8A6F: 'huì',  # 詯
    0x8A70: 'jié',  # 詰
    0x8A71: 'huà',  # 話
    0x8A72: 'gāi',  # 該
    0x8A73: 'xiáng',  # 詳
    0x8A74: 'wēi',  # 詴
    0x8A75: 'shēn',  # 詵
    0x8A76: 'chóu',  # 詶
    0x8A77: 'tóng',  # 詷
    0x8A78: 'mí',  # 詸
    0x8A79: 'zhān',  # 詹
    0x8A7A: 'míng',  # 詺
    0x8A7B: 'luò',  # 詻
    0x8A7C: 'huī',  # 詼
    0x8A7D: 'yán',  # 詽
    0x8A7E: 'xiōng',  # 詾
    0x8A7F: 'guà',  # 詿
    0x8A80: 'èr',  # 誀
    0x8A81: 'bìng',  # 誁
    0x8A82: 'tiǎo,diào',  # 誂
    0x8A83: 'yí,chǐ,chì',  # 誃
    0x8A84: 'lěi',  # 誄
    0x8A85: 'zhū',  # 誅
    0x8A86: 'kuāng',  # 誆
    0x8A87: 'kuā,kuà',  # 誇
    0x8A88: 'wū',  # 誈
    0x8A89: 'yù',  # 誉
    0x8A8A: 'téng',  # 誊
    0x8A8B: 'jì',  # 誋
    0x8A8C: 'zhì',  # 誌
    0x8A8D: 'rèn',  # 認
    0x8A8E: 'cù',  # 誎
    0x8A8F: 'lǎng,làng',  # 誏
    0x8A90: 'é',  # 誐
    0x8A91: 'kuáng',  # 誑
    0x8A92: 'ēi,éi,ěi,èi,xī',  # 誒
    0x8A93: 'shì',  # 誓
    0x8A94: 'tǐng',  # 誔
    0x8A95: 'dàn',  # 誕
    0x8A96: 'bèi,bó',  # 誖
    0x8A97: 'chán',  # 誗
    0x8A98: 'yòu',  # 誘
    0x8A99: 'kēng',  # 誙
    0x8A9A: 'qiào',  # 誚
    0x8A9B: 'qīn',  # 誛
    0x8A9C: 'shuà',  # 誜
    0x8A9D: 'ān',  # 誝
    0x8A9E: 'yǔ,yù',  # 語
    0x8A9F: 'xiào',  # 誟
    0x8AA0: 'chéng',  # 誠
    0x8AA1: 'jiè',  # 誡
    0x8AA2: 'xiàn',  # 誢
    0x8AA3: 'wū',  # 誣
    0x8AA4: 'wù',  # 誤
    0x8AA5: 'gào',  # 誥
    0x8AA6: 'sòng',  # 誦
    0x8AA7: 'bū',  # 誧
    0x8AA8: 'huì',  # 誨
    0x8AA9: 'jìng',  # 誩
    0x8AAA: 'shuō,shuì,yuè',  # 說
    0x8AAB: 'zhèn',  # 誫
    0x8AAC: 'shuō,shuì,yuè',  # 説
    0x8AAD: 'dú',  # 読
    0x8AAE: 'huā',  # 誮
    0x8AAF: 'chàng',  # 誯
    0x8AB0: 'shuí,shéi',  # 誰
    0x8AB1: 'jié',  # 誱
    0x8AB2: 'kè',  # 課
    0x8AB3: 'qū,juè',  # 誳
    0x8AB4: 'cóng',  # 誴
    0x8AB5: 'xiáo',  # 誵
    0x8AB6: 'suì',  # 誶
    0x8AB7: 'wǎng',  # 誷
    0x8AB8: 'xián',  # 誸
    0x8AB9: 'fěi',  # 誹
    0x8ABA: 'chī,lài',  # 誺
    0x8ABB: 'tà',  # 誻
    0x8ABC: 'yì',  # 誼
    0x8ABD: 'nì,ná',  # 誽
    0x8ABE: 'yín',  # 誾
    0x8ABF: 'diào,tiáo',  # 調
    0x8AC0: 'pǐ,bēi',  # 諀
    0x8AC1: 'zhuó',  # 諁
    0x8AC2: 'chǎn',  # 諂
    0x8AC3: 'chēn',  # 諃
    0x8AC4: 'zhūn',  # 諄
    0x8AC5: 'jì,jī',  # 諅
    0x8AC6: 'qī',  # 諆
    0x8AC7: 'tán',  # 談
    0x8AC8: 'zhuì',  # 諈
    0x8AC9: 'wěi',  # 諉
    0x8ACA: 'jū',  # 諊
    0x8ACB: 'qǐng',  # 請
    0x8ACC: 'dǒng',  # 諌
    0x8ACD: 'zhèng',  # 諍
    0x8ACE: 'zé,zuò,zhǎ,cuò',  # 諎
    0x8ACF: 'zōu',  # 諏
    0x8AD0: 'qiān',  # 諐
    0x8AD1: 'zhuó',  # 諑
    0x8AD2: 'liàng',  # 諒
    0x8AD3: 'jiàn',  # 諓
    0x8AD4: 'chù,jí',  # 諔
    0x8AD5: 'xià,háo',  # 諕
    0x8AD6: 'lùn,lún',  # 論
    0x8AD7: 'shěn',  # 諗
    0x8AD8: 'biǎo',  # 諘
    0x8AD9: 'huà',  # 諙
    0x8ADA: 'biàn',  # 諚
    0x8ADB: 'yú',  # 諛
    0x8ADC: 'dié',  # 諜
    0x8ADD: 'xū',  # 諝
    0x8ADE: 'piǎn',  # 諞
    0x8ADF: 'shì,dì',  # 諟
    0x8AE0: 'xuān',  # 諠
    0x8AE1: 'shì',  # 諡
    0x8AE2: 'hùn',  # 諢
    0x8AE3: 'huà,guā',  # 諣
    0x8AE4: 'è',  # 諤
    0x8AE5: 'zhòng',  # 諥
    0x8AE6: 'dì',  # 諦
    0x8AE7: 'xié',  # 諧
    0x8AE8: 'fú',  # 諨
    0x8AE9: 'pǔ',  # 諩
    0x8AEA: 'tíng',  # 諪
    0x8AEB: 'jiàn',  # 諫
    0x8AEC: 'qǐ',  # 諬
    0x8AED: 'yù',  # 諭
    0x8AEE: 'zī',  # 諮
    0x8AEF: 'zhuān',  # 諯
    0x8AF0: 'xǐ,shāi,āi',  # 諰
    0x8AF1: 'huì',  # 諱
    0x8AF2: 'yīn',  # 諲
    0x8AF3: 'ān',  # 諳
    0x8AF4: 'xián',  # 諴
    0x8AF5: 'nán,nàn',  # 諵
    0x8AF6: 'chén',  # 諶
    0x8AF7: 'fěng',  # 諷
    0x8AF8: 'zhū',  # 諸
    0x8AF9: 'yáng',  # 諹
    0x8AFA: 'yàn',  # 諺
    0x8AFB: 'huáng',  # 諻
    0x8AFC: 'xuān',  # 諼
    0x8AFD: 'gé',  # 諽
    0x8AFE: 'nuò',  # 諾
    0x8AFF: 'xǔ',  # 諿
    0x8B00: 'móu',  # 謀
    0x8B01: 'yè',  # 謁
    0x8B02: 'wèi',  # 謂
    0x8B03: 'xīng',  # 謃
    0x8B04: 'téng',  # 謄
    0x8B05: 'zhōu',  # 謅
    0x8B06: 'shàn',  # 謆
    0x8B07: 'jiǎn',  # 謇
    0x8B08: 'bó',  # 謈
    0x8B09: 'kuì',  # 謉
    0x8B0A: 'huǎng',  # 謊
    0x8B0B: 'huò',  # 謋
    0x8B0C: 'gē',  # 謌
    0x8B0D: 'yíng',  # 謍
    0x8B0E: 'mí',  # 謎
    0x8B0F: 'xiǎo',  # 謏
    0x8B10: 'mì',  # 謐
    0x8B11: 'xǐ',  # 謑
    0x8B12: 'qiāng',  # 謒
    0x8B13: 'chēn',  # 謓
    0x8B14: 'xuè',  # 謔
    0x8B15: 'tí',  # 謕
    0x8B16: 'sù',  # 謖
    0x8B17: 'bàng',  # 謗
    0x8B18: 'chí',  # 謘
    0x8B19: 'qiān',  # 謙
    0x8B1A: 'shì',  # 謚
    0x8B1B: 'jiǎng',  # 講
    0x8B1C: 'yuán',  # 謜
    0x8B1D: 'xiè',  # 謝
    0x8B1E: 'hè',  # 謞
    0x8B1F: 'tāo',  # 謟
    0x8B20: 'yáo',  # 謠
    0x8B21: 'yáo',  # 謡
    0x8B22: 'lū',  # 謢
    0x8B23: 'yú',  # 謣
    0x8B24: 'biāo',  # 謤
    0x8B25: 'còng',  # 謥
    0x8B26: 'qǐng',  # 謦
    0x8B27: 'lí',  # 謧
    0x8B28: 'mó',  # 謨
    0x8B29: 'mó',  # 謩
    0x8B2A: 'shāng',  # 謪
    0x8B2B: 'zhé',  # 謫
    0x8B2C: 'miù',  # 謬
    0x8B2D: 'jiǎn',  # 謭
    0x8B2E: 'zé',  # 謮
    0x8B2F: 'jiē',  # 謯
    0x8B30: 'lián',  # 謰
    0x8B31: 'lóu',  # 謱
    0x8B32: 'càn',  # 謲
    0x8B33: 'ōu',  # 謳
    0x8B34: 'gùn',  # 謴
    0x8B35: 'xí',  # 謵
    0x8B36: 'zhuó',  # 謶
    0x8B37: 'áo',  # 謷
    0x8B38: 'áo',  # 謸
    0x8B39: 'jǐn',  # 謹
    0x8B3A: 'zhé',  # 謺
    0x8B3B: 'yí',  # 謻
    0x8B3C: 'hū',  # 謼
    0x8B3D: 'jiàng',  # 謽
    0x8B3E: 'mán',  # 謾
    0x8B3F: 'cháo',  # 謿
    0x8B40: 'hàn',  # 譀
    0x8B41: 'huá',  # 譁
    0x8B42: 'chǎn',  # 譂
    0x8B43: 'xū',  # 譃
    0x8B44: 'zēng',  # 譄
    0x8B45: 'sè',  # 譅
    0x8B46: 'xī',  # 譆
    0x8B47: 'zhā',  # 譇
    0x8B48: 'duì',  # 譈
    0x8B49: 'zhèng',  # 證
    0x8B4A: 'náo',  # 譊
    0x8B4B: 'lán',  # 譋
    0x8B4C: 'é',  # 譌
    0x8B4D: 'yīng',  # 譍
    0x8B4E: 'jué',  # 譎
    0x8B4F: 'jī',  # 譏
    0x8B50: 'zǔn',  # 譐
    0x8B51: 'jiǎo',  # 譑
    0x8B52: 'bò',  # 譒
    0x8B53: 'huì',  # 譓
    0x8B54: 'zhuàn',  # 譔
    0x8B55: 'wú',  # 譕
    0x8B56: 'zèn',  # 譖
    0x8B57: 'zhá',  # 譗
    0x8B58: 'shí',  # 識
    0x8B59: 'qiáo',  # 譙
    0x8B5A: 'tán',  # 譚
    0x8B5B: 'jiàn',  # 譛
    0x8B5C: 'pǔ',  # 譜
    0x8B5D: 'shéng',  # 譝
    0x8B5E: 'xuān',  # 譞
    0x8B5F: 'zào',  # 譟
    0x8B60: 'tán',  # 譠
    0x8B61: 'dǎng',  # 譡
    0x8B62: 'suì',  # 譢
    0x8B63: 'xiǎn',  # 譣
    0x8B64: 'jī',  # 譤
    0x8B65: 'jiào',  # 譥
    0x8B66: 'jǐng',  # 警
    0x8B67: 'zhàn',  # 譧
    0x8B68: 'nóng',  # 譨
    0x8B69: 'yī',  # 譩
    0x8B6A: 'ǎi',  # 譪
    0x8B6B: 'zhān',  # 譫
    0x8B6C: 'pì',  # 譬
    0x8B6D: 'huǐ',  # 譭
    0x8B6E: 'huà',  # 譮
    0x8B6F: 'yì',  # 譯
    0x8B70: 'yì',  # 議
    0x8B71: 'shàn',  # 譱
    0x8B72: 'ràng',  # 譲
    0x8B73: 'ròu',  # 譳
    0x8B74: 'qiǎn',  # 譴
    0x8B75: 'duì',  # 譵
    0x8B76: 'tà',  # 譶
    0x8B77: 'hù',  # 護
    0x8B78: 'zhōu',  # 譸
    0x8B79: 'háo',  # 譹
    0x8B7A: 'ài',  # 譺
    0x8B7B: 'yīng',  # 譻
    0x8B7C: 'jiān',  # 譼
    0x8B7D: 'yù',  # 譽
    0x8B7E: 'jiǎn',  # 譾
    0x8B7F: 'huì',  # 譿
    0x8B80: 'dú',  # 讀
    0x8B81: 'zhé',  # 讁
    0x8B82: 'juàn,xuān',  # 讂
    0x8B83: 'zàn',  # 讃
    0x8B84: 'lěi',  # 讄
    0x8B85: 'shěn',  # 讅
    0x8B86: 'wèi',  # 讆
    0x8B87: 'chǎn',  # 讇
    0x8B88: 'lì',  # 讈
    0x8B89: 'yí,tuī',  # 讉
    0x8B8A: 'biàn',  # 變
    0x8B8B: 'zhé',  # 讋
    0x8B8C: 'yàn',  # 讌
    0x8B8D: 'è',  # 讍
    0x8B8E: 'chóu',  # 讎
    0x8B8F: 'wèi',  # 讏
    0x8B90: 'chóu',  # 讐
    0x8B91: 'yào',  # 讑
    0x8B92: 'chán',  # 讒
    0x8B93: 'ràng',  # 讓
    0x8B94: 'yǐn',  # 讔
    0x8B95: 'lán',  # 讕
    0x8B96: 'chèn',  # 讖
    0x8B97: 'xié',  # 讗
    0x8B98: 'niè',  # 讘
    0x8B99: 'huān',  # 讙
    0x8B9A: 'zàn',  # 讚
    0x8B9B: 'yì',  # 讛
    0x8B9C: 'dǎng',  # 讜
    0x8B9D: 'zhán',  # 讝
    0x8B9E: 'yàn',  # 讞
    0x8B9F: 'dú',  # 讟
    0x8BA0: 'yán',  # 讠
    0x8BA1: 'jì',  # 计
    0x8BA2: 'dìng',  # 订
    0x8BA3: 'fù',  # 讣
    0x8BA4: 'rèn',  # 认
    0x8BA5: 'jī',  # 讥
    0x8BA6: 'jié',  # 讦
    0x8BA7: 'hòng',  # 讧
    0x8BA8: 'tǎo',  # 讨
    0x8BA9: 'ràng',  # 让
    0x8BAA: 'shàn',  # 讪
    0x8BAB: 'qì',  # 讫
    0x8BAC: 'tuō',  # 讬
    0x8BAD: 'xùn',  # 训
    0x8BAE: 'yì',  # 议
    0x8BAF: 'xùn',  # 讯
    0x8BB0: 'jì',  # 记
    0x8BB1: 'rèn',  # 讱
    0x8BB2: 'jiǎng',  # 讲
    0x8BB3: 'huì',  # 讳
    0x8BB4: 'ōu',  # 讴
    0x8BB5: 'jù',  # 讵
    0x8BB6: 'yà',  # 讶
    0x8BB7: 'nè',  # 讷
    0x8BB8: 'xǔ,hǔ',  # 许
    0x8BB9: 'é',  # 讹
    0x8BBA: 'lùn,lún',  # 论
    0x8BBB: 'xiōng',  # 讻
    0x8BBC: 'sòng',  # 讼
    0x8BBD: 'fěng',  # 讽
    0x8BBE: 'shè',  # 设
    0x8BBF: 'fǎng',  # 访
    0x8BC0: 'jué',  # 诀
    0x8BC1: 'zhèng',  # 证
    0x8BC2: 'gǔ',  # 诂
    0x8BC3: 'hē',  # 诃
    0x8BC4: 'píng',  # 评
    0x8BC5: 'zǔ',  # 诅
    0x8BC6: 'shí,zhì',  # 识
    0x8BC7: 'xiòng',  # 诇
    0x8BC8: 'zhà',  # 诈
    0x8BC9: 'sù',  # 诉
    0x8BCA: 'zhěn',  # 诊
    0x8BCB: 'dǐ',  # 诋
    0x8BCC: 'zhōu',  # 诌
    0x8BCD: 'cí',  # 词
    0x8BCE: 'qū',  # 诎
    0x8BCF: 'zhào',  # 诏
    0x8BD0: 'bì',  # 诐
    0x8BD1: 'yì',  # 译
    0x8BD2: 'yí,dài',  # 诒
    0x8BD3: 'kuāng',  # 诓
    0x8BD4: 'lěi',  # 诔
    0x8BD5: 'shì',  # 试
    0x8BD6: 'guà',  # 诖
    0x8BD7: 'shī',  # 诗
    0x8BD8: 'jié,jí',  # 诘
    0x8BD9: 'huī',  # 诙
    0x8BDA: 'chéng',  # 诚
    0x8BDB: 'zhū',  # 诛
    0x8BDC: 'shēn',  # 诜
    0x8BDD: 'huà',  # 话
    0x8BDE: 'dàn',  # 诞
    0x8BDF: 'gòu',  # 诟
    0x8BE0: 'quán',  # 诠
    0x8BE1: 'guǐ',  # 诡
    0x8BE2: 'xún',  # 询
    0x8BE3: 'yì',  # 诣
    0x8BE4: 'zhèng',  # 诤
    0x8BE5: 'gāi',  # 该
    0x8BE6: 'xiáng,yáng',  # 详
    0x8BE7: 'chà',  # 诧
    0x8BE8: 'hùn',  # 诨
    0x8BE9: 'xǔ',  # 诩
    0x8BEA: 'zhōu,chóu',  # 诪
    0x8BEB: 'jiè',  # 诫
    0x8BEC: 'wū',  # 诬
    0x8BED: 'yǔ,yù',  # 语
    0x8BEE: 'qiào',  # 诮
    0x8BEF: 'wù',  # 误
    0x8BF0: 'gào',  # 诰
    0x8BF1: 'yòu',  # 诱
    0x8BF2: 'huì',  # 诲
    0x8BF3: 'kuáng',  # 诳
    0x8BF4: 'shuō,shuì,yuè',  # 说
    0x8BF5: 'sòng',  # 诵
    0x8BF6: 'ēi,éi,ěi,èi,xī',  # 诶
    0x8BF7: 'qǐng',  # 请
    0x8BF8: 'zhū',  # 诸
    0x8BF9: 'zōu',  # 诹
    0x8BFA: 'nuò',  # 诺
    0x8BFB: 'dú,dòu',  # 读
    0x8BFC: 'zhuó',  # 诼
    0x8BFD: 'fěi',  # 诽
    0x8BFE: 'kè',  # 课
    0x8BFF: 'wěi',  # 诿
    0x8C00: 'yú',  # 谀
    0x8C01: 'shuí',  # 谁
    0x8C02: 'shěn',  # 谂
    0x8C03: 'tiáo,diào,zhōu',  # 调
    0x8C04: 'chǎn',  # 谄
    0x8C05: 'liàng',  # 谅
    0x8C06: 'zhūn',  # 谆
    0x8C07: 'suì',  # 谇
    0x8C08: 'tán',  # 谈
    0x8C09: 'shěn',  # 谉
    0x8C0A: 'yì',  # 谊
    0x8C0B: 'móu',  # 谋
    0x8C0C: 'chén,shèn',  # 谌
    0x8C0D: 'dié',  # 谍
    0x8C0E: 'huǎng',  # 谎
    0x8C0F: 'jiàn',  # 谏
    0x8C10: 'xié',  # 谐
    0x8C11: 'xuè',  # 谑
    0x8C12: 'yè',  # 谒
    0x8C13: 'wèi',  # 谓
    0x8C14: 'è',  # 谔
    0x8C15: 'yù',  # 谕
    0x8C16: 'xuān',  # 谖
    0x8C17: 'chán',  # 谗
    0x8C18: 'zī',  # 谘
    0x8C19: 'ān',  # 谙
    0x8C1A: 'yàn',  # 谚
    0x8C1B: 'dì',  # 谛
    0x8C1C: 'mí',  # 谜
    0x8C1D: 'piǎn',  # 谝
    0x8C1E: 'xū',  # 谞
    0x8C1F: 'mó',  # 谟
    0x8C20: 'dǎng',  # 谠
    0x8C21: 'sù',  # 谡
    0x8C22: 'xiè',  # 谢
    0x8C23: 'yáo',  # 谣
    0x8C24: 'bàng',  # 谤
    0x8C25: 'shì',  # 谥
    0x8C26: 'qiān',  # 谦
    0x8C27: 'mì',  # 谧
    0x8C28: 'jǐn',  # 谨
    0x8C29: 'mán',  # 谩
    0x8C2A: 'zhé',  # 谪
    0x8C2B: 'jiǎn',  # 谫
    0x8C2C: 'miù',  # 谬
    0x8C2D: 'tán',  # 谭
    0x8C2E: 'zèn',  # 谮
    0x8C2F: 'qiáo',  # 谯
    0x8C30: 'lán',  # 谰
    0x8C31: 'pǔ',  # 谱
    0x8C32: 'jué',  # 谲
    0x8C33: 'yàn',  # 谳
    0x8C34: 'qiǎn',  # 谴
    0x8C35: 'zhān',  # 谵
    0x8C36: 'chèn',  # 谶
    0x8C37: 'gǔ',  # 谷
    0x8C38: 'qiān',  # 谸
    0x8C39: 'hóng',  # 谹
    0x8C3A: 'xiā',  # 谺
    0x8C3B: 'jí',  # 谻
    0x8C3C: 'hóng',  # 谼
    0x8C3D: 'hān',  # 谽
    0x8C3E: 'hōng',  # 谾
    0x8C3F: 'xī',  # 谿
    0x8C40: 'xī',  # 豀
    0x8C41: 'huō,huò,huá',  # 豁
    0x8C42: 'liáo',  # 豂
    0x8C43: 'hǎn',  # 豃
    0x8C44: 'dú',  # 豄
    0x8C45: 'lóng',  # 豅
    0x8C46: 'dòu',  # 豆
    0x8C47: 'jiāng',  # 豇
    0x8C48: 'qǐ,kǎi',  # 豈
    0x8C49: 'chǐ',  # 豉
    0x8C4A: 'lǐ',  # 豊
    0x8C4B: 'dēng',  # 豋
    0x8C4C: 'wān',  # 豌
    0x8C4D: 'bī',  # 豍
    0x8C4E: 'shù',  # 豎
    0x8C4F: 'xiàn',  # 豏
    0x8C50: 'fēng',  # 豐
    0x8C51: 'zhì',  # 豑
    0x8C52: 'zhì',  # 豒
    0x8C53: 'yàn',  # 豓
    0x8C54: 'yàn',  # 豔
    0x8C55: 'shǐ',  # 豕
    0x8C56: 'chù',  # 豖
    0x8C57: 'huī',  # 豗
    0x8C58: 'tún',  # 豘
    0x8C59: 'yì',  # 豙
    0x8C5A: 'tún',  # 豚
    0x8C5B: 'yì',  # 豛
    0x8C5C: 'jiān',  # 豜
    0x8C5D: 'bā',  # 豝
    0x8C5E: 'hòu',  # 豞
    0x8C5F: 'è',  # 豟
    0x8C60: 'chú',  # 豠
    0x8C61: 'xiàng',  # 象
    0x8C62: 'huàn',  # 豢
    0x8C63: 'jiān,yàn',  # 豣
    0x8C64: 'kěn',  # 豤
    0x8C65: 'gāi',  # 豥
    0x8C66: 'jù',  # 豦
    0x8C67: 'fú',  # 豧
    0x8C68: 'xī',  # 豨
    0x8C69: 'bīn',  # 豩
    0x8C6A: 'háo',  # 豪
    0x8C6B: 'yù',  # 豫
    0x8C6C: 'zhū',  # 豬
    0x8C6D: 'jiā',  # 豭
    0x8C6E: 'fén',  # 豮
    0x8C6F: 'xī',  # 豯
    0x8C70: 'hù',  # 豰
    0x8C71: 'wēn',  # 豱
    0x8C72: 'huán',  # 豲
    0x8C73: 'bīn',  # 豳
    0x8C74: 'dí',  # 豴
    0x8C75: 'zōng',  # 豵
    0x8C76: 'fén',  # 豶
    0x8C77: 'yì',  # 豷
    0x8C78: 'zhì',  # 豸
    0x8C79: 'bào',  # 豹
    0x8C7A: 'chái',  # 豺
    0x8C7B: 'àn',  # 豻
    0x8C7C: 'pí',  # 豼
    0x8C7D: 'nà',  # 豽
    0x8C7E: 'pī',  # 豾
    0x8C7F: 'gǒu',  # 豿
    0x8C80: 'nà',  # 貀
    0x8C81: 'yòu',  # 貁
    0x8C82: 'diāo',  # 貂
    0x8C83: 'mò',  # 貃
    0x8C84: 'sì',  # 貄
    0x8C85: 'xiū',  # 貅
    0x8C86: 'huán,huān',  # 貆
    0x8C87: 'kěn,kūn',  # 貇
    0x8C88: 'hé,mò',  # 貈
    0x8C89: 'hé,háo,mò',  # 貉
    0x8C8A: 'mò',  # 貊
    0x8C8B: 'àn',  # 貋
    0x8C8C: 'mào',  # 貌
    0x8C8D: 'lí',  # 貍
    0x8C8E: 'ní',  # 貎
    0x8C8F: 'bǐ',  # 貏
    0x8C90: 'yǔ',  # 貐
    0x8C91: 'jiā',  # 貑
    0x8C92: 'tuān,tuàn',  # 貒
    0x8C93: 'māo,máo',  # 貓
    0x8C94: 'pí',  # 貔
    0x8C95: 'xī',  # 貕
    0x8C96: 'yì',  # 貖
    0x8C97: 'jù,lóu',  # 貗
    0x8C98: 'mò',  # 貘
    0x8C99: 'chū',  # 貙
    0x8C9A: 'tán',  # 貚
    0x8C9B: 'huān',  # 貛
    0x8C9C: 'jué',  # 貜
    0x8C9D: 'bèi',  # 貝
    0x8C9E: 'zhēn',  # 貞
    0x8C9F: 'yuán,yún,yùn',  # 貟
    0x8CA0: 'fù',  # 負
    0x8CA1: 'cái',  # 財
    0x8CA2: 'gòng',  # 貢
    0x8CA3: 'dài',  # 貣
    0x8CA4: 'yì,yí',  # 貤
    0x8CA5: 'háng',  # 貥
    0x8CA6: 'wán',  # 貦
    0x8CA7: 'pín',  # 貧
    0x8CA8: 'huò',  # 貨
    0x8CA9: 'fàn',  # 販
    0x8CAA: 'tān',  # 貪
    0x8CAB: 'guàn',  # 貫
    0x8CAC: 'zé,zhài',  # 責
    0x8CAD: 'zhì',  # 貭
    0x8CAE: 'èr',  # 貮
    0x8CAF: 'zhù',  # 貯
    0x8CB0: 'shì',  # 貰
    0x8CB1: 'bì',  # 貱
    0x8CB2: 'zī',  # 貲
    0x8CB3: 'èr',  # 貳
    0x8CB4: 'guì',  # 貴
    0x8CB5: 'piǎn',  # 貵
    0x8CB6: 'biǎn',  # 貶
    0x8CB7: 'mǎi',  # 買
    0x8CB8: 'dài',  # 貸
    0x8CB9: 'shèng',  # 貹
    0x8CBA: 'kuàng',  # 貺
    0x8CBB: 'fèi',  # 費
    0x8CBC: 'tiē',  # 貼
    0x8CBD: 'yí',  # 貽
    0x8CBE: 'chí',  # 貾
    0x8CBF: 'mào',  # 貿
    0x8CC0: 'hè',  # 賀
    0x8CC1: 'bì,bēn',  # 賁
    0x8CC2: 'lù',  # 賂
    0x8CC3: 'lìn',  # 賃
    0x8CC4: 'huì',  # 賄
    0x8CC5: 'gāi',  # 賅
    0x8CC6: 'pián',  # 賆
    0x8CC7: 'zī',  # 資
    0x8CC8: 'jiǎ,gǔ,jià',  # 賈
    0x8CC9: 'xù',  # 賉
    0x8CCA: 'zéi',  # 賊
    0x8CCB: 'jiǎo',  # 賋
    0x8CCC: 'gāi',  # 賌
    0x8CCD: 'zāng',  # 賍
    0x8CCE: 'jiàn',  # 賎
    0x8CCF: 'yīng',  # 賏
    0x8CD0: 'jùn',  # 賐
    0x8CD1: 'zhèn',  # 賑
    0x8CD2: 'shē',  # 賒
    0x8CD3: 'bīn',  # 賓
    0x8CD4: 'bīn',  # 賔
    0x8CD5: 'qiú',  # 賕
    0x8CD6: 'shē',  # 賖
    0x8CD7: 'chuàn',  # 賗
    0x8CD8: 'zāng',  # 賘
    0x8CD9: 'zhōu',  # 賙
    0x8CDA: 'lài',  # 賚
    0x8CDB: 'zàn',  # 賛
    0x8CDC: 'cì',  # 賜
    0x8CDD: 'chēn',  # 賝
    0x8CDE: 'shǎng',  # 賞
    0x8CDF: 'tiǎn',  # 賟
    0x8CE0: 'péi',  # 賠
    0x8CE1: 'gēng',  # 賡
    0x8CE2: 'xián',  # 賢
    0x8CE3: 'mài',  # 賣
    0x8CE4: 'jiàn',  # 賤
    0x8CE5: 'suì',  # 賥
    0x8CE6: 'fù',  # 賦
    0x8CE7: 'dǎn',  # 賧
    0x8CE8: 'cóng',  # 賨
    0x8CE9: 'cóng',  # 賩
    0x8CEA: 'zhì',  # 質
    0x8CEB: 'jī',  # 賫
    0x8CEC: 'zhàng',  # 賬
    0x8CED: 'dǔ',  # 賭
    0x8CEE: 'jìn',  # 賮
    0x8CEF: 'xiōng,mín',  # 賯
    0x8CF0: 'chǔn',  # 賰
    0x8CF1: 'yǔn',  # 賱
    0x8CF2: 'bǎo',  # 賲
    0x8CF3: 'zāi',  # 賳
    0x8CF4: 'lài',  # 賴
    0x8CF5: 'fèng',  # 賵
    0x8CF6: 'càng',  # 賶
    0x8CF7: 'jī',  # 賷
    0x8CF8: 'shèng',  # 賸
    0x8CF9: 'ài',  # 賹
    0x8CFA: 'zhuàn,zuàn',  # 賺
    0x8CFB: 'fù',  # 賻
    0x8CFC: 'gòu',  # 購
    0x8CFD: 'sài',  # 賽
    0x8CFE: 'zé',  # 賾
    0x8CFF: 'liáo',  # 賿
    0x8D00: 'yì',  # 贀
    0x8D01: 'bài',  # 贁
    0x8D02: 'chěn',  # 贂
    0x8D03: 'wàn,zhuàn',  # 贃
    0x8D04: 'zhì',  # 贄
    0x8D05: 'zhuì',  # 贅
    0x8D06: 'biāo',  # 贆
    0x8D07: 'yūn',  # 贇
    0x8D08: 'zèng',  # 贈
    0x8D09: 'dàn',  # 贉
    0x8D0A: 'zàn',  # 贊
    0x8D0B: 'yàn',  # 贋
    0x8D0C: 'pú',  # 贌
    0x8D0D: 'shàn',  # 贍
    0x8D0E: 'wàn',  # 贎
    0x8D0F: 'yíng',  # 贏
    0x8D10: 'jìn',  # 贐
    0x8D11: 'gàn',  # 贑
    0x8D12: 'xián',  # 贒
    0x8D13: 'zāng',  # 贓
    0x8D14: 'bì',  # 贔
    0x8D15: 'dú',  # 贕
    0x8D16: 'shú',  # 贖
    0x8D17: 'yàn',  # 贗
    0x8D18: 'shǎng',  # 贘
    0x8D19: 'xuàn',  # 贙
    0x8D1A: 'lòng',  # 贚
    0x8D1B: 'gàn',  # 贛
    0x8D1C: 'zāng',  # 贜
    0x8D1D: 'bèi',  # 贝
    0x8D1E: 'zhēn',  # 贞
    0x8D1F: 'fù',  # 负
    0x8D20: 'yuán,yùn',  # 贠
    0x8D21: 'gòng',  # 贡
    0x8D22: 'cái',  # 财
    0x8D23: 'zé,zhài',  # 责
    0x8D24: 'xián',  # 贤
    0x8D25: 'bài',  # 败
    0x8D26: 'zhàng',  # 账
    0x8D27: 'huò',  # 货
    0x8D28: 'zhì',  # 质
    0x8D29: 'fàn',  # 贩
    0x8D2A: 'tān',  # 贪
    0x8D2B: 'pín',  # 贫
    0x8D2C: 'biǎn',  # 贬
    0x8D2D: 'gòu',  # 购
    0x8D2E: 'zhù',  # 贮
    0x8D2F: 'guàn',  # 贯
    0x8D30: 'èr',  # 贰
    0x8D31: 'jiàn',  # 贱
    0x8D32: 'bì,bēn',  # 贲
    0x8D33: 'shì',  # 贳
    0x8D34: 'tiē',  # 贴
    0x8D35: 'guì',  # 贵
    0x8D36: 'kuàng',  # 贶
    0x8D37: 'dài',  # 贷
    0x8D38: 'mào',  # 贸
    0x8D39: 'fèi',  # 费
    0x8D3A: 'hè',  # 贺
    0x8D3B: 'yí',  # 贻
    0x8D3C: 'zéi',  # 贼
    0x8D3D: 'zhì',  # 贽
    0x8D3E: 'gǔ,jiǎ',  # 贾
    0x8D3F: 'huì',  # 贿
    0x8D40: 'zī',  # 赀
    0x8D41: 'lìn',  # 赁
    0x8D42: 'lù',  # 赂
    0x8D43: 'zāng',  # 赃
    0x8D44: 'zī',  # 资
    0x8D45: 'gāi',  # 赅
    0x8D46: 'jìn',  # 赆
    0x8D47: 'qiú',  # 赇
    0x8D48: 'zhèn',  # 赈
    0x8D49: 'lài',  # 赉
    0x8D4A: 'shē',  # 赊
    0x8D4B: 'fù',  # 赋
    0x8D4C: 'dǔ',  # 赌
    0x8D4D: 'jī',  # 赍
    0x8D4E: 'shú',  # 赎
    0x8D4F: 'shǎng',  # 赏
    0x8D50: 'cì',  # 赐
    0x8D51: 'bì',  # 赑
    0x8D52: 'zhōu',  # 赒
    0x8D53: 'gēng',  # 赓
    0x8D54: 'péi',  # 赔
    0x8D55: 'dǎn',  # 赕
    0x8D56: 'lài',  # 赖
    0x8D57: 'fèng',  # 赗
    0x8D58: 'zhuì',  # 赘
    0x8D59: 'fù',  # 赙
    0x8D5A: 'zhuàn',  # 赚
    0x8D5B: 'sài',  # 赛
    0x8D5C: 'zé',  # 赜
    0x8D5D: 'yàn',  # 赝
    0x8D5E: 'zàn',  # 赞
    0x8D5F: 'yūn',  # 赟
    0x8D60: 'zèng',  # 赠
    0x8D61: 'shàn',  # 赡
    0x8D62: 'yíng',  # 赢
    0x8D63: 'gàn',  # 赣
    0x8D64: 'chì',  # 赤
    0x8D65: 'xī',  # 赥
    0x8D66: 'shè',  # 赦
    0x8D67: 'nǎn',  # 赧
    0x8D68: 'tóng',  # 赨
    0x8D69: 'xì',  # 赩
    0x8D6A: 'chēng',  # 赪
    0x8D6B: 'hè',  # 赫
    0x8D6C: 'chēng',  # 赬
    0x8D6D: 'zhě',  # 赭
    0x8D6E: 'xiá',  # 赮
    0x8D6F: 'táng',  # 赯
    0x8D70: 'zǒu',  # 走
    0x8D71: 'zǒu',  # 赱
    0x8D72: 'lì',  # 赲
    0x8D73: 'jiū',  # 赳
    0x8D74: 'fù',  # 赴
    0x8D75: 'zhào',  # 赵
    0x8D76: 'gǎn',  # 赶
    0x8D77: 'qǐ',  # 起
    0x8D78: 'shàn',  # 赸
    0x8D79: 'qióng',  # 赹
    0x8D7A: 'yǐn',  # 赺
    0x8D7B: 'xiǎn',  # 赻
    0x8D7C: 'zī',  # 赼
    0x8D7D: 'jué',  # 赽
    0x8D7E: 'qǐn',  # 赾
    0x8D7F: 'chí',  # 赿
    0x8D80: 'cī',  # 趀
    0x8D81: 'chèn',  # 趁
    0x8D82: 'chèn',  # 趂
    0x8D83: 'dié,tú',  # 趃
    0x8D84: 'qiè,jū',  # 趄
    0x8D85: 'chāo',  # 超
    0x8D86: 'dī',  # 趆
    0x8D87: 'xì',  # 趇
    0x8D88: 'zhān',  # 趈
    0x8D89: 'jué',  # 趉
    0x8D8A: 'yuè',  # 越
    0x8D8B: 'qū,cù',  # 趋
    0x8D8C: 'jí,jié',  # 趌
    0x8D8D: 'qū',  # 趍
    0x8D8E: 'chú',  # 趎
    0x8D8F: 'guā,huó',  # 趏
    0x8D90: 'xuè',  # 趐
    0x8D91: 'zī',  # 趑
    0x8D92: 'tiào',  # 趒
    0x8D93: 'duǒ',  # 趓
    0x8D94: 'liè',  # 趔
    0x8D95: 'gǎn',  # 趕
    0x8D96: 'suō',  # 趖
    0x8D97: 'cù',  # 趗
    0x8D98: 'xí',  # 趘
    0x8D99: 'zhào',  # 趙
    0x8D9A: 'sù',  # 趚
    0x8D9B: 'yǐn',  # 趛
    0x8D9C: 'jú',  # 趜
    0x8D9D: 'jiàn',  # 趝
    0x8D9E: 'què,qì,jí',  # 趞
    0x8D9F: 'tàng,tāng',  # 趟
    0x8DA0: 'chuō,zhuó',  # 趠
    0x8DA1: 'cuǐ',  # 趡
    0x8DA2: 'lù',  # 趢
    0x8DA3: 'qù,cù',  # 趣
    0x8DA4: 'dàng',  # 趤
    0x8DA5: 'qiū',  # 趥
    0x8DA6: 'zī',  # 趦
    0x8DA7: 'tí',  # 趧
    0x8DA8: 'qū,cù',  # 趨
    0x8DA9: 'chì',  # 趩
    0x8DAA: 'huáng',  # 趪
    0x8DAB: 'qiáo',  # 趫
    0x8DAC: 'qiāo',  # 趬
    0x8DAD: 'jiào',  # 趭
    0x8DAE: 'zào',  # 趮
    0x8DAF: 'tì,yuè',  # 趯
    0x8DB0: 'ěr',  # 趰
    0x8DB1: 'zǎn',  # 趱
    0x8DB2: 'zǎn',  # 趲
    0x8DB3: 'zú',  # 足
    0x8DB4: 'pā',  # 趴
    0x8DB5: 'bào,bō',  # 趵
    0x8DB6: 'kuà,wù',  # 趶
    0x8DB7: 'kē',  # 趷
    0x8DB8: 'dǔn',  # 趸
    0x8DB9: 'jué,guì',  # 趹
    0x8DBA: 'fū',  # 趺
    0x8DBB: 'chěn',  # 趻
    0x8DBC: 'jiǎn',  # 趼
    0x8DBD: 'fāng,fàng,páng',  # 趽
    0x8DBE: 'zhǐ',  # 趾
    0x8DBF: 'tā',  # 趿
    0x8DC0: 'yuè',  # 跀
    0x8DC1: 'bà,páo',  # 跁
    0x8DC2: 'qí,qǐ',  # 跂
    0x8DC3: 'yuè',  # 跃
    0x8DC4: 'qiāng,qiàng',  # 跄
    0x8DC5: 'tuò',  # 跅
    0x8DC6: 'tái',  # 跆
    0x8DC7: 'yì',  # 跇
    0x8DC8: 'jiàn,chén',  # 跈
    0x8DC9: 'líng',  # 跉
    0x8DCA: 'mèi',  # 跊
    0x8DCB: 'bá',  # 跋
    0x8DCC: 'diē',  # 跌
    0x8DCD: 'kū',  # 跍
    0x8DCE: 'tuó',  # 跎
    0x8DCF: 'jiā',  # 跏
    0x8DD0: 'cī,cǐ',  # 跐
    0x8DD1: 'pǎo,páo',  # 跑
    0x8DD2: 'qiǎ',  # 跒
    0x8DD3: 'zhù',  # 跓
    0x8DD4: 'jū',  # 跔
    0x8DD5: 'diǎn,tiē,dié',  # 跕
    0x8DD6: 'zhí',  # 跖
    0x8DD7: 'fū',  # 跗
    0x8DD8: 'pán,bàn',  # 跘
    0x8DD9: 'jū,jù,qiè',  # 跙
    0x8DDA: 'shān',  # 跚
    0x8DDB: 'bǒ',  # 跛
    0x8DDC: 'ní',  # 跜
    0x8DDD: 'jù',  # 距
    0x8DDE: 'lì,luò',  # 跞
    0x8DDF: 'gēn',  # 跟
    0x8DE0: 'yí',  # 跠
    0x8DE1: 'jì',  # 跡
    0x8DE2: 'dài,duò,duō,chí',  # 跢
    0x8DE3: 'xiǎn',  # 跣
    0x8DE4: 'jiāo',  # 跤
    0x8DE5: 'duò',  # 跥
    0x8DE6: 'zhū',  # 跦
    0x8DE7: 'quán',  # 跧
    0x8DE8: 'kuà',  # 跨
    0x8DE9: 'zhuǎi',  # 跩
    0x8DEA: 'guì',  # 跪
    0x8DEB: 'qióng',  # 跫
    0x8DEC: 'kuǐ',  # 跬
    0x8DED: 'xiáng',  # 跭
    0x8DEE: 'dié',  # 跮
    0x8DEF: 'lù',  # 路
    0x8DF0: 'pián,bèng',  # 跰
    0x8DF1: 'zhì',  # 跱
    0x8DF2: 'jié',  # 跲
    0x8DF3: 'tiào,táo',  # 跳
    0x8DF4: 'cǎi',  # 跴
    0x8DF5: 'jiàn',  # 践
    0x8DF6: 'dá',  # 跶
    0x8DF7: 'qiāo',  # 跷
    0x8DF8: 'bì',  # 跸
    0x8DF9: 'xiān',  # 跹
    0x8DFA: 'duò',  # 跺
    0x8DFB: 'jī',  # 跻
    0x8DFC: 'jú',  # 跼
    0x8DFD: 'jì',  # 跽
    0x8DFE: 'shū,chōu',  # 跾
    0x8DFF: 'tú',  # 跿
    0x8E00: 'chuò',  # 踀
    0x8E01: 'jìng',  # 踁
    0x8E02: 'niè',  # 踂
    0x8E03: 'xiāo',  # 踃
    0x8E04: 'bù',  # 踄
    0x8E05: 'xué',  # 踅
    0x8E06: 'cūn',  # 踆
    0x8E07: 'mǔ',  # 踇
    0x8E08: 'shū',  # 踈
    0x8E09: 'liáng,liàng',  # 踉
    0x8E0A: 'yǒng',  # 踊
    0x8E0B: 'jiǎo',  # 踋
    0x8E0C: 'chóu',  # 踌
    0x8E0D: 'qiāo',  # 踍
    0x8E0E: 'móu',  # 踎
    0x8E0F: 'tà',  # 踏
    0x8E10: 'jiàn',  # 踐
    0x8E11: 'jī',  # 踑
    0x8E12: 'wō',  # 踒
    0x8E13: 'wěi',  # 踓
    0x8E14: 'chuō',  # 踔
    0x8E15: 'jié',  # 踕
    0x8E16: 'jí',  # 踖
    0x8E17: 'niè',  # 踗
    0x8E18: 'jū',  # 踘
    0x8E19: 'niè',  # 踙
    0x8E1A: 'lún',  # 踚
    0x8E1B: 'lù',  # 踛
    0x8E1C: 'lèng',  # 踜
    0x8E1D: 'huái',  # 踝
    0x8E1E: 'jù',  # 踞
    0x8E1F: 'chí',  # 踟
    0x8E20: 'wǎn',  # 踠
    0x8E21: 'quán',  # 踡
    0x8E22: 'tī',  # 踢
    0x8E23: 'bó',  # 踣
    0x8E24: 'zú',  # 踤
    0x8E25: 'qiè',  # 踥
    0x8E26: 'qī',  # 踦
    0x8E27: 'cù',  # 踧
    0x8E28: 'zōng',  # 踨
    0x8E29: 'cǎi',  # 踩
    0x8E2A: 'zōng',  # 踪
    0x8E2B: 'pèng',  # 踫
    0x8E2C: 'zhì',  # 踬
    0x8E2D: 'zhēng',  # 踭
    0x8E2E: 'diǎn',  # 踮
    0x8E2F: 'zhí',  # 踯
    0x8E30: 'yú',  # 踰
    0x8E31: 'duó',  # 踱
    0x8E32: 'dùn',  # 踲
    0x8E33: 'chuǎn',  # 踳
    0x8E34: 'yǒng',  # 踴
    0x8E35: 'zhǒng',  # 踵
    0x8E36: 'dì',  # 踶
    0x8E37: 'zhě',  # 踷
    0x8E38: 'chěn',  # 踸
    0x8E39: 'chuài',  # 踹
    0x8E3A: 'jiàn',  # 踺
    0x8E3B: 'guā',  # 踻
    0x8E3C: 'táng',  # 踼
    0x8E3D: 'jǔ',  # 踽
    0x8E3E: 'fú',  # 踾
    0x8E3F: 'cù',  # 踿
    0x8E40: 'dié',  # 蹀
    0x8E41: 'pián',  # 蹁
    0x8E42: 'róu',  # 蹂
    0x8E43: 'nuò',  # 蹃
    0x8E44: 'tí',  # 蹄
    0x8E45: 'chǎ',  # 蹅
    0x8E46: 'tuǐ',  # 蹆
    0x8E47: 'jiǎn',  # 蹇
    0x8E48: 'dǎo',  # 蹈
    0x8E49: 'cuō',  # 蹉
    0x8E4A: 'qī,xī',  # 蹊
    0x8E4B: 'tà',  # 蹋
    0x8E4C: 'qiāng',  # 蹌
    0x8E4D: 'niǎn',  # 蹍
    0x8E4E: 'diān',  # 蹎
    0x8E4F: 'tí',  # 蹏
    0x8E50: 'jí',  # 蹐
    0x8E51: 'niè',  # 蹑
    0x8E52: 'pán',  # 蹒
    0x8E53: 'liū',  # 蹓
    0x8E54: 'zàn',  # 蹔
    0x8E55: 'bì',  # 蹕
    0x8E56: 'chōng',  # 蹖
    0x8E57: 'lù',  # 蹗
    0x8E58: 'liáo',  # 蹘
    0x8E59: 'cù',  # 蹙
    0x8E5A: 'tāng',  # 蹚
    0x8E5B: 'dài',  # 蹛
    0x8E5C: 'sù',  # 蹜
    0x8E5D: 'xǐ',  # 蹝
    0x8E5E: 'kuǐ',  # 蹞
    0x8E5F: 'jì',  # 蹟
    0x8E60: 'zhí',  # 蹠
    0x8E61: 'qiāng',  # 蹡
    0x8E62: 'dí',  # 蹢
    0x8E63: 'pán',  # 蹣
    0x8E64: 'zōng',  # 蹤
    0x8E65: 'lián',  # 蹥
    0x8E66: 'bèng',  # 蹦
    0x8E67: 'zāo',  # 蹧
    0x8E68: 'niǎn',  # 蹨
    0x8E69: 'bié',  # 蹩
    0x8E6A: 'tuí',  # 蹪
    0x8E6B: 'jú',  # 蹫
    0x8E6C: 'dēng',  # 蹬
    0x8E6D: 'cèng',  # 蹭
    0x8E6E: 'xiān',  # 蹮
    0x8E6F: 'fán',  # 蹯
    0x8E70: 'chú',  # 蹰
    0x8E71: 'zhōng',  # 蹱
    0x8E72: 'dūn',  # 蹲
    0x8E73: 'bō',  # 蹳
    0x8E74: 'cù',  # 蹴
    0x8E75: 'cù',  # 蹵
    0x8E76: 'jué,juě',  # 蹶
    0x8E77: 'jué',  # 蹷
    0x8E78: 'lìn',  # 蹸
    0x8E79: 'tà',  # 蹹
    0x8E7A: 'qiāo',  # 蹺
    0x8E7B: 'qiāo',  # 蹻
    0x8E7C: 'pǔ',  # 蹼
    0x8E7D: 'liāo',  # 蹽
    0x8E7E: 'dūn',  # 蹾
    0x8E7F: 'cuān',  # 蹿
    0x8E80: 'guàn',  # 躀
    0x8E81: 'zào',  # 躁
    0x8E82: 'tà',  # 躂
    0x8E83: 'bì',  # 躃
    0x8E84: 'bì',  # 躄
    0x8E85: 'zhú',  # 躅
    0x8E86: 'jù',  # 躆
    0x8E87: 'chú',  # 躇
    0x8E88: 'qiào',  # 躈
    0x8E89: 'dǔn',  # 躉
    0x8E8A: 'chóu',  # 躊
    0x8E8B: 'jī',  # 躋
    0x8E8C: 'wǔ',  # 躌
    0x8E8D: 'yuè',  # 躍
    0x8E8E: 'niǎn',  # 躎
    0x8E8F: 'lìn',  # 躏
    0x8E90: 'liè',  # 躐
    0x8E91: 'zhí',  # 躑
    0x8E92: 'lì,luò',  # 躒
    0x8E93: 'zhì',  # 躓
    0x8E94: 'chán',  # 躔
    0x8E95: 'chú',  # 躕
    0x8E96: 'duàn',  # 躖
    0x8E97: 'wèi',  # 躗
    0x8E98: 'lóng,lǒng',  # 躘
    0x8E99: 'lìn',  # 躙
    0x8E9A: 'xiān',  # 躚
    0x8E9B: 'wèi',  # 躛
    0x8E9C: 'zuān',  # 躜
    0x8E9D: 'lán',  # 躝
    0x8E9E: 'xiè',  # 躞
    0x8E9F: 'ráng',  # 躟
    0x8EA0: 'sǎ,xiè',  # 躠
    0x8EA1: 'niè',  # 躡
    0x8EA2: 'tà',  # 躢
    0x8EA3: 'qú',  # 躣
    0x8EA4: 'jí',  # 躤
    0x8EA5: 'cuān',  # 躥
    0x8EA6: 'zuān',  # 躦
    0x8EA7: 'xǐ',  # 躧
    0x8EA8: 'kuí',  # 躨
    0x8EA9: 'jué',  # 躩
    0x8EAA: 'lìn',  # 躪
    0x8EAB: 'shēn',  # 身
    0x8EAC: 'gōng',  # 躬
    0x8EAD: 'dān',  # 躭
    0x8EAE: 'fēn',  # 躮
    0x8EAF: 'qū',  # 躯
    0x8EB0: 'tǐ',  # 躰
    0x8EB1: 'duǒ',  # 躱
    0x8EB2: 'duǒ',  # 躲
    0x8EB3: 'gōng',  # 躳
    0x8EB4: 'láng',  # 躴
    0x8EB5: 'rěn',  # 躵
    0x8EB6: 'luǒ',  # 躶
    0x8EB7: 'ǎi',  # 躷
    0x8EB8: 'jī',  # 躸
    0x8EB9: 'jū',  # 躹
    0x8EBA: 'tǎng',  # 躺
    0x8EBB: 'kōng',  # 躻
    0x8EBC: 'lào',  # 躼
    0x8EBD: 'yǎn',  # 躽
    0x8EBE: 'měi',  # 躾
    0x8EBF: 'kāng',  # 躿
    0x8EC0: 'qū',  # 軀
    0x8EC1: 'lóu',  # 軁
    0x8EC2: 'lào',  # 軂
    0x8EC3: 'duǒ',  # 軃
    0x8EC4: 'zhí',  # 軄
    0x8EC5: 'yàn',  # 軅
    0x8EC6: 'tǐ',  # 軆
    0x8EC7: 'dào',  # 軇
    0x8EC8: 'yīng',  # 軈
    0x8EC9: 'yù',  # 軉
    0x8ECA: 'chē,jū',  # 車
    0x8ECB: 'yà,zhá,gá',  # 軋
    0x8ECC: 'guǐ',  # 軌
    0x8ECD: 'jūn',  # 軍
    0x8ECE: 'wèi',  # 軎
    0x8ECF: 'yuè',  # 軏
    0x8ED0: 'xìn,xiàn',  # 軐
    0x8ED1: 'dài',  # 軑
    0x8ED2: 'xuān',  # 軒
    0x8ED3: 'fàn,guǐ',  # 軓
    0x8ED4: 'rèn',  # 軔
    0x8ED5: 'shān',  # 軕
    0x8ED6: 'kuáng',  # 軖
    0x8ED7: 'shū',  # 軗
    0x8ED8: 'tún',  # 軘
    0x8ED9: 'chén',  # 軙
    0x8EDA: 'dài',  # 軚
    0x8EDB: 'è',  # 軛
    0x8EDC: 'nà',  # 軜
    0x8EDD: 'qí',  # 軝
    0x8EDE: 'máo',  # 軞
    0x8EDF: 'ruǎn',  # 軟
    0x8EE0: 'kuáng',  # 軠
    0x8EE1: 'qián',  # 軡
    0x8EE2: 'zhuàn,zhuǎn',  # 転
    0x8EE3: 'hōng',  # 軣
    0x8EE4: 'hū',  # 軤
    0x8EE5: 'qú',  # 軥
    0x8EE6: 'kuàng',  # 軦
    0x8EE7: 'dǐ',  # 軧
    0x8EE8: 'líng',  # 軨
    0x8EE9: 'dài',  # 軩
    0x8EEA: 'āo,ào',  # 軪
    0x8EEB: 'zhěn',  # 軫
    0x8EEC: 'fàn',  # 軬
    0x8EED: 'kuāng',  # 軭
    0x8EEE: 'yǎng',  # 軮
    0x8EEF: 'pēng',  # 軯
    0x8EF0: 'bèi',  # 軰
    0x8EF1: 'gū',  # 軱
    0x8EF2: 'gū',  # 軲
    0x8EF3: 'páo',  # 軳
    0x8EF4: 'zhù',  # 軴
    0x8EF5: 'rǒng',  # 軵
    0x8EF6: 'è',  # 軶
    0x8EF7: 'bá',  # 軷
    0x8EF8: 'zhóu,zhòu',  # 軸
    0x8EF9: 'zhǐ',  # 軹
    0x8EFA: 'yáo',  # 軺
    0x8EFB: 'kē,kě',  # 軻
    0x8EFC: 'yì,dié',  # 軼
    0x8EFD: 'qīng',  # 軽
    0x8EFE: 'shì',  # 軾
    0x8EFF: 'píng',  # 軿
    0x8F00: 'ér',  # 輀
    0x8F01: 'gǒng',  # 輁
    0x8F02: 'jú',  # 輂
    0x8F03: 'jiào',  # 較
    0x8F04: 'guāng',  # 輄
    0x8F05: 'lù',  # 輅
    0x8F06: 'kǎi',  # 輆
    0x8F07: 'quán',  # 輇
    0x8F08: 'zhōu',  # 輈
    0x8F09: 'zài',  # 載
    0x8F0A: 'zhì',  # 輊
    0x8F0B: 'shē',  # 輋
    0x8F0C: 'liàng',  # 輌
    0x8F0D: 'yù',  # 輍
    0x8F0E: 'shāo',  # 輎
    0x8F0F: 'yóu',  # 輏
    0x8F10: 'wàn',  # 輐
    0x8F11: 'yǐn',  # 輑
    0x8F12: 'zhé',  # 輒
    0x8F13: 'wǎn',  # 輓
    0x8F14: 'fǔ',  # 輔
    0x8F15: 'qīng',  # 輕
    0x8F16: 'zhōu',  # 輖
    0x8F17: 'ní',  # 輗
    0x8F18: 'líng',  # 輘
    0x8F19: 'zhé',  # 輙
    0x8F1A: 'hàn',  # 輚
    0x8F1B: 'liàng',  # 輛
    0x8F1C: 'zī',  # 輜
    0x8F1D: 'huī',  # 輝
    0x8F1E: 'wǎng',  # 輞
    0x8F1F: 'chuò',  # 輟
    0x8F20: 'guǒ',  # 輠
    0x8F21: 'kǎn',  # 輡
    0x8F22: 'yǐ',  # 輢
    0x8F23: 'péng',  # 輣
    0x8F24: 'qiàn',  # 輤
    0x8F25: 'gǔn',  # 輥
    0x8F26: 'niǎn',  # 輦
    0x8F27: 'píng',  # 輧
    0x8F28: 'guǎn',  # 輨
    0x8F29: 'bèi',  # 輩
    0x8F2A: 'lún',  # 輪
    0x8F2B: 'pái',  # 輫
    0x8F2C: 'liáng',  # 輬
    0x8F2D: 'ruǎn',  # 輭
    0x8F2E: 'róu',  # 輮
    0x8F2F: 'jí',  # 輯
    0x8F30: 'yáng',  # 輰
    0x8F31: 'xián',  # 輱
    0x8F32: 'chuán',  # 輲
    0x8F33: 'còu',  # 輳
    0x8F34: 'chūn',  # 輴
    0x8F35: 'gé',  # 輵
    0x8F36: 'yóu',  # 輶
    0x8F37: 'hōng',  # 輷
    0x8F38: 'shū',  # 輸
    0x8F39: 'fù',  # 輹
    0x8F3A: 'zī',  # 輺
    0x8F3B: 'fú',  # 輻
    0x8F3C: 'wēn',  # 輼
    0x8F3D: 'fàn',  # 輽
    0x8F3E: 'zhǎn',  # 輾
    0x8F3F: 'yú',  # 輿
    0x8F40: 'wēn',  # 轀
    0x8F41: 'tāo',  # 轁
    0x8F42: 'gǔ',  # 轂
    0x8F43: 'zhēn',  # 轃
    0x8F44: 'xiá',  # 轄
    0x8F45: 'yuán',  # 轅
    0x8F46: 'lù',  # 轆
    0x8F47: 'jiāo',  # 轇
    0x8F48: 'cháo',  # 轈
    0x8F49: 'zhuǎn',  # 轉
    0x8F4A: 'wèi',  # 轊
    0x8F4B: 'hūn',  # 轋
    0x8F4C: 'xuě',  # 轌
    0x8F4D: 'zhé',  # 轍
    0x8F4E: 'jiào',  # 轎
    0x8F4F: 'zhàn',  # 轏
    0x8F50: 'bú',  # 轐
    0x8F51: 'lǎo',  # 轑
    0x8F52: 'fén',  # 轒
    0x8F53: 'fān',  # 轓
    0x8F54: 'lín',  # 轔
    0x8F55: 'gé',  # 轕
    0x8F56: 'sè',  # 轖
    0x8F57: 'kǎn',  # 轗
    0x8F58: 'huàn',  # 轘
    0x8F59: 'yǐ',  # 轙
    0x8F5A: 'jí',  # 轚
    0x8F5B: 'duì',  # 轛
    0x8F5C: 'ér',  # 轜
    0x8F5D: 'yú',  # 轝
    0x8F5E: 'jiàn',  # 轞
    0x8F5F: 'hōng',  # 轟
    0x8F60: 'léi',  # 轠
    0x8F61: 'pèi',  # 轡
    0x8F62: 'lì',  # 轢
    0x8F63: 'lì',  # 轣
    0x8F64: 'lú',  # 轤
    0x8F65: 'lìn',  # 轥
    0x8F66: 'chē,jū',  # 车
    0x8F67: 'yà',  # 轧
    0x8F68: 'guǐ',  # 轨
    0x8F69: 'xuān',  # 轩
    0x8F6A: 'dài',  # 轪
    0x8F6B: 'rèn',  # 轫
    0x8F6C: 'zhuǎn,zhuàn,zhuǎi',  # 转
    0x8F6D: 'è',  # 轭
    0x8F6E: 'lún',  # 轮
    0x8F6F: 'ruǎn',  # 软
    0x8F70: 'hōng',  # 轰
    0x8F71: 'gū',  # 轱
    0x8F72: 'kē',  # 轲
    0x8F73: 'lú',  # 轳
    0x8F74: 'zhóu,zhòu',  # 轴
    0x8F75: 'zhǐ',  # 轵
    0x8F76: 'yì',  # 轶
    0x8F77: 'hū',  # 轷
    0x8F78: 'zhěn',  # 轸
    0x8F79: 'lì',  # 轹
    0x8F7A: 'yáo',  # 轺
    0x8F7B: 'qīng',  # 轻
    0x8F7C: 'shì',  # 轼
    0x8F7D: 'zǎi,zài',  # 载
    0x8F7E: 'zhì',  # 轾
    0x8F7F: 'jiào',  # 轿
    0x8F80: 'zhōu',  # 辀
    0x8F81: 'quán',  # 辁
    0x8F82: 'lù',  # 辂
    0x8F83: 'jiào',  # 较
    0x8F84: 'zhé',  # 辄
    0x8F85: 'fǔ',  # 辅
    0x8F86: 'liàng',  # 辆
    0x8F87: 'niǎn',  # 辇
    0x8F88: 'bèi',  # 辈
    0x8F89: 'huī',  # 辉
    0x8F8A: 'gǔn',  # 辊
    0x8F8B: 'wǎng',  # 辋
    0x8F8C: 'liáng',  # 辌
    0x8F8D: 'chuò',  # 辍
    0x8F8E: 'zī',  # 辎
    0x8F8F: 'còu',  # 辏
    0x8F90: 'fú',  # 辐
    0x8F91: 'jí',  # 辑
    0x8F92: 'wēn',  # 辒
    0x8F93: 'shū',  # 输
    0x8F94: 'pèi',  # 辔
    0x8F95: 'yuán',  # 辕
    0x8F96: 'xiá',  # 辖
    0x8F97: 'zhǎn,niǎn',  # 辗
    0x8F98: 'lù',  # 辘
    0x8F99: 'zhé',  # 辙
    0x8F9A: 'lín',  # 辚
    0x8F9B: 'xīn',  # 辛
    0x8F9C: 'gū',  # 辜
    0x8F9D: 'cí',  # 辝
    0x8F9E: 'cí',  # 辞
    0x8F9F: 'bì,pì',  # 辟
    0x8FA0: 'zuì',  # 辠
    0x8FA1: 'biàn',  # 辡
    0x8FA2: 'là',  # 辢
    0x8FA3: 'là',  # 辣
    0x8FA4: 'cí',  # 辤
    0x8FA5: 'xuē',  # 辥
    0x8FA6: 'bàn',  # 辦
    0x8FA7: 'biàn',  # 辧
    0x8FA8: 'biàn',  # 辨
    0x8FA9: 'biàn',  # 辩
    0x8FAA: 'xuē',  # 辪
    0x8FAB: 'biàn',  # 辫
    0x8FAC: 'bān',  # 辬
    0x8FAD: 'cí',  # 辭
    0x8FAE: 'biàn',  # 辮
    0x8FAF: 'biàn',  # 辯
    0x8FB0: 'chén',  # 辰
    0x8FB1: 'rǔ',  # 辱
    0x8FB2: 'nóng',  # 農
    0x8FB3: 'nóng',  # 辳
    0x8FB4: 'zhěn',  # 辴
    0x8FB5: 'chuò',  # 辵
    0x8FB6: 'chuò',  # 辶
    0x8FB7: 'yī',  # 辷
    0x8FB8: 'réng',  # 辸
    0x8FB9: 'biān',  # 边
    0x8FBA: 'dào,biān',  # 辺
    0x8FBB: 'shi',  # 辻
    0x8FBC: 'yū',  # 込
    0x8FBD: 'liáo',  # 辽
    0x8FBE: 'dá',  # 达
    0x8FBF: 'chān',  # 辿
    0x8FC0: 'gān',  # 迀
    0x8FC1: 'qiān',  # 迁
    0x8FC2: 'yū',  # 迂
    0x8FC3: 'yū',  # 迃
    0x8FC4: 'qì',  # 迄
    0x8FC5: 'xùn',  # 迅
    0x8FC6: 'yǐ,yí',  # 迆
    0x8FC7: 'guò,guo,guō',  # 过
    0x8FC8: 'mài',  # 迈
    0x8FC9: 'qī',  # 迉
    0x8FCA: 'zā',  # 迊
    0x8FCB: 'wàng,kuāng',  # 迋
    0x8FCC: 'tù',  # 迌
    0x8FCD: 'zhūn',  # 迍
    0x8FCE: 'yíng',  # 迎
    0x8FCF: 'dá',  # 迏
    0x8FD0: 'yùn',  # 运
    0x8FD1: 'jìn',  # 近
    0x8FD2: 'háng',  # 迒
    0x8FD3: 'yà',  # 迓
    0x8FD4: 'fǎn',  # 返
    0x8FD5: 'wǔ',  # 迕
    0x8FD6: 'dá',  # 迖
    0x8FD7: 'é',  # 迗
    0x8FD8: 'huán,hái',  # 还
    0x8FD9: 'zhè,zhèi',  # 这
    0x8FDA: 'dá',  # 迚
    0x8FDB: 'jìn',  # 进
    0x8FDC: 'yuǎn,yuàn',  # 远
    0x8FDD: 'wéi',  # 违
    0x8FDE: 'lián',  # 连
    0x8FDF: 'chí',  # 迟
    0x8FE0: 'chè',  # 迠
    0x8FE1: 'chí',  # 迡
    0x8FE2: 'tiáo',  # 迢
    0x8FE3: 'zhì,lì',  # 迣
    0x8FE4: 'yǐ,yí',  # 迤
    0x8FE5: 'jiǒng',  # 迥
    0x8FE6: 'jiā',  # 迦
    0x8FE7: 'chén',  # 迧
    0x8FE8: 'dài',  # 迨
    0x8FE9: 'ěr',  # 迩
    0x8FEA: 'dí',  # 迪
    0x8FEB: 'pò,pǎi',  # 迫
    0x8FEC: 'zhù,wǎng',  # 迬
    0x8FED: 'dié',  # 迭
    0x8FEE: 'zé',  # 迮
    0x8FEF: 'táo',  # 迯
    0x8FF0: 'shù',  # 述
    0x8FF1: 'yǐ,yí',  # 迱
    0x8FF2: 'keop',  # 迲
    0x8FF3: 'jìng',  # 迳
    0x8FF4: 'huí',  # 迴
    0x8FF5: 'dòng',  # 迵
    0x8FF6: 'yòu',  # 迶
    0x8FF7: 'mí',  # 迷
    0x8FF8: 'bèng',  # 迸
    0x8FF9: 'jì',  # 迹
    0x8FFA: 'nǎi',  # 迺
    0x8FFB: 'yí',  # 迻
    0x8FFC: 'jié',  # 迼
    0x8FFD: 'zhuī,duī',  # 追
    0x8FFE: 'liè',  # 迾
    0x8FFF: 'xùn',  # 迿
    0x9000: 'tuì',  # 退
    0x9001: 'sòng',  # 送
    0x9002: 'shì',  # 适
    0x9003: 'táo',  # 逃
    0x9004: 'páng',  # 逄
    0x9005: 'hòu',  # 逅
    0x9006: 'nì',  # 逆
    0x9007: 'dùn',  # 逇
    0x9008: 'jiǒng',  # 逈
    0x9009: 'xuǎn',  # 选
    0x900A: 'xùn',  # 逊
    0x900B: 'bū',  # 逋
    0x900C: 'yōu',  # 逌
    0x900D: 'xiāo',  # 逍
    0x900E: 'qiú',  # 逎
    0x900F: 'tòu',  # 透
    0x9010: 'zhú',  # 逐
    0x9011: 'qiú',  # 逑
    0x9012: 'dì',  # 递
    0x9013: 'dì',  # 逓
    0x9014: 'tú',  # 途
    0x9015: 'jìng',  # 逕
    0x9016: 'tì',  # 逖
    0x9017: 'dòu',  # 逗
    0x9018: 'yǐ',  # 逘
    0x9019: 'zhè',  # 這
    0x901A: 'tōng',  # 通
    0x901B: 'guàng',  # 逛
    0x901C: 'wǔ',  # 逜
    0x901D: 'shì',  # 逝
    0x901E: 'chěng',  # 逞
    0x901F: 'sù',  # 速
    0x9020: 'zào',  # 造
    0x9021: 'qūn',  # 逡
    0x9022: 'féng',  # 逢
    0x9023: 'lián',  # 連
    0x9024: 'suò',  # 逤
    0x9025: 'huí',  # 逥
    0x9026: 'lǐ',  # 逦
    0x9027: 'gǔ',  # 逧
    0x9028: 'lái',  # 逨
    0x9029: 'bèn',  # 逩
    0x902A: 'cuò',  # 逪
    0x902B: 'zhú',  # 逫
    0x902C: 'bèng',  # 逬
    0x902D: 'huàn',  # 逭
    0x902E: 'dài',  # 逮
    0x902F: 'lù',  # 逯
    0x9030: 'yóu',  # 逰
    0x9031: 'zhōu',  # 週
    0x9032: 'jìn',  # 進
    0x9033: 'yù',  # 逳
    0x9034: 'chuō',  # 逴
    0x9035: 'kuí',  # 逵
    0x9036: 'wēi',  # 逶
    0x9037: 'tì',  # 逷
    0x9038: 'yì',  # 逸
    0x9039: 'dá',  # 逹
    0x903A: 'yuǎn',  # 逺
    0x903B: 'luó',  # 逻
    0x903C: 'bī',  # 逼
    0x903D: 'nuò',  # 逽
    0x903E: 'yú',  # 逾
    0x903F: 'dàng',  # 逿
    0x9040: 'suí',  # 遀
    0x9041: 'dùn',  # 遁
    0x9042: 'suì',  # 遂
    0x9043: 'yǎn',  # 遃
    0x9044: 'chuán',  # 遄
    0x9045: 'chí',  # 遅
    0x9046: 'dì,tí',  # 遆
    0x9047: 'yù',  # 遇
    0x9048: 'shí',  # 遈
    0x9049: 'zhēn',  # 遉
    0x904A: 'yóu',  # 遊
    0x904B: 'yùn',  # 運
    0x904C: 'è',  # 遌
    0x904D: 'biàn',  # 遍
    0x904E: 'guò',  # 過
    0x904F: 'è',  # 遏
    0x9050: 'xiá',  # 遐
    0x9051: 'huáng',  # 遑
    0x9052: 'qiú',  # 遒
    0x9053: 'dào',  # 道
    0x9054: 'dá',  # 達
    0x9055: 'wéi',  # 違
    0x9056: 'nán',  # 遖
    0x9057: 'yí',  # 遗
    0x9058: 'gòu',  # 遘
    0x9059: 'yáo',  # 遙
    0x905A: 'chòu',  # 遚
    0x905B: 'liù',  # 遛
    0x905C: 'xùn',  # 遜
    0x905D: 'tà',  # 遝
    0x905E: 'dì',  # 遞
    0x905F: 'chí',  # 遟
    0x9060: 'yuǎn',  # 遠
    0x9061: 'sù',  # 遡
    0x9062: 'tà',  # 遢
    0x9063: 'qiǎn',  # 遣
    0x9064: 'mǎ',  # 遤
    0x9065: 'yáo',  # 遥
    0x9066: 'guàn',  # 遦
    0x9067: 'zhāng',  # 遧
    0x9068: 'áo',  # 遨
    0x9069: 'shì',  # 適
    0x906A: 'cà',  # 遪
    0x906B: 'chì',  # 遫
    0x906C: 'sù',  # 遬
    0x906D: 'zāo',  # 遭
    0x906E: 'zhē',  # 遮
    0x906F: 'dùn',  # 遯
    0x9070: 'dì',  # 遰
    0x9071: 'lóu',  # 遱
    0x9072: 'chí',  # 遲
    0x9073: 'cuō',  # 遳
    0x9074: 'lín',  # 遴
    0x9075: 'zūn',  # 遵
    0x9076: 'rào',  # 遶
    0x9077: 'qiān',  # 遷
    0x9078: 'xuǎn',  # 選
    0x9079: 'yù',  # 遹
    0x907A: 'yí',  # 遺
    0x907B: 'è',  # 遻
    0x907C: 'liáo',  # 遼
    0x907D: 'jù',  # 遽
    0x907E: 'shì',  # 遾
    0x907F: 'bì',  # 避
    0x9080: 'yāo',  # 邀
    0x9081: 'mài',  # 邁
    0x9082: 'xiè',  # 邂
    0x9083: 'suì',  # 邃
    0x9084: 'huán,hái',  # 還
    0x9085: 'zhān',  # 邅
    0x9086: 'téng',  # 邆
    0x9087: 'ěr',  # 邇
    0x9088: 'miǎo',  # 邈
    0x9089: 'biān',  # 邉
    0x908A: 'biān',  # 邊
    0x908B: 'lā',  # 邋
    0x908C: 'lí,chí',  # 邌
    0x908D: 'yuán',  # 邍
    0x908E: 'yáo',  # 邎
    0x908F: 'luó',  # 邏
    0x9090: 'lǐ',  # 邐
    0x9091: 'yì',  # 邑
    0x9092: 'tíng',  # 邒
    0x9093: 'dèng',  # 邓
    0x9094: 'qǐ',  # 邔
    0x9095: 'yōng',  # 邕
    0x9096: 'shān',  # 邖
    0x9097: 'hán',  # 邗
    0x9098: 'yú',  # 邘
    0x9099: 'máng',  # 邙
    0x909A: 'rú',  # 邚
    0x909B: 'qióng',  # 邛
    0x909C: 'xī',  # 邜
    0x909D: 'kuàng',  # 邝
    0x909E: 'fū',  # 邞
    0x909F: 'kàng,háng',  # 邟
    0x90A0: 'bīn',  # 邠
    0x90A1: 'fāng',  # 邡
    0x90A2: 'xíng',  # 邢
    0x90A3: 'nà,nǎ,nèi,nā',  # 那
    0x90A4: 'xīn',  # 邤
    0x90A5: 'shěn',  # 邥
    0x90A6: 'bāng',  # 邦
    0x90A7: 'yuán',  # 邧
    0x90A8: 'cūn',  # 邨
    0x90A9: 'huǒ',  # 邩
    0x90AA: 'xié,yá,yé,yú,xú',  # 邪
    0x90AB: 'bāng',  # 邫
    0x90AC: 'wū',  # 邬
    0x90AD: 'jù',  # 邭
    0x90AE: 'yóu',  # 邮
    0x90AF: 'hán',  # 邯
    0x90B0: 'tái',  # 邰
    0x90B1: 'qiū',  # 邱
    0x90B2: 'bì',  # 邲
    0x90B3: 'pī',  # 邳
    0x90B4: 'bǐng',  # 邴
    0x90B5: 'shào',  # 邵
    0x90B6: 'bèi',  # 邶
    0x90B7: 'wǎ',  # 邷
    0x90B8: 'dǐ',  # 邸
    0x90B9: 'zōu',  # 邹
    0x90BA: 'yè',  # 邺
    0x90BB: 'lín',  # 邻
    0x90BC: 'kuāng',  # 邼
    0x90BD: 'guī',  # 邽
    0x90BE: 'zhū',  # 邾
    0x90BF: 'shī',  # 邿
    0x90C0: 'kū',  # 郀
    0x90C1: 'yù',  # 郁
    0x90C2: 'gāi,hái',  # 郂
    0x90C3: 'hé',  # 郃
    0x90C4: 'qiè,xì',  # 郄
    0x90C5: 'zhì',  # 郅
    0x90C6: 'jí',  # 郆
    0x90C7: 'xún,huán',  # 郇
    0x90C8: 'hòu',  # 郈
    0x90C9: 'xíng',  # 郉
    0x90CA: 'jiāo',  # 郊
    0x90CB: 'xí',  # 郋
    0x90CC: 'guī',  # 郌
    0x90CD: 'nà',  # 郍
    0x90CE: 'láng,làng',  # 郎
    0x90CF: 'jiá',  # 郏
    0x90D0: 'kuài',  # 郐
    0x90D1: 'zhèng',  # 郑
    0x90D2: 'láng',  # 郒
    0x90D3: 'yùn',  # 郓
    0x90D4: 'yán',  # 郔
    0x90D5: 'chéng',  # 郕
    0x90D6: 'dòu',  # 郖
    0x90D7: 'xī',  # 郗
    0x90D8: 'lǚ',  # 郘
    0x90D9: 'fǔ',  # 郙
    0x90DA: 'wú',  # 郚
    0x90DB: 'fú',  # 郛
    0x90DC: 'gào',  # 郜
    0x90DD: 'hǎo',  # 郝
    0x90DE: 'láng',  # 郞
    0x90DF: 'jiá',  # 郟
    0x90E0: 'gěng',  # 郠
    0x90E1: 'jùn',  # 郡
    0x90E2: 'yǐng',  # 郢
    0x90E3: 'bó',  # 郣
    0x90E4: 'xì',  # 郤
    0x90E5: 'bèi',  # 郥
    0x90E6: 'lì,zhí',  # 郦
    0x90E7: 'yún',  # 郧
    0x90E8: 'bù',  # 部
    0x90E9: 'xiáo,ǎo',  # 郩
    0x90EA: 'qī',  # 郪
    0x90EB: 'pí',  # 郫
    0x90EC: 'qīng',  # 郬
    0x90ED: 'guō',  # 郭
    0x90EE: 'zhōu',  # 郮
    0x90EF: 'tán',  # 郯
    0x90F0: 'zōu',  # 郰
    0x90F1: 'píng',  # 郱
    0x90F2: 'lái',  # 郲
    0x90F3: 'ní',  # 郳
    0x90F4: 'chēn',  # 郴
    0x90F5: 'yóu',  # 郵
    0x90F6: 'bù',  # 郶
    0x90F7: 'xiāng',  # 郷
    0x90F8: 'dān',  # 郸
    0x90F9: 'jú',  # 郹
    0x90FA: 'yōng',  # 郺
    0x90FB: 'qiāo',  # 郻
    0x90FC: 'yī',  # 郼
    0x90FD: 'dū,dōu',  # 都
    0x90FE: 'yǎn',  # 郾
    0x90FF: 'méi',  # 郿
    0x9100: 'ruò',  # 鄀
    0x9101: 'bèi',  # 鄁
    0x9102: 'è',  # 鄂
    0x9103: 'shū',  # 鄃
    0x9104: 'juàn',  # 鄄
    0x9105: 'yǔ',  # 鄅
    0x9106: 'yùn',  # 鄆
    0x9107: 'hóu',  # 鄇
    0x9108: 'kuí',  # 鄈
    0x9109: 'xiāng',  # 鄉
    0x910A: 'xiāng',  # 鄊
    0x910B: 'sōu',  # 鄋
    0x910C: 'táng',  # 鄌
    0x910D: 'míng',  # 鄍
    0x910E: 'xī',  # 鄎
    0x910F: 'rǔ',  # 鄏
    0x9110: 'chù',  # 鄐
    0x9111: 'zī',  # 鄑
    0x9112: 'zōu',  # 鄒
    0x9113: 'yì',  # 鄓
    0x9114: 'wū',  # 鄔
    0x9115: 'xiāng',  # 鄕
    0x9116: 'yún',  # 鄖
    0x9117: 'hào',  # 鄗
    0x9118: 'yōng',  # 鄘
    0x9119: 'bǐ',  # 鄙
    0x911A: 'mào',  # 鄚
    0x911B: 'cháo',  # 鄛
    0x911C: 'fū',  # 鄜
    0x911D: 'liǎo',  # 鄝
    0x911E: 'yín',  # 鄞
    0x911F: 'zhuān',  # 鄟
    0x9120: 'hù',  # 鄠
    0x9121: 'qiāo',  # 鄡
    0x9122: 'yān',  # 鄢
    0x9123: 'zhāng',  # 鄣
    0x9124: 'màn',  # 鄤
    0x9125: 'qiāo',  # 鄥
    0x9126: 'xǔ',  # 鄦
    0x9127: 'dèng',  # 鄧
    0x9128: 'bì',  # 鄨
    0x9129: 'xún',  # 鄩
    0x912A: 'bì',  # 鄪
    0x912B: 'zēng',  # 鄫
    0x912C: 'wéi',  # 鄬
    0x912D: 'zhèng',  # 鄭
    0x912E: 'mào',  # 鄮
    0x912F: 'shàn',  # 鄯
    0x9130: 'lín',  # 鄰
    0x9131: 'pó',  # 鄱
    0x9132: 'dān',  # 鄲
    0x9133: 'méng',  # 鄳
    0x9134: 'yè',  # 鄴
    0x9135: 'cào',  # 鄵
    0x9136: 'kuài',  # 鄶
    0x9137: 'fēng',  # 鄷
    0x9138: 'méng',  # 鄸
    0x9139: 'zōu',  # 鄹
    0x913A: 'kuàng',  # 鄺
    0x913B: 'liǎn',  # 鄻
    0x913C: 'zàn',  # 鄼
    0x913D: 'chán',  # 鄽
    0x913E: 'yōu',  # 鄾
    0x913F: 'qí',  # 鄿
    0x9140: 'yàn',  # 酀
    0x9141: 'chán',  # 酁
    0x9142: 'cuó,zàn',  # 酂
    0x9143: 'líng',  # 酃
    0x9144: 'huān',  # 酄
    0x9145: 'xī',  # 酅
    0x9146: 'fēng',  # 酆
    0x9147: 'cuó,zàn',  # 酇
    0x9148: 'lì',  # 酈
    0x9149: 'yǒu',  # 酉
    0x914A: 'dīng,dǐng',  # 酊
    0x914B: 'qiú',  # 酋
    0x914C: 'zhuó',  # 酌
    0x914D: 'pèi',  # 配
    0x914E: 'zhòu',  # 酎
    0x914F: 'yǐ',  # 酏
    0x9150: 'gān',  # 酐
    0x9151: 'yú',  # 酑
    0x9152: 'jiǔ',  # 酒
    0x9153: 'yǎn',  # 酓
    0x9154: 'zuì',  # 酔
    0x9155: 'máo',  # 酕
    0x9156: 'dān',  # 酖
    0x9157: 'xù',  # 酗
    0x9158: 'dòu',  # 酘
    0x9159: 'zhēn',  # 酙
    0x915A: 'fēn',  # 酚
    0x915B: 'yuán',  # 酛
    0x915C: 'fū',  # 酜
    0x915D: 'yùn',  # 酝
    0x915E: 'tài',  # 酞
    0x915F: 'tiān',  # 酟
    0x9160: 'qiǎ',  # 酠
    0x9161: 'tuó',  # 酡
    0x9162: 'zuò',  # 酢
    0x9163: 'hān',  # 酣
    0x9164: 'gū',  # 酤
    0x9165: 'sū',  # 酥
    0x9166: 'pō',  # 酦
    0x9167: 'chóu',  # 酧
    0x9168: 'zài',  # 酨
    0x9169: 'mǐng',  # 酩
    0x916A: 'lào',  # 酪
    0x916B: 'chuò',  # 酫
    0x916C: 'chóu',  # 酬
    0x916D: 'yòu',  # 酭
    0x916E: 'tóng',  # 酮
    0x916F: 'zhǐ',  # 酯
    0x9170: 'xiān',  # 酰
    0x9171: 'jiàng',  # 酱
    0x9172: 'chéng',  # 酲
    0x9173: 'yìn',  # 酳
    0x9174: 'tú',  # 酴
    0x9175: 'jiào',  # 酵
    0x9176: 'méi',  # 酶
    0x9177: 'kù',  # 酷
    0x9178: 'suān',  # 酸
    0x9179: 'lèi',  # 酹
    0x917A: 'pú',  # 酺
    0x917B: 'zuì',  # 酻
    0x917C: 'hǎi',  # 酼
    0x917D: 'yàn',  # 酽
    0x917E: 'shī',  # 酾
    0x917F: 'niàng',  # 酿
    0x9180: 'wéi',  # 醀
    0x9181: 'lù',  # 醁
    0x9182: 'lǎn',  # 醂
    0x9183: 'yān',  # 醃
    0x9184: 'táo',  # 醄
    0x9185: 'pēi',  # 醅
    0x9186: 'zhǎn',  # 醆
    0x9187: 'chún',  # 醇
    0x9188: 'tán,dàn',  # 醈
    0x9189: 'zuì',  # 醉
    0x918A: 'zhuì',  # 醊
    0x918B: 'cù',  # 醋
    0x918C: 'kūn',  # 醌
    0x918D: 'tí,tǐ',  # 醍
    0x918E: 'xián',  # 醎
    0x918F: 'dū',  # 醏
    0x9190: 'hú',  # 醐
    0x9191: 'xǔ',  # 醑
    0x9192: 'xǐng',  # 醒
    0x9193: 'tǎn',  # 醓
    0x9194: 'qiú,chōu',  # 醔
    0x9195: 'chún',  # 醕
    0x9196: 'yùn',  # 醖
    0x9197: 'pō,fā',  # 醗
    0x9198: 'kē',  # 醘
    0x9199: 'sōu',  # 醙
    0x919A: 'mí',  # 醚
    0x919B: 'quán',  # 醛
    0x919C: 'chǒu',  # 醜
    0x919D: 'cuō',  # 醝
    0x919E: 'yùn',  # 醞
    0x919F: 'yòng',  # 醟
    0x91A0: 'àng',  # 醠
    0x91A1: 'zhà',  # 醡
    0x91A2: 'hǎi',  # 醢
    0x91A3: 'táng',  # 醣
    0x91A4: 'jiàng',  # 醤
    0x91A5: 'piǎo',  # 醥
    0x91A6: 'chǎn,chěn',  # 醦
    0x91A7: 'yù',  # 醧
    0x91A8: 'lí',  # 醨
    0x91A9: 'zāo',  # 醩
    0x91AA: 'láo',  # 醪
    0x91AB: 'yī',  # 醫
    0x91AC: 'jiàng',  # 醬
    0x91AD: 'bú',  # 醭
    0x91AE: 'jiào',  # 醮
    0x91AF: 'xī',  # 醯
    0x91B0: 'tán',  # 醰
    0x91B1: 'pō,fā',  # 醱
    0x91B2: 'nóng',  # 醲
    0x91B3: 'yì,shì',  # 醳
    0x91B4: 'lǐ',  # 醴
    0x91B5: 'jù',  # 醵
    0x91B6: 'yàn,liǎn,xiān',  # 醶
    0x91B7: 'yì',  # 醷
    0x91B8: 'niàng',  # 醸
    0x91B9: 'rú',  # 醹
    0x91BA: 'xūn',  # 醺
    0x91BB: 'chóu',  # 醻
    0x91BC: 'yàn',  # 醼
    0x91BD: 'líng',  # 醽
    0x91BE: 'mí',  # 醾
    0x91BF: 'mí',  # 醿
    0x91C0: 'niàng,niáng',  # 釀
    0x91C1: 'xìn',  # 釁
    0x91C2: 'jiào',  # 釂
    0x91C3: 'shī',  # 釃
    0x91C4: 'mí',  # 釄
    0x91C5: 'yàn',  # 釅
    0x91C6: 'biàn',  # 釆
    0x91C7: 'cǎi,cài',  # 采
    0x91C8: 'shì',  # 釈
    0x91C9: 'yòu',  # 釉
    0x91CA: 'shì',  # 释
    0x91CB: 'shì',  # 釋
    0x91CC: 'lǐ',  # 里
    0x91CD: 'zhòng,chóng',  # 重
    0x91CE: 'yě',  # 野
    0x91CF: 'liáng,liàng',  # 量
    0x91D0: 'lí,xǐ,xī',  # 釐
    0x91D1: 'jīn',  # 金
    0x91D2: 'jīn',  # 釒
    0x91D3: 'gá',  # 釓
    0x91D4: 'yǐ',  # 釔
    0x91D5: 'liǎo,liào',  # 釕
    0x91D6: 'dāo',  # 釖
    0x91D7: 'zhāo',  # 釗
    0x91D8: 'dīng,dìng',  # 釘
    0x91D9: 'pō',  # 釙
    0x91DA: 'qiú',  # 釚
    0x91DB: 'hé',  # 釛
    0x91DC: 'fǔ',  # 釜
    0x91DD: 'zhēn',  # 針
    0x91DE: 'zhí',  # 釞
    0x91DF: 'bā',  # 釟
    0x91E0: 'luàn',  # 釠
    0x91E1: 'fǔ',  # 釡
    0x91E2: 'nǎi',  # 釢
    0x91E3: 'diào',  # 釣
    0x91E4: 'shān,shàn',  # 釤
    0x91E5: 'qiǎo,jiǎo',  # 釥
    0x91E6: 'kòu',  # 釦
    0x91E7: 'chuàn',  # 釧
    0x91E8: 'zǐ',  # 釨
    0x91E9: 'fán',  # 釩
    0x91EA: 'huá,yú',  # 釪
    0x91EB: 'huá,wū',  # 釫
    0x91EC: 'hàn',  # 釬
    0x91ED: 'gāng',  # 釭
    0x91EE: 'qí',  # 釮
    0x91EF: 'máng',  # 釯
    0x91F0: 'rì,rèn,jiàn',  # 釰
    0x91F1: 'dì,dài',  # 釱
    0x91F2: 'sì',  # 釲
    0x91F3: 'xì',  # 釳
    0x91F4: 'yì',  # 釴
    0x91F5: 'chāi',  # 釵
    0x91F6: 'shī,yí',  # 釶
    0x91F7: 'tǔ',  # 釷
    0x91F8: 'xī',  # 釸
    0x91F9: 'nǚ',  # 釹
    0x91FA: 'qiān',  # 釺
    0x91FB: 'qiú',  # 釻
    0x91FC: 'rì,rèn,jiàn',  # 釼
    0x91FD: 'pī,zhāo',  # 釽
    0x91FE: 'yé,yá',  # 釾
    0x91FF: 'jīn',  # 釿
    0x9200: 'bǎ',  # 鈀
    0x9201: 'fāng',  # 鈁
    0x9202: 'chén',  # 鈂
    0x9203: 'xíng',  # 鈃
    0x9204: 'dǒu',  # 鈄
    0x9205: 'yuè',  # 鈅
    0x9206: 'qiān',  # 鈆
    0x9207: 'fū',  # 鈇
    0x9208: 'bù',  # 鈈
    0x9209: 'nà',  # 鈉
    0x920A: 'xīn',  # 鈊
    0x920B: 'é',  # 鈋
    0x920C: 'jué',  # 鈌
    0x920D: 'dùn',  # 鈍
    0x920E: 'gōu',  # 鈎
    0x920F: 'yǐn',  # 鈏
    0x9210: 'qián',  # 鈐
    0x9211: 'bǎn',  # 鈑
    0x9212: 'sà',  # 鈒
    0x9213: 'rèn',  # 鈓
    0x9214: 'chāo',  # 鈔
    0x9215: 'niǔ',  # 鈕
    0x9216: 'fēn',  # 鈖
    0x9217: 'yǔn',  # 鈗
    0x9218: 'yǐ',  # 鈘
    0x9219: 'qín',  # 鈙
    0x921A: 'pī',  # 鈚
    0x921B: 'guō',  # 鈛
    0x921C: 'hóng',  # 鈜
    0x921D: 'yín',  # 鈝
    0x921E: 'jūn',  # 鈞
    0x921F: 'diào',  # 鈟
    0x9220: 'yì',  # 鈠
    0x9221: 'zhōng',  # 鈡
    0x9222: 'xǐ',  # 鈢
    0x9223: 'gài',  # 鈣
    0x9224: 'rì',  # 鈤
    0x9225: 'huǒ',  # 鈥
    0x9226: 'tài',  # 鈦
    0x9227: 'kàng',  # 鈧
    0x9228: 'yuán',  # 鈨
    0x9229: 'lú',  # 鈩
    0x922A: 'è',  # 鈪
    0x922B: 'qín',  # 鈫
    0x922C: 'duó',  # 鈬
    0x922D: 'zī',  # 鈭
    0x922E: 'ní',  # 鈮
    0x922F: 'tú',  # 鈯
    0x9230: 'shì',  # 鈰
    0x9231: 'mín',  # 鈱
    0x9232: 'gū',  # 鈲
    0x9233: 'kē',  # 鈳
    0x9234: 'líng',  # 鈴
    0x9235: 'bǐng',  # 鈵
    0x9236: 'sì',  # 鈶
    0x9237: 'gǔ',  # 鈷
    0x9238: 'bó',  # 鈸
    0x9239: 'pí',  # 鈹
    0x923A: 'yù',  # 鈺
    0x923B: 'sì',  # 鈻
    0x923C: 'zuó',  # 鈼
    0x923D: 'bū',  # 鈽
    0x923E: 'yóu',  # 鈾
    0x923F: 'diàn',  # 鈿
    0x9240: 'jiǎ',  # 鉀
    0x9241: 'zhēn',  # 鉁
    0x9242: 'shǐ',  # 鉂
    0x9243: 'shì',  # 鉃
    0x9244: 'tiě',  # 鉄
    0x9245: 'jù',  # 鉅
    0x9246: 'zuān',  # 鉆
    0x9247: 'shī',  # 鉇
    0x9248: 'tā,tuó',  # 鉈
    0x9249: 'xuàn',  # 鉉
    0x924A: 'zhāo',  # 鉊
    0x924B: 'bào,páo',  # 鉋
    0x924C: 'hé',  # 鉌
    0x924D: 'bì',  # 鉍
    0x924E: 'shēng',  # 鉎
    0x924F: 'chú',  # 鉏
    0x9250: 'shí',  # 鉐
    0x9251: 'bó',  # 鉑
    0x9252: 'zhù',  # 鉒
    0x9253: 'chì',  # 鉓
    0x9254: 'zā',  # 鉔
    0x9255: 'pǒ',  # 鉕
    0x9256: 'tóng',  # 鉖
    0x9257: 'qián',  # 鉗
    0x9258: 'fú',  # 鉘
    0x9259: 'zhǎi',  # 鉙
    0x925A: 'mǎo',  # 鉚
    0x925B: 'qiān',  # 鉛
    0x925C: 'fú',  # 鉜
    0x925D: 'lì',  # 鉝
    0x925E: 'yuè',  # 鉞
    0x925F: 'pī',  # 鉟
    0x9260: 'yāng',  # 鉠
    0x9261: 'bàn',  # 鉡
    0x9262: 'bō',  # 鉢
    0x9263: 'jié',  # 鉣
    0x9264: 'gōu',  # 鉤
    0x9265: 'shù',  # 鉥
    0x9266: 'zhēng',  # 鉦
    0x9267: 'mǔ',  # 鉧
    0x9268: 'xǐ',  # 鉨
    0x9269: 'xǐ',  # 鉩
    0x926A: 'dì',  # 鉪
    0x926B: 'jiā',  # 鉫
    0x926C: 'mù',  # 鉬
    0x926D: 'tǎn',  # 鉭
    0x926E: 'shén',  # 鉮
    0x926F: 'yǐ',  # 鉯
    0x9270: 'sī',  # 鉰
    0x9271: 'kuàng',  # 鉱
    0x9272: 'kǎ',  # 鉲
    0x9273: 'běi',  # 鉳
    0x9274: 'jiàn',  # 鉴
    0x9275: 'tóng',  # 鉵
    0x9276: 'xíng',  # 鉶
    0x9277: 'hóng',  # 鉷
    0x9278: 'jiǎo',  # 鉸
    0x9279: 'chǐ',  # 鉹
    0x927A: 'ěr',  # 鉺
    0x927B: 'gè',  # 鉻
    0x927C: 'bǐng,píng',  # 鉼
    0x927D: 'shì',  # 鉽
    0x927E: 'máo',  # 鉾
    0x927F: 'hā,kē',  # 鉿
    0x9280: 'yín',  # 銀
    0x9281: 'jūn',  # 銁
    0x9282: 'zhōu',  # 銂
    0x9283: 'chòng',  # 銃
    0x9284: 'xiǎng,jiōng',  # 銄
    0x9285: 'tóng',  # 銅
    0x9286: 'mò',  # 銆
    0x9287: 'lèi',  # 銇
    0x9288: 'jī',  # 銈
    0x9289: 'yù,sì',  # 銉
    0x928A: 'xù,huì',  # 銊
    0x928B: 'rén,rěn',  # 銋
    0x928C: 'zùn',  # 銌
    0x928D: 'zhì',  # 銍
    0x928E: 'qióng',  # 銎
    0x928F: 'shàn,shuò',  # 銏
    0x9290: 'chì,lì',  # 銐
    0x9291: 'xiǎn,xǐ',  # 銑
    0x9292: 'xíng',  # 銒
    0x9293: 'quán',  # 銓
    0x9294: 'pī',  # 銔
    0x9295: 'tiě',  # 銕
    0x9296: 'zhū',  # 銖
    0x9297: 'hóu,xiàng',  # 銗
    0x9298: 'míng',  # 銘
    0x9299: 'kuǎ',  # 銙
    0x929A: 'diào,tiáo,yáo',  # 銚
    0x929B: 'xiān,kuò,tiǎn,guā',  # 銛
    0x929C: 'xián',  # 銜
    0x929D: 'xiū',  # 銝
    0x929E: 'jūn',  # 銞
    0x929F: 'chā',  # 銟
    0x92A0: 'lǎo',  # 銠
    0x92A1: 'jí',  # 銡
    0x92A2: 'pǐ',  # 銢
    0x92A3: 'rú',  # 銣
    0x92A4: 'mǐ',  # 銤
    0x92A5: 'yī',  # 銥
    0x92A6: 'yīn',  # 銦
    0x92A7: 'guāng',  # 銧
    0x92A8: 'ǎn',  # 銨
    0x92A9: 'diū',  # 銩
    0x92AA: 'yǒu',  # 銪
    0x92AB: 'sè',  # 銫
    0x92AC: 'kào',  # 銬
    0x92AD: 'qián',  # 銭
    0x92AE: 'luán',  # 銮
    0x92AF: 'sī',  # 銯
    0x92B0: 'āi',  # 銰
    0x92B1: 'diào',  # 銱
    0x92B2: 'hàn',  # 銲
    0x92B3: 'ruì',  # 銳
    0x92B4: 'shì,zhì',  # 銴
    0x92B5: 'kēng',  # 銵
    0x92B6: 'qiú',  # 銶
    0x92B7: 'xiāo',  # 銷
    0x92B8: 'zhé,niè',  # 銸
    0x92B9: 'xiù',  # 銹
    0x92BA: 'zàng',  # 銺
    0x92BB: 'tī',  # 銻
    0x92BC: 'cuò',  # 銼
    0x92BD: 'xiān,kuò,tiǎn,guā',  # 銽
    0x92BE: 'hòng,gǒng',  # 銾
    0x92BF: 'zhōng,yōng',  # 銿
    0x92C0: 'tōu,tù,dòu',  # 鋀
    0x92C1: 'lǚ',  # 鋁
    0x92C2: 'méi,méng',  # 鋂
    0x92C3: 'láng',  # 鋃
    0x92C4: 'wàn,jiǎn',  # 鋄
    0x92C5: 'xīn',  # 鋅
    0x92C6: 'yún',  # 鋆
    0x92C7: 'bèi',  # 鋇
    0x92C8: 'wù',  # 鋈
    0x92C9: 'sù',  # 鋉
    0x92CA: 'yù',  # 鋊
    0x92CB: 'chán',  # 鋋
    0x92CC: 'tǐng,dìng',  # 鋌
    0x92CD: 'bó',  # 鋍
    0x92CE: 'hàn',  # 鋎
    0x92CF: 'jiá',  # 鋏
    0x92D0: 'hóng',  # 鋐
    0x92D1: 'juān,jiān,cuān',  # 鋑
    0x92D2: 'fēng',  # 鋒
    0x92D3: 'chān',  # 鋓
    0x92D4: 'wǎn',  # 鋔
    0x92D5: 'zhì',  # 鋕
    0x92D6: 'sī,tuó',  # 鋖
    0x92D7: 'xuān,juān,juàn',  # 鋗
    0x92D8: 'huá,wú,wū',  # 鋘
    0x92D9: 'wú',  # 鋙
    0x92DA: 'tiáo',  # 鋚
    0x92DB: 'kuàng',  # 鋛
    0x92DC: 'zhuó,chuò',  # 鋜
    0x92DD: 'lüè',  # 鋝
    0x92DE: 'xíng,xìng,jīng',  # 鋞
    0x92DF: 'qǐn',  # 鋟
    0x92E0: 'shèn',  # 鋠
    0x92E1: 'hán',  # 鋡
    0x92E2: 'lüè',  # 鋢
    0x92E3: 'yé',  # 鋣
    0x92E4: 'chú',  # 鋤
    0x92E5: 'zèng',  # 鋥
    0x92E6: 'jū,jú',  # 鋦
    0x92E7: 'xiàn',  # 鋧
    0x92E8: 'é',  # 鋨
    0x92E9: 'máng',  # 鋩
    0x92EA: 'pū,pù',  # 鋪
    0x92EB: 'lí',  # 鋫
    0x92EC: 'pàn',  # 鋬
    0x92ED: 'ruì',  # 鋭
    0x92EE: 'chéng',  # 鋮
    0x92EF: 'gào',  # 鋯
    0x92F0: 'lǐ',  # 鋰
    0x92F1: 'tè',  # 鋱
    0x92F2: 'bīng',  # 鋲
    0x92F3: 'zhù',  # 鋳
    0x92F4: 'zhèn',  # 鋴
    0x92F5: 'tū',  # 鋵
    0x92F6: 'liǔ',  # 鋶
    0x92F7: 'zuì,niè',  # 鋷
    0x92F8: 'jù,jū',  # 鋸
    0x92F9: 'chǎng',  # 鋹
    0x92FA: 'yuǎn,yuān,wǎn,wān',  # 鋺
    0x92FB: 'jiān,jiàn',  # 鋻
    0x92FC: 'gāng,gàng',  # 鋼
    0x92FD: 'diào',  # 鋽
    0x92FE: 'táo',  # 鋾
    0x92FF: 'shǎng',  # 鋿
    0x9300: 'lún',  # 錀
    0x9301: 'kè',  # 錁
    0x9302: 'líng',  # 錂
    0x9303: 'pī',  # 錃
    0x9304: 'lù',  # 錄
    0x9305: 'lí',  # 錅
    0x9306: 'qīng',  # 錆
    0x9307: 'péi',  # 錇
    0x9308: 'juǎn',  # 錈
    0x9309: 'mín',  # 錉
    0x930A: 'zuì',  # 錊
    0x930B: 'péng',  # 錋
    0x930C: 'àn',  # 錌
    0x930D: 'pī',  # 錍
    0x930E: 'xiàn',  # 錎
    0x930F: 'yā',  # 錏
    0x9310: 'zhuī',  # 錐
    0x9311: 'lèi',  # 錑
    0x9312: 'ā',  # 錒
    0x9313: 'kōng',  # 錓
    0x9314: 'tà',  # 錔
    0x9315: 'kūn',  # 錕
    0x9316: 'dú',  # 錖
    0x9317: 'nèi',  # 錗
    0x9318: 'chuí',  # 錘
    0x9319: 'zī',  # 錙
    0x931A: 'zhēng',  # 錚
    0x931B: 'bēn',  # 錛
    0x931C: 'niè',  # 錜
    0x931D: 'cóng',  # 錝
    0x931E: 'chún',  # 錞
    0x931F: 'tán',  # 錟
    0x9320: 'dìng',  # 錠
    0x9321: 'qí',  # 錡
    0x9322: 'qián',  # 錢
    0x9323: 'zhuì',  # 錣
    0x9324: 'jī',  # 錤
    0x9325: 'yù',  # 錥
    0x9326: 'jǐn',  # 錦
    0x9327: 'guǎn',  # 錧
    0x9328: 'máo',  # 錨
    0x9329: 'chāng',  # 錩
    0x932A: 'tiǎn',  # 錪
    0x932B: 'xī',  # 錫
    0x932C: 'liàn',  # 錬
    0x932D: 'diāo',  # 錭
    0x932E: 'gù',  # 錮
    0x932F: 'cuò',  # 錯
    0x9330: 'shù',  # 錰
    0x9331: 'zhēn',  # 錱
    0x9332: 'lù',  # 録
    0x9333: 'měng',  # 錳
    0x9334: 'lù',  # 錴
    0x9335: 'huā',  # 錵
    0x9336: 'biǎo',  # 錶
    0x9337: 'gá',  # 錷
    0x9338: 'lái',  # 錸
    0x9339: 'kěn',  # 錹
    0x933A: 'fāng',  # 錺
    0x933B: 'bū',  # 錻
    0x933C: 'nài',  # 錼
    0x933D: 'wàn',  # 錽
    0x933E: 'zàn',  # 錾
    0x933F: 'hǔ',  # 錿
    0x9340: 'dé',  # 鍀
    0x9341: 'xiān',  # 鍁
    0x9342: 'piān',  # 鍂
    0x9343: 'huò',  # 鍃
    0x9344: 'liàng',  # 鍄
    0x9345: 'fǎ',  # 鍅
    0x9346: 'mén',  # 鍆
    0x9347: 'kǎi',  # 鍇
    0x9348: 'yāng',  # 鍈
    0x9349: 'chí',  # 鍉
    0x934A: 'liàn',  # 鍊
    0x934B: 'guō',  # 鍋
    0x934C: 'xiǎn',  # 鍌
    0x934D: 'dù',  # 鍍
    0x934E: 'tú',  # 鍎
    0x934F: 'wéi',  # 鍏
    0x9350: 'zōng',  # 鍐
    0x9351: 'fù',  # 鍑
    0x9352: 'róu',  # 鍒
    0x9353: 'jí',  # 鍓
    0x9354: 'è',  # 鍔
    0x9355: 'jūn',  # 鍕
    0x9356: 'chěn',  # 鍖
    0x9357: 'tí',  # 鍗
    0x9358: 'zhá',  # 鍘
    0x9359: 'hù',  # 鍙
    0x935A: 'yáng',  # 鍚
    0x935B: 'duàn',  # 鍛
    0x935C: 'xiá',  # 鍜
    0x935D: 'yú',  # 鍝
    0x935E: 'kēng',  # 鍞
    0x935F: 'shēng',  # 鍟
    0x9360: 'huáng',  # 鍠
    0x9361: 'wěi',  # 鍡
    0x9362: 'fù',  # 鍢
    0x9363: 'zhāo',  # 鍣
    0x9364: 'chā',  # 鍤
    0x9365: 'qiè',  # 鍥
    0x9366: 'shī',  # 鍦
    0x9367: 'hōng',  # 鍧
    0x9368: 'kuí',  # 鍨
    0x9369: 'nuò',  # 鍩
    0x936A: 'móu',  # 鍪
    0x936B: 'qiāo',  # 鍫
    0x936C: 'qiāo',  # 鍬
    0x936D: 'hóu',  # 鍭
    0x936E: 'tōu',  # 鍮
    0x936F: 'cōng',  # 鍯
    0x9370: 'huán',  # 鍰
    0x9371: 'yè',  # 鍱
    0x9372: 'mín',  # 鍲
    0x9373: 'jiàn',  # 鍳
    0x9374: 'duān',  # 鍴
    0x9375: 'jiàn',  # 鍵
    0x9376: 'sī',  # 鍶
    0x9377: 'kuí',  # 鍷
    0x9378: 'hú',  # 鍸
    0x9379: 'xuān',  # 鍹
    0x937A: 'zhě',  # 鍺
    0x937B: 'jié',  # 鍻
    0x937C: 'zhēn',  # 鍼
    0x937D: 'biān',  # 鍽
    0x937E: 'zhōng',  # 鍾
    0x937F: 'zī',  # 鍿
    0x9380: 'xiū',  # 鎀
    0x9381: 'yé',  # 鎁
    0x9382: 'měi',  # 鎂
    0x9383: 'pài',  # 鎃
    0x9384: 'āi',  # 鎄
    0x9385: 'jiè',  # 鎅
    0x9386: 'qián',  # 鎆
    0x9387: 'méi',  # 鎇
    0x9388: 'cuō,chā',  # 鎈
    0x9389: 'dā,tà',  # 鎉
    0x938A: 'bàng',  # 鎊
    0x938B: 'xiá',  # 鎋
    0x938C: 'lián',  # 鎌
    0x938D: 'suǒ,sè',  # 鎍
    0x938E: 'kài',  # 鎎
    0x938F: 'liú',  # 鎏
    0x9390: 'yáo,zú',  # 鎐
    0x9391: 'yè,tà,gé',  # 鎑
    0x9392: 'nòu',  # 鎒
    0x9393: 'wēng',  # 鎓
    0x9394: 'róng',  # 鎔
    0x9395: 'táng',  # 鎕
    0x9396: 'suǒ',  # 鎖
    0x9397: 'qiāng,chēng',  # 鎗
    0x9398: 'gé,lì',  # 鎘
    0x9399: 'shuò',  # 鎙
    0x939A: 'chuí',  # 鎚
    0x939B: 'bó',  # 鎛
    0x939C: 'pán',  # 鎜
    0x939D: 'dā',  # 鎝
    0x939E: 'bī,bì,pī',  # 鎞
    0x939F: 'sǎng',  # 鎟
    0x93A0: 'gāng',  # 鎠
    0x93A1: 'zī',  # 鎡
    0x93A2: 'wū',  # 鎢
    0x93A3: 'yíng',  # 鎣
    0x93A4: 'huàng',  # 鎤
    0x93A5: 'tiáo',  # 鎥
    0x93A6: 'liú,liù',  # 鎦
    0x93A7: 'kǎi',  # 鎧
    0x93A8: 'sǔn',  # 鎨
    0x93A9: 'shā',  # 鎩
    0x93AA: 'sōu',  # 鎪
    0x93AB: 'wàn,jiǎn',  # 鎫
    0x93AC: 'gǎo,hào',  # 鎬
    0x93AD: 'zhèn',  # 鎭
    0x93AE: 'zhèn',  # 鎮
    0x93AF: 'láng',  # 鎯
    0x93B0: 'yì',  # 鎰
    0x93B1: 'yuán',  # 鎱
    0x93B2: 'tǎng',  # 鎲
    0x93B3: 'niè',  # 鎳
    0x93B4: 'xí',  # 鎴
    0x93B5: 'jiā',  # 鎵
    0x93B6: 'gē',  # 鎶
    0x93B7: 'mǎ',  # 鎷
    0x93B8: 'juān',  # 鎸
    0x93B9: 'sòng',  # 鎹
    0x93BA: 'zǔ',  # 鎺
    0x93BB: 'suǒ',  # 鎻
    0x93BC: 'xià',  # 鎼
    0x93BD: 'fēng',  # 鎽
    0x93BE: 'wēn',  # 鎾
    0x93BF: 'ná',  # 鎿
    0x93C0: 'lǔ',  # 鏀
    0x93C1: 'suǒ',  # 鏁
    0x93C2: 'ōu',  # 鏂
    0x93C3: 'zú,chuò',  # 鏃
    0x93C4: 'tuán',  # 鏄
    0x93C5: 'xiū,xiù',  # 鏅
    0x93C6: 'guàn',  # 鏆
    0x93C7: 'xuàn',  # 鏇
    0x93C8: 'liàn',  # 鏈
    0x93C9: 'shòu,sōu',  # 鏉
    0x93CA: 'ào',  # 鏊
    0x93CB: 'mǎn',  # 鏋
    0x93CC: 'mò',  # 鏌
    0x93CD: 'luó',  # 鏍
    0x93CE: 'bì',  # 鏎
    0x93CF: 'wèi',  # 鏏
    0x93D0: 'liú',  # 鏐
    0x93D1: 'dí,dī',  # 鏑
    0x93D2: 'sǎn,qiāo,càn',  # 鏒
    0x93D3: 'cōng',  # 鏓
    0x93D4: 'yí',  # 鏔
    0x93D5: 'lù,áo',  # 鏕
    0x93D6: 'áo',  # 鏖
    0x93D7: 'kēng',  # 鏗
    0x93D8: 'qiāng',  # 鏘
    0x93D9: 'cuī',  # 鏙
    0x93DA: 'qī',  # 鏚
    0x93DB: 'shǎng',  # 鏛
    0x93DC: 'tāng,táng',  # 鏜
    0x93DD: 'màn',  # 鏝
    0x93DE: 'yōng',  # 鏞
    0x93DF: 'chǎn',  # 鏟
    0x93E0: 'fēng',  # 鏠
    0x93E1: 'jìng',  # 鏡
    0x93E2: 'biāo',  # 鏢
    0x93E3: 'shù',  # 鏣
    0x93E4: 'lòu',  # 鏤
    0x93E5: 'xiù',  # 鏥
    0x93E6: 'cōng',  # 鏦
    0x93E7: 'lóng',  # 鏧
    0x93E8: 'zàn',  # 鏨
    0x93E9: 'jiàn,zàn',  # 鏩
    0x93EA: 'cáo',  # 鏪
    0x93EB: 'lí',  # 鏫
    0x93EC: 'xià',  # 鏬
    0x93ED: 'xī',  # 鏭
    0x93EE: 'kāng',  # 鏮
    0x93EF: 'shuǎng',  # 鏯
    0x93F0: 'bèng',  # 鏰
    0x93F1: 'zhāng',  # 鏱
    0x93F2: 'qiān',  # 鏲
    0x93F3: 'zhēng',  # 鏳
    0x93F4: 'lù',  # 鏴
    0x93F5: 'huá',  # 鏵
    0x93F6: 'jí',  # 鏶
    0x93F7: 'pú',  # 鏷
    0x93F8: 'huì,suì,ruì',  # 鏸
    0x93F9: 'qiǎng,qiāng',  # 鏹
    0x93FA: 'pō',  # 鏺
    0x93FB: 'lín',  # 鏻
    0x93FC: 'sè',  # 鏼
    0x93FD: 'xiù',  # 鏽
    0x93FE: 'sǎn,xiàn,sà',  # 鏾
    0x93FF: 'chēng',  # 鏿
    0x9400: 'guì',  # 鐀
    0x9401: 'sī',  # 鐁
    0x9402: 'liú',  # 鐂
    0x9403: 'náo',  # 鐃
    0x9404: 'huáng',  # 鐄
    0x9405: 'piě',  # 鐅
    0x9406: 'suì',  # 鐆
    0x9407: 'fán',  # 鐇
    0x9408: 'qiáo',  # 鐈
    0x9409: 'quān',  # 鐉
    0x940A: 'xī',  # 鐊
    0x940B: 'tàng',  # 鐋
    0x940C: 'xiàng',  # 鐌
    0x940D: 'jué',  # 鐍
    0x940E: 'jiāo',  # 鐎
    0x940F: 'zūn',  # 鐏
    0x9410: 'liào',  # 鐐
    0x9411: 'qì',  # 鐑
    0x9412: 'láo',  # 鐒
    0x9413: 'duī',  # 鐓
    0x9414: 'xín',  # 鐔
    0x9415: 'zān',  # 鐕
    0x9416: 'jī',  # 鐖
    0x9417: 'jiǎn',  # 鐗
    0x9418: 'zhōng',  # 鐘
    0x9419: 'dèng',  # 鐙
    0x941A: 'yā',  # 鐚
    0x941B: 'yǐng',  # 鐛
    0x941C: 'duī',  # 鐜
    0x941D: 'jué',  # 鐝
    0x941E: 'nòu',  # 鐞
    0x941F: 'zān',  # 鐟
    0x9420: 'pǔ',  # 鐠
    0x9421: 'tiě',  # 鐡
    0x9422: 'fán',  # 鐢
    0x9423: 'chēng',  # 鐣
    0x9424: 'dǐng',  # 鐤
    0x9425: 'shàn',  # 鐥
    0x9426: 'kāi',  # 鐦
    0x9427: 'jiǎn',  # 鐧
    0x9428: 'fèi',  # 鐨
    0x9429: 'suì',  # 鐩
    0x942A: 'lǔ',  # 鐪
    0x942B: 'juān',  # 鐫
    0x942C: 'huì',  # 鐬
    0x942D: 'yù',  # 鐭
    0x942E: 'lián',  # 鐮
    0x942F: 'zhuō',  # 鐯
    0x9430: 'qiāo',  # 鐰
    0x9431: 'jiàn',  # 鐱
    0x9432: 'zhuó',  # 鐲
    0x9433: 'léi',  # 鐳
    0x9434: 'bì',  # 鐴
    0x9435: 'tiě',  # 鐵
    0x9436: 'huán',  # 鐶
    0x9437: 'yè',  # 鐷
    0x9438: 'duó',  # 鐸
    0x9439: 'guò',  # 鐹
    0x943A: 'dāng,chēng',  # 鐺
    0x943B: 'jù',  # 鐻
    0x943C: 'fén',  # 鐼
    0x943D: 'dá',  # 鐽
    0x943E: 'bèi',  # 鐾
    0x943F: 'yì',  # 鐿
    0x9440: 'ài',  # 鑀
    0x9441: 'zōng',  # 鑁
    0x9442: 'xùn',  # 鑂
    0x9443: 'diào',  # 鑃
    0x9444: 'zhù',  # 鑄
    0x9445: 'héng',  # 鑅
    0x9446: 'zhuì',  # 鑆
    0x9447: 'jī',  # 鑇
    0x9448: 'niè',  # 鑈
    0x9449: 'hé',  # 鑉
    0x944A: 'huò',  # 鑊
    0x944B: 'qīng',  # 鑋
    0x944C: 'bīn',  # 鑌
    0x944D: 'yīng',  # 鑍
    0x944E: 'guì',  # 鑎
    0x944F: 'níng',  # 鑏
    0x9450: 'xū',  # 鑐
    0x9451: 'jiàn',  # 鑑
    0x9452: 'jiàn',  # 鑒
    0x9453: 'qiǎn',  # 鑓
    0x9454: 'chǎ',  # 鑔
    0x9455: 'zhì',  # 鑕
    0x9456: 'miè',  # 鑖
    0x9457: 'lí',  # 鑗
    0x9458: 'léi',  # 鑘
    0x9459: 'jī',  # 鑙
    0x945A: 'zuān',  # 鑚
    0x945B: 'kuàng',  # 鑛
    0x945C: 'shǎng',  # 鑜
    0x945D: 'péng',  # 鑝
    0x945E: 'là',  # 鑞
    0x945F: 'dú',  # 鑟
    0x9460: 'shuò',  # 鑠
    0x9461: 'chuò',  # 鑡
    0x9462: 'lǜ',  # 鑢
    0x9463: 'biāo',  # 鑣
    0x9464: 'bào',  # 鑤
    0x9465: 'lǔ',  # 鑥
    0x9466: 'xián',  # 鑦
    0x9467: 'kuān',  # 鑧
    0x9468: 'lóng',  # 鑨
    0x9469: 'è',  # 鑩
    0x946A: 'lú',  # 鑪
    0x946B: 'xīn',  # 鑫
    0x946C: 'jiàn',  # 鑬
    0x946D: 'lán',  # 鑭
    0x946E: 'bó',  # 鑮
    0x946F: 'jiān',  # 鑯
    0x9470: 'yuè',  # 鑰
    0x9471: 'chán',  # 鑱
    0x9472: 'xiāng',  # 鑲
    0x9473: 'jiàn',  # 鑳
    0x9474: 'xī',  # 鑴
    0x9475: 'guàn',  # 鑵
    0x9476: 'cáng',  # 鑶
    0x9477: 'niè',  # 鑷
    0x9478: 'lěi',  # 鑸
    0x9479: 'cuān',  # 鑹
    0x947A: 'qú',  # 鑺
    0x947B: 'pàn',  # 鑻
    0x947C: 'luó',  # 鑼
    0x947D: 'zuān',  # 鑽
    0x947E: 'luán',  # 鑾
    0x947F: 'záo',  # 鑿
    0x9480: 'niè',  # 钀
    0x9481: 'jué',  # 钁
    0x9482: 'tǎng',  # 钂
    0x9483: 'zhú',  # 钃
    0x9484: 'làn',  # 钄
    0x9485: 'jīn',  # 钅
    0x9486: 'gá',  # 钆
    0x9487: 'yǐ',  # 钇
    0x9488: 'zhēn',  # 针
    0x9489: 'dīng,dìng',  # 钉
    0x948A: 'zhāo',  # 钊
    0x948B: 'pō',  # 钋
    0x948C: 'liǎo,liào',  # 钌
    0x948D: 'tǔ',  # 钍
    0x948E: 'qiān',  # 钎
    0x948F: 'chuàn',  # 钏
    0x9490: 'shān,shàn',  # 钐
    0x9491: 'sà,xì',  # 钑
    0x9492: 'fán',  # 钒
    0x9493: 'diào',  # 钓
    0x9494: 'mén',  # 钔
    0x9495: 'nǚ',  # 钕
    0x9496: 'yáng',  # 钖
    0x9497: 'chāi',  # 钗
    0x9498: 'xíng',  # 钘
    0x9499: 'gài',  # 钙
    0x949A: 'bù',  # 钚
    0x949B: 'tài',  # 钛
    0x949C: 'jù',  # 钜
    0x949D: 'dùn',  # 钝
    0x949E: 'chāo',  # 钞
    0x949F: 'zhōng',  # 钟
    0x94A0: 'nà',  # 钠
    0x94A1: 'bèi',  # 钡
    0x94A2: 'gāng,gàng',  # 钢
    0x94A3: 'bǎn',  # 钣
    0x94A4: 'qián',  # 钤
    0x94A5: 'yuè,yào',  # 钥
    0x94A6: 'qīn',  # 钦
    0x94A7: 'jūn',  # 钧
    0x94A8: 'wū',  # 钨
    0x94A9: 'gōu',  # 钩
    0x94AA: 'kàng',  # 钪
    0x94AB: 'fāng',  # 钫
    0x94AC: 'huǒ',  # 钬
    0x94AD: 'dǒu',  # 钭
    0x94AE: 'niǔ',  # 钮
    0x94AF: 'bǎ,pá',  # 钯
    0x94B0: 'yù',  # 钰
    0x94B1: 'qián',  # 钱
    0x94B2: 'zhēng,zhèng',  # 钲
    0x94B3: 'qián',  # 钳
    0x94B4: 'gǔ',  # 钴
    0x94B5: 'bō',  # 钵
    0x94B6: 'kē',  # 钶
    0x94B7: 'pǒ',  # 钷
    0x94B8: 'bū',  # 钸
    0x94B9: 'bó',  # 钹
    0x94BA: 'yuè',  # 钺
    0x94BB: 'zuān,zuàn',  # 钻
    0x94BC: 'mù',  # 钼
    0x94BD: 'tǎn',  # 钽
    0x94BE: 'jiǎ',  # 钾
    0x94BF: 'diàn,tián',  # 钿
    0x94C0: 'yóu',  # 铀
    0x94C1: 'tiě',  # 铁
    0x94C2: 'bó',  # 铂
    0x94C3: 'líng',  # 铃
    0x94C4: 'shuò',  # 铄
    0x94C5: 'qiān,yán',  # 铅
    0x94C6: 'mǎo',  # 铆
    0x94C7: 'bào,páo',  # 铇
    0x94C8: 'shì',  # 铈
    0x94C9: 'xuàn',  # 铉
    0x94CA: 'tā,tuó',  # 铊
    0x94CB: 'bì',  # 铋
    0x94CC: 'ní',  # 铌
    0x94CD: 'pí,pī',  # 铍
    0x94CE: 'duó',  # 铎
    0x94CF: 'xíng',  # 铏
    0x94D0: 'kào',  # 铐
    0x94D1: 'lǎo',  # 铑
    0x94D2: 'ěr',  # 铒
    0x94D3: 'máng',  # 铓
    0x94D4: 'yā,yà',  # 铔
    0x94D5: 'yǒu',  # 铕
    0x94D6: 'chéng',  # 铖
    0x94D7: 'jiá',  # 铗
    0x94D8: 'yé',  # 铘
    0x94D9: 'náo',  # 铙
    0x94DA: 'zhì',  # 铚
    0x94DB: 'dāng,chēng',  # 铛
    0x94DC: 'tóng',  # 铜
    0x94DD: 'lǚ',  # 铝
    0x94DE: 'diào',  # 铞
    0x94DF: 'yīn',  # 铟
    0x94E0: 'kǎi',  # 铠
    0x94E1: 'zhá',  # 铡
    0x94E2: 'zhū',  # 铢
    0x94E3: 'xiǎn,xǐ',  # 铣
    0x94E4: 'tǐng,dìng',  # 铤
    0x94E5: 'diū',  # 铥
    0x94E6: 'xiān,kuò,tiǎn,guā',  # 铦
    0x94E7: 'huá',  # 铧
    0x94E8: 'quán',  # 铨
    0x94E9: 'shā',  # 铩
    0x94EA: 'hā,kē',  # 铪
    0x94EB: 'diào,tiáo,yáo',  # 铫
    0x94EC: 'gè',  # 铬
    0x94ED: 'míng',  # 铭
    0x94EE: 'zhēng',  # 铮
    0x94EF: 'sè',  # 铯
    0x94F0: 'jiǎo',  # 铰
    0x94F1: 'yī',  # 铱
    0x94F2: 'chǎn',  # 铲
    0x94F3: 'chòng',  # 铳
    0x94F4: 'tàng,tāng',  # 铴
    0x94F5: 'ǎn',  # 铵
    0x94F6: 'yín',  # 银
    0x94F7: 'rú',  # 铷
    0x94F8: 'zhù',  # 铸
    0x94F9: 'láo',  # 铹
    0x94FA: 'pū,pù',  # 铺
    0x94FB: 'wú',  # 铻
    0x94FC: 'lái',  # 铼
    0x94FD: 'tè',  # 铽
    0x94FE: 'liàn',  # 链
    0x94FF: 'kēng',  # 铿
    0x9500: 'xiāo',  # 销
    0x9501: 'suǒ',  # 锁
    0x9502: 'lǐ',  # 锂
    0x9503: 'zèng',  # 锃
    0x9504: 'chú',  # 锄
    0x9505: 'guō',  # 锅
    0x9506: 'gào',  # 锆
    0x9507: 'é',  # 锇
    0x9508: 'xiù',  # 锈
    0x9509: 'cuò',  # 锉
    0x950A: 'lüè',  # 锊
    0x950B: 'fēng',  # 锋
    0x950C: 'xīn',  # 锌
    0x950D: 'liǔ',  # 锍
    0x950E: 'kāi',  # 锎
    0x950F: 'jiǎn',  # 锏
    0x9510: 'ruì',  # 锐
    0x9511: 'tī',  # 锑
    0x9512: 'láng',  # 锒
    0x9513: 'qǐn',  # 锓
    0x9514: 'jū',  # 锔
    0x9515: 'ā',  # 锕
    0x9516: 'qiāng',  # 锖
    0x9517: 'zhě',  # 锗
    0x9518: 'nuò',  # 锘
    0x9519: 'cuò',  # 错
    0x951A: 'máo',  # 锚
    0x951B: 'bēn',  # 锛
    0x951C: 'qí',  # 锜
    0x951D: 'dé',  # 锝
    0x951E: 'kè',  # 锞
    0x951F: 'kūn',  # 锟
    0x9520: 'chāng',  # 锠
    0x9521: 'xī',  # 锡
    0x9522: 'gù',  # 锢
    0x9523: 'luó',  # 锣
    0x9524: 'chuí',  # 锤
    0x9525: 'zhuī',  # 锥
    0x9526: 'jǐn',  # 锦
    0x9527: 'zhì',  # 锧
    0x9528: 'xiān',  # 锨
    0x9529: 'juǎn',  # 锩
    0x952A: 'huò',  # 锪
    0x952B: 'péi',  # 锫
    0x952C: 'tán',  # 锬
    0x952D: 'dìng',  # 锭
    0x952E: 'jiàn',  # 键
    0x952F: 'jù',  # 锯
    0x9530: 'měng',  # 锰
    0x9531: 'zī',  # 锱
    0x9532: 'qiè',  # 锲
    0x9533: 'yīng',  # 锳
    0x9534: 'kǎi',  # 锴
    0x9535: 'qiāng',  # 锵
    0x9536: 'sī',  # 锶
    0x9537: 'è',  # 锷
    0x9538: 'chā',  # 锸
    0x9539: 'qiāo',  # 锹
    0x953A: 'zhōng',  # 锺
    0x953B: 'duàn',  # 锻
    0x953C: 'sōu',  # 锼
    0x953D: 'huáng',  # 锽
    0x953E: 'huán',  # 锾
    0x953F: 'āi',  # 锿
    0x9540: 'dù',  # 镀
    0x9541: 'měi',  # 镁
    0x9542: 'lòu',  # 镂
    0x9543: 'zī',  # 镃
    0x9544: 'fèi',  # 镄
    0x9545: 'méi',  # 镅
    0x9546: 'mò',  # 镆
    0x9547: 'zhèn',  # 镇
    0x9548: 'bó',  # 镈
    0x9549: 'gé,lì',  # 镉
    0x954A: 'niè',  # 镊
    0x954B: 'tǎng',  # 镋
    0x954C: 'juān',  # 镌
    0x954D: 'niè',  # 镍
    0x954E: 'ná',  # 镎
    0x954F: 'liú',  # 镏
    0x9550: 'gǎo,hào',  # 镐
    0x9551: 'bàng',  # 镑
    0x9552: 'yì',  # 镒
    0x9553: 'jiā',  # 镓
    0x9554: 'bīn',  # 镔
    0x9555: 'róng',  # 镕
    0x9556: 'biāo',  # 镖
    0x9557: 'tāng',  # 镗
    0x9558: 'màn',  # 镘
    0x9559: 'luó',  # 镙
    0x955A: 'bèng',  # 镚
    0x955B: 'yōng',  # 镛
    0x955C: 'jìng',  # 镜
    0x955D: 'dí',  # 镝
    0x955E: 'zú',  # 镞
    0x955F: 'xuàn',  # 镟
    0x9560: 'liú',  # 镠
    0x9561: 'xín',  # 镡
    0x9562: 'jué',  # 镢
    0x9563: 'liào',  # 镣
    0x9564: 'pú',  # 镤
    0x9565: 'lǔ',  # 镥
    0x9566: 'duī',  # 镦
    0x9567: 'lán',  # 镧
    0x9568: 'pǔ',  # 镨
    0x9569: 'cuān',  # 镩
    0x956A: 'qiǎng',  # 镪
    0x956B: 'dèng',  # 镫
    0x956C: 'huò',  # 镬
    0x956D: 'léi',  # 镭
    0x956E: 'huán',  # 镮
    0x956F: 'zhuó',  # 镯
    0x9570: 'lián',  # 镰
    0x9571: 'yì',  # 镱
    0x9572: 'chǎ',  # 镲
    0x9573: 'biāo',  # 镳
    0x9574: 'là',  # 镴
    0x9575: 'chán',  # 镵
    0x9576: 'xiāng',  # 镶
    0x9577: 'cháng,zhǎng',  # 長
    0x9578: 'cháng',  # 镸
    0x9579: 'jiǔ',  # 镹
    0x957A: 'ǎo',  # 镺
    0x957B: 'dié',  # 镻
    0x957C: 'jié',  # 镼
    0x957D: 'liǎo',  # 镽
    0x957E: 'mí',  # 镾
    0x957F: 'cháng,zhǎng',  # 长
    0x9580: 'mén',  # 門
    0x9581: 'mà',  # 閁
    0x9582: 'shuān',  # 閂
    0x9583: 'shǎn',  # 閃
    0x9584: 'huò,shǎn',  # 閄
    0x9585: 'mén',  # 閅
    0x9586: 'yán',  # 閆
    0x9587: 'bì',  # 閇
    0x9588: 'hàn,bì',  # 閈
    0x9589: 'bì',  # 閉
    0x958A: 'shān',  # 閊
    0x958B: 'kāi',  # 開
    0x958C: 'kāng,kàng',  # 閌
    0x958D: 'bēng',  # 閍
    0x958E: 'hóng',  # 閎
    0x958F: 'rùn',  # 閏
    0x9590: 'sàn',  # 閐
    0x9591: 'xián',  # 閑
    0x9592: 'xián,jiān,jiàn',  # 閒
    0x9593: 'jiān,jiàn',  # 間
    0x9594: 'mǐn',  # 閔
    0x9595: 'xiā,xiǎ',  # 閕
    0x9596: 'shuǐ',  # 閖
    0x9597: 'dòu',  # 閗
    0x9598: 'zhá',  # 閘
    0x9599: 'nào',  # 閙
    0x959A: 'zhān',  # 閚
    0x959B: 'pēng,pèng',  # 閛
    0x959C: 'xiǎ,kě',  # 閜
    0x959D: 'líng',  # 閝
    0x959E: 'biàn,guān',  # 閞
    0x959F: 'bì',  # 閟
    0x95A0: 'rùn',  # 閠
    0x95A1: 'hé',  # 閡
    0x95A2: 'guān',  # 関
    0x95A3: 'gé',  # 閣
    0x95A4: 'hé,gé',  # 閤
    0x95A5: 'fá',  # 閥
    0x95A6: 'chù',  # 閦
    0x95A7: 'hòng,xiàng',  # 閧
    0x95A8: 'guī',  # 閨
    0x95A9: 'mǐn',  # 閩
    0x95AA: 'sē,xī',  # 閪
    0x95AB: 'kǔn',  # 閫
    0x95AC: 'làng',  # 閬
    0x95AD: 'lǘ',  # 閭
    0x95AE: 'tíng,tǐng',  # 閮
    0x95AF: 'shà',  # 閯
    0x95B0: 'jú',  # 閰
    0x95B1: 'yuè',  # 閱
    0x95B2: 'yuè',  # 閲
    0x95B3: 'chǎn',  # 閳
    0x95B4: 'qù',  # 閴
    0x95B5: 'lìn',  # 閵
    0x95B6: 'chāng',  # 閶
    0x95B7: 'shā',  # 閷
    0x95B8: 'kǔn',  # 閸
    0x95B9: 'yān',  # 閹
    0x95BA: 'wén',  # 閺
    0x95BB: 'yán',  # 閻
    0x95BC: 'è,yān',  # 閼
    0x95BD: 'hūn',  # 閽
    0x95BE: 'yù',  # 閾
    0x95BF: 'wén',  # 閿
    0x95C0: 'hòng',  # 闀
    0x95C1: 'bāo',  # 闁
    0x95C2: 'hòng,juǎn,xiàng',  # 闂
    0x95C3: 'qù',  # 闃
    0x95C4: 'yǎo',  # 闄
    0x95C5: 'wén',  # 闅
    0x95C6: 'bǎn,pàn',  # 闆
    0x95C7: 'àn',  # 闇
    0x95C8: 'wéi',  # 闈
    0x95C9: 'yīn',  # 闉
    0x95CA: 'kuò',  # 闊
    0x95CB: 'què',  # 闋
    0x95CC: 'lán',  # 闌
    0x95CD: 'dū,shé',  # 闍
    0x95CE: 'quán',  # 闎
    0x95CF: 'phdeng',  # 闏
    0x95D0: 'tián',  # 闐
    0x95D1: 'niè',  # 闑
    0x95D2: 'tà',  # 闒
    0x95D3: 'kǎi',  # 闓
    0x95D4: 'hé',  # 闔
    0x95D5: 'què,quē',  # 闕
    0x95D6: 'chuǎng',  # 闖
    0x95D7: 'guān',  # 闗
    0x95D8: 'dòu',  # 闘
    0x95D9: 'qǐ',  # 闙
    0x95DA: 'kuī',  # 闚
    0x95DB: 'táng,tāng,chāng',  # 闛
    0x95DC: 'guān',  # 關
    0x95DD: 'piáo',  # 闝
    0x95DE: 'kàn,hǎn',  # 闞
    0x95DF: 'xì,sè,tà',  # 闟
    0x95E0: 'huì',  # 闠
    0x95E1: 'chǎn',  # 闡
    0x95E2: 'pì',  # 闢
    0x95E3: 'dāng,dàng',  # 闣
    0x95E4: 'huán',  # 闤
    0x95E5: 'tà',  # 闥
    0x95E6: 'wén',  # 闦
    0x95E7: 'tā',  # 闧
    0x95E8: 'mén',  # 门
    0x95E9: 'shuān',  # 闩
    0x95EA: 'shǎn',  # 闪
    0x95EB: 'yán',  # 闫
    0x95EC: 'hàn,bì',  # 闬
    0x95ED: 'bì',  # 闭
    0x95EE: 'wèn',  # 问
    0x95EF: 'chuǎng',  # 闯
    0x95F0: 'rùn',  # 闰
    0x95F1: 'wéi',  # 闱
    0x95F2: 'xián',  # 闲
    0x95F3: 'hóng',  # 闳
    0x95F4: 'jiān,jiàn',  # 间
    0x95F5: 'mǐn',  # 闵
    0x95F6: 'kàng,kāng',  # 闶
    0x95F7: 'mèn,mēn',  # 闷
    0x95F8: 'zhá',  # 闸
    0x95F9: 'nào',  # 闹
    0x95FA: 'guī',  # 闺
    0x95FB: 'wén',  # 闻
    0x95FC: 'tà',  # 闼
    0x95FD: 'mǐn',  # 闽
    0x95FE: 'lǘ',  # 闾
    0x95FF: 'kǎi',  # 闿
    0x9600: 'fá',  # 阀
    0x9601: 'gé',  # 阁
    0x9602: 'hé',  # 阂
    0x9603: 'kǔn',  # 阃
    0x9604: 'jiū',  # 阄
    0x9605: 'yuè',  # 阅
    0x9606: 'làng',  # 阆
    0x9607: 'dū,shé',  # 阇
    0x9608: 'yù',  # 阈
    0x9609: 'yān',  # 阉
    0x960A: 'chāng',  # 阊
    0x960B: 'xì',  # 阋
    0x960C: 'wén',  # 阌
    0x960D: 'hūn',  # 阍
    0x960E: 'yán',  # 阎
    0x960F: 'è',  # 阏
    0x9610: 'chǎn',  # 阐
    0x9611: 'lán',  # 阑
    0x9612: 'qù',  # 阒
    0x9613: 'huì',  # 阓
    0x9614: 'kuò',  # 阔
    0x9615: 'què',  # 阕
    0x9616: 'hé',  # 阖
    0x9617: 'tián',  # 阗
    0x9618: 'tà',  # 阘
    0x9619: 'quē,què',  # 阙
    0x961A: 'kàn',  # 阚
    0x961B: 'huán',  # 阛
    0x961C: 'fù',  # 阜
    0x961D: 'fǔ',  # 阝
    0x961E: 'lè',  # 阞
    0x961F: 'duì',  # 队
    0x9620: 'xìn',  # 阠
    0x9621: 'qiān',  # 阡
    0x9622: 'wù',  # 阢
    0x9623: 'yì',  # 阣
    0x9624: 'tuó',  # 阤
    0x9625: 'yīn',  # 阥
    0x9626: 'yáng',  # 阦
    0x9627: 'dǒu',  # 阧
    0x9628: 'è',  # 阨
    0x9629: 'shēng',  # 阩
    0x962A: 'bǎn',  # 阪
    0x962B: 'péi',  # 阫
    0x962C: 'kēng',  # 阬
    0x962D: 'yǔn',  # 阭
    0x962E: 'ruǎn',  # 阮
    0x962F: 'zhǐ',  # 阯
    0x9630: 'pí',  # 阰
    0x9631: 'jǐng',  # 阱
    0x9632: 'fáng',  # 防
    0x9633: 'yáng',  # 阳
    0x9634: 'yīn',  # 阴
    0x9635: 'zhèn',  # 阵
    0x9636: 'jiē',  # 阶
    0x9637: 'chēng',  # 阷
    0x9638: 'è',  # 阸
    0x9639: 'qū',  # 阹
    0x963A: 'dǐ',  # 阺
    0x963B: 'zǔ',  # 阻
    0x963C: 'zuò',  # 阼
    0x963D: 'diàn',  # 阽
    0x963E: 'lín',  # 阾
    0x963F: 'ā,ē',  # 阿
    0x9640: 'tuó',  # 陀
    0x9641: 'tuó',  # 陁
    0x9642: 'bēi,pí,pō',  # 陂
    0x9643: 'bǐng',  # 陃
    0x9644: 'fù',  # 附
    0x9645: 'jì',  # 际
    0x9646: 'lù',  # 陆
    0x9647: 'lǒng',  # 陇
    0x9648: 'chén',  # 陈
    0x9649: 'xíng',  # 陉
    0x964A: 'duò',  # 陊
    0x964B: 'lòu',  # 陋
    0x964C: 'mò',  # 陌
    0x964D: 'jiàng,xiáng',  # 降
    0x964E: 'shū',  # 陎
    0x964F: 'duò',  # 陏
    0x9650: 'xiàn',  # 限
    0x9651: 'ér',  # 陑
    0x9652: 'guǐ',  # 陒
    0x9653: 'yū',  # 陓
    0x9654: 'gāi',  # 陔
    0x9655: 'shǎn',  # 陕
    0x9656: 'jùn',  # 陖
    0x9657: 'qiào',  # 陗
    0x9658: 'xíng',  # 陘
    0x9659: 'chún',  # 陙
    0x965A: 'wǔ',  # 陚
    0x965B: 'bì',  # 陛
    0x965C: 'xiá',  # 陜
    0x965D: 'shǎn',  # 陝
    0x965E: 'shēng',  # 陞
    0x965F: 'zhì',  # 陟
    0x9660: 'pū',  # 陠
    0x9661: 'dǒu',  # 陡
    0x9662: 'yuàn',  # 院
    0x9663: 'zhèn',  # 陣
    0x9664: 'chú',  # 除
    0x9665: 'xiàn',  # 陥
    0x9666: 'dǎo',  # 陦
    0x9667: 'niè',  # 陧
    0x9668: 'yǔn',  # 陨
    0x9669: 'xiǎn',  # 险
    0x966A: 'péi',  # 陪
    0x966B: 'fèi',  # 陫
    0x966C: 'zōu',  # 陬
    0x966D: 'qí',  # 陭
    0x966E: 'duì',  # 陮
    0x966F: 'lún',  # 陯
    0x9670: 'yīn',  # 陰
    0x9671: 'jū',  # 陱
    0x9672: 'chuí',  # 陲
    0x9673: 'chén',  # 陳
    0x9674: 'pī',  # 陴
    0x9675: 'líng',  # 陵
    0x9676: 'táo',  # 陶
    0x9677: 'xiàn',  # 陷
    0x9678: 'lù',  # 陸
    0x9679: 'shēng',  # 陹
    0x967A: 'xiǎn',  # 険
    0x967B: 'yīn',  # 陻
    0x967C: 'zhǔ',  # 陼
    0x967D: 'yáng',  # 陽
    0x967E: 'réng',  # 陾
    0x967F: 'xiá',  # 陿
    0x9680: 'chóng',  # 隀
    0x9681: 'yàn,yǎn',  # 隁
    0x9682: 'yīn',  # 隂
    0x9683: 'yú,yáo,shù',  # 隃
    0x9684: 'dī',  # 隄
    0x9685: 'yú',  # 隅
    0x9686: 'lóng',  # 隆
    0x9687: 'wēi',  # 隇
    0x9688: 'wēi',  # 隈
    0x9689: 'niè',  # 隉
    0x968A: 'duì,zhuì',  # 隊
    0x968B: 'suí,duò',  # 隋
    0x968C: 'àn',  # 隌
    0x968D: 'huáng',  # 隍
    0x968E: 'jiē',  # 階
    0x968F: 'suí',  # 随
    0x9690: 'yǐn,yìn',  # 隐
    0x9691: 'qí,gāi,ái',  # 隑
    0x9692: 'yǎn',  # 隒
    0x9693: 'huī,duò',  # 隓
    0x9694: 'gé',  # 隔
    0x9695: 'yǔn',  # 隕
    0x9696: 'wù',  # 隖
    0x9697: 'wěi,kuí',  # 隗
    0x9698: 'ài',  # 隘
    0x9699: 'xì',  # 隙
    0x969A: 'táng',  # 隚
    0x969B: 'jì',  # 際
    0x969C: 'zhàng',  # 障
    0x969D: 'dǎo',  # 隝
    0x969E: 'áo',  # 隞
    0x969F: 'xì',  # 隟
    0x96A0: 'yǐn,yìn',  # 隠
    0x96A1: 'sà',  # 隡
    0x96A2: 'rǎo',  # 隢
    0x96A3: 'lín',  # 隣
    0x96A4: 'tuí',  # 隤
    0x96A5: 'dèng',  # 隥
    0x96A6: 'pí',  # 隦
    0x96A7: 'suì',  # 隧
    0x96A8: 'suí',  # 隨
    0x96A9: 'ào,yù',  # 隩
    0x96AA: 'xiǎn',  # 險
    0x96AB: 'fén',  # 隫
    0x96AC: 'nǐ',  # 隬
    0x96AD: 'ér',  # 隭
    0x96AE: 'jī',  # 隮
    0x96AF: 'dǎo',  # 隯
    0x96B0: 'xí',  # 隰
    0x96B1: 'yǐn,yìn',  # 隱
    0x96B2: 'zhì',  # 隲
    0x96B3: 'huī,duò',  # 隳
    0x96B4: 'lǒng',  # 隴
    0x96B5: 'xī',  # 隵
    0x96B6: 'lì',  # 隶
    0x96B7: 'lì',  # 隷
    0x96B8: 'lì',  # 隸
    0x96B9: 'zhuī,cuī,wéi',  # 隹
    0x96BA: 'hú,hè',  # 隺
    0x96BB: 'zhī',  # 隻
    0x96BC: 'sǔn',  # 隼
    0x96BD: 'jùn,juàn',  # 隽
    0x96BE: 'nán,nàn,nuó',  # 难
    0x96BF: 'yì',  # 隿
    0x96C0: 'què,qiāo,qiǎo',  # 雀
    0x96C1: 'yàn',  # 雁
    0x96C2: 'qín',  # 雂
    0x96C3: 'jiān',  # 雃
    0x96C4: 'xióng',  # 雄
    0x96C5: 'yǎ',  # 雅
    0x96C6: 'jí',  # 集
    0x96C7: 'gù',  # 雇
    0x96C8: 'huán',  # 雈
    0x96C9: 'zhì',  # 雉
    0x96CA: 'gòu',  # 雊
    0x96CB: 'jùn,juàn',  # 雋
    0x96CC: 'cí',  # 雌
    0x96CD: 'yōng',  # 雍
    0x96CE: 'jū',  # 雎
    0x96CF: 'chú',  # 雏
    0x96D0: 'hū',  # 雐
    0x96D1: 'zá',  # 雑
    0x96D2: 'luò',  # 雒
    0x96D3: 'yú',  # 雓
    0x96D4: 'chóu',  # 雔
    0x96D5: 'diāo',  # 雕
    0x96D6: 'suī',  # 雖
    0x96D7: 'hàn',  # 雗
    0x96D8: 'huò',  # 雘
    0x96D9: 'shuāng',  # 雙
    0x96DA: 'guàn,huán',  # 雚
    0x96DB: 'chú',  # 雛
    0x96DC: 'zá',  # 雜
    0x96DD: 'yōng',  # 雝
    0x96DE: 'jī',  # 雞
    0x96DF: 'guī,xī',  # 雟
    0x96E0: 'chóu',  # 雠
    0x96E1: 'liù',  # 雡
    0x96E2: 'lí',  # 離
    0x96E3: 'nán,nàn,nuó',  # 難
    0x96E4: 'yù',  # 雤
    0x96E5: 'zá',  # 雥
    0x96E6: 'chóu',  # 雦
    0x96E7: 'jí',  # 雧
    0x96E8: 'yǔ,yù',  # 雨
    0x96E9: 'yú',  # 雩
    0x96EA: 'xuě',  # 雪
    0x96EB: 'nǎ',  # 雫
    0x96EC: 'fǒu',  # 雬
    0x96ED: 'sè,xí',  # 雭
    0x96EE: 'mù',  # 雮
    0x96EF: 'wén',  # 雯
    0x96F0: 'fēn',  # 雰
    0x96F1: 'pāng',  # 雱
    0x96F2: 'yún',  # 雲
    0x96F3: 'lì',  # 雳
    0x96F4: 'chì',  # 雴
    0x96F5: 'yāng',  # 雵
    0x96F6: 'líng',  # 零
    0x96F7: 'léi',  # 雷
    0x96F8: 'án',  # 雸
    0x96F9: 'báo',  # 雹
    0x96FA: 'wù,méng',  # 雺
    0x96FB: 'diàn',  # 電
    0x96FC: 'dàng',  # 雼
    0x96FD: 'hū,hù',  # 雽
    0x96FE: 'wù',  # 雾
    0x96FF: 'diào',  # 雿
    0x9700: 'xū',  # 需
    0x9701: 'jì',  # 霁
    0x9702: 'mù',  # 霂
    0x9703: 'chén',  # 霃
    0x9704: 'xiāo',  # 霄
    0x9705: 'zhá',  # 霅
    0x9706: 'tíng',  # 霆
    0x9707: 'zhèn',  # 震
    0x9708: 'pèi',  # 霈
    0x9709: 'méi',  # 霉
    0x970A: 'líng',  # 霊
    0x970B: 'qī',  # 霋
    0x970C: 'zhōu',  # 霌
    0x970D: 'huò',  # 霍
    0x970E: 'shà',  # 霎
    0x970F: 'fēi',  # 霏
    0x9710: 'hóng',  # 霐
    0x9711: 'zhān',  # 霑
    0x9712: 'yīn',  # 霒
    0x9713: 'ní',  # 霓
    0x9714: 'shù',  # 霔
    0x9715: 'tún',  # 霕
    0x9716: 'lín',  # 霖
    0x9717: 'líng',  # 霗
    0x9718: 'dòng',  # 霘
    0x9719: 'yīng',  # 霙
    0x971A: 'wù',  # 霚
    0x971B: 'líng',  # 霛
    0x971C: 'shuāng',  # 霜
    0x971D: 'líng',  # 霝
    0x971E: 'xiá',  # 霞
    0x971F: 'hóng',  # 霟
    0x9720: 'yīn',  # 霠
    0x9721: 'mài',  # 霡
    0x9722: 'mài',  # 霢
    0x9723: 'yǔn',  # 霣
    0x9724: 'liù',  # 霤
    0x9725: 'mèng',  # 霥
    0x9726: 'bīn',  # 霦
    0x9727: 'wù',  # 霧
    0x9728: 'wèi',  # 霨
    0x9729: 'kuò',  # 霩
    0x972A: 'yín',  # 霪
    0x972B: 'xí',  # 霫
    0x972C: 'yì',  # 霬
    0x972D: 'ǎi',  # 霭
    0x972E: 'dàn',  # 霮
    0x972F: 'tèng',  # 霯
    0x9730: 'xiàn',  # 霰
    0x9731: 'yù',  # 霱
    0x9732: 'lòu,lù',  # 露
    0x9733: 'lóng',  # 霳
    0x9734: 'dài',  # 霴
    0x9735: 'jí',  # 霵
    0x9736: 'pāng',  # 霶
    0x9737: 'yáng',  # 霷
    0x9738: 'bà',  # 霸
    0x9739: 'pī',  # 霹
    0x973A: 'wēi',  # 霺
    0x973B: 'fēng',  # 霻
    0x973C: 'xì',  # 霼
    0x973D: 'jì',  # 霽
    0x973E: 'mái',  # 霾
    0x973F: 'méng',  # 霿
    0x9740: 'méng',  # 靀
    0x9741: 'léi',  # 靁
    0x9742: 'lì',  # 靂
    0x9743: 'huò',  # 靃
    0x9744: 'ǎi',  # 靄
    0x9745: 'fèi',  # 靅
    0x9746: 'dài',  # 靆
    0x9747: 'lóng',  # 靇
    0x9748: 'lìng',  # 靈
    0x9749: 'ài',  # 靉
    0x974A: 'fēng',  # 靊
    0x974B: 'lì',  # 靋
    0x974C: 'bǎo',  # 靌
    0x974D: 'hè',  # 靍
    0x974E: 'hè',  # 靎
    0x974F: 'hè',  # 靏
    0x9750: 'bìng',  # 靐
    0x9751: 'qīng',  # 靑
    0x9752: 'qīng',  # 青
    0x9753: 'jìng,liàng',  # 靓
    0x9754: 'tiān',  # 靔
    0x9755: 'zhèng',  # 靕
    0x9756: 'jìng',  # 靖
    0x9757: 'chēng',  # 靗
    0x9758: 'qìng',  # 靘
    0x9759: 'jìng',  # 静
    0x975A: 'jìng',  # 靚
    0x975B: 'diàn',  # 靛
    0x975C: 'jìng',  # 靜
    0x975D: 'tiān',  # 靝
    0x975E: 'fēi',  # 非
    0x975F: 'fēi',  # 靟
    0x9760: 'kào',  # 靠
    0x9761: 'mí',  # 靡
    0x9762: 'miàn',  # 面
    0x9763: 'miàn',  # 靣
    0x9764: 'pào',  # 靤
    0x9765: 'yè',  # 靥
    0x9766: 'miǎn',  # 靦
    0x9767: 'huì',  # 靧
    0x9768: 'yè',  # 靨
    0x9769: 'gé',  # 革
    0x976A: 'dīng',  # 靪
    0x976B: 'chá',  # 靫
    0x976C: 'jiān',  # 靬
    0x976D: 'rèn',  # 靭
    0x976E: 'dí',  # 靮
    0x976F: 'dù',  # 靯
    0x9770: 'wù',  # 靰
    0x9771: 'rèn',  # 靱
    0x9772: 'qín',  # 靲
    0x9773: 'jìn',  # 靳
    0x9774: 'xuē',  # 靴
    0x9775: 'niǔ',  # 靵
    0x9776: 'bǎ',  # 靶
    0x9777: 'yǐn',  # 靷
    0x9778: 'sǎ',  # 靸
    0x9779: 'nà',  # 靹
    0x977A: 'mò',  # 靺
    0x977B: 'zǔ',  # 靻
    0x977C: 'dá',  # 靼
    0x977D: 'bàn',  # 靽
    0x977E: 'xiè',  # 靾
    0x977F: 'yào',  # 靿
    0x9780: 'táo',  # 鞀
    0x9781: 'bèi',  # 鞁
    0x9782: 'jiē',  # 鞂
    0x9783: 'hóng',  # 鞃
    0x9784: 'páo',  # 鞄
    0x9785: 'yāng,yàng',  # 鞅
    0x9786: 'bǐng',  # 鞆
    0x9787: 'yīn',  # 鞇
    0x9788: 'gé,tà,sǎ',  # 鞈
    0x9789: 'táo',  # 鞉
    0x978A: 'jié,jí',  # 鞊
    0x978B: 'xié',  # 鞋
    0x978C: 'ān',  # 鞌
    0x978D: 'ān',  # 鞍
    0x978E: 'hén',  # 鞎
    0x978F: 'gǒng',  # 鞏
    0x9790: 'qiǎ',  # 鞐
    0x9791: 'dá',  # 鞑
    0x9792: 'qiáo',  # 鞒
    0x9793: 'tīng',  # 鞓
    0x9794: 'mán,mèn',  # 鞔
    0x9795: 'biān,yìng',  # 鞕
    0x9796: 'suī',  # 鞖
    0x9797: 'tiáo',  # 鞗
    0x9798: 'qiào,shāo',  # 鞘
    0x9799: 'xuān,juān',  # 鞙
    0x979A: 'kòng',  # 鞚
    0x979B: 'běng',  # 鞛
    0x979C: 'tà',  # 鞜
    0x979D: 'shàng,zhǎng',  # 鞝
    0x979E: 'bǐng,pí,bì,bēi',  # 鞞
    0x979F: 'kuò',  # 鞟
    0x97A0: 'jū',  # 鞠
    0x97A1: 'la',  # 鞡
    0x97A2: 'xiè,dié',  # 鞢
    0x97A3: 'róu',  # 鞣
    0x97A4: 'bāng',  # 鞤
    0x97A5: 'ēng',  # 鞥
    0x97A6: 'qiū',  # 鞦
    0x97A7: 'qiū',  # 鞧
    0x97A8: 'hé',  # 鞨
    0x97A9: 'qiào',  # 鞩
    0x97AA: 'mù,móu',  # 鞪
    0x97AB: 'jū',  # 鞫
    0x97AC: 'jiàn,jiān',  # 鞬
    0x97AD: 'biān',  # 鞭
    0x97AE: 'dī',  # 鞮
    0x97AF: 'jiān',  # 鞯
    0x97B0: 'wēn,yùn',  # 鞰
    0x97B1: 'tāo',  # 鞱
    0x97B2: 'gōu',  # 鞲
    0x97B3: 'tà',  # 鞳
    0x97B4: 'bèi',  # 鞴
    0x97B5: 'xié',  # 鞵
    0x97B6: 'pán',  # 鞶
    0x97B7: 'gé',  # 鞷
    0x97B8: 'bì,bǐng',  # 鞸
    0x97B9: 'kuò',  # 鞹
    0x97BA: 'tāng',  # 鞺
    0x97BB: 'lóu',  # 鞻
    0x97BC: 'guì',  # 鞼
    0x97BD: 'qiáo',  # 鞽
    0x97BE: 'xuē',  # 鞾
    0x97BF: 'jī',  # 鞿
    0x97C0: 'jiān',  # 韀
    0x97C1: 'jiāng',  # 韁
    0x97C2: 'chàn',  # 韂
    0x97C3: 'dá',  # 韃
    0x97C4: 'huò',  # 韄
    0x97C5: 'xiǎn',  # 韅
    0x97C6: 'qiān',  # 韆
    0x97C7: 'dú',  # 韇
    0x97C8: 'wā',  # 韈
    0x97C9: 'jiān',  # 韉
    0x97CA: 'lán',  # 韊
    0x97CB: 'wéi',  # 韋
    0x97CC: 'rèn',  # 韌
    0x97CD: 'fú',  # 韍
    0x97CE: 'mèi,wà',  # 韎
    0x97CF: 'quàn',  # 韏
    0x97D0: 'gé',  # 韐
    0x97D1: 'wěi',  # 韑
    0x97D2: 'qiào',  # 韒
    0x97D3: 'hán',  # 韓
    0x97D4: 'chàng',  # 韔
    0x97D5: 'kuò',  # 韕
    0x97D6: 'rǒu',  # 韖
    0x97D7: 'yùn',  # 韗
    0x97D8: 'shè,xiè',  # 韘
    0x97D9: 'wěi',  # 韙
    0x97DA: 'gé',  # 韚
    0x97DB: 'bài',  # 韛
    0x97DC: 'tāo',  # 韜
    0x97DD: 'gōu',  # 韝
    0x97DE: 'yùn',  # 韞
    0x97DF: 'gāo',  # 韟
    0x97E0: 'bì',  # 韠
    0x97E1: 'wěi',  # 韡
    0x97E2: 'suì',  # 韢
    0x97E3: 'dú',  # 韣
    0x97E4: 'wà',  # 韤
    0x97E5: 'dú',  # 韥
    0x97E6: 'wéi',  # 韦
    0x97E7: 'rèn',  # 韧
    0x97E8: 'fú',  # 韨
    0x97E9: 'hán',  # 韩
    0x97EA: 'wěi',  # 韪
    0x97EB: 'yùn,wēn',  # 韫
    0x97EC: 'tāo',  # 韬
    0x97ED: 'jiǔ',  # 韭
    0x97EE: 'jiǔ',  # 韮
    0x97EF: 'xiān',  # 韯
    0x97F0: 'xiè',  # 韰
    0x97F1: 'xiān',  # 韱
    0x97F2: 'jī',  # 韲
    0x97F3: 'yīn',  # 音
    0x97F4: 'zá',  # 韴
    0x97F5: 'yùn',  # 韵
    0x97F6: 'sháo',  # 韶
    0x97F7: 'lè',  # 韷
    0x97F8: 'péng',  # 韸
    0x97F9: 'huáng',  # 韹
    0x97FA: 'yīng',  # 韺
    0x97FB: 'yùn',  # 韻
    0x97FC: 'péng',  # 韼
    0x97FD: 'ān',  # 韽
    0x97FE: 'yīn',  # 韾
    0x97FF: 'xiǎng',  # 響
    0x9800: 'hù',  # 頀
    0x9801: 'yè',  # 頁
    0x9802: 'dǐng',  # 頂
    0x9803: 'qǐng',  # 頃
    0x9804: 'qiú',  # 頄
    0x9805: 'xiàng',  # 項
    0x9806: 'shùn',  # 順
    0x9807: 'hān',  # 頇
    0x9808: 'xū',  # 須
    0x9809: 'yí',  # 頉
    0x980A: 'xū',  # 頊
    0x980B: 'ě',  # 頋
    0x980C: 'sòng',  # 頌
    0x980D: 'kuǐ',  # 頍
    0x980E: 'qí',  # 頎
    0x980F: 'háng',  # 頏
    0x9810: 'yù',  # 預
    0x9811: 'wán',  # 頑
    0x9812: 'bān',  # 頒
    0x9813: 'dùn',  # 頓
    0x9814: 'dí',  # 頔
    0x9815: 'dān',  # 頕
    0x9816: 'pàn',  # 頖
    0x9817: 'pō',  # 頗
    0x9818: 'lǐng',  # 領
    0x9819: 'chè',  # 頙
    0x981A: 'jǐng',  # 頚
    0x981B: 'lèi',  # 頛
    0x981C: 'hé',  # 頜
    0x981D: 'qiāo',  # 頝
    0x981E: 'è',  # 頞
    0x981F: 'é',  # 頟
    0x9820: 'wěi',  # 頠
    0x9821: 'jié',  # 頡
    0x9822: 'kuò',  # 頢
    0x9823: 'shěn',  # 頣
    0x9824: 'yí',  # 頤
    0x9825: 'yí',  # 頥
    0x9826: 'kē',  # 頦
    0x9827: 'duǐ',  # 頧
    0x9828: 'yǔ',  # 頨
    0x9829: 'pīng',  # 頩
    0x982A: 'lèi',  # 頪
    0x982B: 'fǔ',  # 頫
    0x982C: 'jiá',  # 頬
    0x982D: 'tóu',  # 頭
    0x982E: 'huì',  # 頮
    0x982F: 'kuí',  # 頯
    0x9830: 'jiá',  # 頰
    0x9831: 'luō',  # 頱
    0x9832: 'tǐng',  # 頲
    0x9833: 'chēng',  # 頳
    0x9834: 'yǐng',  # 頴
    0x9835: 'jūn',  # 頵
    0x9836: 'hú',  # 頶
    0x9837: 'hàn',  # 頷
    0x9838: 'jǐng',  # 頸
    0x9839: 'tuí',  # 頹
    0x983A: 'tuí',  # 頺
    0x983B: 'bīn',  # 頻
    0x983C: 'lài',  # 頼
    0x983D: 'tuí',  # 頽
    0x983E: 'zī',  # 頾
    0x983F: 'zī',  # 頿
    0x9840: 'chuí',  # 顀
    0x9841: 'dìng',  # 顁
    0x9842: 'lài',  # 顂
    0x9843: 'tán',  # 顃
    0x9844: 'hàn',  # 顄
    0x9845: 'qiān',  # 顅
    0x9846: 'kē',  # 顆
    0x9847: 'cuì',  # 顇
    0x9848: 'jiǒng',  # 顈
    0x9849: 'qīn',  # 顉
    0x984A: 'yí',  # 顊
    0x984B: 'sāi',  # 顋
    0x984C: 'tí',  # 題
    0x984D: 'é',  # 額
    0x984E: 'è',  # 顎
    0x984F: 'yán',  # 顏
    0x9850: 'wèn',  # 顐
    0x9851: 'kǎn',  # 顑
    0x9852: 'yóng',  # 顒
    0x9853: 'zhuān',  # 顓
    0x9854: 'yán',  # 顔
    0x9855: 'xiǎn',  # 顕
    0x9856: 'xìn',  # 顖
    0x9857: 'yǐ',  # 顗
    0x9858: 'yuàn',  # 願
    0x9859: 'sǎng',  # 顙
    0x985A: 'diān',  # 顚
    0x985B: 'diān',  # 顛
    0x985C: 'jiǎng',  # 顜
    0x985D: 'kuī',  # 顝
    0x985E: 'lèi',  # 類
    0x985F: 'láo',  # 顟
    0x9860: 'piǎo',  # 顠
    0x9861: 'wài',  # 顡
    0x9862: 'mān',  # 顢
    0x9863: 'cù',  # 顣
    0x9864: 'yáo',  # 顤
    0x9865: 'hào',  # 顥
    0x9866: 'qiáo',  # 顦
    0x9867: 'gù',  # 顧
    0x9868: 'xùn',  # 顨
    0x9869: 'yǎn',  # 顩
    0x986A: 'huì',  # 顪
    0x986B: 'chàn',  # 顫
    0x986C: 'rú',  # 顬
    0x986D: 'méng',  # 顭
    0x986E: 'bīn',  # 顮
    0x986F: 'xiǎn',  # 顯
    0x9870: 'pín',  # 顰
    0x9871: 'lú',  # 顱
    0x9872: 'lǎn',  # 顲
    0x9873: 'niè',  # 顳
    0x9874: 'quán',  # 顴
    0x9875: 'yè',  # 页
    0x9876: 'dǐng',  # 顶
    0x9877: 'qǐng',  # 顷
    0x9878: 'hān',  # 顸
    0x9879: 'xiàng',  # 项
    0x987A: 'shùn',  # 顺
    0x987B: 'xū',  # 须
    0x987C: 'xū',  # 顼
    0x987D: 'wán',  # 顽
    0x987E: 'gù',  # 顾
    0x987F: 'dùn',  # 顿
    0x9880: 'qí',  # 颀
    0x9881: 'bān',  # 颁
    0x9882: 'sòng',  # 颂
    0x9883: 'háng',  # 颃
    0x9884: 'yù',  # 预
    0x9885: 'lú',  # 颅
    0x9886: 'lǐng',  # 领
    0x9887: 'pō',  # 颇
    0x9888: 'jǐng,gěng',  # 颈
    0x9889: 'jié,xié,jiá',  # 颉
    0x988A: 'jiá',  # 颊
    0x988B: 'tǐng',  # 颋
    0x988C: 'hé,gé',  # 颌
    0x988D: 'yǐng',  # 颍
    0x988E: 'jiǒng',  # 颎
    0x988F: 'kē',  # 颏
    0x9890: 'yí',  # 颐
    0x9891: 'pín,bīn',  # 频
    0x9892: 'huì',  # 颒
    0x9893: 'tuí',  # 颓
    0x9894: 'hàn',  # 颔
    0x9895: 'yǐng',  # 颕
    0x9896: 'yǐng',  # 颖
    0x9897: 'kē',  # 颗
    0x9898: 'tí',  # 题
    0x9899: 'yóng',  # 颙
    0x989A: 'è',  # 颚
    0x989B: 'zhuān',  # 颛
    0x989C: 'yán',  # 颜
    0x989D: 'é',  # 额
    0x989E: 'niè',  # 颞
    0x989F: 'mān',  # 颟
    0x98A0: 'diān',  # 颠
    0x98A1: 'sǎng',  # 颡
    0x98A2: 'hào',  # 颢
    0x98A3: 'lèi',  # 颣
    0x98A4: 'chàn,zhàn',  # 颤
    0x98A5: 'rú',  # 颥
    0x98A6: 'pín',  # 颦
    0x98A7: 'quán',  # 颧
    0x98A8: 'fēng,fěng',  # 風
    0x98A9: 'biāo,diū',  # 颩
    0x98AA: 'guā',  # 颪
    0x98AB: 'fú',  # 颫
    0x98AC: 'xiā',  # 颬
    0x98AD: 'zhǎn',  # 颭
    0x98AE: 'biāo',  # 颮
    0x98AF: 'sà',  # 颯
    0x98B0: 'bá,fú',  # 颰
    0x98B1: 'tái',  # 颱
    0x98B2: 'liè',  # 颲
    0x98B3: 'guā',  # 颳
    0x98B4: 'xuàn',  # 颴
    0x98B5: 'xiāo',  # 颵
    0x98B6: 'jù',  # 颶
    0x98B7: 'biāo',  # 颷
    0x98B8: 'sī',  # 颸
    0x98B9: 'wěi',  # 颹
    0x98BA: 'yáng',  # 颺
    0x98BB: 'yáo',  # 颻
    0x98BC: 'sōu',  # 颼
    0x98BD: 'kǎi',  # 颽
    0x98BE: 'sāo,sōu',  # 颾
    0x98BF: 'fān',  # 颿
    0x98C0: 'liú',  # 飀
    0x98C1: 'xí',  # 飁
    0x98C2: 'liù,liáo',  # 飂
    0x98C3: 'piāo',  # 飃
    0x98C4: 'piāo',  # 飄
    0x98C5: 'liú',  # 飅
    0x98C6: 'biāo',  # 飆
    0x98C7: 'biāo',  # 飇
    0x98C8: 'biāo',  # 飈
    0x98C9: 'liáo',  # 飉
    0x98CA: 'biāo',  # 飊
    0x98CB: 'sè',  # 飋
    0x98CC: 'fēng',  # 飌
    0x98CD: 'xiū',  # 飍
    0x98CE: 'fēng,fěng',  # 风
    0x98CF: 'yáng',  # 飏
    0x98D0: 'zhǎn',  # 飐
    0x98D1: 'biāo',  # 飑
    0x98D2: 'sà',  # 飒
    0x98D3: 'jù',  # 飓
    0x98D4: 'sī',  # 飔
    0x98D5: 'sōu',  # 飕
    0x98D6: 'yáo',  # 飖
    0x98D7: 'liú',  # 飗
    0x98D8: 'piāo',  # 飘
    0x98D9: 'biāo',  # 飙
    0x98DA: 'biāo',  # 飚
    0x98DB: 'fēi',  # 飛
    0x98DC: 'fān',  # 飜
    0x98DD: 'fēi',  # 飝
    0x98DE: 'fēi',  # 飞
    0x98DF: 'shí,sì,yì',  # 食
    0x98E0: 'shí',  # 飠
    0x98E1: 'cān',  # 飡
    0x98E2: 'jī',  # 飢
    0x98E3: 'dìng',  # 飣
    0x98E4: 'sì',  # 飤
    0x98E5: 'tuō',  # 飥
    0x98E6: 'zhān',  # 飦
    0x98E7: 'sūn',  # 飧
    0x98E8: 'xiǎng',  # 飨
    0x98E9: 'tún',  # 飩
    0x98EA: 'rèn',  # 飪
    0x98EB: 'yù',  # 飫
    0x98EC: 'yǎng,juàn',  # 飬
    0x98ED: 'chì',  # 飭
    0x98EE: 'yǐn,yìn',  # 飮
    0x98EF: 'fàn',  # 飯
    0x98F0: 'fàn',  # 飰
    0x98F1: 'sūn',  # 飱
    0x98F2: 'yǐn,yìn',  # 飲
    0x98F3: 'zhù,tǒu',  # 飳
    0x98F4: 'yí,sì',  # 飴
    0x98F5: 'zuò,zé,zhā',  # 飵
    0x98F6: 'bì',  # 飶
    0x98F7: 'jiě',  # 飷
    0x98F8: 'tāo',  # 飸
    0x98F9: 'bǎo',  # 飹
    0x98FA: 'cí',  # 飺
    0x98FB: 'tiè',  # 飻
    0x98FC: 'sì',  # 飼
    0x98FD: 'bǎo',  # 飽
    0x98FE: 'shì',  # 飾
    0x98FF: 'duò',  # 飿
    0x9900: 'hài',  # 餀
    0x9901: 'rèn',  # 餁
    0x9902: 'tiǎn',  # 餂
    0x9903: 'jiǎo',  # 餃
    0x9904: 'hé',  # 餄
    0x9905: 'bǐng',  # 餅
    0x9906: 'yáo',  # 餆
    0x9907: 'tóng',  # 餇
    0x9908: 'cí',  # 餈
    0x9909: 'xiǎng',  # 餉
    0x990A: 'yǎng',  # 養
    0x990B: 'juàn',  # 餋
    0x990C: 'ěr',  # 餌
    0x990D: 'yàn',  # 餍
    0x990E: 'lè',  # 餎
    0x990F: 'xī',  # 餏
    0x9910: 'cān',  # 餐
    0x9911: 'bō',  # 餑
    0x9912: 'něi',  # 餒
    0x9913: 'è',  # 餓
    0x9914: 'bū',  # 餔
    0x9915: 'jùn',  # 餕
    0x9916: 'dòu',  # 餖
    0x9917: 'sù',  # 餗
    0x9918: 'yú',  # 餘
    0x9919: 'shì',  # 餙
    0x991A: 'yáo',  # 餚
    0x991B: 'hún',  # 餛
    0x991C: 'guǒ',  # 餜
    0x991D: 'shì',  # 餝
    0x991E: 'jiàn',  # 餞
    0x991F: 'chuò',  # 餟
    0x9920: 'bǐng',  # 餠
    0x9921: 'xiàn',  # 餡
    0x9922: 'bù',  # 餢
    0x9923: 'yè',  # 餣
    0x9924: 'dàn',  # 餤
    0x9925: 'fēi',  # 餥
    0x9926: 'zhāng',  # 餦
    0x9927: 'wèi',  # 餧
    0x9928: 'guǎn',  # 館
    0x9929: 'è',  # 餩
    0x992A: 'nuǎn',  # 餪
    0x992B: 'yùn',  # 餫
    0x992C: 'hú',  # 餬
    0x992D: 'huáng',  # 餭
    0x992E: 'tiè',  # 餮
    0x992F: 'huì',  # 餯
    0x9930: 'jiān',  # 餰
    0x9931: 'hóu',  # 餱
    0x9932: 'ài',  # 餲
    0x9933: 'xíng',  # 餳
    0x9934: 'fēn',  # 餴
    0x9935: 'wèi',  # 餵
    0x9936: 'gǔ',  # 餶
    0x9937: 'chā',  # 餷
    0x9938: 'sòng',  # 餸
    0x9939: 'táng',  # 餹
    0x993A: 'bó',  # 餺
    0x993B: 'gāo',  # 餻
    0x993C: 'xì',  # 餼
    0x993D: 'kuì',  # 餽
    0x993E: 'liù',  # 餾
    0x993F: 'sōu',  # 餿
    0x9940: 'táo',  # 饀
    0x9941: 'yè',  # 饁
    0x9942: 'wēn',  # 饂
    0x9943: 'mó',  # 饃
    0x9944: 'táng',  # 饄
    0x9945: 'mán',  # 饅
    0x9946: 'bì',  # 饆
    0x9947: 'yù',  # 饇
    0x9948: 'xiū',  # 饈
    0x9949: 'jǐn',  # 饉
    0x994A: 'sǎn',  # 饊
    0x994B: 'kuì',  # 饋
    0x994C: 'zhuàn',  # 饌
    0x994D: 'shàn',  # 饍
    0x994E: 'xī',  # 饎
    0x994F: 'dàn',  # 饏
    0x9950: 'yì',  # 饐
    0x9951: 'jī',  # 饑
    0x9952: 'ráo',  # 饒
    0x9953: 'chēng',  # 饓
    0x9954: 'yōng',  # 饔
    0x9955: 'tāo',  # 饕
    0x9956: 'wèi',  # 饖
    0x9957: 'xiǎng',  # 饗
    0x9958: 'zhān',  # 饘
    0x9959: 'fēn',  # 饙
    0x995A: 'hài',  # 饚
    0x995B: 'méng',  # 饛
    0x995C: 'yàn',  # 饜
    0x995D: 'mó',  # 饝
    0x995E: 'chán',  # 饞
    0x995F: 'xiǎng,náng',  # 饟
    0x9960: 'luó',  # 饠
    0x9961: 'zàn',  # 饡
    0x9962: 'náng',  # 饢
    0x9963: 'shí',  # 饣
    0x9964: 'dìng',  # 饤
    0x9965: 'jī',  # 饥
    0x9966: 'tuō',  # 饦
    0x9967: 'xíng',  # 饧
    0x9968: 'tún',  # 饨
    0x9969: 'xì',  # 饩
    0x996A: 'rèn',  # 饪
    0x996B: 'yù',  # 饫
    0x996C: 'chì',  # 饬
    0x996D: 'fàn',  # 饭
    0x996E: 'yǐn',  # 饮
    0x996F: 'jiàn',  # 饯
    0x9970: 'shì',  # 饰
    0x9971: 'bǎo',  # 饱
    0x9972: 'sì',  # 饲
    0x9973: 'duò',  # 饳
    0x9974: 'yí',  # 饴
    0x9975: 'ěr',  # 饵
    0x9976: 'ráo',  # 饶
    0x9977: 'xiǎng',  # 饷
    0x9978: 'hé',  # 饸
    0x9979: 'gē,le',  # 饹
    0x997A: 'jiǎo',  # 饺
    0x997B: 'xī',  # 饻
    0x997C: 'bǐng',  # 饼
    0x997D: 'bō',  # 饽
    0x997E: 'dòu',  # 饾
    0x997F: 'è',  # 饿
    0x9980: 'yú',  # 馀
    0x9981: 'něi',  # 馁
    0x9982: 'jùn',  # 馂
    0x9983: 'guǒ',  # 馃
    0x9984: 'hún',  # 馄
    0x9985: 'xiàn',  # 馅
    0x9986: 'guǎn',  # 馆
    0x9987: 'chā',  # 馇
    0x9988: 'kuì',  # 馈
    0x9989: 'gǔ',  # 馉
    0x998A: 'sōu',  # 馊
    0x998B: 'chán',  # 馋
    0x998C: 'yè',  # 馌
    0x998D: 'mó',  # 馍
    0x998E: 'bó',  # 馎
    0x998F: 'liù,liú',  # 馏
    0x9990: 'xiū',  # 馐
    0x9991: 'jǐn',  # 馑
    0x9992: 'mán',  # 馒
    0x9993: 'sǎn',  # 馓
    0x9994: 'zhuàn',  # 馔
    0x9995: 'náng,nǎng',  # 馕
    0x9996: 'shǒu',  # 首
    0x9997: 'kuí',  # 馗
    0x9998: 'guó',  # 馘
    0x9999: 'xiāng',  # 香
    0x999A: 'fēn',  # 馚
    0x999B: 'bó',  # 馛
    0x999C: 'ní',  # 馜
    0x999D: 'bì',  # 馝
    0x999E: 'bó',  # 馞
    0x999F: 'tú',  # 馟
    0x99A0: 'hān',  # 馠
    0x99A1: 'fēi',  # 馡
    0x99A2: 'jiān',  # 馢
    0x99A3: 'ān',  # 馣
    0x99A4: 'ài',  # 馤
    0x99A5: 'fù',  # 馥
    0x99A6: 'xiān',  # 馦
    0x99A7: 'yūn,wò',  # 馧
    0x99A8: 'xīn',  # 馨
    0x99A9: 'fén',  # 馩
    0x99AA: 'pīn',  # 馪
    0x99AB: 'xīn',  # 馫
    0x99AC: 'mǎ',  # 馬
    0x99AD: 'yù',  # 馭
    0x99AE: 'féng,píng',  # 馮
    0x99AF: 'hàn,hán',  # 馯
    0x99B0: 'dí',  # 馰
    0x99B1: 'tuó,duò',  # 馱
    0x99B2: 'tuō,zhé',  # 馲
    0x99B3: 'chí',  # 馳
    0x99B4: 'xùn',  # 馴
    0x99B5: 'zhù',  # 馵
    0x99B6: 'zhī,shì',  # 馶
    0x99B7: 'pèi',  # 馷
    0x99B8: 'xìn,jìn',  # 馸
    0x99B9: 'rì',  # 馹
    0x99BA: 'sà',  # 馺
    0x99BB: 'yǔn',  # 馻
    0x99BC: 'wén',  # 馼
    0x99BD: 'zhí',  # 馽
    0x99BE: 'dǎn,dàn',  # 馾
    0x99BF: 'lú',  # 馿
    0x99C0: 'yóu',  # 駀
    0x99C1: 'bó',  # 駁
    0x99C2: 'bǎo',  # 駂
    0x99C3: 'jué,kuài',  # 駃
    0x99C4: 'tuó,duò',  # 駄
    0x99C5: 'yì',  # 駅
    0x99C6: 'qū',  # 駆
    0x99C7: 'wén',  # 駇
    0x99C8: 'qū',  # 駈
    0x99C9: 'jiōng',  # 駉
    0x99CA: 'pǒ',  # 駊
    0x99CB: 'zhāo',  # 駋
    0x99CC: 'yuān',  # 駌
    0x99CD: 'pēng',  # 駍
    0x99CE: 'zhòu',  # 駎
    0x99CF: 'jù',  # 駏
    0x99D0: 'zhù',  # 駐
    0x99D1: 'nú',  # 駑
    0x99D2: 'jū',  # 駒
    0x99D3: 'pī',  # 駓
    0x99D4: 'zǎng',  # 駔
    0x99D5: 'jià',  # 駕
    0x99D6: 'líng',  # 駖
    0x99D7: 'zhěn',  # 駗
    0x99D8: 'tái,dài',  # 駘
    0x99D9: 'fù',  # 駙
    0x99DA: 'yǎng',  # 駚
    0x99DB: 'shǐ',  # 駛
    0x99DC: 'bì',  # 駜
    0x99DD: 'tuó',  # 駝
    0x99DE: 'tuó',  # 駞
    0x99DF: 'sì',  # 駟
    0x99E0: 'liú',  # 駠
    0x99E1: 'mà',  # 駡
    0x99E2: 'pián',  # 駢
    0x99E3: 'táo',  # 駣
    0x99E4: 'zhì',  # 駤
    0x99E5: 'róng',  # 駥
    0x99E6: 'téng',  # 駦
    0x99E7: 'dòng',  # 駧
    0x99E8: 'xún,xuān',  # 駨
    0x99E9: 'quán',  # 駩
    0x99EA: 'shēn',  # 駪
    0x99EB: 'jiōng',  # 駫
    0x99EC: 'ěr',  # 駬
    0x99ED: 'hài',  # 駭
    0x99EE: 'bó',  # 駮
    0x99EF: 'zhū',  # 駯
    0x99F0: 'yīn',  # 駰
    0x99F1: 'luò',  # 駱
    0x99F2: 'zhōu',  # 駲
    0x99F3: 'dàn',  # 駳
    0x99F4: 'hài',  # 駴
    0x99F5: 'liú',  # 駵
    0x99F6: 'jú',  # 駶
    0x99F7: 'sǒng',  # 駷
    0x99F8: 'qīn',  # 駸
    0x99F9: 'máng',  # 駹
    0x99FA: 'liáng,láng',  # 駺
    0x99FB: 'hàn',  # 駻
    0x99FC: 'tú',  # 駼
    0x99FD: 'xuān',  # 駽
    0x99FE: 'tuì',  # 駾
    0x99FF: 'jùn',  # 駿
    0x9A00: 'ě',  # 騀
    0x9A01: 'chěng',  # 騁
    0x9A02: 'xīng',  # 騂
    0x9A03: 'sì',  # 騃
    0x9A04: 'lù',  # 騄
    0x9A05: 'zhuī',  # 騅
    0x9A06: 'zhōu',  # 騆
    0x9A07: 'shè',  # 騇
    0x9A08: 'pián',  # 騈
    0x9A09: 'kūn',  # 騉
    0x9A0A: 'táo',  # 騊
    0x9A0B: 'lái',  # 騋
    0x9A0C: 'zōng',  # 騌
    0x9A0D: 'kè',  # 騍
    0x9A0E: 'qí',  # 騎
    0x9A0F: 'qí',  # 騏
    0x9A10: 'yàn',  # 騐
    0x9A11: 'fēi',  # 騑
    0x9A12: 'sāo',  # 騒
    0x9A13: 'yàn',  # 験
    0x9A14: 'gé',  # 騔
    0x9A15: 'yǎo',  # 騕
    0x9A16: 'wù',  # 騖
    0x9A17: 'piàn',  # 騗
    0x9A18: 'cōng',  # 騘
    0x9A19: 'piàn',  # 騙
    0x9A1A: 'qián',  # 騚
    0x9A1B: 'fēi',  # 騛
    0x9A1C: 'huáng',  # 騜
    0x9A1D: 'qián',  # 騝
    0x9A1E: 'huō',  # 騞
    0x9A1F: 'yú',  # 騟
    0x9A20: 'tí',  # 騠
    0x9A21: 'quán',  # 騡
    0x9A22: 'xiá',  # 騢
    0x9A23: 'zōng',  # 騣
    0x9A24: 'kuí',  # 騤
    0x9A25: 'róu',  # 騥
    0x9A26: 'sī',  # 騦
    0x9A27: 'guā',  # 騧
    0x9A28: 'tuó',  # 騨
    0x9A29: 'guī',  # 騩
    0x9A2A: 'sōu',  # 騪
    0x9A2B: 'qiān',  # 騫
    0x9A2C: 'chéng',  # 騬
    0x9A2D: 'zhì',  # 騭
    0x9A2E: 'liú',  # 騮
    0x9A2F: 'péng',  # 騯
    0x9A30: 'téng',  # 騰
    0x9A31: 'xí',  # 騱
    0x9A32: 'cǎo',  # 騲
    0x9A33: 'dú',  # 騳
    0x9A34: 'yàn',  # 騴
    0x9A35: 'yuán',  # 騵
    0x9A36: 'zōu',  # 騶
    0x9A37: 'sāo',  # 騷
    0x9A38: 'shàn',  # 騸
    0x9A39: 'qí',  # 騹
    0x9A3A: 'zhì',  # 騺
    0x9A3B: 'shuāng',  # 騻
    0x9A3C: 'lù',  # 騼
    0x9A3D: 'xí',  # 騽
    0x9A3E: 'luó',  # 騾
    0x9A3F: 'zhāng',  # 騿
    0x9A40: 'mò',  # 驀
    0x9A41: 'ào',  # 驁
    0x9A42: 'cān',  # 驂
    0x9A43: 'piào',  # 驃
    0x9A44: 'cōng',  # 驄
    0x9A45: 'qū',  # 驅
    0x9A46: 'bì',  # 驆
    0x9A47: 'zhì',  # 驇
    0x9A48: 'yù',  # 驈
    0x9A49: 'xū',  # 驉
    0x9A4A: 'huá',  # 驊
    0x9A4B: 'bō',  # 驋
    0x9A4C: 'sù',  # 驌
    0x9A4D: 'xiāo',  # 驍
    0x9A4E: 'lín',  # 驎
    0x9A4F: 'zhàn',  # 驏
    0x9A50: 'dūn',  # 驐
    0x9A51: 'liú',  # 驑
    0x9A52: 'tuó',  # 驒
    0x9A53: 'céng',  # 驓
    0x9A54: 'diàn',  # 驔
    0x9A55: 'jiāo',  # 驕
    0x9A56: 'tiě',  # 驖
    0x9A57: 'yàn',  # 驗
    0x9A58: 'luó',  # 驘
    0x9A59: 'zhān',  # 驙
    0x9A5A: 'jīng',  # 驚
    0x9A5B: 'yì',  # 驛
    0x9A5C: 'yè',  # 驜
    0x9A5D: 'tuó',  # 驝
    0x9A5E: 'pīn',  # 驞
    0x9A5F: 'zhòu',  # 驟
    0x9A60: 'yàn',  # 驠
    0x9A61: 'lóng',  # 驡
    0x9A62: 'lǘ',  # 驢
    0x9A63: 'téng',  # 驣
    0x9A64: 'xiāng',  # 驤
    0x9A65: 'jì',  # 驥
    0x9A66: 'shuāng',  # 驦
    0x9A67: 'jú',  # 驧
    0x9A68: 'xí',  # 驨
    0x9A69: 'huān',  # 驩
    0x9A6A: 'lí',  # 驪
    0x9A6B: 'biāo',  # 驫
    0x9A6C: 'mǎ',  # 马
    0x9A6D: 'yù',  # 驭
    0x9A6E: 'tuó',  # 驮
    0x9A6F: 'xùn',  # 驯
    0x9A70: 'chí',  # 驰
    0x9A71: 'qū',  # 驱
    0x9A72: 'rì',  # 驲
    0x9A73: 'bó',  # 驳
    0x9A74: 'lǘ',  # 驴
    0x9A75: 'zǎng',  # 驵
    0x9A76: 'shǐ',  # 驶
    0x9A77: 'sì',  # 驷
    0x9A78: 'fù',  # 驸
    0x9A79: 'jū',  # 驹
    0x9A7A: 'zōu',  # 驺
    0x9A7B: 'zhù',  # 驻
    0x9A7C: 'tuó',  # 驼
    0x9A7D: 'nú',  # 驽
    0x9A7E: 'jià',  # 驾
    0x9A7F: 'yì',  # 驿
    0x9A80: 'tái',  # 骀
    0x9A81: 'xiāo',  # 骁
    0x9A82: 'mà',  # 骂
    0x9A83: 'yīn',  # 骃
    0x9A84: 'jiāo',  # 骄
    0x9A85: 'huá',  # 骅
    0x9A86: 'luò',  # 骆
    0x9A87: 'hài',  # 骇
    0x9A88: 'pián',  # 骈
    0x9A89: 'biāo',  # 骉
    0x9A8A: 'lí',  # 骊
    0x9A8B: 'chěng',  # 骋
    0x9A8C: 'yàn',  # 验
    0x9A8D: 'xīng',  # 骍
    0x9A8E: 'qīn',  # 骎
    0x9A8F: 'jùn',  # 骏
    0x9A90: 'qí',  # 骐
    0x9A91: 'qí',  # 骑
    0x9A92: 'kè',  # 骒
    0x9A93: 'zhuī',  # 骓
    0x9A94: 'zōng',  # 骔
    0x9A95: 'sù',  # 骕
    0x9A96: 'cān',  # 骖
    0x9A97: 'piàn',  # 骗
    0x9A98: 'zhì',  # 骘
    0x9A99: 'kuí',  # 骙
    0x9A9A: 'sāo,sǎo',  # 骚
    0x9A9B: 'wù',  # 骛
    0x9A9C: 'áo',  # 骜
    0x9A9D: 'liú',  # 骝
    0x9A9E: 'qiān',  # 骞
    0x9A9F: 'shàn',  # 骟
    0x9AA0: 'piào,biāo',  # 骠
    0x9AA1: 'luó',  # 骡
    0x9AA2: 'cōng',  # 骢
    0x9AA3: 'chǎn',  # 骣
    0x9AA4: 'zhòu',  # 骤
    0x9AA5: 'jì',  # 骥
    0x9AA6: 'shuāng',  # 骦
    0x9AA7: 'xiāng',  # 骧
    0x9AA8: 'gǔ,gū',  # 骨
    0x9AA9: 'wěi',  # 骩
    0x9AAA: 'wěi',  # 骪
    0x9AAB: 'wěi',  # 骫
    0x9AAC: 'yú',  # 骬
    0x9AAD: 'gàn',  # 骭
    0x9AAE: 'yì',  # 骮
    0x9AAF: 'āng',  # 骯
    0x9AB0: 'tóu',  # 骰
    0x9AB1: 'jiè',  # 骱
    0x9AB2: 'bào',  # 骲
    0x9AB3: 'bèi,mó',  # 骳
    0x9AB4: 'cī',  # 骴
    0x9AB5: 'tǐ',  # 骵
    0x9AB6: 'dǐ',  # 骶
    0x9AB7: 'kū',  # 骷
    0x9AB8: 'hái',  # 骸
    0x9AB9: 'qiāo,xiāo',  # 骹
    0x9ABA: 'hóu',  # 骺
    0x9ABB: 'kuà',  # 骻
    0x9ABC: 'gé',  # 骼
    0x9ABD: 'tuǐ',  # 骽
    0x9ABE: 'gěng',  # 骾
    0x9ABF: 'pián',  # 骿
    0x9AC0: 'bì',  # 髀
    0x9AC1: 'kē',  # 髁
    0x9AC2: 'qià',  # 髂
    0x9AC3: 'yú',  # 髃
    0x9AC4: 'suí',  # 髄
    0x9AC5: 'lóu',  # 髅
    0x9AC6: 'bó',  # 髆
    0x9AC7: 'xiāo',  # 髇
    0x9AC8: 'bǎng',  # 髈
    0x9AC9: 'bó,jué',  # 髉
    0x9ACA: 'cī',  # 髊
    0x9ACB: 'kuān',  # 髋
    0x9ACC: 'bìn',  # 髌
    0x9ACD: 'mó',  # 髍
    0x9ACE: 'liáo',  # 髎
    0x9ACF: 'lóu',  # 髏
    0x9AD0: 'xiāo',  # 髐
    0x9AD1: 'dú',  # 髑
    0x9AD2: 'zāng',  # 髒
    0x9AD3: 'suǐ',  # 髓
    0x9AD4: 'tǐ,tī',  # 體
    0x9AD5: 'bìn',  # 髕
    0x9AD6: 'kuān',  # 髖
    0x9AD7: 'lú',  # 髗
    0x9AD8: 'gāo',  # 高
    0x9AD9: 'gāo',  # 髙
    0x9ADA: 'qiào',  # 髚
    0x9ADB: 'kāo',  # 髛
    0x9ADC: 'qiǎo',  # 髜
    0x9ADD: 'láo',  # 髝
    0x9ADE: 'sào',  # 髞
    0x9ADF: 'biāo',  # 髟
    0x9AE0: 'kūn',  # 髠
    0x9AE1: 'kūn',  # 髡
    0x9AE2: 'dí',  # 髢
    0x9AE3: 'fǎng',  # 髣
    0x9AE4: 'xiū',  # 髤
    0x9AE5: 'rán',  # 髥
    0x9AE6: 'máo',  # 髦
    0x9AE7: 'dàn',  # 髧
    0x9AE8: 'kūn',  # 髨
    0x9AE9: 'bìn',  # 髩
    0x9AEA: 'fà',  # 髪
    0x9AEB: 'tiáo',  # 髫
    0x9AEC: 'pī',  # 髬
    0x9AED: 'zī',  # 髭
    0x9AEE: 'fà',  # 髮
    0x9AEF: 'rán',  # 髯
    0x9AF0: 'tì',  # 髰
    0x9AF1: 'bào',  # 髱
    0x9AF2: 'bì,pǒ',  # 髲
    0x9AF3: 'máo,méng',  # 髳
    0x9AF4: 'fú',  # 髴
    0x9AF5: 'ér',  # 髵
    0x9AF6: 'èr',  # 髶
    0x9AF7: 'qū',  # 髷
    0x9AF8: 'gōng',  # 髸
    0x9AF9: 'xiū',  # 髹
    0x9AFA: 'kuò,yuè',  # 髺
    0x9AFB: 'jì',  # 髻
    0x9AFC: 'péng',  # 髼
    0x9AFD: 'zhuā',  # 髽
    0x9AFE: 'shāo',  # 髾
    0x9AFF: 'shā',  # 髿
    0x9B00: 'tì',  # 鬀
    0x9B01: 'lì',  # 鬁
    0x9B02: 'bìn',  # 鬂
    0x9B03: 'zōng',  # 鬃
    0x9B04: 'tì',  # 鬄
    0x9B05: 'péng',  # 鬅
    0x9B06: 'sōng',  # 鬆
    0x9B07: 'zhēng',  # 鬇
    0x9B08: 'quán',  # 鬈
    0x9B09: 'zōng',  # 鬉
    0x9B0A: 'shùn',  # 鬊
    0x9B0B: 'jiǎn',  # 鬋
    0x9B0C: 'duǒ',  # 鬌
    0x9B0D: 'hú',  # 鬍
    0x9B0E: 'là',  # 鬎
    0x9B0F: 'jiū',  # 鬏
    0x9B10: 'qí',  # 鬐
    0x9B11: 'lián',  # 鬑
    0x9B12: 'zhěn',  # 鬒
    0x9B13: 'bìn',  # 鬓
    0x9B14: 'péng',  # 鬔
    0x9B15: 'mà',  # 鬕
    0x9B16: 'sān',  # 鬖
    0x9B17: 'mán',  # 鬗
    0x9B18: 'mán',  # 鬘
    0x9B19: 'sēng',  # 鬙
    0x9B1A: 'xū',  # 鬚
    0x9B1B: 'liè',  # 鬛
    0x9B1C: 'qiān',  # 鬜
    0x9B1D: 'qiān',  # 鬝
    0x9B1E: 'nóng',  # 鬞
    0x9B1F: 'huán',  # 鬟
    0x9B20: 'kuò',  # 鬠
    0x9B21: 'níng',  # 鬡
    0x9B22: 'bìn',  # 鬢
    0x9B23: 'liè',  # 鬣
    0x9B24: 'ráng',  # 鬤
    0x9B25: 'dòu',  # 鬥
    0x9B26: 'dòu',  # 鬦
    0x9B27: 'nào',  # 鬧
    0x9B28: 'hòng',  # 鬨
    0x9B29: 'xì',  # 鬩
    0x9B2A: 'dòu',  # 鬪
    0x9B2B: 'kàn',  # 鬫
    0x9B2C: 'dòu',  # 鬬
    0x9B2D: 'dòu',  # 鬭
    0x9B2E: 'jiū',  # 鬮
    0x9B2F: 'chàng',  # 鬯
    0x9B30: 'yù',  # 鬰
    0x9B31: 'yù',  # 鬱
    0x9B32: 'gé,lì',  # 鬲
    0x9B33: 'yàn',  # 鬳
    0x9B34: 'fǔ',  # 鬴
    0x9B35: 'zèng',  # 鬵
    0x9B36: 'guī',  # 鬶
    0x9B37: 'zōng',  # 鬷
    0x9B38: 'liù',  # 鬸
    0x9B39: 'guī',  # 鬹
    0x9B3A: 'shāng',  # 鬺
    0x9B3B: 'yù',  # 鬻
    0x9B3C: 'guǐ',  # 鬼
    0x9B3D: 'mèi',  # 鬽
    0x9B3E: 'jì',  # 鬾
    0x9B3F: 'qí',  # 鬿
    0x9B40: 'gà',  # 魀
    0x9B41: 'kuí',  # 魁
    0x9B42: 'hún',  # 魂
    0x9B43: 'bá',  # 魃
    0x9B44: 'pò',  # 魄
    0x9B45: 'mèi',  # 魅
    0x9B46: 'xū',  # 魆
    0x9B47: 'yǎn',  # 魇
    0x9B48: 'xiāo',  # 魈
    0x9B49: 'liǎng',  # 魉
    0x9B4A: 'yù',  # 魊
    0x9B4B: 'tuí',  # 魋
    0x9B4C: 'qī',  # 魌
    0x9B4D: 'wǎng',  # 魍
    0x9B4E: 'liǎng',  # 魎
    0x9B4F: 'wèi',  # 魏
    0x9B50: 'gān',  # 魐
    0x9B51: 'chī',  # 魑
    0x9B52: 'piāo',  # 魒
    0x9B53: 'bì',  # 魓
    0x9B54: 'mó',  # 魔
    0x9B55: 'jī',  # 魕
    0x9B56: 'xū',  # 魖
    0x9B57: 'chǒu',  # 魗
    0x9B58: 'yǎn',  # 魘
    0x9B59: 'zhān',  # 魙
    0x9B5A: 'yú',  # 魚
    0x9B5B: 'dāo',  # 魛
    0x9B5C: 'rén',  # 魜
    0x9B5D: 'jì',  # 魝
    0x9B5E: 'bā,bà',  # 魞
    0x9B5F: 'hóng',  # 魟
    0x9B60: 'tuō',  # 魠
    0x9B61: 'diào',  # 魡
    0x9B62: 'jǐ',  # 魢
    0x9B63: 'yú',  # 魣
    0x9B64: 'é',  # 魤
    0x9B65: 'jì',  # 魥
    0x9B66: 'shā',  # 魦
    0x9B67: 'háng',  # 魧
    0x9B68: 'tún',  # 魨
    0x9B69: 'mò',  # 魩
    0x9B6A: 'jiè',  # 魪
    0x9B6B: 'shěn',  # 魫
    0x9B6C: 'bǎn',  # 魬
    0x9B6D: 'yuán',  # 魭
    0x9B6E: 'pí',  # 魮
    0x9B6F: 'lǔ',  # 魯
    0x9B70: 'wén',  # 魰
    0x9B71: 'hú',  # 魱
    0x9B72: 'lú',  # 魲
    0x9B73: 'zā',  # 魳
    0x9B74: 'fáng',  # 魴
    0x9B75: 'fén',  # 魵
    0x9B76: 'nà',  # 魶
    0x9B77: 'yóu',  # 魷
    0x9B78: 'piàn',  # 魸
    0x9B79: 'mó',  # 魹
    0x9B7A: 'hé',  # 魺
    0x9B7B: 'xiá',  # 魻
    0x9B7C: 'qū',  # 魼
    0x9B7D: 'hān',  # 魽
    0x9B7E: 'pī',  # 魾
    0x9B7F: 'líng',  # 魿
    0x9B80: 'tuó',  # 鮀
    0x9B81: 'bà',  # 鮁
    0x9B82: 'qiú',  # 鮂
    0x9B83: 'píng',  # 鮃
    0x9B84: 'fú',  # 鮄
    0x9B85: 'bì',  # 鮅
    0x9B86: 'cǐ,jì',  # 鮆
    0x9B87: 'wèi',  # 鮇
    0x9B88: 'jū',  # 鮈
    0x9B89: 'diāo',  # 鮉
    0x9B8A: 'bó,bà',  # 鮊
    0x9B8B: 'yóu',  # 鮋
    0x9B8C: 'gǔn',  # 鮌
    0x9B8D: 'pí',  # 鮍
    0x9B8E: 'nián',  # 鮎
    0x9B8F: 'xīng',  # 鮏
    0x9B90: 'tái',  # 鮐
    0x9B91: 'bào',  # 鮑
    0x9B92: 'fù',  # 鮒
    0x9B93: 'zhǎ,zhà',  # 鮓
    0x9B94: 'jù',  # 鮔
    0x9B95: 'gū',  # 鮕
    0x9B96: 'shí',  # 鮖
    0x9B97: 'dōng',  # 鮗
    0x9B98: 'chou,dài',  # 鮘
    0x9B99: 'tǎ',  # 鮙
    0x9B9A: 'jié',  # 鮚
    0x9B9B: 'shū',  # 鮛
    0x9B9C: 'hòu',  # 鮜
    0x9B9D: 'xiǎng',  # 鮝
    0x9B9E: 'ér',  # 鮞
    0x9B9F: 'ān',  # 鮟
    0x9BA0: 'wéi',  # 鮠
    0x9BA1: 'zhào',  # 鮡
    0x9BA2: 'zhū',  # 鮢
    0x9BA3: 'yìn',  # 鮣
    0x9BA4: 'liè',  # 鮤
    0x9BA5: 'luò,gé',  # 鮥
    0x9BA6: 'tóng',  # 鮦
    0x9BA7: 'yí',  # 鮧
    0x9BA8: 'yì',  # 鮨
    0x9BA9: 'bìng',  # 鮩
    0x9BAA: 'wěi',  # 鮪
    0x9BAB: 'jiāo',  # 鮫
    0x9BAC: 'kū',  # 鮬
    0x9BAD: 'guī,xié',  # 鮭
    0x9BAE: 'xiān,xiǎn',  # 鮮
    0x9BAF: 'gé',  # 鮯
    0x9BB0: 'huí',  # 鮰
    0x9BB1: 'lǎo',  # 鮱
    0x9BB2: 'fú',  # 鮲
    0x9BB3: 'kào',  # 鮳
    0x9BB4: 'xiū',  # 鮴
    0x9BB5: 'tuō',  # 鮵
    0x9BB6: 'jūn',  # 鮶
    0x9BB7: 'tí',  # 鮷
    0x9BB8: 'miǎn',  # 鮸
    0x9BB9: 'shāo',  # 鮹
    0x9BBA: 'zhǎ',  # 鮺
    0x9BBB: 'suō',  # 鮻
    0x9BBC: 'qīn',  # 鮼
    0x9BBD: 'yú',  # 鮽
    0x9BBE: 'něi',  # 鮾
    0x9BBF: 'zhé',  # 鮿
    0x9BC0: 'gǔn',  # 鯀
    0x9BC1: 'gěng',  # 鯁
    0x9BC2: 'sū',  # 鯂
    0x9BC3: 'wú',  # 鯃
    0x9BC4: 'qiú',  # 鯄
    0x9BC5: 'shān',  # 鯅
    0x9BC6: 'pū,bū',  # 鯆
    0x9BC7: 'huàn',  # 鯇
    0x9BC8: 'tiáo',  # 鯈
    0x9BC9: 'lǐ',  # 鯉
    0x9BCA: 'shā',  # 鯊
    0x9BCB: 'shā',  # 鯋
    0x9BCC: 'kào',  # 鯌
    0x9BCD: 'méng',  # 鯍
    0x9BCE: 'chéng',  # 鯎
    0x9BCF: 'lí',  # 鯏
    0x9BD0: 'zǒu',  # 鯐
    0x9BD1: 'xī',  # 鯑
    0x9BD2: 'yǒng',  # 鯒
    0x9BD3: 'shēn',  # 鯓
    0x9BD4: 'zī',  # 鯔
    0x9BD5: 'qí',  # 鯕
    0x9BD6: 'qīng',  # 鯖
    0x9BD7: 'xiǎng',  # 鯗
    0x9BD8: 'něi',  # 鯘
    0x9BD9: 'chún',  # 鯙
    0x9BDA: 'jì',  # 鯚
    0x9BDB: 'diāo',  # 鯛
    0x9BDC: 'qiè',  # 鯜
    0x9BDD: 'gù',  # 鯝
    0x9BDE: 'zhǒu',  # 鯞
    0x9BDF: 'dōng',  # 鯟
    0x9BE0: 'lái',  # 鯠
    0x9BE1: 'fēi',  # 鯡
    0x9BE2: 'ní',  # 鯢
    0x9BE3: 'yì,sī',  # 鯣
    0x9BE4: 'kūn',  # 鯤
    0x9BE5: 'lù',  # 鯥
    0x9BE6: 'jiù',  # 鯦
    0x9BE7: 'chāng',  # 鯧
    0x9BE8: 'jīng',  # 鯨
    0x9BE9: 'lún',  # 鯩
    0x9BEA: 'líng',  # 鯪
    0x9BEB: 'zōu',  # 鯫
    0x9BEC: 'lí',  # 鯬
    0x9BED: 'měng',  # 鯭
    0x9BEE: 'zōng',  # 鯮
    0x9BEF: 'zhì',  # 鯯
    0x9BF0: 'nián',  # 鯰
    0x9BF1: 'hǔ',  # 鯱
    0x9BF2: 'yú',  # 鯲
    0x9BF3: 'dǐ',  # 鯳
    0x9BF4: 'shī',  # 鯴
    0x9BF5: 'shēn',  # 鯵
    0x9BF6: 'huàn',  # 鯶
    0x9BF7: 'tí',  # 鯷
    0x9BF8: 'hóu',  # 鯸
    0x9BF9: 'xīng',  # 鯹
    0x9BFA: 'zhū',  # 鯺
    0x9BFB: 'là',  # 鯻
    0x9BFC: 'zōng',  # 鯼
    0x9BFD: 'jì',  # 鯽
    0x9BFE: 'biān',  # 鯾
    0x9BFF: 'biān',  # 鯿
    0x9C00: 'huàn',  # 鰀
    0x9C01: 'quán',  # 鰁
    0x9C02: 'zéi',  # 鰂
    0x9C03: 'wēi',  # 鰃
    0x9C04: 'wēi',  # 鰄
    0x9C05: 'yú',  # 鰅
    0x9C06: 'chūn',  # 鰆
    0x9C07: 'róu',  # 鰇
    0x9C08: 'dié',  # 鰈
    0x9C09: 'huáng',  # 鰉
    0x9C0A: 'liàn',  # 鰊
    0x9C0B: 'yǎn',  # 鰋
    0x9C0C: 'qiū',  # 鰌
    0x9C0D: 'qiū',  # 鰍
    0x9C0E: 'jiǎn',  # 鰎
    0x9C0F: 'bī',  # 鰏
    0x9C10: 'è',  # 鰐
    0x9C11: 'yáng',  # 鰑
    0x9C12: 'fù',  # 鰒
    0x9C13: 'sāi,xǐ',  # 鰓
    0x9C14: 'jiān',  # 鰔
    0x9C15: 'xiā',  # 鰕
    0x9C16: 'tuǒ',  # 鰖
    0x9C17: 'hú',  # 鰗
    0x9C18: 'shì',  # 鰘
    0x9C19: 'ruò',  # 鰙
    0x9C1A: 'xuān',  # 鰚
    0x9C1B: 'wēn',  # 鰛
    0x9C1C: 'jiān',  # 鰜
    0x9C1D: 'hào',  # 鰝
    0x9C1E: 'wū',  # 鰞
    0x9C1F: 'páng',  # 鰟
    0x9C20: 'sāo',  # 鰠
    0x9C21: 'liú',  # 鰡
    0x9C22: 'mǎ',  # 鰢
    0x9C23: 'shí',  # 鰣
    0x9C24: 'shī',  # 鰤
    0x9C25: 'guān',  # 鰥
    0x9C26: 'zī',  # 鰦
    0x9C27: 'téng',  # 鰧
    0x9C28: 'tǎ',  # 鰨
    0x9C29: 'yáo',  # 鰩
    0x9C2A: 'è',  # 鰪
    0x9C2B: 'yóng',  # 鰫
    0x9C2C: 'qián',  # 鰬
    0x9C2D: 'qí',  # 鰭
    0x9C2E: 'wēn',  # 鰮
    0x9C2F: 'ruò',  # 鰯
    0x9C30: 'shén',  # 鰰
    0x9C31: 'lián',  # 鰱
    0x9C32: 'áo',  # 鰲
    0x9C33: 'lè',  # 鰳
    0x9C34: 'huī',  # 鰴
    0x9C35: 'mǐn',  # 鰵
    0x9C36: 'jì',  # 鰶
    0x9C37: 'tiáo',  # 鰷
    0x9C38: 'qū',  # 鰸
    0x9C39: 'jiān',  # 鰹
    0x9C3A: 'shēn',  # 鰺
    0x9C3B: 'mán',  # 鰻
    0x9C3C: 'xí',  # 鰼
    0x9C3D: 'qiú',  # 鰽
    0x9C3E: 'piào',  # 鰾
    0x9C3F: 'jì',  # 鰿
    0x9C40: 'jì',  # 鱀
    0x9C41: 'zhú',  # 鱁
    0x9C42: 'jiāng',  # 鱂
    0x9C43: 'xiū',  # 鱃
    0x9C44: 'zhuān',  # 鱄
    0x9C45: 'yōng',  # 鱅
    0x9C46: 'zhāng',  # 鱆
    0x9C47: 'kāng',  # 鱇
    0x9C48: 'xuě',  # 鱈
    0x9C49: 'biē',  # 鱉
    0x9C4A: 'yù',  # 鱊
    0x9C4B: 'qū',  # 鱋
    0x9C4C: 'xiàng',  # 鱌
    0x9C4D: 'bō',  # 鱍
    0x9C4E: 'jiǎo',  # 鱎
    0x9C4F: 'xún',  # 鱏
    0x9C50: 'sù',  # 鱐
    0x9C51: 'huáng',  # 鱑
    0x9C52: 'zūn',  # 鱒
    0x9C53: 'shàn',  # 鱓
    0x9C54: 'shàn',  # 鱔
    0x9C55: 'fān',  # 鱕
    0x9C56: 'guì',  # 鱖
    0x9C57: 'lín',  # 鱗
    0x9C58: 'xún',  # 鱘
    0x9C59: 'yáo',  # 鱙
    0x9C5A: 'xǐ',  # 鱚
    0x9C5B: 'zēng',  # 鱛
    0x9C5C: 'xiāng',  # 鱜
    0x9C5D: 'fèn',  # 鱝
    0x9C5E: 'guān',  # 鱞
    0x9C5F: 'hòu',  # 鱟
    0x9C60: 'kuài',  # 鱠
    0x9C61: 'zéi',  # 鱡
    0x9C62: 'sāo',  # 鱢
    0x9C63: 'zhān',  # 鱣
    0x9C64: 'gǎn',  # 鱤
    0x9C65: 'guì',  # 鱥
    0x9C66: 'yìng',  # 鱦
    0x9C67: 'lǐ',  # 鱧
    0x9C68: 'cháng',  # 鱨
    0x9C69: 'léi',  # 鱩
    0x9C6A: 'shǔ',  # 鱪
    0x9C6B: 'ài',  # 鱫
    0x9C6C: 'rú',  # 鱬
    0x9C6D: 'jì',  # 鱭
    0x9C6E: 'xù',  # 鱮
    0x9C6F: 'hù',  # 鱯
    0x9C70: 'shǔ',  # 鱰
    0x9C71: 'lǐ',  # 鱱
    0x9C72: 'liè',  # 鱲
    0x9C73: 'lè',  # 鱳
    0x9C74: 'miè',  # 鱴
    0x9C75: 'zhēn',  # 鱵
    0x9C76: 'xiǎng',  # 鱶
    0x9C77: 'è',  # 鱷
    0x9C78: 'lú',  # 鱸
    0x9C79: 'guàn',  # 鱹
    0x9C7A: 'lí',  # 鱺
    0x9C7B: 'xiān',  # 鱻
    0x9C7C: 'yú',  # 鱼
    0x9C7D: 'dāo',  # 鱽
    0x9C7E: 'jǐ',  # 鱾
    0x9C7F: 'yóu',  # 鱿
    0x9C80: 'tún',  # 鲀
    0x9C81: 'lǔ',  # 鲁
    0x9C82: 'fáng',  # 鲂
    0x9C83: 'bā,bà',  # 鲃
    0x9C84: 'hé,gě',  # 鲄
    0x9C85: 'bà',  # 鲅
    0x9C86: 'píng',  # 鲆
    0x9C87: 'nián',  # 鲇
    0x9C88: 'lú',  # 鲈
    0x9C89: 'yóu',  # 鲉
    0x9C8A: 'zhǎ,zhà',  # 鲊
    0x9C8B: 'fù',  # 鲋
    0x9C8C: 'bó,bà',  # 鲌
    0x9C8D: 'bào',  # 鲍
    0x9C8E: 'hòu',  # 鲎
    0x9C8F: 'pí',  # 鲏
    0x9C90: 'tái',  # 鲐
    0x9C91: 'guī,xié',  # 鲑
    0x9C92: 'jié',  # 鲒
    0x9C93: 'kào',  # 鲓
    0x9C94: 'wěi',  # 鲔
    0x9C95: 'ér',  # 鲕
    0x9C96: 'tóng',  # 鲖
    0x9C97: 'zéi',  # 鲗
    0x9C98: 'hòu',  # 鲘
    0x9C99: 'kuài',  # 鲙
    0x9C9A: 'jì',  # 鲚
    0x9C9B: 'jiāo',  # 鲛
    0x9C9C: 'xiān,xiǎn',  # 鲜
    0x9C9D: 'zhǎ',  # 鲝
    0x9C9E: 'xiǎng',  # 鲞
    0x9C9F: 'xún',  # 鲟
    0x9CA0: 'gěng',  # 鲠
    0x9CA1: 'lí',  # 鲡
    0x9CA2: 'lián',  # 鲢
    0x9CA3: 'jiān',  # 鲣
    0x9CA4: 'lǐ',  # 鲤
    0x9CA5: 'shí',  # 鲥
    0x9CA6: 'tiáo',  # 鲦
    0x9CA7: 'gǔn',  # 鲧
    0x9CA8: 'shā',  # 鲨
    0x9CA9: 'huàn',  # 鲩
    0x9CAA: 'jūn',  # 鲪
    0x9CAB: 'jì',  # 鲫
    0x9CAC: 'yǒng',  # 鲬
    0x9CAD: 'qīng',  # 鲭
    0x9CAE: 'líng',  # 鲮
    0x9CAF: 'qí',  # 鲯
    0x9CB0: 'zōu',  # 鲰
    0x9CB1: 'fēi',  # 鲱
    0x9CB2: 'kūn',  # 鲲
    0x9CB3: 'chāng',  # 鲳
    0x9CB4: 'gù',  # 鲴
    0x9CB5: 'ní',  # 鲵
    0x9CB6: 'nián',  # 鲶
    0x9CB7: 'diāo',  # 鲷
    0x9CB8: 'jīng',  # 鲸
    0x9CB9: 'shēn',  # 鲹
    0x9CBA: 'shī',  # 鲺
    0x9CBB: 'zī',  # 鲻
    0x9CBC: 'fèn',  # 鲼
    0x9CBD: 'dié',  # 鲽
    0x9CBE: 'bī',  # 鲾
    0x9CBF: 'cháng',  # 鲿
    0x9CC0: 'tí',  # 鳀
    0x9CC1: 'wēn',  # 鳁
    0x9CC2: 'wēi',  # 鳂
    0x9CC3: 'sāi,xǐ',  # 鳃
    0x9CC4: 'è',  # 鳄
    0x9CC5: 'qiū',  # 鳅
    0x9CC6: 'fù',  # 鳆
    0x9CC7: 'huáng',  # 鳇
    0x9CC8: 'quán',  # 鳈
    0x9CC9: 'jiāng',  # 鳉
    0x9CCA: 'biān',  # 鳊
    0x9CCB: 'sāo',  # 鳋
    0x9CCC: 'áo',  # 鳌
    0x9CCD: 'qí',  # 鳍
    0x9CCE: 'tǎ',  # 鳎
    0x9CCF: 'guān',  # 鳏
    0x9CD0: 'yáo',  # 鳐
    0x9CD1: 'páng',  # 鳑
    0x9CD2: 'jiān',  # 鳒
    0x9CD3: 'lè',  # 鳓
    0x9CD4: 'biào',  # 鳔
    0x9CD5: 'xuě',  # 鳕
    0x9CD6: 'biē',  # 鳖
    0x9CD7: 'mán',  # 鳗
    0x9CD8: 'mǐn',  # 鳘
    0x9CD9: 'yōng',  # 鳙
    0x9CDA: 'wèi',  # 鳚
    0x9CDB: 'xí',  # 鳛
    0x9CDC: 'guì,jué',  # 鳜
    0x9CDD: 'shàn',  # 鳝
    0x9CDE: 'lín',  # 鳞
    0x9CDF: 'zūn',  # 鳟
    0x9CE0: 'hù',  # 鳠
    0x9CE1: 'gǎn',  # 鳡
    0x9CE2: 'lǐ',  # 鳢
    0x9CE3: 'zhān,shàn',  # 鳣
    0x9CE4: 'guǎn',  # 鳤
    0x9CE5: 'niǎo,diǎo',  # 鳥
    0x9CE6: 'yǐ',  # 鳦
    0x9CE7: 'fú',  # 鳧
    0x9CE8: 'lì',  # 鳨
    0x9CE9: 'jiū',  # 鳩
    0x9CEA: 'bú',  # 鳪
    0x9CEB: 'yàn',  # 鳫
    0x9CEC: 'fú',  # 鳬
    0x9CED: 'diāo,zhāo',  # 鳭
    0x9CEE: 'jī',  # 鳮
    0x9CEF: 'fèng',  # 鳯
    0x9CF0: 'rù',  # 鳰
    0x9CF1: 'gān,hàn,yàn',  # 鳱
    0x9CF2: 'shī',  # 鳲
    0x9CF3: 'fèng',  # 鳳
    0x9CF4: 'míng',  # 鳴
    0x9CF5: 'bǎo',  # 鳵
    0x9CF6: 'yuān',  # 鳶
    0x9CF7: 'zhī',  # 鳷
    0x9CF8: 'hù',  # 鳸
    0x9CF9: 'qín',  # 鳹
    0x9CFA: 'fū,guī',  # 鳺
    0x9CFB: 'bān,fén',  # 鳻
    0x9CFC: 'wén',  # 鳼
    0x9CFD: 'jiān,qiān,zhān',  # 鳽
    0x9CFE: 'shī',  # 鳾
    0x9CFF: 'yù',  # 鳿
    0x9D00: 'fǒu',  # 鴀
    0x9D01: 'yāo',  # 鴁
    0x9D02: 'jué',  # 鴂
    0x9D03: 'jué',  # 鴃
    0x9D04: 'pǐ',  # 鴄
    0x9D05: 'huān',  # 鴅
    0x9D06: 'zhèn',  # 鴆
    0x9D07: 'bǎo',  # 鴇
    0x9D08: 'yàn',  # 鴈
    0x9D09: 'yā',  # 鴉
    0x9D0A: 'zhèng',  # 鴊
    0x9D0B: 'fāng',  # 鴋
    0x9D0C: 'fèng',  # 鴌
    0x9D0D: 'wén',  # 鴍
    0x9D0E: 'ōu',  # 鴎
    0x9D0F: 'dài',  # 鴏
    0x9D10: 'jiā',  # 鴐
    0x9D11: 'rú',  # 鴑
    0x9D12: 'líng',  # 鴒
    0x9D13: 'miè',  # 鴓
    0x9D14: 'fú',  # 鴔
    0x9D15: 'tuó',  # 鴕
    0x9D16: 'mín',  # 鴖
    0x9D17: 'lì',  # 鴗
    0x9D18: 'biǎn',  # 鴘
    0x9D19: 'zhì',  # 鴙
    0x9D1A: 'gē',  # 鴚
    0x9D1B: 'yuān',  # 鴛
    0x9D1C: 'cí',  # 鴜
    0x9D1D: 'qú',  # 鴝
    0x9D1E: 'xiāo',  # 鴞
    0x9D1F: 'chī',  # 鴟
    0x9D20: 'dàn',  # 鴠
    0x9D21: 'jū',  # 鴡
    0x9D22: 'yāo',  # 鴢
    0x9D23: 'gū',  # 鴣
    0x9D24: 'zhōng',  # 鴤
    0x9D25: 'yù',  # 鴥
    0x9D26: 'yāng',  # 鴦
    0x9D27: 'yù',  # 鴧
    0x9D28: 'yā',  # 鴨
    0x9D29: 'dié',  # 鴩
    0x9D2A: 'yù',  # 鴪
    0x9D2B: 'tián',  # 鴫
    0x9D2C: 'yīng',  # 鴬
    0x9D2D: 'duī',  # 鴭
    0x9D2E: 'wū',  # 鴮
    0x9D2F: 'ér',  # 鴯
    0x9D30: 'guā',  # 鴰
    0x9D31: 'ài',  # 鴱
    0x9D32: 'zhī',  # 鴲
    0x9D33: 'yàn',  # 鴳
    0x9D34: 'héng',  # 鴴
    0x9D35: 'xiāo',  # 鴵
    0x9D36: 'jiá',  # 鴶
    0x9D37: 'liè',  # 鴷
    0x9D38: 'zhū',  # 鴸
    0x9D39: 'yáng',  # 鴹
    0x9D3A: 'yí',  # 鴺
    0x9D3B: 'hóng',  # 鴻
    0x9D3C: 'lù',  # 鴼
    0x9D3D: 'rú',  # 鴽
    0x9D3E: 'móu',  # 鴾
    0x9D3F: 'gē',  # 鴿
    0x9D40: 'rén',  # 鵀
    0x9D41: 'jiāo',  # 鵁
    0x9D42: 'xiū',  # 鵂
    0x9D43: 'zhōu',  # 鵃
    0x9D44: 'chī',  # 鵄
    0x9D45: 'luò',  # 鵅
    0x9D46: 'héng',  # 鵆
    0x9D47: 'nián',  # 鵇
    0x9D48: 'ě',  # 鵈
    0x9D49: 'luán',  # 鵉
    0x9D4A: 'jiá',  # 鵊
    0x9D4B: 'jì',  # 鵋
    0x9D4C: 'tú',  # 鵌
    0x9D4D: 'huān',  # 鵍
    0x9D4E: 'tuǒ',  # 鵎
    0x9D4F: 'bū',  # 鵏
    0x9D50: 'wú',  # 鵐
    0x9D51: 'jiān',  # 鵑
    0x9D52: 'yù',  # 鵒
    0x9D53: 'bó',  # 鵓
    0x9D54: 'jùn',  # 鵔
    0x9D55: 'jùn',  # 鵕
    0x9D56: 'bī',  # 鵖
    0x9D57: 'xī',  # 鵗
    0x9D58: 'jùn',  # 鵘
    0x9D59: 'jú',  # 鵙
    0x9D5A: 'tū',  # 鵚
    0x9D5B: 'jìng',  # 鵛
    0x9D5C: 'tí',  # 鵜
    0x9D5D: 'é',  # 鵝
    0x9D5E: 'é',  # 鵞
    0x9D5F: 'kuáng',  # 鵟
    0x9D60: 'hú',  # 鵠
    0x9D61: 'wǔ',  # 鵡
    0x9D62: 'shēn',  # 鵢
    0x9D63: 'lài',  # 鵣
    0x9D64: 'zān',  # 鵤
    0x9D65: 'pàn',  # 鵥
    0x9D66: 'lù',  # 鵦
    0x9D67: 'pí',  # 鵧
    0x9D68: 'shū',  # 鵨
    0x9D69: 'fú',  # 鵩
    0x9D6A: 'ān',  # 鵪
    0x9D6B: 'zhuó',  # 鵫
    0x9D6C: 'péng',  # 鵬
    0x9D6D: 'qín',  # 鵭
    0x9D6E: 'qiān',  # 鵮
    0x9D6F: 'bēi',  # 鵯
    0x9D70: 'diāo',  # 鵰
    0x9D71: 'lù',  # 鵱
    0x9D72: 'què',  # 鵲
    0x9D73: 'jiān',  # 鵳
    0x9D74: 'jú',  # 鵴
    0x9D75: 'tù',  # 鵵
    0x9D76: 'yā',  # 鵶
    0x9D77: 'yuān',  # 鵷
    0x9D78: 'qí',  # 鵸
    0x9D79: 'lí',  # 鵹
    0x9D7A: 'yè',  # 鵺
    0x9D7B: 'zhuī',  # 鵻
    0x9D7C: 'kōng',  # 鵼
    0x9D7D: 'duò',  # 鵽
    0x9D7E: 'kūn',  # 鵾
    0x9D7F: 'shēng',  # 鵿
    0x9D80: 'qí',  # 鶀
    0x9D81: 'jīng',  # 鶁
    0x9D82: 'yì',  # 鶂
    0x9D83: 'yì',  # 鶃
    0x9D84: 'jīng',  # 鶄
    0x9D85: 'zī',  # 鶅
    0x9D86: 'lái',  # 鶆
    0x9D87: 'dōng',  # 鶇
    0x9D88: 'qī',  # 鶈
    0x9D89: 'chún',  # 鶉
    0x9D8A: 'gēng',  # 鶊
    0x9D8B: 'jū',  # 鶋
    0x9D8C: 'qū',  # 鶌
    0x9D8D: 'yì',  # 鶍
    0x9D8E: 'zūn',  # 鶎
    0x9D8F: 'jī',  # 鶏
    0x9D90: 'shù',  # 鶐
    0x9D91: 'yīng',  # 鶑
    0x9D92: 'chì',  # 鶒
    0x9D93: 'miáo',  # 鶓
    0x9D94: 'róu',  # 鶔
    0x9D95: 'ān',  # 鶕
    0x9D96: 'qiū',  # 鶖
    0x9D97: 'tí,chí',  # 鶗
    0x9D98: 'hú',  # 鶘
    0x9D99: 'tí,chí',  # 鶙
    0x9D9A: 'è',  # 鶚
    0x9D9B: 'jiē',  # 鶛
    0x9D9C: 'máo',  # 鶜
    0x9D9D: 'fú,bì',  # 鶝
    0x9D9E: 'chūn',  # 鶞
    0x9D9F: 'tú',  # 鶟
    0x9DA0: 'yǎn',  # 鶠
    0x9DA1: 'hé,jiè',  # 鶡
    0x9DA2: 'yuán',  # 鶢
    0x9DA3: 'piān,biǎn',  # 鶣
    0x9DA4: 'kūn',  # 鶤
    0x9DA5: 'méi',  # 鶥
    0x9DA6: 'hú',  # 鶦
    0x9DA7: 'yīng',  # 鶧
    0x9DA8: 'chuàn,zhì',  # 鶨
    0x9DA9: 'wù',  # 鶩
    0x9DAA: 'jú',  # 鶪
    0x9DAB: 'dōng',  # 鶫
    0x9DAC: 'cāng,qiāng',  # 鶬
    0x9DAD: 'fǎng',  # 鶭
    0x9DAE: 'hè,hú',  # 鶮
    0x9DAF: 'yīng',  # 鶯
    0x9DB0: 'yuán',  # 鶰
    0x9DB1: 'xiān',  # 鶱
    0x9DB2: 'wēng',  # 鶲
    0x9DB3: 'shī',  # 鶳
    0x9DB4: 'hè',  # 鶴
    0x9DB5: 'chú',  # 鶵
    0x9DB6: 'táng',  # 鶶
    0x9DB7: 'xiá',  # 鶷
    0x9DB8: 'ruò',  # 鶸
    0x9DB9: 'liú',  # 鶹
    0x9DBA: 'jī',  # 鶺
    0x9DBB: 'gǔ,hú',  # 鶻
    0x9DBC: 'jiān',  # 鶼
    0x9DBD: 'sǔn,xùn',  # 鶽
    0x9DBE: 'hàn',  # 鶾
    0x9DBF: 'cí',  # 鶿
    0x9DC0: 'cí',  # 鷀
    0x9DC1: 'yì',  # 鷁
    0x9DC2: 'yào',  # 鷂
    0x9DC3: 'yàn',  # 鷃
    0x9DC4: 'jī',  # 鷄
    0x9DC5: 'lì',  # 鷅
    0x9DC6: 'tián',  # 鷆
    0x9DC7: 'kòu',  # 鷇
    0x9DC8: 'tī',  # 鷈
    0x9DC9: 'tī',  # 鷉
    0x9DCA: 'yì',  # 鷊
    0x9DCB: 'tú',  # 鷋
    0x9DCC: 'mǎ',  # 鷌
    0x9DCD: 'xiāo',  # 鷍
    0x9DCE: 'gāo',  # 鷎
    0x9DCF: 'tián',  # 鷏
    0x9DD0: 'chén',  # 鷐
    0x9DD1: 'jì',  # 鷑
    0x9DD2: 'tuán',  # 鷒
    0x9DD3: 'zhè',  # 鷓
    0x9DD4: 'áo',  # 鷔
    0x9DD5: 'yǎo',  # 鷕
    0x9DD6: 'yī',  # 鷖
    0x9DD7: 'ōu',  # 鷗
    0x9DD8: 'chì',  # 鷘
    0x9DD9: 'zhì',  # 鷙
    0x9DDA: 'liù',  # 鷚
    0x9DDB: 'yōng',  # 鷛
    0x9DDC: 'lóu,lǚ',  # 鷜
    0x9DDD: 'bì',  # 鷝
    0x9DDE: 'shuāng',  # 鷞
    0x9DDF: 'zhuó',  # 鷟
    0x9DE0: 'yú',  # 鷠
    0x9DE1: 'wú',  # 鷡
    0x9DE2: 'jué',  # 鷢
    0x9DE3: 'yín',  # 鷣
    0x9DE4: 'tí',  # 鷤
    0x9DE5: 'sī',  # 鷥
    0x9DE6: 'jiāo',  # 鷦
    0x9DE7: 'yì',  # 鷧
    0x9DE8: 'huá',  # 鷨
    0x9DE9: 'bì',  # 鷩
    0x9DEA: 'yīng',  # 鷪
    0x9DEB: 'sù',  # 鷫
    0x9DEC: 'huáng',  # 鷬
    0x9DED: 'fán',  # 鷭
    0x9DEE: 'jiāo',  # 鷮
    0x9DEF: 'liáo',  # 鷯
    0x9DF0: 'yàn',  # 鷰
    0x9DF1: 'gāo',  # 鷱
    0x9DF2: 'jiù',  # 鷲
    0x9DF3: 'xián',  # 鷳
    0x9DF4: 'xián',  # 鷴
    0x9DF5: 'tú',  # 鷵
    0x9DF6: 'mǎi',  # 鷶
    0x9DF7: 'zūn',  # 鷷
    0x9DF8: 'yù',  # 鷸
    0x9DF9: 'yīng',  # 鷹
    0x9DFA: 'lù',  # 鷺
    0x9DFB: 'tuán',  # 鷻
    0x9DFC: 'xián',  # 鷼
    0x9DFD: 'xué',  # 鷽
    0x9DFE: 'yì',  # 鷾
    0x9DFF: 'pì',  # 鷿
    0x9E00: 'zhǔ',  # 鸀
    0x9E01: 'luó',  # 鸁
    0x9E02: 'xī',  # 鸂
    0x9E03: 'yì',  # 鸃
    0x9E04: 'jī',  # 鸄
    0x9E05: 'zé',  # 鸅
    0x9E06: 'yú',  # 鸆
    0x9E07: 'zhān',  # 鸇
    0x9E08: 'yè',  # 鸈
    0x9E09: 'yáng',  # 鸉
    0x9E0A: 'pì',  # 鸊
    0x9E0B: 'níng',  # 鸋
    0x9E0C: 'hù',  # 鸌
    0x9E0D: 'mí',  # 鸍
    0x9E0E: 'yīng',  # 鸎
    0x9E0F: 'méng',  # 鸏
    0x9E10: 'dí',  # 鸐
    0x9E11: 'yuè',  # 鸑
    0x9E12: 'yù',  # 鸒
    0x9E13: 'lěi',  # 鸓
    0x9E14: 'bǔ',  # 鸔
    0x9E15: 'lú',  # 鸕
    0x9E16: 'hè',  # 鸖
    0x9E17: 'lóng',  # 鸗
    0x9E18: 'shuāng',  # 鸘
    0x9E19: 'yuè',  # 鸙
    0x9E1A: 'yīng',  # 鸚
    0x9E1B: 'guàn',  # 鸛
    0x9E1C: 'qú',  # 鸜
    0x9E1D: 'lí',  # 鸝
    0x9E1E: 'luán',  # 鸞
    0x9E1F: 'niǎo',  # 鸟
    0x9E20: 'jiū',  # 鸠
    0x9E21: 'jī',  # 鸡
    0x9E22: 'yuān',  # 鸢
    0x9E23: 'míng',  # 鸣
    0x9E24: 'shī',  # 鸤
    0x9E25: 'ōu',  # 鸥
    0x9E26: 'yā',  # 鸦
    0x9E27: 'cāng',  # 鸧
    0x9E28: 'bǎo',  # 鸨
    0x9E29: 'zhèn',  # 鸩
    0x9E2A: 'gū',  # 鸪
    0x9E2B: 'dōng',  # 鸫
    0x9E2C: 'lú',  # 鸬
    0x9E2D: 'yā',  # 鸭
    0x9E2E: 'xiāo',  # 鸮
    0x9E2F: 'yāng',  # 鸯
    0x9E30: 'líng',  # 鸰
    0x9E31: 'chī',  # 鸱
    0x9E32: 'qú',  # 鸲
    0x9E33: 'yuān',  # 鸳
    0x9E34: 'xué',  # 鸴
    0x9E35: 'tuó',  # 鸵
    0x9E36: 'sī',  # 鸶
    0x9E37: 'zhì',  # 鸷
    0x9E38: 'ér',  # 鸸
    0x9E39: 'guā',  # 鸹
    0x9E3A: 'xiū',  # 鸺
    0x9E3B: 'héng',  # 鸻
    0x9E3C: 'zhōu',  # 鸼
    0x9E3D: 'gē',  # 鸽
    0x9E3E: 'luán',  # 鸾
    0x9E3F: 'hóng',  # 鸿
    0x9E40: 'wú',  # 鹀
    0x9E41: 'bó',  # 鹁
    0x9E42: 'lí',  # 鹂
    0x9E43: 'juān',  # 鹃
    0x9E44: 'hú',  # 鹄
    0x9E45: 'é',  # 鹅
    0x9E46: 'yù',  # 鹆
    0x9E47: 'xián',  # 鹇
    0x9E48: 'tí',  # 鹈
    0x9E49: 'wǔ',  # 鹉
    0x9E4A: 'què',  # 鹊
    0x9E4B: 'miáo',  # 鹋
    0x9E4C: 'ān',  # 鹌
    0x9E4D: 'kūn',  # 鹍
    0x9E4E: 'bēi',  # 鹎
    0x9E4F: 'péng',  # 鹏
    0x9E50: 'qiān',  # 鹐
    0x9E51: 'chún',  # 鹑
    0x9E52: 'gēng',  # 鹒
    0x9E53: 'yuān',  # 鹓
    0x9E54: 'sù',  # 鹔
    0x9E55: 'hú',  # 鹕
    0x9E56: 'hé',  # 鹖
    0x9E57: 'è',  # 鹗
    0x9E58: 'gǔ',  # 鹘
    0x9E59: 'qiū',  # 鹙
    0x9E5A: 'cí',  # 鹚
    0x9E5B: 'méi',  # 鹛
    0x9E5C: 'wù',  # 鹜
    0x9E5D: 'yì',  # 鹝
    0x9E5E: 'yào',  # 鹞
    0x9E5F: 'wēng',  # 鹟
    0x9E60: 'liú',  # 鹠
    0x9E61: 'jī',  # 鹡
    0x9E62: 'yì',  # 鹢
    0x9E63: 'jiān',  # 鹣
    0x9E64: 'hè',  # 鹤
    0x9E65: 'yī',  # 鹥
    0x9E66: 'yīng',  # 鹦
    0x9E67: 'zhè',  # 鹧
    0x9E68: 'liù',  # 鹨
    0x9E69: 'liáo',  # 鹩
    0x9E6A: 'jiāo',  # 鹪
    0x9E6B: 'jiù',  # 鹫
    0x9E6C: 'yù',  # 鹬
    0x9E6D: 'lù',  # 鹭
    0x9E6E: 'huán',  # 鹮
    0x9E6F: 'zhān',  # 鹯
    0x9E70: 'yīng',  # 鹰
    0x9E71: 'hù',  # 鹱
    0x9E72: 'méng',  # 鹲
    0x9E73: 'guàn',  # 鹳
    0x9E74: 'shuāng',  # 鹴
    0x9E75: 'lǔ',  # 鹵
    0x9E76: 'jīn',  # 鹶
    0x9E77: 'líng',  # 鹷
    0x9E78: 'jiǎn',  # 鹸
    0x9E79: 'xián',  # 鹹
    0x9E7A: 'cuó',  # 鹺
    0x9E7B: 'jiǎn',  # 鹻
    0x9E7C: 'jiǎn',  # 鹼
    0x9E7D: 'yán',  # 鹽
    0x9E7E: 'cuó',  # 鹾
    0x9E7F: 'lù',  # 鹿
    0x9E80: 'yōu',  # 麀
    0x9E81: 'cū',  # 麁
    0x9E82: 'jǐ',  # 麂
    0x9E83: 'páo,biāo',  # 麃
    0x9E84: 'cū',  # 麄
    0x9E85: 'páo',  # 麅
    0x9E86: 'zhù,cū',  # 麆
    0x9E87: 'jūn,qún',  # 麇
    0x9E88: 'zhǔ',  # 麈
    0x9E89: 'jiān',  # 麉
    0x9E8A: 'mí',  # 麊
    0x9E8B: 'mí',  # 麋
    0x9E8C: 'yǔ',  # 麌
    0x9E8D: 'liú',  # 麍
    0x9E8E: 'chén',  # 麎
    0x9E8F: 'jūn',  # 麏
    0x9E90: 'lín',  # 麐
    0x9E91: 'ní',  # 麑
    0x9E92: 'qí',  # 麒
    0x9E93: 'lù',  # 麓
    0x9E94: 'jiù',  # 麔
    0x9E95: 'jūn',  # 麕
    0x9E96: 'jīng',  # 麖
    0x9E97: 'lí,lì',  # 麗
    0x9E98: 'xiāng',  # 麘
    0x9E99: 'xián',  # 麙
    0x9E9A: 'jiā',  # 麚
    0x9E9B: 'mí',  # 麛
    0x9E9C: 'lì',  # 麜
    0x9E9D: 'shè',  # 麝
    0x9E9E: 'zhāng',  # 麞
    0x9E9F: 'lín',  # 麟
    0x9EA0: 'jīng',  # 麠
    0x9EA1: 'qí',  # 麡
    0x9EA2: 'líng',  # 麢
    0x9EA3: 'yán',  # 麣
    0x9EA4: 'cū',  # 麤
    0x9EA5: 'mài',  # 麥
    0x9EA6: 'mài',  # 麦
    0x9EA7: 'hé',  # 麧
    0x9EA8: 'chǎo',  # 麨
    0x9EA9: 'fū',  # 麩
    0x9EAA: 'miàn',  # 麪
    0x9EAB: 'miàn',  # 麫
    0x9EAC: 'fū',  # 麬
    0x9EAD: 'pào',  # 麭
    0x9EAE: 'qù',  # 麮
    0x9EAF: 'qū',  # 麯
    0x9EB0: 'móu',  # 麰
    0x9EB1: 'fū',  # 麱
    0x9EB2: 'xiàn',  # 麲
    0x9EB3: 'lái',  # 麳
    0x9EB4: 'qū',  # 麴
    0x9EB5: 'miàn',  # 麵
    0x9EB6: 'chi',  # 麶
    0x9EB7: 'fēng',  # 麷
    0x9EB8: 'fū',  # 麸
    0x9EB9: 'qū',  # 麹
    0x9EBA: 'miàn',  # 麺
    0x9EBB: 'má',  # 麻
    0x9EBC: 'mó,me',  # 麼
    0x9EBD: 'mó,me,ma',  # 麽
    0x9EBE: 'huī',  # 麾
    0x9EBF: 'mí',  # 麿
    0x9EC0: 'zōu',  # 黀
    0x9EC1: 'nún',  # 黁
    0x9EC2: 'fén',  # 黂
    0x9EC3: 'huáng',  # 黃
    0x9EC4: 'huáng',  # 黄
    0x9EC5: 'jīn',  # 黅
    0x9EC6: 'guāng',  # 黆
    0x9EC7: 'tiān',  # 黇
    0x9EC8: 'tǒu',  # 黈
    0x9EC9: 'hóng',  # 黉
    0x9ECA: 'huà',  # 黊
    0x9ECB: 'kuàng',  # 黋
    0x9ECC: 'hóng',  # 黌
    0x9ECD: 'shǔ',  # 黍
    0x9ECE: 'lí',  # 黎
    0x9ECF: 'nián',  # 黏
    0x9ED0: 'chī',  # 黐
    0x9ED1: 'hēi',  # 黑
    0x9ED2: 'hēi',  # 黒
    0x9ED3: 'yì',  # 黓
    0x9ED4: 'qián',  # 黔
    0x9ED5: 'dǎn',  # 黕
    0x9ED6: 'xì',  # 黖
    0x9ED7: 'tún',  # 黗
    0x9ED8: 'mò',  # 默
    0x9ED9: 'mò',  # 黙
    0x9EDA: 'qián',  # 黚
    0x9EDB: 'dài',  # 黛
    0x9EDC: 'chù',  # 黜
    0x9EDD: 'yǒu',  # 黝
    0x9EDE: 'diǎn',  # 點
    0x9EDF: 'yī',  # 黟
    0x9EE0: 'xiá',  # 黠
    0x9EE1: 'yǎn',  # 黡
    0x9EE2: 'qū',  # 黢
    0x9EE3: 'měi',  # 黣
    0x9EE4: 'yǎn',  # 黤
    0x9EE5: 'qíng',  # 黥
    0x9EE6: 'yuè',  # 黦
    0x9EE7: 'lí',  # 黧
    0x9EE8: 'dǎng',  # 黨
    0x9EE9: 'dú',  # 黩
    0x9EEA: 'cǎn',  # 黪
    0x9EEB: 'yān',  # 黫
    0x9EEC: 'yǎn',  # 黬
    0x9EED: 'yǎn',  # 黭
    0x9EEE: 'dàn,shèn',  # 黮
    0x9EEF: 'àn',  # 黯
    0x9EF0: 'zhěn,yān',  # 黰
    0x9EF1: 'dài',  # 黱
    0x9EF2: 'cǎn',  # 黲
    0x9EF3: 'yī',  # 黳
    0x9EF4: 'méi',  # 黴
    0x9EF5: 'dǎn,zhǎn',  # 黵
    0x9EF6: 'yǎn',  # 黶
    0x9EF7: 'dú',  # 黷
    0x9EF8: 'lú',  # 黸
    0x9EF9: 'zhǐ',  # 黹
    0x9EFA: 'fěn',  # 黺
    0x9EFB: 'fú',  # 黻
    0x9EFC: 'fǔ',  # 黼
    0x9EFD: 'mǐn,miǎn,měng',  # 黽
    0x9EFE: 'mǐn,miǎn,měng',  # 黾
    0x9EFF: 'yuán',  # 黿
    0x9F00: 'cù',  # 鼀
    0x9F01: 'qù',  # 鼁
    0x9F02: 'cháo',  # 鼂
    0x9F03: 'wā',  # 鼃
    0x9F04: 'zhū',  # 鼄
    0x9F05: 'zhī',  # 鼅
    0x9F06: 'měng',  # 鼆
    0x9F07: 'áo',  # 鼇
    0x9F08: 'biē',  # 鼈
    0x9F09: 'tuó',  # 鼉
    0x9F0A: 'bì',  # 鼊
    0x9F0B: 'yuán',  # 鼋
    0x9F0C: 'cháo',  # 鼌
    0x9F0D: 'tuó',  # 鼍
    0x9F0E: 'dǐng',  # 鼎
    0x9F0F: 'mì',  # 鼏
    0x9F10: 'nài',  # 鼐
    0x9F11: 'dǐng',  # 鼑
    0x9F12: 'zī',  # 鼒
    0x9F13: 'gǔ',  # 鼓
    0x9F14: 'gǔ',  # 鼔
    0x9F15: 'dōng',  # 鼕
    0x9F16: 'fén',  # 鼖
    0x9F17: 'táo',  # 鼗
    0x9F18: 'yuān',  # 鼘
    0x9F19: 'pí',  # 鼙
    0x9F1A: 'chāng',  # 鼚
    0x9F1B: 'gāo',  # 鼛
    0x9F1C: 'cào',  # 鼜
    0x9F1D: 'yuān',  # 鼝
    0x9F1E: 'tāng',  # 鼞
    0x9F1F: 'tēng',  # 鼟
    0x9F20: 'shǔ',  # 鼠
    0x9F21: 'shǔ',  # 鼡
    0x9F22: 'fén',  # 鼢
    0x9F23: 'fèi',  # 鼣
    0x9F24: 'wén',  # 鼤
    0x9F25: 'bá',  # 鼥
    0x9F26: 'diāo',  # 鼦
    0x9F27: 'tuó',  # 鼧
    0x9F28: 'zhōng',  # 鼨
    0x9F29: 'qú',  # 鼩
    0x9F2A: 'shēng',  # 鼪
    0x9F2B: 'shí',  # 鼫
    0x9F2C: 'yòu',  # 鼬
    0x9F2D: 'shí',  # 鼭
    0x9F2E: 'tíng',  # 鼮
    0x9F2F: 'wú',  # 鼯
    0x9F30: 'jú',  # 鼰
    0x9F31: 'jīng',  # 鼱
    0x9F32: 'hún',  # 鼲
    0x9F33: 'jú',  # 鼳
    0x9F34: 'yǎn',  # 鼴
    0x9F35: 'tū',  # 鼵
    0x9F36: 'sī',  # 鼶
    0x9F37: 'xī',  # 鼷
    0x9F38: 'xiàn',  # 鼸
    0x9F39: 'yǎn',  # 鼹
    0x9F3A: 'léi',  # 鼺
    0x9F3B: 'bí',  # 鼻
    0x9F3C: 'yào',  # 鼼
    0x9F3D: 'qiú',  # 鼽
    0x9F3E: 'hān',  # 鼾
    0x9F3F: 'wù',  # 鼿
    0x9F40: 'wù',  # 齀
    0x9F41: 'hōu',  # 齁
    0x9F42: 'xiè',  # 齂
    0x9F43: 'è',  # 齃
    0x9F44: 'zhā',  # 齄
    0x9F45: 'xiù',  # 齅
    0x9F46: 'wèng',  # 齆
    0x9F47: 'zhā',  # 齇
    0x9F48: 'nòng',  # 齈
    0x9F49: 'nàng',  # 齉
    0x9F4A: 'qí,zhāi',  # 齊
    0x9F4B: 'zhāi',  # 齋
    0x9F4C: 'jì',  # 齌
    0x9F4D: 'zī',  # 齍
    0x9F4E: 'jí',  # 齎
    0x9F4F: 'jī',  # 齏
    0x9F50: 'qí,jì,zī,zhāi',  # 齐
    0x9F51: 'jī',  # 齑
    0x9F52: 'chǐ',  # 齒
    0x9F53: 'chèn',  # 齓
    0x9F54: 'chèn',  # 齔
    0x9F55: 'hé',  # 齕
    0x9F56: 'yá',  # 齖
    0x9F57: 'yīn',  # 齗
    0x9F58: 'xiè',  # 齘
    0x9F59: 'bāo',  # 齙
    0x9F5A: 'zé',  # 齚
    0x9F5B: 'xiè',  # 齛
    0x9F5C: 'zī',  # 齜
    0x9F5D: 'chī',  # 齝
    0x9F5E: 'yàn',  # 齞
    0x9F5F: 'jǔ',  # 齟
    0x9F60: 'tiáo',  # 齠
    0x9F61: 'líng',  # 齡
    0x9F62: 'líng',  # 齢
    0x9F63: 'chū',  # 齣
    0x9F64: 'quán',  # 齤
    0x9F65: 'xiè',  # 齥
    0x9F66: 'yín',  # 齦
    0x9F67: 'niè',  # 齧
    0x9F68: 'jiù',  # 齨
    0x9F69: 'yǎo',  # 齩
    0x9F6A: 'chuò',  # 齪
    0x9F6B: 'yǔn',  # 齫
    0x9F6C: 'yǔ',  # 齬
    0x9F6D: 'chǔ',  # 齭
    0x9F6E: 'yǐ',  # 齮
    0x9F6F: 'ní',  # 齯
    0x9F70: 'zé',  # 齰
    0x9F71: 'zōu',  # 齱
    0x9F72: 'qǔ',  # 齲
    0x9F73: 'yǔn',  # 齳
    0x9F74: 'yǎn',  # 齴
    0x9F75: 'yú',  # 齵
    0x9F76: 'è',  # 齶
    0x9F77: 'wò',  # 齷
    0x9F78: 'yì',  # 齸
    0x9F79: 'cī',  # 齹
    0x9F7A: 'zōu',  # 齺
    0x9F7B: 'diān',  # 齻
    0x9F7C: 'chǔ',  # 齼
    0x9F7D: 'jìn',  # 齽
    0x9F7E: 'yà',  # 齾
    0x9F7F: 'chǐ',  # 齿
    0x9F80: 'chèn',  # 龀
    0x9F81: 'hé',  # 龁
    0x9F82: 'yín,kěn',  # 龂
    0x9F83: 'jǔ',  # 龃
    0x9F84: 'líng',  # 龄
    0x9F85: 'bāo',  # 龅
    0x9F86: 'tiáo',  # 龆
    0x9F87: 'zī',  # 龇
    0x9F88: 'yín,kěn',  # 龈
    0x9F89: 'yǔ',  # 龉
    0x9F8A: 'chuò',  # 龊
    0x9F8B: 'qǔ',  # 龋
    0x9F8C: 'wò',  # 龌
    0x9F8D: 'lóng,lǒng',  # 龍
    0x9F8E: 'páng',  # 龎
    0x9F8F: 'gōng,wò',  # 龏
    0x9F90: 'páng',  # 龐
    0x9F91: 'yǎn',  # 龑
    0x9F92: 'lóng',  # 龒
    0x9F93: 'lóng,lǒng',  # 龓
    0x9F94: 'gōng',  # 龔
    0x9F95: 'kān',  # 龕
    0x9F96: 'dá',  # 龖
    0x9F97: 'líng',  # 龗
    0x9F98: 'dá',  # 龘
    0x9F99: 'lóng',  # 龙
    0x9F9A: 'gōng',  # 龚
    0x9F9B: 'kān',  # 龛
    0x9F9C: 'guī,jūn,qiū',  # 龜
    0x9F9D: 'qiū',  # 龝
    0x9F9E: 'biē',  # 龞
    0x9F9F: 'guī,jūn,qiū',  # 龟
    0x9FA0: 'yuè',  # 龠
    0x9FA1: 'chuī',  # 龡
    0x9FA2: 'hé',  # 龢
    0x9FA3: 'jiǎo',  # 龣
    0x9FA4: 'xié',  # 龤
    # 0x9FA5: '',  # 龥
    0x9FA6: 'cháng',  # 龦
    0x9FA7: 'shǔ',  # 龧
    0x9FA8: 'huái',  # 龨
    # 0x9FA9: '',  # 龩
    0x9FAA: 'zhān',  # 龪
    0x9FAB: 'gàn',  # 龫
    # 0x9FAC: '',  # 龬
    # 0x9FAD: '',  # 龭
    0x9FAE: 'jì',  # 龮
    0x9FAF: 'yuè',  # 龯
    0x9FB0: 'zǒu',  # 龰
    0x9FB1: 'sì',  # 龱
    0x9FB2: 'kù',  # 龲
    # 0x9FB3: '',  # 龳
    # 0x9FB4: '',  # 龴
    0x9FB5: 'shǒu',  # 龵
    # 0x9FB6: '',  # 龶
    0x9FB7: 'gòng',  # 龷
    # 0x9FB8: '',  # 龸
    0x9FB9: 'juǎn',  # 龹
    0x9FBA: 'zhuó',  # 龺
    0x9FBB: 'luán',  # 龻
    # 0x9FBC: '',  # 龼
    # 0x9FBD: '',  # 龽
    # 0x9FBE: '',  # 龾
    # 0x9FBF: '',  # 龿
    # 0x9FC0: '',  # 鿀
    # 0x9FC1: '',  # 鿁
    # 0x9FC2: '',  # 鿂
    0x9FC3: 'shǎn',  # 鿃
    0x9FC4: 'liáng',  # 鿄
    # 0x9FC5: '',  # 鿅
    # 0x9FC6: '',  # 鿆
    # 0x9FC7: '',  # 鿇
    # 0x9FC8: '',  # 鿈
    # 0x9FC9: '',  # 鿉
    # 0x9FCA: '',  # 鿊
    # 0x9FCB: '',  # 鿋
    0x9FCC: 'liáng,liàng',  # 鿌
    # 0x9FCD: '',  #
    # 0x9FCE: '',  #
    # 0x9FCF: '',  #
    # 0x9FD0: '',  #
    # 0x9FD1: '',  #
    # 0x9FD2: '',  #
    # 0x9FD3: '',  #
    # 0x9FD4: '',  #
    # 0x9FD5: '',  #
    # 0x9FD6: '',  #
    # 0x9FD7: '',  #
    # 0x9FD8: '',  #
    # 0x9FD9: '',  #
    # 0x9FDA: '',  #
    # 0x9FDB: '',  #
    # 0x9FDC: '',  #
    # 0x9FDD: '',  #
    # 0x9FDE: '',  #
    # 0x9FDF: '',  #
    # 0x9FE0: '',  #
    # 0x9FE1: '',  #
    # 0x9FE2: '',  #
    # 0x9FE3: '',  #
    # 0x9FE4: '',  #
    # 0x9FE5: '',  #
    # 0x9FE6: '',  #
    # 0x9FE7: '',  #
    # 0x9FE8: '',  #
    # 0x9FE9: '',  #
    # 0x9FEA: '',  #
    # 0x9FEB: '',  #
    # 0x9FEC: '',  #
    # 0x9FED: '',  #
    # 0x9FEE: '',  #
    # 0x9FEF: '',  #
    # 0x9FF0: '',  #
    # 0x9FF1: '',  #
    # 0x9FF2: '',  #
    # 0x9FF3: '',  #
    # 0x9FF4: '',  #
    # 0x9FF5: '',  #
    # 0x9FF6: '',  #
    # 0x9FF7: '',  #
    # 0x9FF8: '',  #
    # 0x9FF9: '',  #
    # 0x9FFA: '',  #
    # 0x9FFB: '',  #
    # 0x9FFC: '',  #
    # 0x9FFD: '',  #
    # 0x9FFE: '',  #
    # 0x9FFF: '',  #

    # CJK 兼容:[F900-FAFF]
    # 0xF900: '',  # 豈
    # 0xF901: '',  # 更
    # 0xF902: '',  # 車
    # 0xF903: '',  # 賈
    # 0xF904: '',  # 滑
    # 0xF905: '',  # 串
    # 0xF906: '',  # 句
    # 0xF907: '',  # 龜
    # 0xF908: '',  # 龜
    # 0xF909: '',  # 契
    # 0xF90A: '',  # 金
    # 0xF90B: '',  # 喇
    # 0xF90C: '',  # 奈
    # 0xF90D: '',  # 懶
    # 0xF90E: '',  # 癩
    # 0xF90F: '',  # 羅
    # 0xF910: '',  # 蘿
    # 0xF911: '',  # 螺
    # 0xF912: '',  # 裸
    # 0xF913: '',  # 邏
    # 0xF914: '',  # 樂
    # 0xF915: '',  # 洛
    # 0xF916: '',  # 烙
    # 0xF917: '',  # 珞
    # 0xF918: '',  # 落
    # 0xF919: '',  # 酪
    # 0xF91A: '',  # 駱
    # 0xF91B: '',  # 亂
    # 0xF91C: '',  # 卵
    # 0xF91D: '',  # 欄
    # 0xF91E: '',  # 爛
    # 0xF91F: '',  # 蘭
    # 0xF920: '',  # 鸞
    # 0xF921: '',  # 嵐
    # 0xF922: '',  # 濫
    # 0xF923: '',  # 藍
    # 0xF924: '',  # 襤
    # 0xF925: '',  # 拉
    # 0xF926: '',  # 臘
    # 0xF927: '',  # 蠟
    # 0xF928: '',  # 廊
    # 0xF929: '',  # 朗
    # 0xF92A: '',  # 浪
    # 0xF92B: '',  # 狼
    # 0xF92C: '',  # 郎
    # 0xF92D: '',  # 來
    # 0xF92E: '',  # 冷
    # 0xF92F: '',  # 勞
    # 0xF930: '',  # 擄
    # 0xF931: '',  # 櫓
    # 0xF932: '',  # 爐
    # 0xF933: '',  # 盧
    # 0xF934: '',  # 老
    # 0xF935: '',  # 蘆
    # 0xF936: '',  # 虜
    # 0xF937: '',  # 路
    # 0xF938: '',  # 露
    # 0xF939: '',  # 魯
    # 0xF93A: '',  # 鷺
    # 0xF93B: '',  # 碌
    # 0xF93C: '',  # 祿
    # 0xF93D: '',  # 綠
    # 0xF93E: '',  # 菉
    # 0xF93F: '',  # 錄
    # 0xF940: '',  # 鹿
    # 0xF941: '',  # 論
    # 0xF942: '',  # 壟
    # 0xF943: '',  # 弄
    # 0xF944: '',  # 籠
    # 0xF945: '',  # 聾
    # 0xF946: '',  # 牢
    # 0xF947: '',  # 磊
    # 0xF948: '',  # 賂
    # 0xF949: '',  # 雷
    # 0xF94A: '',  # 壘
    # 0xF94B: '',  # 屢
    # 0xF94C: '',  # 樓
    # 0xF94D: '',  # 淚
    # 0xF94E: '',  # 漏
    # 0xF94F: '',  # 累
    # 0xF950: '',  # 縷
    # 0xF951: '',  # 陋
    # 0xF952: '',  # 勒
    # 0xF953: '',  # 肋
    # 0xF954: '',  # 凜
    # 0xF955: '',  # 凌
    # 0xF956: '',  # 稜
    # 0xF957: '',  # 綾
    # 0xF958: '',  # 菱
    # 0xF959: '',  # 陵
    # 0xF95A: '',  # 讀
    # 0xF95B: '',  # 拏
    # 0xF95C: '',  # 樂
    # 0xF95D: '',  # 諾
    # 0xF95E: '',  # 丹
    # 0xF95F: '',  # 寧
    # 0xF960: '',  # 怒
    # 0xF961: '',  # 率
    # 0xF962: '',  # 異
    # 0xF963: '',  # 北
    # 0xF964: '',  # 磻
    # 0xF965: '',  # 便
    # 0xF966: '',  # 復
    # 0xF967: '',  # 不
    # 0xF968: '',  # 泌
    # 0xF969: '',  # 數
    # 0xF96A: '',  # 索
    # 0xF96B: '',  # 參
    # 0xF96C: '',  # 塞
    # 0xF96D: '',  # 省
    # 0xF96E: '',  # 葉
    # 0xF96F: '',  # 說
    # 0xF970: '',  # 殺
    # 0xF971: '',  # 辰
    # 0xF972: '',  # 沈
    # 0xF973: '',  # 拾
    # 0xF974: '',  # 若
    # 0xF975: '',  # 掠
    # 0xF976: '',  # 略
    # 0xF977: '',  # 亮
    # 0xF978: '',  # 兩
    # 0xF979: '',  # 凉
    # 0xF97A: '',  # 梁
    # 0xF97B: '',  # 糧
    # 0xF97C: '',  # 良
    # 0xF97D: '',  # 諒
    # 0xF97E: '',  # 量
    # 0xF97F: '',  # 勵
    # 0xF980: '',  # 呂
    # 0xF981: '',  # 女
    # 0xF982: '',  # 廬
    # 0xF983: '',  # 旅
    # 0xF984: '',  # 濾
    # 0xF985: '',  # 礪
    # 0xF986: '',  # 閭
    # 0xF987: '',  # 驪
    # 0xF988: '',  # 麗
    # 0xF989: '',  # 黎
    # 0xF98A: '',  # 力
    # 0xF98B: '',  # 曆
    # 0xF98C: '',  # 歷
    # 0xF98D: '',  # 轢
    # 0xF98E: '',  # 年
    # 0xF98F: '',  # 憐
    # 0xF990: '',  # 戀
    # 0xF991: '',  # 撚
    # 0xF992: '',  # 漣
    # 0xF993: '',  # 煉
    # 0xF994: '',  # 璉
    # 0xF995: '',  # 秊
    # 0xF996: '',  # 練
    # 0xF997: '',  # 聯
    # 0xF998: '',  # 輦
    # 0xF999: '',  # 蓮
    # 0xF99A: '',  # 連
    # 0xF99B: '',  # 鍊
    # 0xF99C: '',  # 列
    # 0xF99D: '',  # 劣
    # 0xF99E: '',  # 咽
    # 0xF99F: '',  # 烈
    # 0xF9A0: '',  # 裂
    # 0xF9A1: '',  # 說
    # 0xF9A2: '',  # 廉
    # 0xF9A3: '',  # 念
    # 0xF9A4: '',  # 捻
    # 0xF9A5: '',  # 殮
    # 0xF9A6: '',  # 簾
    # 0xF9A7: '',  # 獵
    # 0xF9A8: '',  # 令
    # 0xF9A9: '',  # 囹
    # 0xF9AA: '',  # 寧
    # 0xF9AB: '',  # 嶺
    # 0xF9AC: '',  # 怜
    # 0xF9AD: '',  # 玲
    # 0xF9AE: '',  # 瑩
    # 0xF9AF: '',  # 羚
    # 0xF9B0: '',  # 聆
    # 0xF9B1: '',  # 鈴
    # 0xF9B2: '',  # 零
    # 0xF9B3: '',  # 靈
    # 0xF9B4: '',  # 領
    # 0xF9B5: '',  # 例
    # 0xF9B6: '',  # 禮
    # 0xF9B7: '',  # 醴
    # 0xF9B8: '',  # 隸
    # 0xF9B9: '',  # 惡
    # 0xF9BA: '',  # 了
    # 0xF9BB: '',  # 僚
    # 0xF9BC: '',  # 寮
    # 0xF9BD: '',  # 尿
    # 0xF9BE: '',  # 料
    # 0xF9BF: '',  # 樂
    # 0xF9C0: '',  # 燎
    # 0xF9C1: '',  # 療
    # 0xF9C2: '',  # 蓼
    # 0xF9C3: '',  # 遼
    # 0xF9C4: '',  # 龍
    # 0xF9C5: '',  # 暈
    # 0xF9C6: '',  # 阮
    # 0xF9C7: '',  # 劉
    # 0xF9C8: '',  # 杻
    # 0xF9C9: '',  # 柳
    # 0xF9CA: '',  # 流
    # 0xF9CB: '',  # 溜
    # 0xF9CC: '',  # 琉
    # 0xF9CD: '',  # 留
    # 0xF9CE: '',  # 硫
    # 0xF9CF: '',  # 紐
    # 0xF9D0: '',  # 類
    # 0xF9D1: '',  # 六
    # 0xF9D2: '',  # 戮
    # 0xF9D3: '',  # 陸
    # 0xF9D4: '',  # 倫
    # 0xF9D5: '',  # 崙
    # 0xF9D6: '',  # 淪
    # 0xF9D7: '',  # 輪
    # 0xF9D8: '',  # 律
    # 0xF9D9: '',  # 慄
    # 0xF9DA: '',  # 栗
    # 0xF9DB: '',  # 率
    # 0xF9DC: '',  # 隆
    # 0xF9DD: '',  # 利
    # 0xF9DE: '',  # 吏
    # 0xF9DF: '',  # 履
    # 0xF9E0: '',  # 易
    # 0xF9E1: '',  # 李
    # 0xF9E2: '',  # 梨
    # 0xF9E3: '',  # 泥
    # 0xF9E4: '',  # 理
    # 0xF9E5: '',  # 痢
    # 0xF9E6: '',  # 罹
    # 0xF9E7: '',  # 裏
    # 0xF9E8: '',  # 裡
    # 0xF9E9: '',  # 里
    # 0xF9EA: '',  # 離
    # 0xF9EB: '',  # 匿
    # 0xF9EC: '',  # 溺
    # 0xF9ED: '',  # 吝
    # 0xF9EE: '',  # 燐
    # 0xF9EF: '',  # 璘
    # 0xF9F0: '',  # 藺
    # 0xF9F1: '',  # 隣
    # 0xF9F2: '',  # 鱗
    # 0xF9F3: '',  # 麟
    # 0xF9F4: '',  # 林
    # 0xF9F5: '',  # 淋
    # 0xF9F6: '',  # 臨
    # 0xF9F7: '',  # 立
    # 0xF9F8: '',  # 笠
    # 0xF9F9: '',  # 粒
    # 0xF9FA: '',  # 狀
    # 0xF9FB: '',  # 炙
    # 0xF9FC: '',  # 識
    # 0xF9FD: '',  # 什
    # 0xF9FE: '',  # 茶
    # 0xF9FF: '',  # 刺
    # 0xFA00: '',  # 切
    # 0xFA01: '',  # 度
    # 0xFA02: '',  # 拓
    # 0xFA03: '',  # 糖
    # 0xFA04: '',  # 宅
    # 0xFA05: '',  # 洞
    # 0xFA06: '',  # 暴
    # 0xFA07: '',  # 輻
    # 0xFA08: '',  # 行
    # 0xFA09: '',  # 降
    # 0xFA0A: '',  # 見
    # 0xFA0B: '',  # 廓
    # 0xFA0C: '',  # 兀
    # 0xFA0D: '',  # 嗀
    # 0xFA0E: '',  # 﨎
    # 0xFA0F: '',  # 﨏
    # 0xFA10: '',  # 塚
    # 0xFA11: '',  # 﨑
    # 0xFA12: '',  # 晴
    # 0xFA13: '',  # 﨓
    # 0xFA14: '',  # 﨔
    # 0xFA15: '',  # 凞
    # 0xFA16: '',  # 猪
    # 0xFA17: '',  # 益
    # 0xFA18: '',  # 礼
    # 0xFA19: '',  # 神
    # 0xFA1A: '',  # 祥
    # 0xFA1B: '',  # 福
    # 0xFA1C: '',  # 靖
    # 0xFA1D: '',  # 精
    0xFA1E: 'yǔ',  # 羽
    # 0xFA1F: '',  # 﨟
    # 0xFA20: '',  # 蘒
    # 0xFA21: '',  # 﨡
    # 0xFA22: '',  # 諸
    # 0xFA23: '',  # 﨣
    0xFA24: 'jí',  # 﨤
    # 0xFA25: '',  # 逸
    # 0xFA26: '',  # 都
    # 0xFA27: '',  # 﨧
    # 0xFA28: '',  # 﨨
    0xFA29: 'dǎo',  # 﨩
    # 0xFA2A: '',  # 飯
    # 0xFA2B: '',  # 飼
    # 0xFA2C: '',  # 館
    # 0xFA2D: '',  # 鶴
    # 0xFA2E: '',  # 郞
    # 0xFA2F: '',  # 隷
    # 0xFA30: '',  # 侮
    # 0xFA31: '',  # 僧
    # 0xFA32: '',  # 免
    # 0xFA33: '',  # 勉
    # 0xFA34: '',  # 勤
    # 0xFA35: '',  # 卑
    # 0xFA36: '',  # 喝
    # 0xFA37: '',  # 嘆
    # 0xFA38: '',  # 器
    # 0xFA39: '',  # 塀
    # 0xFA3A: '',  # 墨
    # 0xFA3B: '',  # 層
    # 0xFA3C: '',  # 屮
    # 0xFA3D: '',  # 悔
    # 0xFA3E: '',  # 慨
    # 0xFA3F: '',  # 憎
    # 0xFA40: '',  # 懲
    # 0xFA41: '',  # 敏
    # 0xFA42: '',  # 既
    # 0xFA43: '',  # 暑
    # 0xFA44: '',  # 梅
    # 0xFA45: '',  # 海
    # 0xFA46: '',  # 渚
    # 0xFA47: '',  # 漢
    # 0xFA48: '',  # 煮
    # 0xFA49: '',  # 爫
    # 0xFA4A: '',  # 琢
    # 0xFA4B: '',  # 碑
    # 0xFA4C: '',  # 社
    # 0xFA4D: '',  # 祉
    # 0xFA4E: '',  # 祈
    # 0xFA4F: '',  # 祐
    # 0xFA50: '',  # 祖
    # 0xFA51: '',  # 祝
    # 0xFA52: '',  # 禍
    # 0xFA53: '',  # 禎
    # 0xFA54: '',  # 穀
    # 0xFA55: '',  # 突
    # 0xFA56: '',  # 節
    # 0xFA57: '',  # 練
    # 0xFA58: '',  # 縉
    # 0xFA59: '',  # 繁
    # 0xFA5A: '',  # 署
    # 0xFA5B: '',  # 者
    # 0xFA5C: '',  # 臭
    # 0xFA5D: '',  # 艹
    # 0xFA5E: '',  # 艹
    # 0xFA5F: '',  # 著
    # 0xFA60: '',  # 褐
    # 0xFA61: '',  # 視
    # 0xFA62: '',  # 謁
    # 0xFA63: '',  # 謹
    # 0xFA64: '',  # 賓
    # 0xFA65: '',  # 贈
    # 0xFA66: '',  # 辶
    # 0xFA67: '',  # 逸
    # 0xFA68: '',  # 難
    # 0xFA69: '',  # 響
    # 0xFA6A: '',  # 頻
    # 0xFA6B: '',  #
    # 0xFA6C: '',  #
    # 0xFA6D: '',  #
    # 0xFA6E: '',  #
    # 0xFA6F: '',  #
    # 0xFA70: '',  # 並
    # 0xFA71: '',  # 况
    # 0xFA72: '',  # 全
    # 0xFA73: '',  # 侀
    # 0xFA74: '',  # 充
    # 0xFA75: '',  # 冀
    # 0xFA76: '',  # 勇
    # 0xFA77: '',  # 勺
    # 0xFA78: '',  # 喝
    # 0xFA79: '',  # 啕
    # 0xFA7A: '',  # 喙
    # 0xFA7B: '',  # 嗢
    # 0xFA7C: '',  # 塚
    # 0xFA7D: '',  # 墳
    # 0xFA7E: '',  # 奄
    # 0xFA7F: '',  # 奔
    # 0xFA80: '',  # 婢
    # 0xFA81: '',  # 嬨
    # 0xFA82: '',  # 廒
    # 0xFA83: '',  # 廙
    # 0xFA84: '',  # 彩
    # 0xFA85: '',  # 徭
    # 0xFA86: '',  # 惘
    # 0xFA87: '',  # 慎
    # 0xFA88: '',  # 愈
    # 0xFA89: '',  # 憎
    # 0xFA8A: '',  # 慠
    # 0xFA8B: '',  # 懲
    # 0xFA8C: '',  # 戴
    # 0xFA8D: '',  # 揄
    # 0xFA8E: '',  # 搜
    # 0xFA8F: '',  # 摒
    # 0xFA90: '',  # 敖
    # 0xFA91: '',  # 晴
    # 0xFA92: '',  # 朗
    # 0xFA93: '',  # 望
    # 0xFA94: '',  # 杖
    # 0xFA95: '',  # 歹
    # 0xFA96: '',  # 殺
    # 0xFA97: '',  # 流
    # 0xFA98: '',  # 滛
    # 0xFA99: '',  # 滋
    # 0xFA9A: '',  # 漢
    # 0xFA9B: '',  # 瀞
    # 0xFA9C: '',  # 煮
    # 0xFA9D: '',  # 瞧
    # 0xFA9E: '',  # 爵
    # 0xFA9F: '',  # 犯
    # 0xFAA0: '',  # 猪
    # 0xFAA1: '',  # 瑱
    # 0xFAA2: '',  # 甆
    # 0xFAA3: '',  # 画
    # 0xFAA4: '',  # 瘝
    # 0xFAA5: '',  # 瘟
    # 0xFAA6: '',  # 益
    # 0xFAA7: '',  # 盛
    # 0xFAA8: '',  # 直
    # 0xFAA9: '',  # 睊
    # 0xFAAA: '',  # 着
    # 0xFAAB: '',  # 磌
    # 0xFAAC: '',  # 窱
    # 0xFAAD: '',  # 節
    # 0xFAAE: '',  # 类
    # 0xFAAF: '',  # 絛
    # 0xFAB0: '',  # 練
    # 0xFAB1: '',  # 缾
    # 0xFAB2: '',  # 者
    # 0xFAB3: '',  # 荒
    # 0xFAB4: '',  # 華
    # 0xFAB5: '',  # 蝹
    # 0xFAB6: '',  # 襁
    # 0xFAB7: '',  # 覆
    # 0xFAB8: '',  # 視
    # 0xFAB9: '',  # 調
    # 0xFABA: '',  # 諸
    # 0xFABB: '',  # 請
    # 0xFABC: '',  # 謁
    # 0xFABD: '',  # 諾
    # 0xFABE: '',  # 諭
    # 0xFABF: '',  # 謹
    # 0xFAC0: '',  # 變
    # 0xFAC1: '',  # 贈
    # 0xFAC2: '',  # 輸
    # 0xFAC3: '',  # 遲
    # 0xFAC4: '',  # 醙
    # 0xFAC5: '',  # 鉶
    # 0xFAC6: '',  # 陼
    # 0xFAC7: '',  # 難
    # 0xFAC8: '',  # 靖
    # 0xFAC9: '',  # 韛
    # 0xFACA: '',  # 響
    # 0xFACB: '',  # 頋
    # 0xFACC: '',  # 頻
    # 0xFACD: '',  # 鬒
    # 0xFACE: '',  # 龜
    # 0xFACF: '',  # 𢡊
    # 0xFAD0: '',  # 𢡄
    # 0xFAD1: '',  # 𣏕
    # 0xFAD2: '',  # 㮝
    # 0xFAD3: '',  # 䀘
    # 0xFAD4: '',  # 䀹
    # 0xFAD5: '',  # 𥉉
    # 0xFAD6: '',  # 𥳐
    # 0xFAD7: '',  # 𧻓
    # 0xFAD8: '',  # 齃
    # 0xFAD9: '',  # 龎
    # 0xFADA: '',  #
    # 0xFADB: '',  #
    # 0xFADC: '',  #
    # 0xFADD: '',  #
    # 0xFADE: '',  #
    # 0xFADF: '',  #
    # 0xFAE0: '',  #
    # 0xFAE1: '',  #
    # 0xFAE2: '',  #
    # 0xFAE3: '',  #
    # 0xFAE4: '',  #
    # 0xFAE5: '',  #
    # 0xFAE6: '',  #
    # 0xFAE7: '',  #
    # 0xFAE8: '',  #
    # 0xFAE9: '',  #
    # 0xFAEA: '',  #
    # 0xFAEB: '',  #
    # 0xFAEC: '',  #
    # 0xFAED: '',  #
    # 0xFAEE: '',  #
    # 0xFAEF: '',  #
    # 0xFAF0: '',  #
    # 0xFAF1: '',  #
    # 0xFAF2: '',  #
    # 0xFAF3: '',  #
    # 0xFAF4: '',  #
    # 0xFAF5: '',  #
    # 0xFAF6: '',  #
    # 0xFAF7: '',  #
    # 0xFAF8: '',  #
    # 0xFAF9: '',  #
    # 0xFAFA: '',  #
    # 0xFAFB: '',  #
    # 0xFAFC: '',  #
    # 0xFAFD: '',  #
    # 0xFAFE: '',  #
    # 0xFAFF: '',  #
}

# Python 中高位(FFFF 以上) Unicode 字符的长度不再是1而是2，所以暂不处理。
'''
    # CJK 扩展 B:[20000-2A6DF]
    0x20000: 'hē',  # 𠀀
    0x20001: 'qī',  # 𠀁
    # 0x20002: '',  # 𠀂
    0x20003: 'qiě,jī',  # 𠀃
    # 0x20004: '',  # 𠀄
    0x20005: 'hài',  # 𠀅
    # 0x20006: '',  # 𠀆
    0x20007: 'qiě',  # 𠀇
    0x20008: 'qiū',  # 𠀈
    0x20009: 'qiū',  # 𠀉
    0x2000A: 'cāo',  # 𠀊
    # 0x2000B: '',  # 𠀋
    0x2000C: 'qiū',  # 𠀌
    0x2000D: 'shì',  # 𠀍
    # 0x2000E: '',  # 𠀎
    # 0x2000F: '',  # 𠀏
    # 0x20010: '',  # 𠀐
    # 0x20011: '',  # 𠀑
    # 0x20012: '',  # 𠀒
    0x20013: 'sī',  # 𠀓
    0x20014: 'jué',  # 𠀔
    0x20015: 'gèn',  # 𠀕
    # 0x20016: '',  # 𠀖
    # 0x20017: '',  # 𠀗
    # 0x20018: '',  # 𠀘
    # 0x20019: '',  # 𠀙
    0x2001A: 'bù',  # 𠀚
    0x2001B: 'yù',  # 𠀛
    # 0x2001C: '',  # 𠀜
    0x2001D: 'kōng',  # 𠀝
    # 0x2001E: '',  # 𠀞
    # 0x2001F: '',  # 𠀟
    # 0x20020: '',  # 𠀠
    # 0x20021: '',  # 𠀡
    0x20022: 'zī',  # 𠀢
    # 0x20023: '',  # 𠀣
    0x20024: 'bìng',  # 𠀤
    # 0x20025: '',  # 𠀥
    0x20026: 'xíng',  # 𠀦
    # 0x20027: '',  # 𠀧
    # 0x20028: '',  # 𠀨
    # 0x20029: '',  # 𠀩
    # 0x2002A: '',  # 𠀪
    # 0x2002B: '',  # 𠀫
    0x2002C: 'tiǎn',  # 𠀬
    # 0x2002D: '',  # 𠀭
    0x2002E: 'jī',  # 𠀮
    # 0x2002F: '',  # 𠀯
    # 0x20030: '',  # 𠀰
    0x20031: 'mǒu',  # 𠀱
    # 0x20032: '',  # 𠀲
    # 0x20033: '',  # 𠀳
    # 0x20034: '',  # 𠀴
    # 0x20035: '',  # 𠀵
    # 0x20036: '',  # 𠀶
    0x20037: 'jī',  # 𠀷
    0x20038: 'yè',  # 𠀸
    0x20039: 'jūn',  # 𠀹
    # 0x2003A: '',  # 𠀺
    # 0x2003B: '',  # 𠀻
    0x2003C: 'qián,xià',  # 𠀼
    0x2003D: 'lù',  # 𠀽
    0x2003E: 'pēi',  # 𠀾
    # 0x2003F: '',  # 𠀿
    # 0x20040: '',  # 𠁀
    # 0x20041: '',  # 𠁁
    # 0x20042: '',  # 𠁂
    # 0x20043: '',  # 𠁃
    # 0x20044: '',  # 𠁄
    # 0x20045: '',  # 𠁅
    # 0x20046: '',  # 𠁆
    # 0x20047: '',  # 𠁇
    # 0x20048: '',  # 𠁈
    0x20049: 'chū',  # 𠁉
    # 0x2004A: '',  # 𠁊
    # 0x2004B: '',  # 𠁋
    # 0x2004C: '',  # 𠁌
    # 0x2004D: '',  # 𠁍
    # 0x2004E: '',  # 𠁎
    # 0x2004F: '',  # 𠁏
    # 0x20050: '',  # 𠁐
    # 0x20051: '',  # 𠁑
    # 0x20052: '',  # 𠁒
    # 0x20053: '',  # 𠁓
    # 0x20054: '',  # 𠁔
    # 0x20055: '',  # 𠁕
    # 0x20056: '',  # 𠁖
    0x20057: 'shì,hè',  # 𠁗
    # 0x20058: '',  # 𠁘
    # 0x20059: '',  # 𠁙
    # 0x2005A: '',  # 𠁚
    # 0x2005B: '',  # 𠁛
    # 0x2005C: '',  # 𠁜
    # 0x2005D: '',  # 𠁝
    0x2005E: 'pēi',  # 𠁞
    # 0x2005F: '',  # 𠁟
    0x20060: 'qiè',  # 𠁠
    0x20061: 'bǔ',  # 𠁡
    # 0x20062: '',  # 𠁢
    # 0x20063: '',  # 𠁣
    # 0x20064: '',  # 𠁤
    0x20065: 'guǎi',  # 𠁥
    0x20066: 'zhōng',  # 𠁦
    0x20067: 'zhōng',  # 𠁧
    # 0x20068: '',  # 𠁨
    0x20069: 'zhōng',  # 𠁩
    # 0x2006A: '',  # 𠁪
    # 0x2006B: '',  # 𠁫
    # 0x2006C: '',  # 𠁬
    0x2006D: 'qí',  # 𠁭
    0x2006E: 'shū',  # 𠁮
    # 0x2006F: '',  # 𠁯
    0x20070: 'guāi',  # 𠁰
    0x20071: 'shì',  # 𠁱
    # 0x20072: '',  # 𠁲
    # 0x20073: '',  # 𠁳
    0x20074: 'guī',  # 𠁴
    # 0x20075: '',  # 𠁵
    # 0x20076: '',  # 𠁶
    0x20077: 'chǎn',  # 𠁷
    # 0x20078: '',  # 𠁸
    # 0x20079: '',  # 𠁹
    # 0x2007A: '',  # 𠁺
    # 0x2007B: '',  # 𠁻
    0x2007C: 'yī',  # 𠁼
    0x2007D: 'wán',  # 𠁽
    # 0x2007E: '',  # 𠁾
    0x2007F: 'dān',  # 𠁿
    # 0x20080: '',  # 𠂀
    # 0x20081: '',  # 𠂁
    0x20082: 'zhōng',  # 𠂂
    # 0x20083: '',  # 𠂃
    0x20084: 'huān',  # 𠂄
    # 0x20085: '',  # 𠂅
    0x20086: 'yì',  # 𠂆
    0x20087: 'zuǒ',  # 𠂇
    0x20088: 'jié',  # 𠂈
    # 0x20089: '',  # 𠂉
    # 0x2008A: '',  # 𠂊
    # 0x2008B: '',  # 𠂋
    # 0x2008C: '',  # 𠂌
    # 0x2008D: '',  # 𠂍
    # 0x2008E: '',  # 𠂎
    # 0x2008F: '',  # 𠂏
    # 0x20090: '',  # 𠂐
    0x20091: 'zōu',  # 𠂑
    # 0x20092: '',  # 𠂒
    # 0x20093: '',  # 𠂓
    0x20094: 'zǐ',  # 𠂔
    0x20095: 'shǐ',  # 𠂕
    0x20096: 'dì',  # 𠂖
    # 0x20097: '',  # 𠂗
    # 0x20098: '',  # 𠂘
    # 0x20099: '',  # 𠂙
    # 0x2009A: '',  # 𠂚
    # 0x2009B: '',  # 𠂛
    # 0x2009C: '',  # 𠂜
    # 0x2009D: '',  # 𠂝
    # 0x2009E: '',  # 𠂞
    0x2009F: 'jīn',  # 𠂟
    # 0x200A0: '',  # 𠂠
    # 0x200A1: '',  # 𠂡
    0x200A2: 'pài',  # 𠂢
    0x200A3: 'yī',  # 𠂣
    0x200A4: 'duī',  # 𠂤
    0x200A5: 'cóng',  # 𠂥
    # 0x200A6: '',  # 𠂦
    0x200A7: 'shèn',  # 𠂧
    # 0x200A8: '',  # 𠂨
    # 0x200A9: '',  # 𠂩
    # 0x200AA: '',  # 𠂪
    # 0x200AB: '',  # 𠂫
    # 0x200AC: '',  # 𠂬
    # 0x200AD: '',  # 𠂭
    # 0x200AE: '',  # 𠂮
    # 0x200AF: '',  # 𠂯
    # 0x200B0: '',  # 𠂰
    # 0x200B1: '',  # 𠂱
    # 0x200B2: '',  # 𠂲
    0x200B3: 'zǒng',  # 𠂳
    # 0x200B4: '',  # 𠂴
    # 0x200B5: '',  # 𠂵
    # 0x200B6: '',  # 𠂶
    0x200B7: 'xìng',  # 𠂷
    0x200B8: 'huáng',  # 𠂸
    0x200B9: 'chuí',  # 𠂹
    0x200BA: 'sī',  # 𠂺
    # 0x200BB: '',  # 𠂻
    # 0x200BC: '',  # 𠂼
    # 0x200BD: '',  # 𠂽
    # 0x200BE: '',  # 𠂾
    0x200BF: 'shǒu',  # 𠂿
    # 0x200C0: '',  # 𠃀
    # 0x200C1: '',  # 𠃁
    # 0x200C2: '',  # 𠃂
    # 0x200C3: '',  # 𠃃
    # 0x200C4: '',  # 𠃄
    # 0x200C5: '',  # 𠃅
    # 0x200C6: '',  # 𠃆
    # 0x200C7: '',  # 𠃇
    # 0x200C8: '',  # 𠃈
    0x200C9: 'yà',  # 𠃉
    0x200CA: 'yǐn',  # 𠃊
    0x200CB: 'gōng',  # 𠃋
    0x200CC: 'gǔn',  # 𠃌
    # 0x200CD: '',  # 𠃍
    # 0x200CE: '',  # 𠃎
    0x200CF: 'jiū',  # 𠃏
    0x200D0: 'huì',  # 𠃐
    # 0x200D1: '',  # 𠃑
    0x200D2: 'yě',  # 𠃒
    # 0x200D3: '',  # 𠃓
    0x200D4: 'jiǔ',  # 𠃔
    0x200D5: 'zhōu',  # 𠃕
    0x200D6: 'jiū',  # 𠃖
    # 0x200D7: '',  # 𠃗
    # 0x200D8: '',  # 𠃘
    # 0x200D9: '',  # 𠃙
    # 0x200DA: '',  # 𠃚
    # 0x200DB: '',  # 𠃛
    # 0x200DC: '',  # 𠃜
    # 0x200DD: '',  # 𠃝
    0x200DE: 'lǐ',  # 𠃞
    0x200DF: 'yě',  # 𠃟
    # 0x200E0: '',  # 𠃠
    # 0x200E1: '',  # 𠃡
    # 0x200E2: '',  # 𠃢
    # 0x200E3: '',  # 𠃣
    0x200E4: 'huāng',  # 𠃤
    0x200E5: 'jǔ',  # 𠃥
    # 0x200E6: '',  # 𠃦
    # 0x200E7: '',  # 𠃧
    0x200E8: 'jǐ',  # 𠃨
    # 0x200E9: '',  # 𠃩
    # 0x200EA: '',  # 𠃪
    0x200EB: 'shēn',  # 𠃫
    # 0x200EC: '',  # 𠃬
    0x200ED: 'shǐ',  # 𠃭
    # 0x200EE: '',  # 𠃮
    # 0x200EF: '',  # 𠃯
    # 0x200F0: '',  # 𠃰
    # 0x200F1: '',  # 𠃱
    0x200F2: 'jié',  # 𠃲
    0x200F3: 'kuí',  # 𠃳
    # 0x200F4: '',  # 𠃴
    # 0x200F5: '',  # 𠃵
    # 0x200F6: '',  # 𠃶
    # 0x200F7: '',  # 𠃷
    # 0x200F8: '',  # 𠃸
    # 0x200F9: '',  # 𠃹
    0x200FA: 'jiù',  # 𠃺
    # 0x200FB: '',  # 𠃻
    0x200FC: 'sī',  # 𠃼
    # 0x200FD: '',  # 𠃽
    # 0x200FE: '',  # 𠃾
    # 0x200FF: '',  # 𠃿
    # 0x20100: '',  # 𠄀
    # 0x20101: '',  # 𠄁
    # 0x20102: '',  # 𠄂
    0x20103: 'gān,qián',  # 𠄃
    # 0x20104: '',  # 𠄄
    0x20105: 'yè',  # 𠄅
    # 0x20106: '',  # 𠄆
    0x20107: 'lào',  # 𠄇
    0x20108: 'lín',  # 𠄈
    0x20109: 'dòng',  # 𠄉
    # 0x2010A: '',  # 𠄊
    0x2010B: 'gān,qián',  # 𠄋
    0x2010C: 'jué,zhuì',  # 𠄌
    0x2010D: 'jié',  # 𠄍
    0x2010E: 'nǎi',  # 𠄎
    0x2010F: 'diǎo',  # 𠄏
    0x20110: 'mā',  # 𠄐
    0x20111: 'jué',  # 𠄑
    0x20112: 'chuí,shā',  # 𠄒
    0x20113: 'zhōu',  # 𠄓
    0x20114: 'huàn',  # 𠄔
    0x20115: 'nǎi',  # 𠄕
    0x20116: 'líng',  # 𠄖
    0x20117: 'zhōu',  # 𠄗
    # 0x20118: '',  # 𠄘
    0x20119: 'zhēng',  # 𠄙
    0x2011A: 'tīng',  # 𠄚
    0x2011B: 'yù',  # 𠄛
    # 0x2011C: '',  # 𠄜
    0x2011D: 'yù',  # 𠄝
    0x2011E: 'shàng',  # 𠄞
    0x2011F: 'xià',  # 𠄟
    0x20120: 'shàng',  # 𠄠
    0x20121: 'wǔ',  # 𠄡
    0x20122: 'xuān',  # 𠄢
    0x20123: 'gèn',  # 𠄣
    0x20124: 'chún',  # 𠄤
    # 0x20125: '',  # 𠄥
    # 0x20126: '',  # 𠄦
    # 0x20127: '',  # 𠄧
    0x20128: 'héng',  # 𠄨
    # 0x20129: '',  # 𠄩
    # 0x2012A: '',  # 𠄪
    # 0x2012B: '',  # 𠄫
    # 0x2012C: '',  # 𠄬
    # 0x2012D: '',  # 𠄭
    0x2012E: 'yà,mǒ',  # 𠄮
    # 0x2012F: '',  # 𠄯
    0x20130: 'lǎo',  # 𠄰
    0x20131: 'yí',  # 𠄱
    # 0x20132: '',  # 𠄲
    # 0x20133: '',  # 𠄳
    # 0x20134: '',  # 𠄴
    0x20135: 'shèng',  # 𠄵
    # 0x20136: '',  # 𠄶
    # 0x20137: '',  # 𠄷
    # 0x20138: '',  # 𠄸
    0x20139: 'jí',  # 𠄹
    # 0x2013A: '',  # 𠄺
    # 0x2013B: '',  # 𠄻
    # 0x2013C: '',  # 𠄼
    # 0x2013D: '',  # 𠄽
    # 0x2013E: '',  # 𠄾
    0x2013F: 'wéi',  # 𠄿
    # 0x20140: '',  # 𠅀
    # 0x20141: '',  # 𠅁
    0x20142: 'jié',  # 𠅂
    0x20143: 'yì',  # 𠅃
    # 0x20144: '',  # 𠅄
    0x20145: 'sòng',  # 𠅅
    # 0x20146: '',  # 𠅆
    # 0x20147: '',  # 𠅇
    0x20148: 'nào',  # 𠅈
    # 0x20149: '',  # 𠅉
    # 0x2014A: '',  # 𠅊
    # 0x2014B: '',  # 𠅋
    0x2014C: 'yí',  # 𠅌
    # 0x2014D: '',  # 𠅍
    # 0x2014E: '',  # 𠅎
    # 0x2014F: '',  # 𠅏
    # 0x20150: '',  # 𠅐
    # 0x20151: '',  # 𠅑
    # 0x20152: '',  # 𠅒
    0x20153: 'yóu',  # 𠅓
    0x20154: 'kè',  # 𠅔
    # 0x20155: '',  # 𠅕
    0x20156: 'hēng',  # 𠅖
    0x20157: 'diè',  # 𠅗
    # 0x20158: '',  # 𠅘
    # 0x20159: '',  # 𠅙
    0x2015A: 'qí',  # 𠅚
    # 0x2015B: '',  # 𠅛
    # 0x2015C: '',  # 𠅜
    # 0x2015D: '',  # 𠅝
    0x2015E: 'chèng,shèng',  # 𠅞
    0x2015F: 'chèng,shèng',  # 𠅟
    0x20160: 'xiǎng',  # 𠅠
    0x20161: 'kè',  # 𠅡
    # 0x20162: '',  # 𠅢
    0x20163: 'gǎng',  # 𠅣
    0x20164: 'xí',  # 𠅤
    # 0x20165: '',  # 𠅥
    # 0x20166: '',  # 𠅦
    # 0x20167: '',  # 𠅧
    # 0x20168: '',  # 𠅨
    0x20169: 'shú',  # 𠅩
    0x2016A: 'guō',  # 𠅪
    0x2016B: 'shèng',  # 𠅫
    0x2016C: 'bāo',  # 𠅬
    # 0x2016D: '',  # 𠅭
    # 0x2016E: '',  # 𠅮
    # 0x2016F: '',  # 𠅯
    # 0x20170: '',  # 𠅰
    0x20171: 'xiè',  # 𠅱
    # 0x20172: '',  # 𠅲
    # 0x20173: '',  # 𠅳
    # 0x20174: '',  # 𠅴
    # 0x20175: '',  # 𠅵
    # 0x20176: '',  # 𠅶
    # 0x20177: '',  # 𠅷
    # 0x20178: '',  # 𠅸
    0x20179: 'zhàng',  # 𠅹
    # 0x2017A: '',  # 𠅺
    # 0x2017B: '',  # 𠅻
    # 0x2017C: '',  # 𠅼
    # 0x2017D: '',  # 𠅽
    # 0x2017E: '',  # 𠅾
    # 0x2017F: '',  # 𠅿
    # 0x20180: '',  # 𠆀
    0x20181: 'luǒ',  # 𠆁
    0x20182: 'shuāi',  # 𠆂
    # 0x20183: '',  # 𠆃
    # 0x20184: '',  # 𠆄
    # 0x20185: '',  # 𠆅
    # 0x20186: '',  # 𠆆
    # 0x20187: '',  # 𠆇
    # 0x20188: '',  # 𠆈
    # 0x20189: '',  # 𠆉
    # 0x2018A: '',  # 𠆊
    # 0x2018B: '',  # 𠆋
    0x2018C: 'yōng',  # 𠆌
    # 0x2018D: '',  # 𠆍
    # 0x2018E: '',  # 𠆎
    # 0x2018F: '',  # 𠆏
    0x20190: 'xù',  # 𠆐
    # 0x20191: '',  # 𠆑
    # 0x20192: '',  # 𠆒
    # 0x20193: '',  # 𠆓
    # 0x20194: '',  # 𠆔
    # 0x20195: '',  # 𠆕
    # 0x20196: '',  # 𠆖
    # 0x20197: '',  # 𠆗
    # 0x20198: '',  # 𠆘
    0x20199: 'diè',  # 𠆙
    # 0x2019A: '',  # 𠆚
    0x2019B: 'dān',  # 𠆛
    # 0x2019C: '',  # 𠆜
    0x2019D: 'xiāng',  # 𠆝
    # 0x2019E: '',  # 𠆞
    0x2019F: 'wěi',  # 𠆟
    # 0x201A0: '',  # 𠆠
    # 0x201A1: '',  # 𠆡
    # 0x201A2: '',  # 𠆢
    0x201A3: 'guǎ,zhuǎ',  # 𠆣
    0x201A4: 'dīng',  # 𠆤
    # 0x201A5: '',  # 𠆥
    0x201A6: 'zhà',  # 𠆦
    0x201A7: 'rén',  # 𠆧
    # 0x201A8: '',  # 𠆨
    0x201A9: 'fàn',  # 𠆩
    # 0x201AA: '',  # 𠆪
    # 0x201AB: '',  # 𠆫
    # 0x201AC: '',  # 𠆬
    0x201AD: 'yīn',  # 𠆭
    0x201AE: 'mò',  # 𠆮
    # 0x201AF: '',  # 𠆯
    # 0x201B0: '',  # 𠆰
    0x201B1: 'xī',  # 𠆱
    0x201B2: 'yǎn',  # 𠆲
    # 0x201B3: '',  # 𠆳
    # 0x201B4: '',  # 𠆴
    0x201B5: 'ní',  # 𠆵
    0x201B6: 'dàn',  # 𠆶
    # 0x201B7: '',  # 𠆷
    # 0x201B8: '',  # 𠆸
    # 0x201B9: '',  # 𠆹
    # 0x201BA: '',  # 𠆺
    # 0x201BB: '',  # 𠆻
    # 0x201BC: '',  # 𠆼
    # 0x201BD: '',  # 𠆽
    # 0x201BE: '',  # 𠆾
    # 0x201BF: '',  # 𠆿
    # 0x201C0: '',  # 𠇀
    # 0x201C1: '',  # 𠇁
    0x201C2: 'gè,gě',  # 𠇂
    # 0x201C3: '',  # 𠇃
    # 0x201C4: '',  # 𠇄
    # 0x201C5: '',  # 𠇅
    # 0x201C6: '',  # 𠇆
    # 0x201C7: '',  # 𠇇
    # 0x201C8: '',  # 𠇈
    # 0x201C9: '',  # 𠇉
    # 0x201CA: '',  # 𠇊
    0x201CB: 'dǎn',  # 𠇋
    0x201CC: 'hún',  # 𠇌
    # 0x201CD: '',  # 𠇍
    # 0x201CE: '',  # 𠇎
    0x201CF: 'tāo',  # 𠇏
    # 0x201D0: '',  # 𠇐
    # 0x201D1: '',  # 𠇑
    0x201D2: 'gōng',  # 𠇒
    # 0x201D3: '',  # 𠇓
    0x201D4: 'tuō,chà',  # 𠇔
    # 0x201D5: '',  # 𠇕
    # 0x201D6: '',  # 𠇖
    0x201D7: 'kuā',  # 𠇗
    0x201D8: 'chù',  # 𠇘
    # 0x201D9: '',  # 𠇙
    # 0x201DA: '',  # 𠇚
    # 0x201DB: '',  # 𠇛
    # 0x201DC: '',  # 𠇜
    # 0x201DD: '',  # 𠇝
    # 0x201DE: '',  # 𠇞
    # 0x201DF: '',  # 𠇟
    # 0x201E0: '',  # 𠇠
    # 0x201E1: '',  # 𠇡
    # 0x201E2: '',  # 𠇢
    # 0x201E3: '',  # 𠇣
    # 0x201E4: '',  # 𠇤
    # 0x201E5: '',  # 𠇥
    # 0x201E6: '',  # 𠇦
    # 0x201E7: '',  # 𠇧
    # 0x201E8: '',  # 𠇨
    # 0x201E9: '',  # 𠇩
    # 0x201EA: '',  # 𠇪
    # 0x201EB: '',  # 𠇫
    # 0x201EC: '',  # 𠇬
    # 0x201ED: '',  # 𠇭
    0x201EE: 'mìng',  # 𠇮
    0x201EF: 'qù',  # 𠇯
    # 0x201F0: '',  # 𠇰
    0x201F1: 'mò',  # 𠇱
    # 0x201F2: '',  # 𠇲
    0x201F3: 'shī',  # 𠇳
    # 0x201F4: '',  # 𠇴
    0x201F5: 'gǎn',  # 𠇵
    # 0x201F6: '',  # 𠇶
    0x201F7: 'shēng',  # 𠇷
    0x201F8: 'zuǒ',  # 𠇸
    # 0x201F9: '',  # 𠇹
    0x201FA: 'xiá',  # 𠇺
    # 0x201FB: '',  # 𠇻
    0x201FC: 'hǔ',  # 𠇼
    # 0x201FD: '',  # 𠇽
    # 0x201FE: '',  # 𠇾
    # 0x201FF: '',  # 𠇿
    # 0x20200: '',  # 𠈀
    # 0x20201: '',  # 𠈁
    # 0x20202: '',  # 𠈂
    # 0x20203: '',  # 𠈃
    # 0x20204: '',  # 𠈄
    0x20205: 'shōu',  # 𠈅
    # 0x20206: '',  # 𠈆
    # 0x20207: '',  # 𠈇
    # 0x20208: '',  # 𠈈
    # 0x20209: '',  # 𠈉
    0x2020A: 'niě',  # 𠈊
    # 0x2020B: '',  # 𠈋
    # 0x2020C: '',  # 𠈌
    # 0x2020D: '',  # 𠈍
    # 0x2020E: '',  # 𠈎
    # 0x2020F: '',  # 𠈏
    # 0x20210: '',  # 𠈐
    # 0x20211: '',  # 𠈑
    # 0x20212: '',  # 𠈒
    # 0x20213: '',  # 𠈓
    # 0x20214: '',  # 𠈔
    # 0x20215: '',  # 𠈕
    # 0x20216: '',  # 𠈖
    # 0x20217: '',  # 𠈗
    0x20218: 'kuí',  # 𠈘
    # 0x20219: '',  # 𠈙
    # 0x2021A: '',  # 𠈚
    # 0x2021B: '',  # 𠈛
    # 0x2021C: '',  # 𠈜
    # 0x2021D: '',  # 𠈝
    # 0x2021E: '',  # 𠈞
    # 0x2021F: '',  # 𠈟
    # 0x20220: '',  # 𠈠
    # 0x20221: '',  # 𠈡
    # 0x20222: '',  # 𠈢
    # 0x20223: '',  # 𠈣
    0x20224: 'yùn',  # 𠈤
    0x20225: 'guǎ',  # 𠈥
    # 0x20226: '',  # 𠈦
    # 0x20227: '',  # 𠈧
    # 0x20228: '',  # 𠈨
    # 0x20229: '',  # 𠈩
    # 0x2022A: '',  # 𠈪
    # 0x2022B: '',  # 𠈫
    0x2022C: 'xiāo',  # 𠈬
    0x2022D: 'láo',  # 𠈭
    # 0x2022E: '',  # 𠈮
    # 0x2022F: '',  # 𠈯
    0x20230: 'dàn',  # 𠈰
    0x20231: 'suō',  # 𠈱
    # 0x20232: '',  # 𠈲
    # 0x20233: '',  # 𠈳
    # 0x20234: '',  # 𠈴
    0x20235: 'mǎng',  # 𠈵
    0x20236: 'yí',  # 𠈶
    # 0x20237: '',  # 𠈷
    0x20238: 'tè',  # 𠈸
    # 0x20239: '',  # 𠈹
    0x2023A: 'bì',  # 𠈺
    # 0x2023B: '',  # 𠈻
    # 0x2023C: '',  # 𠈼
    # 0x2023D: '',  # 𠈽
    # 0x2023E: '',  # 𠈾
    # 0x2023F: '',  # 𠈿
    # 0x20240: '',  # 𠉀
    # 0x20241: '',  # 𠉁
    # 0x20242: '',  # 𠉂
    # 0x20243: '',  # 𠉃
    # 0x20244: '',  # 𠉄
    # 0x20245: '',  # 𠉅
    # 0x20246: '',  # 𠉆
    # 0x20247: '',  # 𠉇
    # 0x20248: '',  # 𠉈
    # 0x20249: '',  # 𠉉
    # 0x2024A: '',  # 𠉊
    # 0x2024B: '',  # 𠉋
    # 0x2024C: '',  # 𠉌
    # 0x2024D: '',  # 𠉍
    # 0x2024E: '',  # 𠉎
    # 0x2024F: '',  # 𠉏
    # 0x20250: '',  # 𠉐
    # 0x20251: '',  # 𠉑
    # 0x20252: '',  # 𠉒
    # 0x20253: '',  # 𠉓
    # 0x20254: '',  # 𠉔
    # 0x20255: '',  # 𠉕
    # 0x20256: '',  # 𠉖
    # 0x20257: '',  # 𠉗
    # 0x20258: '',  # 𠉘
    # 0x20259: '',  # 𠉙
    # 0x2025A: '',  # 𠉚
    # 0x2025B: '',  # 𠉛
    # 0x2025C: '',  # 𠉜
    # 0x2025D: '',  # 𠉝
    # 0x2025E: '',  # 𠉞
    # 0x2025F: '',  # 𠉟
    # 0x20260: '',  # 𠉠
    # 0x20261: '',  # 𠉡
    0x20262: 'xǐ',  # 𠉢
    0x20263: 'hūn,hùn',  # 𠉣
    0x20264: 'dá',  # 𠉤
    # 0x20265: '',  # 𠉥
    # 0x20266: '',  # 𠉦
    0x20267: 'jù',  # 𠉧
    # 0x20268: '',  # 𠉨
    0x20269: 'dú',  # 𠉩
    # 0x2026A: '',  # 𠉪
    # 0x2026B: '',  # 𠉫
    0x2026C: 'ǎn,yǎn',  # 𠉬
    # 0x2026D: '',  # 𠉭
    # 0x2026E: '',  # 𠉮
    # 0x2026F: '',  # 𠉯
    # 0x20270: '',  # 𠉰
    # 0x20271: '',  # 𠉱
    # 0x20272: '',  # 𠉲
    # 0x20273: '',  # 𠉳
    # 0x20274: '',  # 𠉴
    # 0x20275: '',  # 𠉵
    # 0x20276: '',  # 𠉶
    # 0x20277: '',  # 𠉷
    # 0x20278: '',  # 𠉸
    # 0x20279: '',  # 𠉹
    # 0x2027A: '',  # 𠉺
    # 0x2027B: '',  # 𠉻
    # 0x2027C: '',  # 𠉼
    # 0x2027D: '',  # 𠉽
    # 0x2027E: '',  # 𠉾
    # 0x2027F: '',  # 𠉿
    # 0x20280: '',  # 𠊀
    # 0x20281: '',  # 𠊁
    # 0x20282: '',  # 𠊂
    # 0x20283: '',  # 𠊃
    # 0x20284: '',  # 𠊄
    # 0x20285: '',  # 𠊅
    # 0x20286: '',  # 𠊆
    # 0x20287: '',  # 𠊇
    # 0x20288: '',  # 𠊈
    0x20289: 'mèi',  # 𠊉
    # 0x2028A: '',  # 𠊊
    # 0x2028B: '',  # 𠊋
    0x2028C: 'rán',  # 𠊌
    # 0x2028D: '',  # 𠊍
    0x2028E: 'ái',  # 𠊎
    0x2028F: 'yù,xián',  # 𠊏
    # 0x20290: '',  # 𠊐
    # 0x20291: '',  # 𠊑
    0x20292: 'jiàn',  # 𠊒
    # 0x20293: '',  # 𠊓
    0x20294: 'qì',  # 𠊔
    # 0x20295: '',  # 𠊕
    # 0x20296: '',  # 𠊖
    # 0x20297: '',  # 𠊗
    # 0x20298: '',  # 𠊘
    # 0x20299: '',  # 𠊙
    # 0x2029A: '',  # 𠊚
    # 0x2029B: '',  # 𠊛
    # 0x2029C: '',  # 𠊜
    # 0x2029D: '',  # 𠊝
    # 0x2029E: '',  # 𠊞
    # 0x2029F: '',  # 𠊟
    # 0x202A0: '',  # 𠊠
    # 0x202A1: '',  # 𠊡
    # 0x202A2: '',  # 𠊢
    0x202A3: 'zhòu',  # 𠊣
    0x202A4: 'zhì',  # 𠊤
    0x202A5: 'zhǒng',  # 𠊥
    0x202A6: 'nǎo',  # 𠊦
    0x202A7: 'bìng',  # 𠊧
    # 0x202A8: '',  # 𠊨
    0x202A9: 'zhuàn',  # 𠊩
    0x202AA: 'shù',  # 𠊪
    0x202AB: 'xùn,qióng',  # 𠊫
    0x202AC: 'jué',  # 𠊬
    0x202AD: 'qiǎn',  # 𠊭
    # 0x202AE: '',  # 𠊮
    # 0x202AF: '',  # 𠊯
    0x202B0: 'guǎ',  # 𠊰
    0x202B1: 'hòu',  # 𠊱
    0x202B2: 'tū',  # 𠊲
    # 0x202B3: '',  # 𠊳
    # 0x202B4: '',  # 𠊴
    0x202B5: 'bēng',  # 𠊵
    0x202B6: 'yìng',  # 𠊶
    0x202B7: 'zhì',  # 𠊷
    # 0x202B8: '',  # 𠊸
    # 0x202B9: '',  # 𠊹
    # 0x202BA: '',  # 𠊺
    # 0x202BB: '',  # 𠊻
    # 0x202BC: '',  # 𠊼
    # 0x202BD: '',  # 𠊽
    0x202BE: 'kuí',  # 𠊾
    # 0x202BF: '',  # 𠊿
    # 0x202C0: '',  # 𠋀
    # 0x202C1: '',  # 𠋁
    # 0x202C2: '',  # 𠋂
    # 0x202C3: '',  # 𠋃
    # 0x202C4: '',  # 𠋄
    # 0x202C5: '',  # 𠋅
    # 0x202C6: '',  # 𠋆
    # 0x202C7: '',  # 𠋇
    # 0x202C8: '',  # 𠋈
    # 0x202C9: '',  # 𠋉
    # 0x202CA: '',  # 𠋊
    # 0x202CB: '',  # 𠋋
    # 0x202CC: '',  # 𠋌
    # 0x202CD: '',  # 𠋍
    # 0x202CE: '',  # 𠋎
    # 0x202CF: '',  # 𠋏
    # 0x202D0: '',  # 𠋐
    # 0x202D1: '',  # 𠋑
    # 0x202D2: '',  # 𠋒
    # 0x202D3: '',  # 𠋓
    # 0x202D4: '',  # 𠋔
    # 0x202D5: '',  # 𠋕
    0x202D6: 'liàn',  # 𠋖
    0x202D7: 'yā',  # 𠋗
    # 0x202D8: '',  # 𠋘
    # 0x202D9: '',  # 𠋙
    # 0x202DA: '',  # 𠋚
    # 0x202DB: '',  # 𠋛
    0x202DC: 'guò',  # 𠋜
    0x202DD: 'miǎo',  # 𠋝
    0x202DE: 'shé',  # 𠋞
    0x202DF: 'yǔ',  # 𠋟
    # 0x202E0: '',  # 𠋠
    0x202E1: 'sì',  # 𠋡
    0x202E2: 'sǒu,zhòu',  # 𠋢
    0x202E3: 'yǐ',  # 𠋣
    0x202E4: 'zhì',  # 𠋤
    # 0x202E5: '',  # 𠋥
    # 0x202E6: '',  # 𠋦
    0x202E7: 'qiē',  # 𠋧
    # 0x202E8: '',  # 𠋨
    0x202E9: 'fù',  # 𠋩
    # 0x202EA: '',  # 𠋪
    # 0x202EB: '',  # 𠋫
    0x202EC: 'jú',  # 𠋬
    0x202ED: 'bèi',  # 𠋭
    # 0x202EE: '',  # 𠋮
    0x202EF: 'bì',  # 𠋯
    # 0x202F0: '',  # 𠋰
    # 0x202F1: '',  # 𠋱
    0x202F2: 'suǒ',  # 𠋲
    # 0x202F3: '',  # 𠋳
    # 0x202F4: '',  # 𠋴
    0x202F5: 'qiǎn',  # 𠋵
    0x202F6: 'mǐng',  # 𠋶
    0x202F7: 'chǎn',  # 𠋷
    # 0x202F8: '',  # 𠋸
    # 0x202F9: '',  # 𠋹
    0x202FA: 'sāo',  # 𠋺
    0x202FB: 'jī',  # 𠋻
    # 0x202FC: '',  # 𠋼
    # 0x202FD: '',  # 𠋽
    # 0x202FE: '',  # 𠋾
    # 0x202FF: '',  # 𠋿
    # 0x20300: '',  # 𠌀
    # 0x20301: '',  # 𠌁
    # 0x20302: '',  # 𠌂
    # 0x20303: '',  # 𠌃
    # 0x20304: '',  # 𠌄
    # 0x20305: '',  # 𠌅
    # 0x20306: '',  # 𠌆
    # 0x20307: '',  # 𠌇
    # 0x20308: '',  # 𠌈
    # 0x20309: '',  # 𠌉
    # 0x2030A: '',  # 𠌊
    # 0x2030B: '',  # 𠌋
    # 0x2030C: '',  # 𠌌
    # 0x2030D: '',  # 𠌍
    # 0x2030E: '',  # 𠌎
    # 0x2030F: '',  # 𠌏
    # 0x20310: '',  # 𠌐
    # 0x20311: '',  # 𠌑
    # 0x20312: '',  # 𠌒
    # 0x20313: '',  # 𠌓
    # 0x20314: '',  # 𠌔
    0x20315: 'gòng',  # 𠌕
    0x20316: 'qióng',  # 𠌖
    # 0x20317: '',  # 𠌗
    # 0x20318: '',  # 𠌘
    # 0x20319: '',  # 𠌙
    0x2031A: 'ròng',  # 𠌚
    # 0x2031B: '',  # 𠌛
    # 0x2031C: '',  # 𠌜
    # 0x2031D: '',  # 𠌝
    0x2031E: 'sǒu',  # 𠌞
    0x2031F: 'sǒu',  # 𠌟
    0x20320: 'yáo',  # 𠌠
    # 0x20321: '',  # 𠌡
    # 0x20322: '',  # 𠌢
    # 0x20323: '',  # 𠌣
    # 0x20324: '',  # 𠌤
    0x20325: 'wū',  # 𠌥
    # 0x20326: '',  # 𠌦
    # 0x20327: '',  # 𠌧
    # 0x20328: '',  # 𠌨
    # 0x20329: '',  # 𠌩
    0x2032A: 'chōu,tāo',  # 𠌪
    # 0x2032B: '',  # 𠌫
    # 0x2032C: '',  # 𠌬
    0x2032D: 'shuài',  # 𠌭
    0x2032E: 'zhē',  # 𠌮
    0x2032F: 'lì,lí',  # 𠌯
    0x20330: 'gài',  # 𠌰
    0x20331: 'suī',  # 𠌱
    0x20332: 'zhān',  # 𠌲
    # 0x20333: '',  # 𠌳
    0x20334: 'zhuàng',  # 𠌴
    # 0x20335: '',  # 𠌵
    0x20336: 'huā',  # 𠌶
    # 0x20337: '',  # 𠌷
    # 0x20338: '',  # 𠌸
    # 0x20339: '',  # 𠌹
    # 0x2033A: '',  # 𠌺
    # 0x2033B: '',  # 𠌻
    # 0x2033C: '',  # 𠌼
    0x2033D: 'fù',  # 𠌽
    # 0x2033E: '',  # 𠌾
    # 0x2033F: '',  # 𠌿
    # 0x20340: '',  # 𠍀
    # 0x20341: '',  # 𠍁
    # 0x20342: '',  # 𠍂
    0x20343: 'jī',  # 𠍃
    0x20344: 'dōu',  # 𠍄
    # 0x20345: '',  # 𠍅
    # 0x20346: '',  # 𠍆
    # 0x20347: '',  # 𠍇
    # 0x20348: '',  # 𠍈
    # 0x20349: '',  # 𠍉
    # 0x2034A: '',  # 𠍊
    # 0x2034B: '',  # 𠍋
    # 0x2034C: '',  # 𠍌
    # 0x2034D: '',  # 𠍍
    # 0x2034E: '',  # 𠍎
    # 0x2034F: '',  # 𠍏
    0x20350: 'hú,lěng',  # 𠍐
    # 0x20351: '',  # 𠍑
    # 0x20352: '',  # 𠍒
    # 0x20353: '',  # 𠍓
    # 0x20354: '',  # 𠍔
    # 0x20355: '',  # 𠍕
    # 0x20356: '',  # 𠍖
    0x20357: 'huì',  # 𠍗
    # 0x20358: '',  # 𠍘
    0x20359: 'bǎo',  # 𠍙
    0x2035A: 'jiǎn',  # 𠍚
    0x2035B: 'yǎn',  # 𠍛
    0x2035C: 'zhì',  # 𠍜
    # 0x2035D: '',  # 𠍝
    # 0x2035E: '',  # 𠍞
    # 0x2035F: '',  # 𠍟
    # 0x20360: '',  # 𠍠
    # 0x20361: '',  # 𠍡
    # 0x20362: '',  # 𠍢
    # 0x20363: '',  # 𠍣
    # 0x20364: '',  # 𠍤
    # 0x20365: '',  # 𠍥
    0x20366: 'xián',  # 𠍦
    # 0x20367: '',  # 𠍧
    0x20368: 'měi',  # 𠍨
    0x20369: 'yào',  # 𠍩
    0x2036A: 'dī',  # 𠍪
    0x2036B: 'yí',  # 𠍫
    # 0x2036C: '',  # 𠍬
    # 0x2036D: '',  # 𠍭
    # 0x2036E: '',  # 𠍮
    0x2036F: 'bié',  # 𠍯
    # 0x20370: '',  # 𠍰
    # 0x20371: '',  # 𠍱
    0x20372: 'qú',  # 𠍲
    0x20373: 'yì',  # 𠍳
    # 0x20374: '',  # 𠍴
    0x20375: 'yàng',  # 𠍵
    # 0x20376: '',  # 𠍶
    # 0x20377: '',  # 𠍷
    # 0x20378: '',  # 𠍸
    0x20379: 'zhá',  # 𠍹
    # 0x2037A: '',  # 𠍺
    # 0x2037B: '',  # 𠍻
    # 0x2037C: '',  # 𠍼
    0x2037D: 'shà',  # 𠍽
    # 0x2037E: '',  # 𠍾
    # 0x2037F: '',  # 𠍿
    # 0x20380: '',  # 𠎀
    # 0x20381: '',  # 𠎁
    # 0x20382: '',  # 𠎂
    # 0x20383: '',  # 𠎃
    # 0x20384: '',  # 𠎄
    # 0x20385: '',  # 𠎅
    # 0x20386: '',  # 𠎆
    # 0x20387: '',  # 𠎇
    # 0x20388: '',  # 𠎈
    # 0x20389: '',  # 𠎉
    # 0x2038A: '',  # 𠎊
    # 0x2038B: '',  # 𠎋
    # 0x2038C: '',  # 𠎌
    # 0x2038D: '',  # 𠎍
    # 0x2038E: '',  # 𠎎
    # 0x2038F: '',  # 𠎏
    # 0x20390: '',  # 𠎐
    # 0x20391: '',  # 𠎑
    0x20392: 'mèn',  # 𠎒
    # 0x20393: '',  # 𠎓
    # 0x20394: '',  # 𠎔
    # 0x20395: '',  # 𠎕
    # 0x20396: '',  # 𠎖
    # 0x20397: '',  # 𠎗
    # 0x20398: '',  # 𠎘
    0x20399: 'lái',  # 𠎙
    # 0x2039A: '',  # 𠎚
    # 0x2039B: '',  # 𠎛
    # 0x2039C: '',  # 𠎜
    0x2039D: 'qiān',  # 𠎝
    # 0x2039E: '',  # 𠎞
    # 0x2039F: '',  # 𠎟
    # 0x203A0: '',  # 𠎠
    # 0x203A1: '',  # 𠎡
    # 0x203A2: '',  # 𠎢
    # 0x203A3: '',  # 𠎣
    # 0x203A4: '',  # 𠎤
    # 0x203A5: '',  # 𠎥
    # 0x203A6: '',  # 𠎦
    # 0x203A7: '',  # 𠎧
    # 0x203A8: '',  # 𠎨
    # 0x203A9: '',  # 𠎩
    # 0x203AA: '',  # 𠎪
    # 0x203AB: '',  # 𠎫
    # 0x203AC: '',  # 𠎬
    # 0x203AD: '',  # 𠎭
    0x203AE: 'jué',  # 𠎮
    # 0x203AF: '',  # 𠎯
    0x203B0: 'qī',  # 𠎰
    # 0x203B1: '',  # 𠎱
    # 0x203B2: '',  # 𠎲
    0x203B3: 'yú',  # 𠎳
    # 0x203B4: '',  # 𠎴
    # 0x203B5: '',  # 𠎵
    0x203B6: 'zǎi',  # 𠎶
    0x203B7: 'sà',  # 𠎷
    0x203B8: 'sè',  # 𠎸
    # 0x203B9: '',  # 𠎹
    # 0x203BA: '',  # 𠎺
    0x203BB: 'dùn',  # 𠎻
    # 0x203BC: '',  # 𠎼
    # 0x203BD: '',  # 𠎽
    # 0x203BE: '',  # 𠎾
    0x203BF: 'jiě',  # 𠎿
    0x203C0: 'kē',  # 𠏀
    # 0x203C1: '',  # 𠏁
    # 0x203C2: '',  # 𠏂
    0x203C3: 'yuē',  # 𠏃
    # 0x203C4: '',  # 𠏄
    # 0x203C5: '',  # 𠏅
    # 0x203C6: '',  # 𠏆
    0x203C7: 'jiǎn',  # 𠏇
    0x203C8: 'yáo',  # 𠏈
    # 0x203C9: '',  # 𠏉
    # 0x203CA: '',  # 𠏊
    # 0x203CB: '',  # 𠏋
    # 0x203CC: '',  # 𠏌
    # 0x203CD: '',  # 𠏍
    # 0x203CE: '',  # 𠏎
    # 0x203CF: '',  # 𠏏
    # 0x203D0: '',  # 𠏐
    # 0x203D1: '',  # 𠏑
    # 0x203D2: '',  # 𠏒
    0x203D3: 'xiān',  # 𠏓
    # 0x203D4: '',  # 𠏔
    0x203D5: 'xiào',  # 𠏕
    0x203D6: 'qiāo',  # 𠏖
    # 0x203D7: '',  # 𠏗
    # 0x203D8: '',  # 𠏘
    # 0x203D9: '',  # 𠏙
    0x203DA: 'yù',  # 𠏚
    0x203DB: 'qú',  # 𠏛
    # 0x203DC: '',  # 𠏜
    # 0x203DD: '',  # 𠏝
    # 0x203DE: '',  # 𠏞
    # 0x203DF: '',  # 𠏟
    # 0x203E0: '',  # 𠏠
    0x203E1: 'xiān,líng',  # 𠏡
    0x203E2: 'luò',  # 𠏢
    # 0x203E3: '',  # 𠏣
    0x203E4: 'guǎng',  # 𠏤
    # 0x203E5: '',  # 𠏥
    # 0x203E6: '',  # 𠏦
    0x203E7: 'chēng',  # 𠏧
    0x203E8: 'chuǎng',  # 𠏨
    0x203E9: 'yí',  # 𠏩
    # 0x203EA: '',  # 𠏪
    0x203EB: 'zhěng',  # 𠏫
    # 0x203EC: '',  # 𠏬
    0x203ED: 'zòng',  # 𠏭
    0x203EE: 'duì',  # 𠏮
    # 0x203EF: '',  # 𠏯
    0x203F0: 'zhǎi',  # 𠏰
    # 0x203F1: '',  # 𠏱
    # 0x203F2: '',  # 𠏲
    # 0x203F3: '',  # 𠏳
    # 0x203F4: '',  # 𠏴
    # 0x203F5: '',  # 𠏵
    # 0x203F6: '',  # 𠏶
    # 0x203F7: '',  # 𠏷
    # 0x203F8: '',  # 𠏸
    # 0x203F9: '',  # 𠏹
    # 0x203FA: '',  # 𠏺
    # 0x203FB: '',  # 𠏻
    # 0x203FC: '',  # 𠏼
    # 0x203FD: '',  # 𠏽
    # 0x203FE: '',  # 𠏾
    0x203FF: 'fěi',  # 𠏿
    0x20400: 'yí',  # 𠐀
    0x20401: 'méng',  # 𠐁
    # 0x20402: '',  # 𠐂
    # 0x20403: '',  # 𠐃
    # 0x20404: '',  # 𠐄
    # 0x20405: '',  # 𠐅
    # 0x20406: '',  # 𠐆
    # 0x20407: '',  # 𠐇
    0x20408: 'biān,pián',  # 𠐈
    0x20409: 'jié',  # 𠐉
    0x2040A: 'shù',  # 𠐊
    0x2040B: 'liáo',  # 𠐋
    0x2040C: 'bǐ,bà',  # 𠐌
    0x2040D: 'sú',  # 𠐍
    # 0x2040E: '',  # 𠐎
    # 0x2040F: '',  # 𠐏
    # 0x20410: '',  # 𠐐
    0x20411: 'dì',  # 𠐑
    # 0x20412: '',  # 𠐒
    # 0x20413: '',  # 𠐓
    # 0x20414: '',  # 𠐔
    # 0x20415: '',  # 𠐕
    # 0x20416: '',  # 𠐖
    # 0x20417: '',  # 𠐗
    # 0x20418: '',  # 𠐘
    # 0x20419: '',  # 𠐙
    # 0x2041A: '',  # 𠐚
    # 0x2041B: '',  # 𠐛
    # 0x2041C: '',  # 𠐜
    # 0x2041D: '',  # 𠐝
    # 0x2041E: '',  # 𠐞
    # 0x2041F: '',  # 𠐟
    # 0x20420: '',  # 𠐠
    0x20421: 'bèi',  # 𠐡
    0x20422: 'wèn',  # 𠐢
    # 0x20423: '',  # 𠐣
    # 0x20424: '',  # 𠐤
    # 0x20425: '',  # 𠐥
    # 0x20426: '',  # 𠐦
    0x20427: 'méng',  # 𠐧
    # 0x20428: '',  # 𠐨
    0x20429: 'chǎn',  # 𠐩
    # 0x2042A: '',  # 𠐪
    # 0x2042B: '',  # 𠐫
    # 0x2042C: '',  # 𠐬
    # 0x2042D: '',  # 𠐭
    # 0x2042E: '',  # 𠐮
    # 0x2042F: '',  # 𠐯
    # 0x20430: '',  # 𠐰
    0x20431: 'gàn',  # 𠐱
    0x20432: 'bèi',  # 𠐲
    # 0x20433: '',  # 𠐳
    # 0x20434: '',  # 𠐴
    0x20435: 'dǎo',  # 𠐵
    # 0x20436: '',  # 𠐶
    # 0x20437: '',  # 𠐷
    # 0x20438: '',  # 𠐸
    # 0x20439: '',  # 𠐹
    0x2043A: 'pín',  # 𠐺
    0x2043B: 'jiǎn',  # 𠐻
    0x2043C: 'lìn',  # 𠐼
    0x2043D: 'guì,guī',  # 𠐽
    0x2043E: 'qī',  # 𠐾
    0x2043F: 'hōng',  # 𠐿
    # 0x20440: '',  # 𠑀
    # 0x20441: '',  # 𠑁
    # 0x20442: '',  # 𠑂
    0x20443: 'jí',  # 𠑃
    0x20444: 'xiè',  # 𠑄
    0x20445: 'zhēng',  # 𠑅
    0x20446: 'chǎn',  # 𠑆
    # 0x20447: '',  # 𠑇
    # 0x20448: '',  # 𠑈
    # 0x20449: '',  # 𠑉
    # 0x2044A: '',  # 𠑊
    # 0x2044B: '',  # 𠑋
    # 0x2044C: '',  # 𠑌
    # 0x2044D: '',  # 𠑍
    # 0x2044E: '',  # 𠑎
    # 0x2044F: '',  # 𠑏
    0x20450: 'yáo',  # 𠑐
    0x20451: 'chǎn',  # 𠑑
    # 0x20452: '',  # 𠑒
    # 0x20453: '',  # 𠑓
    # 0x20454: '',  # 𠑔
    # 0x20455: '',  # 𠑕
    # 0x20456: '',  # 𠑖
    # 0x20457: '',  # 𠑗
    0x20458: 'diān',  # 𠑘
    0x20459: 'chòng',  # 𠑙
    0x2045A: 'néi',  # 𠑚
    0x2045B: 'néi',  # 𠑛
    # 0x2045C: '',  # 𠑜
    # 0x2045D: '',  # 𠑝
    0x2045E: 'zhài',  # 𠑞
    0x2045F: 'biān,pián',  # 𠑟
    # 0x20460: '',  # 𠑠
    0x20461: 'chǎn',  # 𠑡
    # 0x20462: '',  # 𠑢
    # 0x20463: '',  # 𠑣
    # 0x20464: '',  # 𠑤
    # 0x20465: '',  # 𠑥
    # 0x20466: '',  # 𠑦
    # 0x20467: '',  # 𠑧
    # 0x20468: '',  # 𠑨
    # 0x20469: '',  # 𠑩
    0x2046A: 'xiāo',  # 𠑪
    # 0x2046B: '',  # 𠑫
    # 0x2046C: '',  # 𠑬
    # 0x2046D: '',  # 𠑭
    # 0x2046E: '',  # 𠑮
    0x2046F: 'cù',  # 𠑯
    0x20470: 'xīn',  # 𠑰
    0x20471: 'jǐng',  # 𠑱
    0x20472: 'qiān',  # 𠑲
    # 0x20473: '',  # 𠑳
    0x20474: 'qīng',  # 𠑴
    # 0x20475: '',  # 𠑵
    0x20476: 'wú',  # 𠑶
    0x20477: 'cháng,zhǎng',  # 𠑷
    # 0x20478: '',  # 𠑸
    0x20479: 'gǔ',  # 𠑹
    0x2047A: 'tiān',  # 𠑺
    0x2047B: 'cháng,zhǎng',  # 𠑻
    # 0x2047C: '',  # 𠑼
    0x2047D: 'chōng',  # 𠑽
    0x2047E: 'sǐ',  # 𠑾
    # 0x2047F: '',  # 𠑿
    # 0x20480: '',  # 𠒀
    # 0x20481: '',  # 𠒁
    # 0x20482: '',  # 𠒂
    0x20483: 'sì',  # 𠒃
    0x20484: 'wù',  # 𠒄
    0x20485: 'sì',  # 𠒅
    0x20486: 'ér',  # 𠒆
    # 0x20487: '',  # 𠒇
    # 0x20488: '',  # 𠒈
    # 0x20489: '',  # 𠒉
    # 0x2048A: '',  # 𠒊
    # 0x2048B: '',  # 𠒋
    0x2048C: 'qiāng',  # 𠒌
    0x2048D: 'yú',  # 𠒍
    # 0x2048E: '',  # 𠒎
    # 0x2048F: '',  # 𠒏
    # 0x20490: '',  # 𠒐
    # 0x20491: '',  # 𠒑
    # 0x20492: '',  # 𠒒
    # 0x20493: '',  # 𠒓
    # 0x20494: '',  # 𠒔
    # 0x20495: '',  # 𠒕
    # 0x20496: '',  # 𠒖
    # 0x20497: '',  # 𠒗
    # 0x20498: '',  # 𠒘
    # 0x20499: '',  # 𠒙
    # 0x2049A: '',  # 𠒚
    # 0x2049B: '',  # 𠒛
    0x2049C: 'yuǎn',  # 𠒜
    0x2049D: 'bǐng',  # 𠒝
    # 0x2049E: '',  # 𠒞
    # 0x2049F: '',  # 𠒟
    # 0x204A0: '',  # 𠒠
    # 0x204A1: '',  # 𠒡
    0x204A2: 'wán',  # 𠒢
    # 0x204A3: '',  # 𠒣
    # 0x204A4: '',  # 𠒤
    # 0x204A5: '',  # 𠒥
    # 0x204A6: '',  # 𠒦
    0x204A7: 'bó',  # 𠒧
    0x204A8: 'liáng,liàng',  # 𠒨
    # 0x204A9: '',  # 𠒩
    # 0x204AA: '',  # 𠒪
    # 0x204AB: '',  # 𠒫
    # 0x204AC: '',  # 𠒬
    # 0x204AD: '',  # 𠒭
    # 0x204AE: '',  # 𠒮
    # 0x204AF: '',  # 𠒯
    0x204B0: 'niǎo,ní',  # 𠒰
    0x204B1: 'pì',  # 𠒱
    # 0x204B2: '',  # 𠒲
    # 0x204B3: '',  # 𠒳
    # 0x204B4: '',  # 𠒴
    0x204B5: 'liàn',  # 𠒵
    # 0x204B6: '',  # 𠒶
    # 0x204B7: '',  # 𠒷
    0x204B8: 'rǎo',  # 𠒸
    # 0x204B9: '',  # 𠒹
    # 0x204BA: '',  # 𠒺
    # 0x204BB: '',  # 𠒻
    # 0x204BC: '',  # 𠒼
    # 0x204BD: '',  # 𠒽
    0x204BE: 'fàn',  # 𠒾
    0x204BF: 'dí',  # 𠒿
    # 0x204C0: '',  # 𠓀
    # 0x204C1: '',  # 𠓁
    # 0x204C2: '',  # 𠓂
    # 0x204C3: '',  # 𠓃
    # 0x204C4: '',  # 𠓄
    # 0x204C5: '',  # 𠓅
    0x204C6: 'jīng',  # 𠓆
    # 0x204C7: '',  # 𠓇
    # 0x204C8: '',  # 𠓈
    # 0x204C9: '',  # 𠓉
    0x204CA: 'huī,dān',  # 𠓊
    0x204CB: 'yì',  # 𠓋
    0x204CC: 'xián',  # 𠓌
    # 0x204CD: '',  # 𠓍
    # 0x204CE: '',  # 𠓎
    # 0x204CF: '',  # 𠓏
    # 0x204D0: '',  # 𠓐
    # 0x204D1: '',  # 𠓑
    # 0x204D2: '',  # 𠓒
    # 0x204D3: '',  # 𠓓
    # 0x204D4: '',  # 𠓔
    # 0x204D5: '',  # 𠓕
    0x204D6: 'lán',  # 𠓖
    0x204D7: 'fù',  # 𠓗
    # 0x204D8: '',  # 𠓘
    0x204D9: 'xiòng',  # 𠓙
    # 0x204DA: '',  # 𠓚
    0x204DB: 'jí',  # 𠓛
    0x204DC: 'liǎng',  # 𠓜
    0x204DD: 'tāo',  # 𠓝
    0x204DE: 'jí',  # 𠓞
    0x204DF: 'fá',  # 𠓟
    # 0x204E0: '',  # 𠓠
    0x204E1: 'shǐ',  # 𠓡
    0x204E2: 'jiè',  # 𠓢
    0x204E3: 'zhá',  # 𠓣
    0x204E4: 'shī',  # 𠓤
    # 0x204E5: '',  # 𠓥
    # 0x204E6: '',  # 𠓦
    # 0x204E7: '',  # 𠓧
    # 0x204E8: '',  # 𠓨
    # 0x204E9: '',  # 𠓩
    0x204EA: 'qí',  # 𠓪
    0x204EB: 'biǎn',  # 𠓫
    # 0x204EC: '',  # 𠓬
    0x204ED: 'lǎn',  # 𠓭
    0x204EE: 'lǐn',  # 𠓮
    # 0x204EF: '',  # 𠓯
    # 0x204F0: '',  # 𠓰
    0x204F1: 'yù',  # 𠓱
    0x204F2: 'chéng',  # 𠓲
    # 0x204F3: '',  # 𠓳
    0x204F4: 'quán',  # 𠓴
    0x204F5: 'bì',  # 𠓵
    0x204F6: 'zhì',  # 𠓶
    0x204F7: 'bì,chéng',  # 𠓷
    0x204F8: 'shèng',  # 𠓸
    # 0x204F9: '',  # 𠓹
    # 0x204FA: '',  # 𠓺
    # 0x204FB: '',  # 𠓻
    # 0x204FC: '',  # 𠓼
    0x204FD: 'shèng',  # 𠓽
    # 0x204FE: '',  # 𠓾
    0x204FF: 'qín',  # 𠓿
    0x20500: 'bān',  # 𠔀
    0x20501: 'bié',  # 𠔁
    0x20502: 'biāo',  # 𠔂
    0x20503: 'xī',  # 𠔃
    # 0x20504: '',  # 𠔄
    # 0x20505: '',  # 𠔅
    # 0x20506: '',  # 𠔆
    # 0x20507: '',  # 𠔇
    0x20508: 'zhōng',  # 𠔈
    0x20509: 'juàn',  # 𠔉
    0x2050A: 'cháng,zhǎng',  # 𠔊
    0x2050B: 'jī,xìn',  # 𠔋
    0x2050C: 'jué',  # 𠔌
    0x2050D: 'xī',  # 𠔍
    0x2050E: 'qǐn',  # 𠔎
    # 0x2050F: '',  # 𠔏
    0x20510: 'jī',  # 𠔐
    0x20511: 'hài',  # 𠔑
    0x20512: 'chǐ',  # 𠔒
    0x20513: 'diǎn',  # 𠔓
    0x20514: 'yǔ',  # 𠔔
    0x20515: 'lún',  # 𠔕
    0x20516: 'jǔ',  # 𠔖
    # 0x20517: '',  # 𠔗
    # 0x20518: '',  # 𠔘
    0x20519: 'zhōng',  # 𠔙
    0x2051A: 'qì',  # 𠔚
    0x2051B: 'jī',  # 𠔛
    # 0x2051C: '',  # 𠔜
    # 0x2051D: '',  # 𠔝
    # 0x2051E: '',  # 𠔞
    0x2051F: 'duó',  # 𠔟
    0x20520: 'yuè',  # 𠔠
    # 0x20521: '',  # 𠔡
    # 0x20522: '',  # 𠔢
    # 0x20523: '',  # 𠔣
    # 0x20524: '',  # 𠔤
    # 0x20525: '',  # 𠔥
    # 0x20526: '',  # 𠔦
    # 0x20527: '',  # 𠔧
    0x20528: 'lián',  # 𠔨
    # 0x20529: '',  # 𠔩
    # 0x2052A: '',  # 𠔪
    # 0x2052B: '',  # 𠔫
    # 0x2052C: '',  # 𠔬
    # 0x2052D: '',  # 𠔭
    # 0x2052E: '',  # 𠔮
    0x2052F: 'bān',  # 𠔯
    0x20530: 'diǎn',  # 𠔰
    # 0x20531: '',  # 𠔱
    0x20532: 'héng',  # 𠔲
    # 0x20533: '',  # 𠔳
    # 0x20534: '',  # 𠔴
    # 0x20535: '',  # 𠔵
    0x20536: 'qī',  # 𠔶
    # 0x20537: '',  # 𠔷
    0x20538: 'jī,qī',  # 𠔸
    0x20539: 'chén',  # 𠔹
    0x2053A: 'qiān',  # 𠔺
    0x2053B: 'zhèng',  # 𠔻
    0x2053C: 'mǎo',  # 𠔼
    0x2053D: 'rén',  # 𠔽
    0x2053E: 'zhōng',  # 𠔾
    # 0x2053F: '',  # 𠔿
    # 0x20540: '',  # 𠕀
    0x20541: 'cóng',  # 𠕁
    0x20542: 'zài',  # 𠕂
    0x20543: 'wǎng',  # 𠕃
    0x20544: 'nà',  # 𠕄
    0x20545: 'zài',  # 𠕅
    0x20546: 'diàn',  # 𠕆
    0x20547: 'diàn',  # 𠕇
    # 0x20548: '',  # 𠕈
    # 0x20549: '',  # 𠕉
    0x2054A: 'tǐng',  # 𠕊
    0x2054B: 'cè',  # 𠕋
    0x2054C: 'zōng',  # 𠕌
    0x2054D: 'guān',  # 𠕍
    # 0x2054E: '',  # 𠕎
    # 0x2054F: '',  # 𠕏
    0x20550: 'cè',  # 𠕐
    0x20551: 'dān',  # 𠕑
    0x20552: 'yǔ',  # 𠕒
    # 0x20553: '',  # 𠕓
    # 0x20554: '',  # 𠕔
    0x20555: 'jiōng',  # 𠕕
    0x20556: 'zhǎo',  # 𠕖
    0x20557: 'chuò',  # 𠕗
    0x20558: 'yǔ',  # 𠕘
    # 0x20559: '',  # 𠕙
    # 0x2055A: '',  # 𠕚
    0x2055B: 'hé',  # 𠕛
    # 0x2055C: '',  # 𠕜
    0x2055D: 'nuó',  # 𠕝
    0x2055E: 'cì',  # 𠕞
    0x2055F: 'niǎn',  # 𠕟
    0x20560: 'chéng',  # 𠕠
    # 0x20561: '',  # 𠕡
    # 0x20562: '',  # 𠕢
    0x20563: 'qià',  # 𠕣
    0x20564: 'yuān',  # 𠕤
    0x20565: 'dào',  # 𠕥
    0x20566: 'yù',  # 𠕦
    0x20567: 'jiǎo',  # 𠕧
    0x20568: 'jì',  # 𠕨
    0x20569: 'bēi',  # 𠕩
    # 0x2056A: '',  # 𠕪
    # 0x2056B: '',  # 𠕫
    # 0x2056C: '',  # 𠕬
    0x2056D: 'zhào',  # 𠕭
    0x2056E: 'xū',  # 𠕮
    # 0x2056F: '',  # 𠕯
    0x20570: 'nuó',  # 𠕰
    # 0x20571: '',  # 𠕱
    0x20572: 'yǔ',  # 𠕲
    0x20573: 'dí',  # 𠕳
    0x20574: 'jiū',  # 𠕴
    # 0x20575: '',  # 𠕵
    # 0x20576: '',  # 𠕶
    # 0x20577: '',  # 𠕷
    0x20578: 'suǐ',  # 𠕸
    # 0x20579: '',  # 𠕹
    # 0x2057A: '',  # 𠕺
    0x2057B: 'yāo',  # 𠕻
    # 0x2057C: '',  # 𠕼
    # 0x2057D: '',  # 𠕽
    # 0x2057E: '',  # 𠕾
    0x2057F: 'wāng',  # 𠕿
    # 0x20580: '',  # 𠖀
    # 0x20581: '',  # 𠖁
    0x20582: 'liáo',  # 𠖂
    # 0x20583: '',  # 𠖃
    0x20584: 'tóng',  # 𠖄
    # 0x20585: '',  # 𠖅
    0x20586: 'mèng',  # 𠖆
    # 0x20587: '',  # 𠖇
    # 0x20588: '',  # 𠖈
    # 0x20589: '',  # 𠖉
    # 0x2058A: '',  # 𠖊
    0x2058B: 'yǒu',  # 𠖋
    # 0x2058C: '',  # 𠖌
    # 0x2058D: '',  # 𠖍
    # 0x2058E: '',  # 𠖎
    # 0x2058F: '',  # 𠖏
    # 0x20590: '',  # 𠖐
    # 0x20591: '',  # 𠖑
    # 0x20592: '',  # 𠖒
    0x20593: 'sī',  # 𠖓
    # 0x20594: '',  # 𠖔
    # 0x20595: '',  # 𠖕
    # 0x20596: '',  # 𠖖
    # 0x20597: '',  # 𠖗
    # 0x20598: '',  # 𠖘
    # 0x20599: '',  # 𠖙
    # 0x2059A: '',  # 𠖚
    0x2059B: 'lòu',  # 𠖛
    # 0x2059C: '',  # 𠖜
    # 0x2059D: '',  # 𠖝
    # 0x2059E: '',  # 𠖞
    0x2059F: 'yīn',  # 𠖟
    # 0x205A0: '',  # 𠖠
    # 0x205A1: '',  # 𠖡
    # 0x205A2: '',  # 𠖢
    # 0x205A3: '',  # 𠖣
    # 0x205A4: '',  # 𠖤
    0x205A5: 'chǒng',  # 𠖥
    # 0x205A6: '',  # 𠖦
    # 0x205A7: '',  # 𠖧
    # 0x205A8: '',  # 𠖨
    # 0x205A9: '',  # 𠖩
    # 0x205AA: '',  # 𠖪
    0x205AB: 'gǎn',  # 𠖫
    0x205AC: 'jiū',  # 𠖬
    # 0x205AD: '',  # 𠖭
    # 0x205AE: '',  # 𠖮
    # 0x205AF: '',  # 𠖯
    # 0x205B0: '',  # 𠖰
    # 0x205B1: '',  # 𠖱
    # 0x205B2: '',  # 𠖲
    # 0x205B3: '',  # 𠖳
    # 0x205B4: '',  # 𠖴
    # 0x205B5: '',  # 𠖵
    0x205B6: 'qìn',  # 𠖶
    0x205B7: 'jiǒng',  # 𠖷
    # 0x205B8: '',  # 𠖸
    0x205B9: 'xié,xiá',  # 𠖹
    # 0x205BA: '',  # 𠖺
    # 0x205BB: '',  # 𠖻
    # 0x205BC: '',  # 𠖼
    # 0x205BD: '',  # 𠖽
    # 0x205BE: '',  # 𠖾
    # 0x205BF: '',  # 𠖿
    # 0x205C0: '',  # 𠗀
    # 0x205C1: '',  # 𠗁
    0x205C2: 'hè',  # 𠗂
    # 0x205C3: '',  # 𠗃
    # 0x205C4: '',  # 𠗄
    # 0x205C5: '',  # 𠗅
    0x205C6: 'tāo',  # 𠗆
    # 0x205C7: '',  # 𠗇
    0x205C8: 'qiú',  # 𠗈
    0x205C9: 'xié',  # 𠗉
    0x205CA: 'jìng',  # 𠗊
    0x205CB: 'niǎn',  # 𠗋
    0x205CC: 'jìng',  # 𠗌
    # 0x205CD: '',  # 𠗍
    # 0x205CE: '',  # 𠗎
    0x205CF: 'jí',  # 𠗏
    # 0x205D0: '',  # 𠗐
    # 0x205D1: '',  # 𠗑
    # 0x205D2: '',  # 𠗒
    # 0x205D3: '',  # 𠗓
    # 0x205D4: '',  # 𠗔
    # 0x205D5: '',  # 𠗕
    # 0x205D6: '',  # 𠗖
    # 0x205D7: '',  # 𠗗
    0x205D8: 'tiǎn',  # 𠗘
    0x205D9: 'hán',  # 𠗙
    0x205DA: 'cuì',  # 𠗚
    0x205DB: 'dié',  # 𠗛
    # 0x205DC: '',  # 𠗜
    0x205DD: 'qǐng',  # 𠗝
    # 0x205DE: '',  # 𠗞
    # 0x205DF: '',  # 𠗟
    # 0x205E0: '',  # 𠗠
    # 0x205E1: '',  # 𠗡
    # 0x205E2: '',  # 𠗢
    # 0x205E3: '',  # 𠗣
    # 0x205E4: '',  # 𠗤
    0x205E5: 'pìng',  # 𠗥
    0x205E6: 'píng',  # 𠗦
    # 0x205E7: '',  # 𠗧
    0x205E8: 'dié',  # 𠗨
    0x205E9: 'lòu',  # 𠗩
    # 0x205EA: '',  # 𠗪
    # 0x205EB: '',  # 𠗫
    # 0x205EC: '',  # 𠗬
    # 0x205ED: '',  # 𠗭
    # 0x205EE: '',  # 𠗮
    # 0x205EF: '',  # 𠗯
    # 0x205F0: '',  # 𠗰
    # 0x205F1: '',  # 𠗱
    # 0x205F2: '',  # 𠗲
    0x205F3: 'liǎn',  # 𠗳
    0x205F4: 'hán',  # 𠗴
    0x205F5: 'pāng',  # 𠗵
    0x205F6: 'táng',  # 𠗶
    # 0x205F7: '',  # 𠗷
    # 0x205F8: '',  # 𠗸
    # 0x205F9: '',  # 𠗹
    0x205FA: 'yí',  # 𠗺
    0x205FB: 'xuán',  # 𠗻
    0x205FC: 'suò',  # 𠗼
    0x205FD: 'liú',  # 𠗽
    0x205FE: 'shuǎng',  # 𠗾
    0x205FF: 'shèn',  # 𠗿
    # 0x20600: '',  # 𠘀
    0x20601: 'bù',  # 𠘁
    0x20602: 'sōu',  # 𠘂
    # 0x20603: '',  # 𠘃
    # 0x20604: '',  # 𠘄
    0x20605: 'qín',  # 𠘅
    0x20606: 'shěn',  # 𠘆
    # 0x20607: '',  # 𠘇
    # 0x20608: '',  # 𠘈
    # 0x20609: '',  # 𠘉
    0x2060A: 'nòng',  # 𠘊
    0x2060B: 'tǐng',  # 𠘋
    0x2060C: 'jiāng',  # 𠘌
    # 0x2060D: '',  # 𠘍
    # 0x2060E: '',  # 𠘎
    # 0x2060F: '',  # 𠘏
    # 0x20610: '',  # 𠘐
    # 0x20611: '',  # 𠘑
    # 0x20612: '',  # 𠘒
    # 0x20613: '',  # 𠘓
    # 0x20614: '',  # 𠘔
    0x20615: 'xī',  # 𠘕
    0x20616: 'zhì',  # 𠘖
    # 0x20617: '',  # 𠘗
    # 0x20618: '',  # 𠘘
    # 0x20619: '',  # 𠘙
    # 0x2061A: '',  # 𠘚
    # 0x2061B: '',  # 𠘛
    # 0x2061C: '',  # 𠘜
    0x2061D: 'lài',  # 𠘝
    0x2061E: 'lì',  # 𠘞
    0x2061F: 'lì',  # 𠘟
    # 0x20620: '',  # 𠘠
    # 0x20621: '',  # 𠘡
    0x20622: 'hé',  # 𠘢
    0x20623: 'jiào',  # 𠘣
    # 0x20624: '',  # 𠘤
    0x20625: 'yán',  # 𠘥
    # 0x20626: '',  # 𠘦
    0x20627: 'shū',  # 𠘧
    # 0x20628: '',  # 𠘨
    # 0x20629: '',  # 𠘩
    0x2062A: 'shǐ',  # 𠘪
    # 0x2062B: '',  # 𠘫
    # 0x2062C: '',  # 𠘬
    # 0x2062D: '',  # 𠘭
    # 0x2062E: '',  # 𠘮
    # 0x2062F: '',  # 𠘯
    # 0x20630: '',  # 𠘰
    0x20631: 'zhěn',  # 𠘱
    # 0x20632: '',  # 𠘲
    0x20633: 'yōu',  # 𠘳
    # 0x20634: '',  # 𠘴
    # 0x20635: '',  # 𠘵
    # 0x20636: '',  # 𠘶
    # 0x20637: '',  # 𠘷
    # 0x20638: '',  # 𠘸
    # 0x20639: '',  # 𠘹
    0x2063A: 'suò',  # 𠘺
    0x2063B: 'wú',  # 𠘻
    # 0x2063C: '',  # 𠘼
    # 0x2063D: '',  # 𠘽
    # 0x2063E: '',  # 𠘾
    # 0x2063F: '',  # 𠘿
    # 0x20640: '',  # 𠙀
    0x20641: 'cháng',  # 𠙁
    0x20642: 'cóng',  # 𠙂
    # 0x20643: '',  # 𠙃
    # 0x20644: '',  # 𠙄
    # 0x20645: '',  # 𠙅
    0x20646: 'jù',  # 𠙆
    # 0x20647: '',  # 𠙇
    # 0x20648: '',  # 𠙈
    # 0x20649: '',  # 𠙉
    # 0x2064A: '',  # 𠙊
    # 0x2064B: '',  # 𠙋
    # 0x2064C: '',  # 𠙌
    # 0x2064D: '',  # 𠙍
    0x2064E: 'shū',  # 𠙎
    # 0x2064F: '',  # 𠙏
    # 0x20650: '',  # 𠙐
    # 0x20651: '',  # 𠙑
    # 0x20652: '',  # 𠙒
    # 0x20653: '',  # 𠙓
    0x20654: 'jiù',  # 𠙔
    0x20655: 'wéi',  # 𠙕
    # 0x20656: '',  # 𠙖
    # 0x20657: '',  # 𠙗
    # 0x20658: '',  # 𠙘
    # 0x20659: '',  # 𠙙
    # 0x2065A: '',  # 𠙚
    # 0x2065B: '',  # 𠙛
    # 0x2065C: '',  # 𠙜
    # 0x2065D: '',  # 𠙝
    0x2065E: 'huò',  # 𠙞
    # 0x2065F: '',  # 𠙟
    0x20660: 'shuāng,shuǎng',  # 𠙠
    # 0x20661: '',  # 𠙡
    # 0x20662: '',  # 𠙢
    # 0x20663: '',  # 𠙣
    0x20664: 'jiē',  # 𠙤
    # 0x20665: '',  # 𠙥
    # 0x20666: '',  # 𠙦
    # 0x20667: '',  # 𠙧
    # 0x20668: '',  # 𠙨
    # 0x20669: '',  # 𠙩
    # 0x2066A: '',  # 𠙪
    # 0x2066B: '',  # 𠙫
    0x2066C: 'zǎo',  # 𠙬
    # 0x2066D: '',  # 𠙭
    # 0x2066E: '',  # 𠙮
    # 0x2066F: '',  # 𠙯
    # 0x20670: '',  # 𠙰
    # 0x20671: '',  # 𠙱
    # 0x20672: '',  # 𠙲
    # 0x20673: '',  # 𠙳
    0x20674: 'qū',  # 𠙴
    # 0x20675: '',  # 𠙵
    0x20676: 'ǒu',  # 𠙶
    # 0x20677: '',  # 𠙷
    # 0x20678: '',  # 𠙸
    # 0x20679: '',  # 𠙹
    # 0x2067A: '',  # 𠙺
    # 0x2067B: '',  # 𠙻
    0x2067C: 'guǎ',  # 𠙼
    # 0x2067D: '',  # 𠙽
    # 0x2067E: '',  # 𠙾
    # 0x2067F: '',  # 𠙿
    # 0x20680: '',  # 𠚀
    # 0x20681: '',  # 𠚁
    # 0x20682: '',  # 𠚂
    0x20683: 'háo',  # 𠚃
    0x20684: 'lǐ',  # 𠚄
    0x20685: 'zhì',  # 𠚅
    0x20686: 'xiàn',  # 𠚆
    # 0x20687: '',  # 𠚇
    # 0x20688: '',  # 𠚈
    0x20689: 'bū',  # 𠚉
    0x2068A: 'chàng',  # 𠚊
    # 0x2068B: '',  # 𠚋
    # 0x2068C: '',  # 𠚌
    # 0x2068D: '',  # 𠚍
    # 0x2068E: '',  # 𠚎
    # 0x2068F: '',  # 𠚏
    # 0x20690: '',  # 𠚐
    # 0x20691: '',  # 𠚑
    # 0x20692: '',  # 𠚒
    0x20693: 'yūn',  # 𠚓
    0x20694: 'hé',  # 𠚔
    # 0x20695: '',  # 𠚕
    # 0x20696: '',  # 𠚖
    # 0x20697: '',  # 𠚗
    # 0x20698: '',  # 𠚘
    # 0x20699: '',  # 𠚙
    # 0x2069A: '',  # 𠚚
    # 0x2069B: '',  # 𠚛
    0x2069C: 'tāo',  # 𠚜
    # 0x2069D: '',  # 𠚝
    # 0x2069E: '',  # 𠚞
    # 0x2069F: '',  # 𠚟
    0x206A0: 'biāo',  # 𠚠
    0x206A1: 'tāo',  # 𠚡
    # 0x206A2: '',  # 𠚢
    0x206A3: 'dāo',  # 𠚣
    # 0x206A4: '',  # 𠚤
    0x206A5: 'diāo',  # 𠚥
    # 0x206A6: '',  # 𠚦
    0x206A7: 'èr',  # 𠚧
    0x206A8: 'jiū',  # 𠚨
    # 0x206A9: '',  # 𠚩
    # 0x206AA: '',  # 𠚪
    # 0x206AB: '',  # 𠚫
    # 0x206AC: '',  # 𠚬
    0x206AD: 'dì',  # 𠚭
    0x206AE: 'yì',  # 𠚮
    0x206AF: 'kūn',  # 𠚯
    # 0x206B0: '',  # 𠚰
    0x206B1: 'zhé',  # 𠚱
    # 0x206B2: '',  # 𠚲
    # 0x206B3: '',  # 𠚳
    0x206B4: 'zhōu',  # 𠚴
    0x206B5: 'jù',  # 𠚵
    # 0x206B6: '',  # 𠚶
    # 0x206B7: '',  # 𠚷
    # 0x206B8: '',  # 𠚸
    0x206B9: 'shàn',  # 𠚹
    0x206BA: 'shà',  # 𠚺
    0x206BB: 'diāo',  # 𠚻
    0x206BC: 'bān',  # 𠚼
    0x206BD: 'jī',  # 𠚽
    # 0x206BE: '',  # 𠚾
    # 0x206BF: '',  # 𠚿
    0x206C0: 'zhōng',  # 𠛀
    # 0x206C1: '',  # 𠛁
    # 0x206C2: '',  # 𠛂
    0x206C3: 'yí',  # 𠛃
    # 0x206C4: '',  # 𠛄
    0x206C5: 'kōu',  # 𠛅
    # 0x206C6: '',  # 𠛆
    # 0x206C7: '',  # 𠛇
    # 0x206C8: '',  # 𠛈
    # 0x206C9: '',  # 𠛉
    0x206CA: 'gē',  # 𠛊
    0x206CB: 'bā',  # 𠛋
    # 0x206CC: '',  # 𠛌
    # 0x206CD: '',  # 𠛍
    0x206CE: 'gōu',  # 𠛎
    # 0x206CF: '',  # 𠛏
    # 0x206D0: '',  # 𠛐
    0x206D1: 'xián',  # 𠛑
    0x206D2: 'guā',  # 𠛒
    0x206D3: 'liǔ',  # 𠛓
    0x206D4: 'chǐ',  # 𠛔
    0x206D5: 'guāi',  # 𠛕
    0x206D6: 'chuān',  # 𠛖
    # 0x206D7: '',  # 𠛗
    0x206D8: 'lí',  # 𠛘
    0x206D9: 'cù',  # 𠛙
    0x206DA: 'shuā',  # 𠛚
    # 0x206DB: '',  # 𠛛
    # 0x206DC: '',  # 𠛜
    # 0x206DD: '',  # 𠛝
    # 0x206DE: '',  # 𠛞
    # 0x206DF: '',  # 𠛟
    # 0x206E0: '',  # 𠛠
    0x206E1: 'bǐ',  # 𠛡
    0x206E2: 'gē',  # 𠛢
    # 0x206E3: '',  # 𠛣
    # 0x206E4: '',  # 𠛤
    0x206E5: 'bǐng',  # 𠛥
    0x206E6: 'lì',  # 𠛦
    # 0x206E7: '',  # 𠛧
    # 0x206E8: '',  # 𠛨
    0x206E9: 'jiǔ',  # 𠛩
    0x206EA: 'tiāo,diāo',  # 𠛪
    0x206EB: 'duǒ',  # 𠛫
    0x206EC: 'xíng',  # 𠛬
    0x206ED: 'yān,yuān',  # 𠛭
    0x206EE: 'quān',  # 𠛮
    # 0x206EF: '',  # 𠛯
    0x206F0: 'bié',  # 𠛰
    0x206F1: 'liè,zā',  # 𠛱
    # 0x206F2: '',  # 𠛲
    0x206F3: 'kè,hé',  # 𠛳
    # 0x206F4: '',  # 𠛴
    0x206F5: 'gēn',  # 𠛵
    0x206F6: 'zhēn',  # 𠛶
    # 0x206F7: '',  # 𠛷
    0x206F8: 'fén',  # 𠛸
    # 0x206F9: '',  # 𠛹
    # 0x206FA: '',  # 𠛺
    # 0x206FB: '',  # 𠛻
    # 0x206FC: '',  # 𠛼
    # 0x206FD: '',  # 𠛽
    # 0x206FE: '',  # 𠛾
    # 0x206FF: '',  # 𠛿
    # 0x20700: '',  # 𠜀
    0x20701: 'yí',  # 𠜁
    # 0x20702: '',  # 𠜂
    0x20703: 'jiù',  # 𠜃
    0x20704: 'xù',  # 𠜄
    0x20705: 'jiǎo',  # 𠜅
    # 0x20706: '',  # 𠜆
    # 0x20707: '',  # 𠜇
    0x20708: 'lǜ',  # 𠜈
    0x20709: 'jiǔ',  # 𠜉
    # 0x2070A: '',  # 𠜊
    0x2070B: 'chǒu',  # 𠜋
    # 0x2070C: '',  # 𠜌
    # 0x2070D: '',  # 𠜍
    0x2070E: 'xiàn',  # 𠜎
    # 0x2070F: '',  # 𠜏
    0x20710: 'kuài',  # 𠜐
    0x20711: 'duì',  # 𠜑
    # 0x20712: '',  # 𠜒
    # 0x20713: '',  # 𠜓
    # 0x20714: '',  # 𠜔
    # 0x20715: '',  # 𠜕
    0x20716: 'luō',  # 𠜖
    0x20717: 'xī,xì',  # 𠜗
    0x20718: 'qìn',  # 𠜘
    0x20719: 'bù',  # 𠜙
    # 0x2071A: '',  # 𠜚
    # 0x2071B: '',  # 𠜛
    # 0x2071C: '',  # 𠜜
    # 0x2071D: '',  # 𠜝
    # 0x2071E: '',  # 𠜞
    # 0x2071F: '',  # 𠜟
    # 0x20720: '',  # 𠜠
    # 0x20721: '',  # 𠜡
    # 0x20722: '',  # 𠜢
    # 0x20723: '',  # 𠜣
    0x20724: 'qià',  # 𠜤
    # 0x20725: '',  # 𠜥
    # 0x20726: '',  # 𠜦
    # 0x20727: '',  # 𠜧
    # 0x20728: '',  # 𠜨
    # 0x20729: '',  # 𠜩
    # 0x2072A: '',  # 𠜪
    # 0x2072B: '',  # 𠜫
    # 0x2072C: '',  # 𠜬
    # 0x2072D: '',  # 𠜭
    # 0x2072E: '',  # 𠜮
    # 0x2072F: '',  # 𠜯
    # 0x20730: '',  # 𠜰
    0x20731: 'pī',  # 𠜱
    0x20732: 'yā',  # 𠜲
    0x20733: 'bēng',  # 𠜳
    0x20734: 'guǒ',  # 𠜴
    0x20735: 'guā',  # 𠜵
    0x20736: 'nǎo',  # 𠜶
    # 0x20737: '',  # 𠜷
    # 0x20738: '',  # 𠜸
    0x20739: 'jú',  # 𠜹
    # 0x2073A: '',  # 𠜺
    # 0x2073B: '',  # 𠜻
    0x2073C: 'qiā',  # 𠜼
    # 0x2073D: '',  # 𠜽
    0x2073E: 'jué,guì',  # 𠜾
    # 0x2073F: '',  # 𠜿
    # 0x20740: '',  # 𠝀
    # 0x20741: '',  # 𠝁
    # 0x20742: '',  # 𠝂
    # 0x20743: '',  # 𠝃
    0x20744: 'lì',  # 𠝄
    # 0x20745: '',  # 𠝅
    # 0x20746: '',  # 𠝆
    # 0x20747: '',  # 𠝇
    # 0x20748: '',  # 𠝈
    # 0x20749: '',  # 𠝉
    # 0x2074A: '',  # 𠝊
    # 0x2074B: '',  # 𠝋
    # 0x2074C: '',  # 𠝌
    # 0x2074D: '',  # 𠝍
    # 0x2074E: '',  # 𠝎
    # 0x2074F: '',  # 𠝏
    0x20750: 'huā',  # 𠝐
    0x20751: 'jiāo',  # 𠝑
    # 0x20752: '',  # 𠝒
    # 0x20753: '',  # 𠝓
    # 0x20754: '',  # 𠝔
    # 0x20755: '',  # 𠝕
    # 0x20756: '',  # 𠝖
    # 0x20757: '',  # 𠝗
    0x20758: 'qià',  # 𠝘
    # 0x20759: '',  # 𠝙
    0x2075A: 'zhá,zhé',  # 𠝚
    0x2075B: 'qiā',  # 𠝛
    # 0x2075C: '',  # 𠝜
    0x2075D: 'zhé,zhá',  # 𠝝
    0x2075E: 'chā',  # 𠝞
    0x2075F: 'yǐng',  # 𠝟
    # 0x20760: '',  # 𠝠
    # 0x20761: '',  # 𠝡
    0x20762: 'yān',  # 𠝢
    # 0x20763: '',  # 𠝣
    0x20764: 'chōng',  # 𠝤
    # 0x20765: '',  # 𠝥
    # 0x20766: '',  # 𠝦
    # 0x20767: '',  # 𠝧
    0x20768: 'chǐ',  # 𠝨
    # 0x20769: '',  # 𠝩
    0x2076A: 'wān',  # 𠝪
    # 0x2076B: '',  # 𠝫
    0x2076C: 'sōu',  # 𠝬
    # 0x2076D: '',  # 𠝭
    # 0x2076E: '',  # 𠝮
    # 0x2076F: '',  # 𠝯
    # 0x20770: '',  # 𠝰
    # 0x20771: '',  # 𠝱
    0x20772: 'kǎn',  # 𠝲
    0x20773: 'yuán',  # 𠝳
    # 0x20774: '',  # 𠝴
    # 0x20775: '',  # 𠝵
    # 0x20776: '',  # 𠝶
    # 0x20777: '',  # 𠝷
    # 0x20778: '',  # 𠝸
    0x20779: 'jiè',  # 𠝹
    # 0x2077A: '',  # 𠝺
    # 0x2077B: '',  # 𠝻
    # 0x2077C: '',  # 𠝼
    0x2077D: 'chóu',  # 𠝽
    # 0x2077E: '',  # 𠝾
    0x2077F: 'suǒ',  # 𠝿
    0x20780: 'tū',  # 𠞀
    # 0x20781: '',  # 𠞁
    # 0x20782: '',  # 𠞂
    0x20783: 'zhé',  # 𠞃
    0x20784: 'tī,chǐ',  # 𠞄
    # 0x20785: '',  # 𠞅
    0x20786: 'wū',  # 𠞆
    # 0x20787: '',  # 𠞇
    0x20788: 'dā',  # 𠞈
    0x20789: 'lì',  # 𠞉
    0x2078A: 'chā,chāi,chá',  # 𠞊
    # 0x2078B: '',  # 𠞋
    # 0x2078C: '',  # 𠞌
    # 0x2078D: '',  # 𠞍
    # 0x2078E: '',  # 𠞎
    # 0x2078F: '',  # 𠞏
    # 0x20790: '',  # 𠞐
    # 0x20791: '',  # 𠞑
    # 0x20792: '',  # 𠞒
    # 0x20793: '',  # 𠞓
    # 0x20794: '',  # 𠞔
    0x20795: 'róng',  # 𠞕
    0x20796: 'gòng',  # 𠞖
    0x20797: 'què',  # 𠞗
    # 0x20798: '',  # 𠞘
    0x20799: 'lí',  # 𠞙
    # 0x2079A: '',  # 𠞚
    # 0x2079B: '',  # 𠞛
    # 0x2079C: '',  # 𠞜
    # 0x2079D: '',  # 𠞝
    0x2079E: 'tāo',  # 𠞞
    # 0x2079F: '',  # 𠞟
    # 0x207A0: '',  # 𠞠
    # 0x207A1: '',  # 𠞡
    # 0x207A2: '',  # 𠞢
    # 0x207A3: '',  # 𠞣
    0x207A4: 'lì',  # 𠞤
    # 0x207A5: '',  # 𠞥
    # 0x207A6: '',  # 𠞦
    0x207A7: 'mí',  # 𠞧
    # 0x207A8: '',  # 𠞨
    0x207A9: 'chì,shuài',  # 𠞩
    # 0x207AA: '',  # 𠞪
    # 0x207AB: '',  # 𠞫
    0x207AC: 'gùn',  # 𠞬
    0x207AD: 'lóu,lòu',  # 𠞭
    0x207AE: 'chuǎng',  # 𠞮
    0x207AF: 'suǒ',  # 𠞯
    0x207B0: 'jiǎo',  # 𠞰
    0x207B1: 'jìn',  # 𠞱
    # 0x207B2: '',  # 𠞲
    # 0x207B3: '',  # 𠞳
    # 0x207B4: '',  # 𠞴
    0x207B5: 'fá',  # 𠞵
    0x207B6: 'zhāi',  # 𠞶
    # 0x207B7: '',  # 𠞷
    # 0x207B8: '',  # 𠞸
    # 0x207B9: '',  # 𠞹
    # 0x207BA: '',  # 𠞺
    # 0x207BB: '',  # 𠞻
    # 0x207BC: '',  # 𠞼
    # 0x207BD: '',  # 𠞽
    0x207BE: 'jìn',  # 𠞾
    0x207BF: 'cuì',  # 𠞿
    # 0x207C0: '',  # 𠟀
    # 0x207C1: '',  # 𠟁
    0x207C2: 'cèng',  # 𠟂
    0x207C3: 'zǔn',  # 𠟃
    0x207C4: 'lì',  # 𠟄
    0x207C5: 'zhào,rì,zhì',  # 𠟅
    # 0x207C6: '',  # 𠟆
    # 0x207C7: '',  # 𠟇
    0x207C8: 'piē',  # 𠟈
    0x207C9: 'zhǎn,chàn',  # 𠟉
    0x207CA: 'xī',  # 𠟊
    0x207CB: 'yào',  # 𠟋
    0x207CC: 'fǔ,pǒu',  # 𠟌
    0x207CD: 'chōng',  # 𠟍
    # 0x207CE: '',  # 𠟎
    # 0x207CF: '',  # 𠟏
    # 0x207D0: '',  # 𠟐
    # 0x207D1: '',  # 𠟑
    # 0x207D2: '',  # 𠟒
    0x207D3: 'cuì',  # 𠟓
    # 0x207D4: '',  # 𠟔
    # 0x207D5: '',  # 𠟕
    # 0x207D6: '',  # 𠟖
    0x207D7: 'guā',  # 𠟗
    # 0x207D8: '',  # 𠟘
    # 0x207D9: '',  # 𠟙
    # 0x207DA: '',  # 𠟚
    # 0x207DB: '',  # 𠟛
    # 0x207DC: '',  # 𠟜
    # 0x207DD: '',  # 𠟝
    # 0x207DE: '',  # 𠟞
    0x207DF: 'fá',  # 𠟟
    # 0x207E0: '',  # 𠟠
    # 0x207E1: '',  # 𠟡
    # 0x207E2: '',  # 𠟢
    0x207E3: 'jī',  # 𠟣
    # 0x207E4: '',  # 𠟤
    # 0x207E5: '',  # 𠟥
    0x207E6: 'sè',  # 𠟦
    0x207E7: 'zhān',  # 𠟧
    0x207E8: 'lìng,líng',  # 𠟨
    0x207E9: 'sè',  # 𠟩
    0x207EA: 'yè',  # 𠟪
    # 0x207EB: '',  # 𠟫
    # 0x207EC: '',  # 𠟬
    # 0x207ED: '',  # 𠟭
    # 0x207EE: '',  # 𠟮
    # 0x207EF: '',  # 𠟯
    0x207F0: 'jū',  # 𠟰
    # 0x207F1: '',  # 𠟱
    # 0x207F2: '',  # 𠟲
    # 0x207F3: '',  # 𠟳
    # 0x207F4: '',  # 𠟴
    # 0x207F5: '',  # 𠟵
    0x207F6: 'tū',  # 𠟶
    # 0x207F7: '',  # 𠟷
    # 0x207F8: '',  # 𠟸
    # 0x207F9: '',  # 𠟹
    0x207FA: 'rú,ruǎn',  # 𠟺
    0x207FB: 'zé,bài',  # 𠟻
    0x207FC: 'huán',  # 𠟼
    # 0x207FD: '',  # 𠟽
    # 0x207FE: '',  # 𠟾
    # 0x207FF: '',  # 𠟿
    # 0x20800: '',  # 𠠀
    0x20801: 'xiǎn',  # 𠠁
    # 0x20802: '',  # 𠠂
    0x20803: 'qiān',  # 𠠃
    0x20804: 'zhào',  # 𠠄
    # 0x20805: '',  # 𠠅
    # 0x20806: '',  # 𠠆
    # 0x20807: '',  # 𠠇
    # 0x20808: '',  # 𠠈
    # 0x20809: '',  # 𠠉
    # 0x2080A: '',  # 𠠊
    0x2080B: 'cán',  # 𠠋
    # 0x2080C: '',  # 𠠌
    0x2080D: 'lí',  # 𠠍
    0x2080E: 'kuò',  # 𠠎
    0x2080F: 'lì',  # 𠠏
    0x20810: 'róu',  # 𠠐
    # 0x20811: '',  # 𠠑
    # 0x20812: '',  # 𠠒
    # 0x20813: '',  # 𠠓
    0x20814: 'dú',  # 𠠔
    # 0x20815: '',  # 𠠕
    # 0x20816: '',  # 𠠖
    0x20817: 'liè',  # 𠠗
    # 0x20818: '',  # 𠠘
    # 0x20819: '',  # 𠠙
    # 0x2081A: '',  # 𠠚
    # 0x2081B: '',  # 𠠛
    0x2081C: 'yīng',  # 𠠜
    0x2081D: 'lì',  # 𠠝
    # 0x2081E: '',  # 𠠞
    # 0x2081F: '',  # 𠠟
    0x20820: 'dú',  # 𠠠
    # 0x20821: '',  # 𠠡
    0x20822: 'líng',  # 𠠢
    # 0x20823: '',  # 𠠣
    # 0x20824: '',  # 𠠤
    # 0x20825: '',  # 𠠥
    # 0x20826: '',  # 𠠦
    # 0x20827: '',  # 𠠧
    # 0x20828: '',  # 𠠨
    # 0x20829: '',  # 𠠩
    0x2082A: 'wān',  # 𠠪
    # 0x2082B: '',  # 𠠫
    # 0x2082C: '',  # 𠠬
    # 0x2082D: '',  # 𠠭
    # 0x2082E: '',  # 𠠮
    0x2082F: 'dié',  # 𠠯
    # 0x20830: '',  # 𠠰
    # 0x20831: '',  # 𠠱
    # 0x20832: '',  # 𠠲
    0x20833: 'jiū',  # 𠠳
    # 0x20834: '',  # 𠠴
    0x20835: 'lì',  # 𠠵
    0x20836: 'kū',  # 𠠶
    0x20837: 'kēng',  # 𠠷
    # 0x20838: '',  # 𠠸
    0x20839: 'zhěn',  # 𠠹
    # 0x2083A: '',  # 𠠺
    # 0x2083B: '',  # 𠠻
    # 0x2083C: '',  # 𠠼
    # 0x2083D: '',  # 𠠽
    # 0x2083E: '',  # 𠠾
    # 0x2083F: '',  # 𠠿
    0x20840: 'hè',  # 𠡀
    # 0x20841: '',  # 𠡁
    0x20842: 'bì,fú',  # 𠡂
    # 0x20843: '',  # 𠡃
    0x20844: 'pī',  # 𠡄
    # 0x20845: '',  # 𠡅
    # 0x20846: '',  # 𠡆
    # 0x20847: '',  # 𠡇
    # 0x20848: '',  # 𠡈
    # 0x20849: '',  # 𠡉
    0x2084A: 'hāng',  # 𠡊
    # 0x2084B: '',  # 𠡋
    # 0x2084C: '',  # 𠡌
    # 0x2084D: '',  # 𠡍
    # 0x2084E: '',  # 𠡎
    # 0x2084F: '',  # 𠡏
    # 0x20850: '',  # 𠡐
    0x20851: 'zhuó',  # 𠡑
    0x20852: 'duǐ',  # 𠡒
    # 0x20853: '',  # 𠡓
    0x20854: 'yì',  # 𠡔
    # 0x20855: '',  # 𠡕
    # 0x20856: '',  # 𠡖
    # 0x20857: '',  # 𠡗
    # 0x20858: '',  # 𠡘
    # 0x20859: '',  # 𠡙
    # 0x2085A: '',  # 𠡚
    # 0x2085B: '',  # 𠡛
    0x2085C: 'kè',  # 𠡜
    0x2085D: 'yì',  # 𠡝
    0x2085E: 'mò',  # 𠡞
    # 0x2085F: '',  # 𠡟
    0x20860: 'chì',  # 𠡠
    0x20861: 'cán',  # 𠡡
    # 0x20862: '',  # 𠡢
    0x20863: 'gěng',  # 𠡣
    0x20864: 'kè',  # 𠡤
    0x20865: 'shì',  # 𠡥
    # 0x20866: '',  # 𠡦
    # 0x20867: '',  # 𠡧
    # 0x20868: '',  # 𠡨
    # 0x20869: '',  # 𠡩
    # 0x2086A: '',  # 𠡪
    # 0x2086B: '',  # 𠡫
    # 0x2086C: '',  # 𠡬
    0x2086D: 'líng,lìng',  # 𠡭
    0x2086E: 'bēng,kēng',  # 𠡮
    # 0x2086F: '',  # 𠡯
    # 0x20870: '',  # 𠡰
    0x20871: 'duàn',  # 𠡱
    # 0x20872: '',  # 𠡲
    # 0x20873: '',  # 𠡳
    # 0x20874: '',  # 𠡴
    # 0x20875: '',  # 𠡵
    0x20876: 'juān',  # 𠡶
    0x20877: 'nǎo',  # 𠡷
    0x20878: 'zǐ',  # 𠡸
    # 0x20879: '',  # 𠡹
    # 0x2087A: '',  # 𠡺
    0x2087B: 'zòng',  # 𠡻
    # 0x2087C: '',  # 𠡼
    # 0x2087D: '',  # 𠡽
    # 0x2087E: '',  # 𠡾
    # 0x2087F: '',  # 𠡿
    # 0x20880: '',  # 𠢀
    # 0x20881: '',  # 𠢁
    # 0x20882: '',  # 𠢂
    0x20883: 'táng',  # 𠢃
    # 0x20884: '',  # 𠢄
    # 0x20885: '',  # 𠢅
    0x20886: 'xiá',  # 𠢆
    0x20887: 'hàn',  # 𠢇
    # 0x20888: '',  # 𠢈
    # 0x20889: '',  # 𠢉
    # 0x2088A: '',  # 𠢊
    # 0x2088B: '',  # 𠢋
    0x2088C: 'lüè',  # 𠢌
    0x2088D: 'qián',  # 𠢍
    # 0x2088E: '',  # 𠢎
    # 0x2088F: '',  # 𠢏
    # 0x20890: '',  # 𠢐
    # 0x20891: '',  # 𠢑
    # 0x20892: '',  # 𠢒
    0x20893: 'mò',  # 𠢓
    0x20894: 'ōu',  # 𠢔
    0x20895: 'háo',  # 𠢕
    # 0x20896: '',  # 𠢖
    # 0x20897: '',  # 𠢗
    # 0x20898: '',  # 𠢘
    0x20899: 'zhá',  # 𠢙
    0x2089A: 'juàn',  # 𠢚
    0x2089B: 'cóng',  # 𠢛
    # 0x2089C: '',  # 𠢜
    # 0x2089D: '',  # 𠢝
    # 0x2089E: '',  # 𠢞
    # 0x2089F: '',  # 𠢟
    0x208A0: 'lì,jí',  # 𠢠
    0x208A1: 'zhá',  # 𠢡
    0x208A2: 'yǒu',  # 𠢢
    0x208A3: 'diàn',  # 𠢣
    0x208A4: 'jué',  # 𠢤
    0x208A5: 'bèi',  # 𠢥
    # 0x208A6: '',  # 𠢦
    # 0x208A7: '',  # 𠢧
    # 0x208A8: '',  # 𠢨
    0x208A9: 'yǎo',  # 𠢩
    0x208AA: 'piē',  # 𠢪
    # 0x208AB: '',  # 𠢫
    # 0x208AC: '',  # 𠢬
    # 0x208AD: '',  # 𠢭
    # 0x208AE: '',  # 𠢮
    # 0x208AF: '',  # 𠢯
    # 0x208B0: '',  # 𠢰
    0x208B1: 'jìn',  # 𠢱
    0x208B2: 'kǎi,xiè',  # 𠢲
    0x208B3: 'sè',  # 𠢳
    0x208B4: 'yǎng',  # 𠢴
    0x208B5: 'jìn',  # 𠢵
    # 0x208B6: '',  # 𠢶
    # 0x208B7: '',  # 𠢷
    # 0x208B8: '',  # 𠢸
    0x208B9: 'kè',  # 𠢹
    # 0x208BA: '',  # 𠢺
    # 0x208BB: '',  # 𠢻
    # 0x208BC: '',  # 𠢼
    # 0x208BD: '',  # 𠢽
    # 0x208BE: '',  # 𠢾
    # 0x208BF: '',  # 𠢿
    # 0x208C0: '',  # 𠣀
    # 0x208C1: '',  # 𠣁
    # 0x208C2: '',  # 𠣂
    # 0x208C3: '',  # 𠣃
    0x208C4: 'chān',  # 𠣄
    # 0x208C5: '',  # 𠣅
    # 0x208C6: '',  # 𠣆
    0x208C7: 'niǎn',  # 𠣇
    # 0x208C8: '',  # 𠣈
    0x208C9: 'wàn',  # 𠣉
    0x208CA: 'lǜ',  # 𠣊
    # 0x208CB: '',  # 𠣋
    # 0x208CC: '',  # 𠣌
    # 0x208CD: '',  # 𠣍
    # 0x208CE: '',  # 𠣎
    # 0x208CF: '',  # 𠣏
    0x208D0: 'yún',  # 𠣐
    0x208D1: 'yāo',  # 𠣑
    0x208D2: 'bāo',  # 𠣒
    # 0x208D3: '',  # 𠣓
    # 0x208D4: '',  # 𠣔
    0x208D5: 'jūn',  # 𠣕
    0x208D6: 'xuán',  # 𠣖
    # 0x208D7: '',  # 𠣗
    0x208D8: 'zhōu',  # 𠣘
    # 0x208D9: '',  # 𠣙
    # 0x208DA: '',  # 𠣚
    # 0x208DB: '',  # 𠣛
    # 0x208DC: '',  # 𠣜
    # 0x208DD: '',  # 𠣝
    # 0x208DE: '',  # 𠣞
    # 0x208DF: '',  # 𠣟
    0x208E0: 'kuì',  # 𠣠
    0x208E1: 'fèng',  # 𠣡
    # 0x208E2: '',  # 𠣢
    # 0x208E3: '',  # 𠣣
    # 0x208E4: '',  # 𠣤
    # 0x208E5: '',  # 𠣥
    # 0x208E6: '',  # 𠣦
    # 0x208E7: '',  # 𠣧
    # 0x208E8: '',  # 𠣨
    # 0x208E9: '',  # 𠣩
    0x208EA: 'qú',  # 𠣪
    0x208EB: 'shào',  # 𠣫
    0x208EC: 'sǔn',  # 𠣬
    # 0x208ED: '',  # 𠣭
    # 0x208EE: '',  # 𠣮
    # 0x208EF: '',  # 𠣯
    0x208F0: 'dū',  # 𠣰
    # 0x208F1: '',  # 𠣱
    0x208F2: 'kuǎi',  # 𠣲
    0x208F3: 'pào',  # 𠣳
    # 0x208F4: '',  # 𠣴
    # 0x208F5: '',  # 𠣵
    # 0x208F6: '',  # 𠣶
    # 0x208F7: '',  # 𠣷
    # 0x208F8: '',  # 𠣸
    # 0x208F9: '',  # 𠣹
    0x208FA: 'bào',  # 𠣺
    # 0x208FB: '',  # 𠣻
    # 0x208FC: '',  # 𠣼
    # 0x208FD: '',  # 𠣽
    0x208FE: 'fù',  # 𠣾
    0x208FF: 'jiù',  # 𠣿
    0x20900: 'rán',  # 𠤀
    # 0x20901: '',  # 𠤁
    # 0x20902: '',  # 𠤂
    # 0x20903: '',  # 𠤃
    0x20904: 'jū',  # 𠤄
    # 0x20905: '',  # 𠤅
    # 0x20906: '',  # 𠤆
    # 0x20907: '',  # 𠤇
    # 0x20908: '',  # 𠤈
    # 0x20909: '',  # 𠤉
    0x2090A: 'qióng',  # 𠤊
    # 0x2090B: '',  # 𠤋
    # 0x2090C: '',  # 𠤌
    0x2090D: 'zhōu',  # 𠤍
    0x2090E: 'huà',  # 𠤎
    0x2090F: 'bǎo',  # 𠤏
    # 0x20910: '',  # 𠤐
    # 0x20911: '',  # 𠤑
    # 0x20912: '',  # 𠤒
    # 0x20913: '',  # 𠤓
    # 0x20914: '',  # 𠤔
    0x20915: 'yí,xián',  # 𠤕
    # 0x20916: '',  # 𠤖
    0x20917: 'yí',  # 𠤗
    0x20918: 'yí,yǐ',  # 𠤘
    # 0x20919: '',  # 𠤙
    # 0x2091A: '',  # 𠤚
    # 0x2091B: '',  # 𠤛
    # 0x2091C: '',  # 𠤜
    0x2091D: 'mào',  # 𠤝
    # 0x2091E: '',  # 𠤞
    # 0x2091F: '',  # 𠤟
    # 0x20920: '',  # 𠤠
    # 0x20921: '',  # 𠤡
    # 0x20922: '',  # 𠤢
    # 0x20923: '',  # 𠤣
    # 0x20924: '',  # 𠤤
    # 0x20925: '',  # 𠤥
    0x20926: 'ruǎn,rú',  # 𠤦
    # 0x20927: '',  # 𠤧
    # 0x20928: '',  # 𠤨
    # 0x20929: '',  # 𠤩
    # 0x2092A: '',  # 𠤪
    0x2092B: 'cí',  # 𠤫
    # 0x2092C: '',  # 𠤬
    # 0x2092D: '',  # 𠤭
    0x2092E: 'hán',  # 𠤮
    # 0x2092F: '',  # 𠤯
    0x20930: 'cóng,xuán',  # 𠤰
    # 0x20931: '',  # 𠤱
    # 0x20932: '',  # 𠤲
    # 0x20933: '',  # 𠤳
    0x20934: 'xì',  # 𠤴
    # 0x20935: '',  # 𠤵
    # 0x20936: '',  # 𠤶
    # 0x20937: '',  # 𠤷
    # 0x20938: '',  # 𠤸
    0x20939: 'quán',  # 𠤹
    0x2093A: 'tiáo',  # 𠤺
    # 0x2093B: '',  # 𠤻
    0x2093C: 'diào',  # 𠤼
    # 0x2093D: '',  # 𠤽
    0x2093E: 'hán',  # 𠤾
    # 0x2093F: '',  # 𠤿
    # 0x20940: '',  # 𠥀
    # 0x20941: '',  # 𠥁
    # 0x20942: '',  # 𠥂
    # 0x20943: '',  # 𠥃
    # 0x20944: '',  # 𠥄
    # 0x20945: '',  # 𠥅
    # 0x20946: '',  # 𠥆
    0x20947: 'yě',  # 𠥇
    # 0x20948: '',  # 𠥈
    # 0x20949: '',  # 𠥉
    0x2094A: 'jī',  # 𠥊
    # 0x2094B: '',  # 𠥋
    # 0x2094C: '',  # 𠥌
    0x2094D: 'ē',  # 𠥍
    0x2094E: 'wéi',  # 𠥎
    # 0x2094F: '',  # 𠥏
    0x20950: 'cāng',  # 𠥐
    0x20951: 'diào',  # 𠥑
    # 0x20952: '',  # 𠥒
    0x20953: 'fāng',  # 𠥓
    # 0x20954: '',  # 𠥔
    0x20955: 'è',  # 𠥕
    0x20956: 'dì',  # 𠥖
    # 0x20957: '',  # 𠥗
    0x20958: 'suǎn',  # 𠥘
    0x20959: 'quán',  # 𠥙
    # 0x2095A: '',  # 𠥚
    # 0x2095B: '',  # 𠥛
    0x2095C: 'è',  # 𠥜
    0x2095D: 'ōu,ǒu',  # 𠥝
    0x2095E: 'xuán',  # 𠥞
    # 0x2095F: '',  # 𠥟
    # 0x20960: '',  # 𠥠
    # 0x20961: '',  # 𠥡
    0x20962: 'wǔ',  # 𠥢
    # 0x20963: '',  # 𠥣
    # 0x20964: '',  # 𠥤
    # 0x20965: '',  # 𠥥
    0x20966: 'yì',  # 𠥦
    0x20967: 'bēi',  # 𠥧
    0x20968: 'móu',  # 𠥨
    0x20969: 'jī',  # 𠥩
    0x2096A: 'tāo',  # 𠥪
    0x2096B: 'biān',  # 𠥫
    0x2096C: 'jiù',  # 𠥬
    # 0x2096D: '',  # 𠥭
    # 0x2096E: '',  # 𠥮
    # 0x2096F: '',  # 𠥯
    0x20970: 'hū',  # 𠥰
    # 0x20971: '',  # 𠥱
    # 0x20972: '',  # 𠥲
    # 0x20973: '',  # 𠥳
    0x20974: 'hán,gān',  # 𠥴
    # 0x20975: '',  # 𠥵
    # 0x20976: '',  # 𠥶
    # 0x20977: '',  # 𠥷
    # 0x20978: '',  # 𠥸
    # 0x20979: '',  # 𠥹
    # 0x2097A: '',  # 𠥺
    # 0x2097B: '',  # 𠥻
    # 0x2097C: '',  # 𠥼
    # 0x2097D: '',  # 𠥽
    # 0x2097E: '',  # 𠥾
    0x2097F: 'shí',  # 𠥿
    # 0x20980: '',  # 𠦀
    # 0x20981: '',  # 𠦁
    # 0x20982: '',  # 𠦂
    0x20983: 'sà',  # 𠦃
    # 0x20984: '',  # 𠦄
    # 0x20985: '',  # 𠦅
    # 0x20986: '',  # 𠦆
    # 0x20987: '',  # 𠦇
    0x20988: 'bì',  # 𠦈
    # 0x20989: '',  # 𠦉
    0x2098A: 'hán',  # 𠦊
    0x2098B: 'jìng',  # 𠦋
    # 0x2098C: '',  # 𠦌
    # 0x2098D: '',  # 𠦍
    0x2098E: 'qìn',  # 𠦎
    0x2098F: 'cuó',  # 𠦏
    0x20990: 'cì',  # 𠦐
    # 0x20991: '',  # 𠦑
    0x20992: 'bān',  # 𠦒
    # 0x20993: '',  # 𠦓
    # 0x20994: '',  # 𠦔
    # 0x20995: '',  # 𠦕
    # 0x20996: '',  # 𠦖
    0x20997: 'duī',  # 𠦗
    # 0x20998: '',  # 𠦘
    # 0x20999: '',  # 𠦙
    # 0x2099A: '',  # 𠦚
    # 0x2099B: '',  # 𠦛
    0x2099C: 'xì,shù',  # 𠦜
    # 0x2099D: '',  # 𠦝
    # 0x2099E: '',  # 𠦞
    # 0x2099F: '',  # 𠦟
    # 0x209A0: '',  # 𠦠
    0x209A1: 'xìng',  # 𠦡
    # 0x209A2: '',  # 𠦢
    # 0x209A3: '',  # 𠦣
    # 0x209A4: '',  # 𠦤
    # 0x209A5: '',  # 𠦥
    # 0x209A6: '',  # 𠦦
    0x209A7: 'zhī',  # 𠦧
    0x209A8: 'luàn',  # 𠦨
    # 0x209A9: '',  # 𠦩
    0x209AA: 'hū',  # 𠦪
    0x209AB: 'jí',  # 𠦫
    0x209AC: 'guāi',  # 𠦬
    # 0x209AD: '',  # 𠦭
    # 0x209AE: '',  # 𠦮
    # 0x209AF: '',  # 𠦯
    # 0x209B0: '',  # 𠦰
    # 0x209B1: '',  # 𠦱
    0x209B2: 'pāng',  # 𠦲
    # 0x209B3: '',  # 𠦳
    # 0x209B4: '',  # 𠦴
    # 0x209B5: '',  # 𠦵
    # 0x209B6: '',  # 𠦶
    # 0x209B7: '',  # 𠦷
    # 0x209B8: '',  # 𠦸
    # 0x209B9: '',  # 𠦹
    # 0x209BA: '',  # 𠦺
    # 0x209BB: '',  # 𠦻
    # 0x209BC: '',  # 𠦼
    # 0x209BD: '',  # 𠦽
    # 0x209BE: '',  # 𠦾
    # 0x209BF: '',  # 𠦿
    0x209C0: 'zhū',  # 𠧀
    # 0x209C1: '',  # 𠧁
    # 0x209C2: '',  # 𠧂
    # 0x209C3: '',  # 𠧃
    # 0x209C4: '',  # 𠧄
    0x209C5: 'bǐ',  # 𠧅
    # 0x209C6: '',  # 𠧆
    0x209C7: 'yú',  # 𠧇
    # 0x209C8: '',  # 𠧈
    # 0x209C9: '',  # 𠧉
    # 0x209CA: '',  # 𠧊
    # 0x209CB: '',  # 𠧋
    # 0x209CC: '',  # 𠧌
    # 0x209CD: '',  # 𠧍
    # 0x209CE: '',  # 𠧎
    # 0x209CF: '',  # 𠧏
    # 0x209D0: '',  # 𠧐
    # 0x209D1: '',  # 𠧑
    0x209D2: 'qǐ',  # 𠧒
    # 0x209D3: '',  # 𠧓
    # 0x209D4: '',  # 𠧔
    0x209D5: 'hé',  # 𠧕
    0x209D6: 'chǔ',  # 𠧖
    # 0x209D7: '',  # 𠧗
    # 0x209D8: '',  # 𠧘
    0x209D9: 'shào',  # 𠧙
    0x209DA: 'chì',  # 𠧚
    0x209DB: 'bó',  # 𠧛
    # 0x209DC: '',  # 𠧜
    # 0x209DD: '',  # 𠧝
    0x209DE: 'zhào',  # 𠧞
    0x209DF: 'réng,nǎi',  # 𠧟
    0x209E0: 'yóu',  # 𠧠
    # 0x209E1: '',  # 𠧡
    # 0x209E2: '',  # 𠧢
    # 0x209E3: '',  # 𠧣
    0x209E4: 'nǎi',  # 𠧤
    # 0x209E5: '',  # 𠧥
    # 0x209E6: '',  # 𠧦
    # 0x209E7: '',  # 𠧧
    # 0x209E8: '',  # 𠧨
    0x209E9: 'huǐ,huì',  # 𠧩
    0x209EA: 'tiáo,yǒu',  # 𠧪
    0x209EB: 'bǎn',  # 𠧫
    # 0x209EC: '',  # 𠧬
    # 0x209ED: '',  # 𠧭
    # 0x209EE: '',  # 𠧮
    # 0x209EF: '',  # 𠧯
    0x209F0: 'xū',  # 𠧰
    # 0x209F1: '',  # 𠧱
    # 0x209F2: '',  # 𠧲
    # 0x209F3: '',  # 𠧳
    0x209F4: 'yóu,yòu',  # 𠧴
    0x209F5: 'chì',  # 𠧵
    # 0x209F6: '',  # 𠧶
    # 0x209F7: '',  # 𠧷
    # 0x209F8: '',  # 𠧸
    # 0x209F9: '',  # 𠧹
    # 0x209FA: '',  # 𠧺
    # 0x209FB: '',  # 𠧻
    # 0x209FC: '',  # 𠧼
    # 0x209FD: '',  # 𠧽
    # 0x209FE: '',  # 𠧾
    0x209FF: 'héng',  # 𠧿
    # 0x20A00: '',  # 𠨀
    # 0x20A01: '',  # 𠨁
    # 0x20A02: '',  # 𠨂
    0x20A03: 'wài',  # 𠨃
    # 0x20A04: '',  # 𠨄
    # 0x20A05: '',  # 𠨅
    0x20A06: 'xiè',  # 𠨆
    # 0x20A07: '',  # 𠨇
    # 0x20A08: '',  # 𠨈
    # 0x20A09: '',  # 𠨉
    0x20A0A: 'jué',  # 𠨊
    # 0x20A0B: '',  # 𠨋
    0x20A0C: 'suī',  # 𠨌
    0x20A0D: 'qīng',  # 𠨍
    0x20A0E: 'zhuàn',  # 𠨎
    # 0x20A0F: '',  # 𠨏
    0x20A10: 'yǎng',  # 𠨐
    # 0x20A11: '',  # 𠨑
    0x20A12: 'bì',  # 𠨒
    # 0x20A13: '',  # 𠨓
    # 0x20A14: '',  # 𠨔
    0x20A15: 'jì',  # 𠨕
    # 0x20A16: '',  # 𠨖
    # 0x20A17: '',  # 𠨗
    0x20A18: 'bì',  # 𠨘
    # 0x20A19: '',  # 𠨙
    0x20A1A: 'xī',  # 𠨚
    # 0x20A1B: '',  # 𠨛
    # 0x20A1C: '',  # 𠨜
    # 0x20A1D: '',  # 𠨝
    # 0x20A1E: '',  # 𠨞
    # 0x20A1F: '',  # 𠨟
    0x20A20: 'jí',  # 𠨠
    # 0x20A21: '',  # 𠨡
    0x20A22: 'jùn',  # 𠨢
    # 0x20A23: '',  # 𠨣
    # 0x20A24: '',  # 𠨤
    0x20A25: 'liáo',  # 𠨥
    0x20A26: 'yōu',  # 𠨦
    # 0x20A27: '',  # 𠨧
    # 0x20A28: '',  # 𠨨
    # 0x20A29: '',  # 𠨩
    # 0x20A2A: '',  # 𠨪
    # 0x20A2B: '',  # 𠨫
    # 0x20A2C: '',  # 𠨬
    0x20A2D: 'jú',  # 𠨭
    # 0x20A2E: '',  # 𠨮
    # 0x20A2F: '',  # 𠨯
    # 0x20A30: '',  # 𠨰
    # 0x20A31: '',  # 𠨱
    0x20A32: 'yuè',  # 𠨲
    # 0x20A33: '',  # 𠨳
    # 0x20A34: '',  # 𠨴
    0x20A35: 'bàng',  # 𠨵
    # 0x20A36: '',  # 𠨶
    # 0x20A37: '',  # 𠨷
    0x20A38: 'pí',  # 𠨸
    # 0x20A39: '',  # 𠨹
    # 0x20A3A: '',  # 𠨺
    0x20A3B: 'zè',  # 𠨻
    # 0x20A3C: '',  # 𠨼
    # 0x20A3D: '',  # 𠨽
    0x20A3E: 'yì',  # 𠨾
    0x20A3F: 'dǐ',  # 𠨿
    0x20A40: 'jú',  # 𠩀
    # 0x20A41: '',  # 𠩁
    0x20A42: 'qiè',  # 𠩂
    # 0x20A43: '',  # 𠩃
    0x20A44: 'suǒ',  # 𠩄
    # 0x20A45: '',  # 𠩅
    0x20A46: 'cì',  # 𠩆
    # 0x20A47: '',  # 𠩇
    0x20A48: 'zhù',  # 𠩈
    0x20A49: 'yuè,jú',  # 𠩉
    # 0x20A4A: '',  # 𠩊
    # 0x20A4B: '',  # 𠩋
    # 0x20A4C: '',  # 𠩌
    # 0x20A4D: '',  # 𠩍
    # 0x20A4E: '',  # 𠩎
    0x20A4F: 'jiāo',  # 𠩏
    # 0x20A50: '',  # 𠩐
    # 0x20A51: '',  # 𠩑
    # 0x20A52: '',  # 𠩒
    # 0x20A53: '',  # 𠩓
    0x20A54: 'shí',  # 𠩔
    0x20A55: 'sī',  # 𠩕
    # 0x20A56: '',  # 𠩖
    0x20A57: 'yí',  # 𠩗
    0x20A58: 'xiá',  # 𠩘
    # 0x20A59: '',  # 𠩙
    # 0x20A5A: '',  # 𠩚
    # 0x20A5B: '',  # 𠩛
    # 0x20A5C: '',  # 𠩜
    # 0x20A5D: '',  # 𠩝
    # 0x20A5E: '',  # 𠩞
    # 0x20A5F: '',  # 𠩟
    0x20A60: 'yuán',  # 𠩠
    # 0x20A61: '',  # 𠩡
    # 0x20A62: '',  # 𠩢
    # 0x20A63: '',  # 𠩣
    # 0x20A64: '',  # 𠩤
    0x20A65: 'guó',  # 𠩥
    # 0x20A66: '',  # 𠩦
    0x20A67: 'kè',  # 𠩧
    # 0x20A68: '',  # 𠩨
    # 0x20A69: '',  # 𠩩
    0x20A6A: 'cuì',  # 𠩪
    0x20A6B: 'yì',  # 𠩫
    # 0x20A6C: '',  # 𠩬
    # 0x20A6D: '',  # 𠩭
    # 0x20A6E: '',  # 𠩮
    # 0x20A6F: '',  # 𠩯
    # 0x20A70: '',  # 𠩰
    # 0x20A71: '',  # 𠩱
    # 0x20A72: '',  # 𠩲
    # 0x20A73: '',  # 𠩳
    # 0x20A74: '',  # 𠩴
    0x20A75: 'lì',  # 𠩵
    # 0x20A76: '',  # 𠩶
    0x20A77: 'diǎn',  # 𠩷
    # 0x20A78: '',  # 𠩸
    # 0x20A79: '',  # 𠩹
    0x20A7A: 'xī,chí',  # 𠩺
    # 0x20A7B: '',  # 𠩻
    # 0x20A7C: '',  # 𠩼
    # 0x20A7D: '',  # 𠩽
    # 0x20A7E: '',  # 𠩾
    0x20A7F: 'bì',  # 𠩿
    # 0x20A80: '',  # 𠪀
    # 0x20A81: '',  # 𠪁
    0x20A82: 'biǎn',  # 𠪂
    0x20A83: 'méi',  # 𠪃
    0x20A84: 'lì',  # 𠪄
    # 0x20A85: '',  # 𠪅
    # 0x20A86: '',  # 𠪆
    0x20A87: 'sǒu',  # 𠪇
    # 0x20A88: '',  # 𠪈
    # 0x20A89: '',  # 𠪉
    # 0x20A8A: '',  # 𠪊
    # 0x20A8B: '',  # 𠪋
    # 0x20A8C: '',  # 𠪌
    # 0x20A8D: '',  # 𠪍
    # 0x20A8E: '',  # 𠪎
    # 0x20A8F: '',  # 𠪏
    0x20A90: 'liú',  # 𠪐
    0x20A91: 'guì',  # 𠪑
    0x20A92: 'kè',  # 𠪒
    # 0x20A93: '',  # 𠪓
    # 0x20A94: '',  # 𠪔
    # 0x20A95: '',  # 𠪕
    # 0x20A96: '',  # 𠪖
    0x20A97: 'yí',  # 𠪗
    0x20A98: 'yín,ǎn,kǎn',  # 𠪘
    0x20A99: 'xǐ',  # 𠪙
    0x20A9A: 'yín,ǎn,kǎn',  # 𠪚
    # 0x20A9B: '',  # 𠪛
    # 0x20A9C: '',  # 𠪜
    # 0x20A9D: '',  # 𠪝
    # 0x20A9E: '',  # 𠪞
    0x20A9F: 'kè',  # 𠪟
    # 0x20AA0: '',  # 𠪠
    # 0x20AA1: '',  # 𠪡
    0x20AA2: 'qīn',  # 𠪢
    0x20AA3: 'shè',  # 𠪣
    # 0x20AA4: '',  # 𠪤
    # 0x20AA5: '',  # 𠪥
    # 0x20AA6: '',  # 𠪦
    0x20AA7: 'wǒ',  # 𠪧
    # 0x20AA8: '',  # 𠪨
    # 0x20AA9: '',  # 𠪩
    # 0x20AAA: '',  # 𠪪
    # 0x20AAB: '',  # 𠪫
    # 0x20AAC: '',  # 𠪬
    # 0x20AAD: '',  # 𠪭
    0x20AAE: 'pì',  # 𠪮
    # 0x20AAF: '',  # 𠪯
    # 0x20AB0: '',  # 𠪰
    0x20AB1: 'lì',  # 𠪱
    0x20AB2: 'jǐn',  # 𠪲
    0x20AB3: 'hǔ',  # 𠪳
    # 0x20AB4: '',  # 𠪴
    # 0x20AB5: '',  # 𠪵
    0x20AB6: 'yuè',  # 𠪶
    0x20AB7: 'hóng',  # 𠪷
    # 0x20AB8: '',  # 𠪸
    # 0x20AB9: '',  # 𠪹
    0x20ABA: 'lì',  # 𠪺
    0x20ABB: 'fù',  # 𠪻
    # 0x20ABC: '',  # 𠪼
    # 0x20ABD: '',  # 𠪽
    # 0x20ABE: '',  # 𠪾
    # 0x20ABF: '',  # 𠪿
    # 0x20AC0: '',  # 𠫀
    # 0x20AC1: '',  # 𠫁
    # 0x20AC2: '',  # 𠫂
    0x20AC3: 'jué',  # 𠫃
    0x20AC4: 'xiān',  # 𠫄
    # 0x20AC5: '',  # 𠫅
    # 0x20AC6: '',  # 𠫆
    # 0x20AC7: '',  # 𠫇
    # 0x20AC8: '',  # 𠫈
    0x20AC9: 'diān',  # 𠫉
    # 0x20ACA: '',  # 𠫊
    # 0x20ACB: '',  # 𠫋
    0x20ACC: 'lì',  # 𠫌
    # 0x20ACD: '',  # 𠫍
    0x20ACE: 'chū',  # 𠫎
    # 0x20ACF: '',  # 𠫏
    0x20AD0: 'yuán',  # 𠫐
    # 0x20AD1: '',  # 𠫑
    0x20AD2: 'yuán',  # 𠫒
    0x20AD3: 'tū',  # 𠫓
    # 0x20AD4: '',  # 𠫔
    # 0x20AD5: '',  # 𠫕
    # 0x20AD6: '',  # 𠫖
    # 0x20AD7: '',  # 𠫗
    0x20AD8: 'jiān',  # 𠫘
    # 0x20AD9: '',  # 𠫙
    # 0x20ADA: '',  # 𠫚
    0x20ADB: 'bǎi',  # 𠫛
    0x20ADC: 'dì',  # 𠫜
    0x20ADD: 'zhǎng',  # 𠫝
    # 0x20ADE: '',  # 𠫞
    # 0x20ADF: '',  # 𠫟
    # 0x20AE0: '',  # 𠫠
    # 0x20AE1: '',  # 𠫡
    # 0x20AE2: '',  # 𠫢
    0x20AE3: 'yù',  # 𠫣
    0x20AE4: 'lìn',  # 𠫤
    # 0x20AE5: '',  # 𠫥
    # 0x20AE6: '',  # 𠫦
    # 0x20AE7: '',  # 𠫧
    0x20AE8: 'duì',  # 𠫨
    # 0x20AE9: '',  # 𠫩
    # 0x20AEA: '',  # 𠫪
    # 0x20AEB: '',  # 𠫫
    # 0x20AEC: '',  # 𠫬
    0x20AED: 'cān',  # 𠫭
    0x20AEE: 'tú',  # 𠫮
    # 0x20AEF: '',  # 𠫯
    # 0x20AF0: '',  # 𠫰
    # 0x20AF1: '',  # 𠫱
    # 0x20AF2: '',  # 𠫲
    # 0x20AF3: '',  # 𠫳
    # 0x20AF4: '',  # 𠫴
    0x20AF5: 'cān',  # 𠫵
    0x20AF6: 'tān',  # 𠫶
    0x20AF7: 'jí',  # 𠫷
    0x20AF8: 'qí,zhāi',  # 𠫸
    0x20AF9: 'shàn',  # 𠫹
    0x20AFA: 'nián,shì',  # 𠫺
    # 0x20AFB: '',  # 𠫻
    # 0x20AFC: '',  # 𠫼
    # 0x20AFD: '',  # 𠫽
    # 0x20AFE: '',  # 𠫾
    # 0x20AFF: '',  # 𠫿
    # 0x20B00: '',  # 𠬀
    # 0x20B01: '',  # 𠬁
    # 0x20B02: '',  # 𠬂
    # 0x20B03: '',  # 𠬃
    # 0x20B04: '',  # 𠬄
    # 0x20B05: '',  # 𠬅
    0x20B06: 'guàn',  # 𠬆
    # 0x20B07: '',  # 𠬇
    0x20B08: 'bǐ',  # 𠬈
    # 0x20B09: '',  # 𠬉
    # 0x20B0A: '',  # 𠬊
    0x20B0B: 'xīng,nián',  # 𠬋
    # 0x20B0C: '',  # 𠬌
    # 0x20B0D: '',  # 𠬍
    # 0x20B0E: '',  # 𠬎
    # 0x20B0F: '',  # 𠬏
    # 0x20B10: '',  # 𠬐
    # 0x20B11: '',  # 𠬑
    # 0x20B12: '',  # 𠬒
    0x20B13: 'zhěn',  # 𠬓
    # 0x20B14: '',  # 𠬔
    # 0x20B15: '',  # 𠬕
    # 0x20B16: '',  # 𠬖
    # 0x20B17: '',  # 𠬗
    # 0x20B18: '',  # 𠬘
    0x20B19: 'sā',  # 𠬙
    # 0x20B1A: '',  # 𠬚
    0x20B1B: 'mò',  # 𠬛
    0x20B1C: 'pān',  # 𠬜
    0x20B1D: 'fú',  # 𠬝
    0x20B1E: 'gǒng',  # 𠬞
    # 0x20B1F: '',  # 𠬟
    # 0x20B20: '',  # 𠬠
    # 0x20B21: '',  # 𠬡
    0x20B22: 'tāo',  # 𠬢
    0x20B23: 'bàng',  # 𠬣
    # 0x20B24: '',  # 𠬤
    # 0x20B25: '',  # 𠬥
    # 0x20B26: '',  # 𠬦
    # 0x20B27: '',  # 𠬧
    # 0x20B28: '',  # 𠬨
    # 0x20B29: '',  # 𠬩
    0x20B2A: 'biào',  # 𠬪
    # 0x20B2B: '',  # 𠬫
    0x20B2C: 'xī',  # 𠬬
    # 0x20B2D: '',  # 𠬭
    0x20B2E: 'jié',  # 𠬮
    # 0x20B2F: '',  # 𠬯
    # 0x20B30: '',  # 𠬰
    # 0x20B31: '',  # 𠬱
    # 0x20B32: '',  # 𠬲
    # 0x20B33: '',  # 𠬳
    # 0x20B34: '',  # 𠬴
    # 0x20B35: '',  # 𠬵
    0x20B36: 'jìn',  # 𠬶
    # 0x20B37: '',  # 𠬷
    0x20B38: 'mò',  # 𠬸
    # 0x20B39: '',  # 𠬹
    # 0x20B3A: '',  # 𠬺
    # 0x20B3B: '',  # 𠬻
    # 0x20B3C: '',  # 𠬼
    # 0x20B3D: '',  # 𠬽
    0x20B3E: 'qiān',  # 𠬾
    # 0x20B3F: '',  # 𠬿
    # 0x20B40: '',  # 𠭀
    # 0x20B41: '',  # 𠭁
    # 0x20B42: '',  # 𠭂
    # 0x20B43: '',  # 𠭃
    # 0x20B44: '',  # 𠭄
    # 0x20B45: '',  # 𠭅
    # 0x20B46: '',  # 𠭆
    # 0x20B47: '',  # 𠭇
    0x20B48: 'sì',  # 𠭈
    0x20B49: 'jǐng',  # 𠭉
    # 0x20B4A: '',  # 𠭊
    0x20B4B: 'chǐ',  # 𠭋
    # 0x20B4C: '',  # 𠭌
    # 0x20B4D: '',  # 𠭍
    # 0x20B4E: '',  # 𠭎
    # 0x20B4F: '',  # 𠭏
    # 0x20B50: '',  # 𠭐
    # 0x20B51: '',  # 𠭑
    # 0x20B52: '',  # 𠭒
    # 0x20B53: '',  # 𠭓
    # 0x20B54: '',  # 𠭔
    # 0x20B55: '',  # 𠭕
    0x20B56: 'gǎn',  # 𠭖
    0x20B57: 'jǐng',  # 𠭗
    0x20B58: 'jǐng',  # 𠭘
    0x20B59: 'shēn',  # 𠭙
    # 0x20B5A: '',  # 𠭚
    # 0x20B5B: '',  # 𠭛
    # 0x20B5C: '',  # 𠭜
    # 0x20B5D: '',  # 𠭝
    # 0x20B5E: '',  # 𠭞
    # 0x20B5F: '',  # 𠭟
    # 0x20B60: '',  # 𠭠
    # 0x20B61: '',  # 𠭡
    # 0x20B62: '',  # 𠭢
    # 0x20B63: '',  # 𠭣
    # 0x20B64: '',  # 𠭤
    0x20B65: 'suì',  # 𠭥
    # 0x20B66: '',  # 𠭦
    # 0x20B67: '',  # 𠭧
    # 0x20B68: '',  # 𠭨
    # 0x20B69: '',  # 𠭩
    # 0x20B6A: '',  # 𠭪
    # 0x20B6B: '',  # 𠭫
    # 0x20B6C: '',  # 𠭬
    # 0x20B6D: '',  # 𠭭
    # 0x20B6E: '',  # 𠭮
    0x20B6F: 'zhā',  # 𠭯
    0x20B70: 'lí',  # 𠭰
    # 0x20B71: '',  # 𠭱
    # 0x20B72: '',  # 𠭲
    # 0x20B73: '',  # 𠭳
    0x20B74: 'zhuō',  # 𠭴
    # 0x20B75: '',  # 𠭵
    # 0x20B76: '',  # 𠭶
    # 0x20B77: '',  # 𠭷
    # 0x20B78: '',  # 𠭸
    0x20B79: 'biàn',  # 𠭹
    # 0x20B7A: '',  # 𠭺
    # 0x20B7B: '',  # 𠭻
    # 0x20B7C: '',  # 𠭼
    # 0x20B7D: '',  # 𠭽
    # 0x20B7E: '',  # 𠭾
    0x20B7F: 'tún',  # 𠭿
    # 0x20B80: '',  # 𠮀
    # 0x20B81: '',  # 𠮁
    # 0x20B82: '',  # 𠮂
    0x20B83: 'bì',  # 𠮃
    # 0x20B84: '',  # 𠮄
    # 0x20B85: '',  # 𠮅
    0x20B86: 'fèi',  # 𠮆
    # 0x20B87: '',  # 𠮇
    # 0x20B88: '',  # 𠮈
    # 0x20B89: '',  # 𠮉
    0x20B8A: 'dé',  # 𠮊
    # 0x20B8B: '',  # 𠮋
    0x20B8C: 'zhú',  # 𠮌
    # 0x20B8D: '',  # 𠮍
    # 0x20B8E: '',  # 𠮎
    # 0x20B8F: '',  # 𠮏
    # 0x20B90: '',  # 𠮐
    0x20B91: 'jū',  # 𠮑
    # 0x20B92: '',  # 𠮒
    # 0x20B93: '',  # 𠮓
    # 0x20B94: '',  # 𠮔
    # 0x20B95: '',  # 𠮕
    # 0x20B96: '',  # 𠮖
    # 0x20B97: '',  # 𠮗
    # 0x20B98: '',  # 𠮘
    0x20B99: 'yǐ',  # 𠮙
    # 0x20B9A: '',  # 𠮚
    # 0x20B9B: '',  # 𠮛
    0x20B9C: 'yà,yīn',  # 𠮜
    # 0x20B9D: '',  # 𠮝
    # 0x20B9E: '',  # 𠮞
    0x20B9F: 'chì',  # 𠮟
    0x20BA0: 'guǎ,bǎi',  # 𠮠
    0x20BA1: 'zhǐ',  # 𠮡
    # 0x20BA2: '',  # 𠮢
    # 0x20BA3: '',  # 𠮣
    # 0x20BA4: '',  # 𠮤
    # 0x20BA5: '',  # 𠮥
    0x20BA6: 'zhào',  # 𠮦
    # 0x20BA7: '',  # 𠮧
    0x20BA8: 'réng',  # 𠮨
    # 0x20BA9: '',  # 𠮩
    # 0x20BAA: '',  # 𠮪
    0x20BAB: 'yōu',  # 𠮫
    # 0x20BAC: '',  # 𠮬
    0x20BAD: 'bó',  # 𠮭
    # 0x20BAE: '',  # 𠮮
    0x20BAF: 'jǐ',  # 𠮯
    0x20BB0: 'pǐn',  # 𠮰
    0x20BB1: 'xū',  # 𠮱
    # 0x20BB2: '',  # 𠮲
    0x20BB3: 'yīng',  # 𠮳
    0x20BB4: 'yāng',  # 𠮴
    0x20BB5: 'màng',  # 𠮵
    0x20BB6: 'gǎ,gě',  # 𠮶
    0x20BB7: 'jí',  # 𠮷
    # 0x20BB8: '',  # 𠮸
    0x20BB9: 'cái',  # 𠮹
    # 0x20BBA: '',  # 𠮺
    # 0x20BBB: '',  # 𠮻
    # 0x20BBC: '',  # 𠮼
    0x20BBD: 'lòng',  # 𠮽
    0x20BBE: 'ǹ',  # 𠮾
    0x20BBF: 'sa,san',  # 𠮿
    0x20BC0: 'chuān',  # 𠯀
    0x20BC1: 'zú',  # 𠯁
    0x20BC2: 'cí',  # 𠯂
    0x20BC3: 'wǔ',  # 𠯃
    0x20BC4: 'rèn',  # 𠯄
    # 0x20BC5: '',  # 𠯅
    # 0x20BC6: '',  # 𠯆
    # 0x20BC7: '',  # 𠯇
    0x20BC8: 'dài',  # 𠯈
    0x20BC9: 'jí',  # 𠯉
    # 0x20BCA: '',  # 𠯊
    0x20BCB: 'yǐ',  # 𠯋
    # 0x20BCC: '',  # 𠯌
    0x20BCD: 'rán',  # 𠯍
    # 0x20BCE: '',  # 𠯎
    # 0x20BCF: '',  # 𠯏
    0x20BD0: 'huò',  # 𠯐
    0x20BD1: 'guā',  # 𠯑
    # 0x20BD2: '',  # 𠯒
    0x20BD3: 'zhé',  # 𠯓
    0x20BD4: 'pì',  # 𠯔
    # 0x20BD5: '',  # 𠯕
    # 0x20BD6: '',  # 𠯖
    0x20BD7: 'zā',  # 𠯗
    0x20BD8: 'bàn',  # 𠯘
    0x20BD9: 'jié',  # 𠯙
    # 0x20BDA: '',  # 𠯚
    # 0x20BDB: '',  # 𠯛
    0x20BDC: 'hōu,xǔ',  # 𠯜
    # 0x20BDD: '',  # 𠯝
    # 0x20BDE: '',  # 𠯞
    0x20BDF: 'xiàn',  # 𠯟
    0x20BE0: 'huī',  # 𠯠
    # 0x20BE1: '',  # 𠯡
    # 0x20BE2: '',  # 𠯢
    0x20BE3: 'zú',  # 𠯣
    # 0x20BE4: '',  # 𠯤
    # 0x20BE5: '',  # 𠯥
    # 0x20BE6: '',  # 𠯦
    # 0x20BE7: '',  # 𠯧
    # 0x20BE8: '',  # 𠯨
    0x20BE9: 'zhā',  # 𠯩
    0x20BEA: 'dāi,dǎi,è',  # 𠯪
    0x20BEB: 'gē',  # 𠯫
    # 0x20BEC: '',  # 𠯬
    0x20BED: 'pì',  # 𠯭
    # 0x20BEE: '',  # 𠯮
    0x20BEF: 'piàn',  # 𠯯
    0x20BF0: 'shí',  # 𠯰
    0x20BF1: 'liǎng',  # 𠯱
    0x20BF2: 'yuè',  # 𠯲
    0x20BF3: 'hù,wěn',  # 𠯳
    0x20BF4: 'biàn',  # 𠯴
    # 0x20BF5: '',  # 𠯵
    # 0x20BF6: '',  # 𠯶
    0x20BF7: 'réng',  # 𠯷
    0x20BF8: 'tīng',  # 𠯸
    0x20BF9: 'réng',  # 𠯹
    # 0x20BFA: '',  # 𠯺
    # 0x20BFB: '',  # 𠯻
    # 0x20BFC: '',  # 𠯼
    # 0x20BFD: '',  # 𠯽
    # 0x20BFE: '',  # 𠯾
    0x20BFF: 'lù,liū',  # 𠯿
    # 0x20C00: '',  # 𠰀
    # 0x20C01: '',  # 𠰁
    # 0x20C02: '',  # 𠰂
    # 0x20C03: '',  # 𠰃
    0x20C04: 'yī',  # 𠰄
    0x20C05: 'zhī',  # 𠰅
    # 0x20C06: '',  # 𠰆
    0x20C07: 'jīn',  # 𠰇
    0x20C08: 'wēng',  # 𠰈
    0x20C09: 'chāo',  # 𠰉
    # 0x20C0A: '',  # 𠰊
    0x20C0B: 'qiū',  # 𠰋
    # 0x20C0C: '',  # 𠰌
    0x20C0D: 'zhǔ,zhù',  # 𠰍
    # 0x20C0E: '',  # 𠰎
    0x20C0F: 'zhá',  # 𠰏
    0x20C10: 'pǒ',  # 𠰐
    0x20C11: 'àn',  # 𠰑
    # 0x20C12: '',  # 𠰒
    0x20C13: 'hé',  # 𠰓
    # 0x20C14: '',  # 𠰔
    0x20C15: 'chū',  # 𠰕
    0x20C16: 'yán',  # 𠰖
    # 0x20C17: '',  # 𠰗
    # 0x20C18: '',  # 𠰘
    # 0x20C19: '',  # 𠰙
    0x20C1A: 'shì',  # 𠰚
    0x20C1B: 'hù,gào',  # 𠰛
    0x20C1C: 'è',  # 𠰜
    # 0x20C1D: '',  # 𠰝
    # 0x20C1E: '',  # 𠰞
    # 0x20C1F: '',  # 𠰟
    # 0x20C20: '',  # 𠰠
    # 0x20C21: '',  # 𠰡
    0x20C22: 'bā',  # 𠰢
    # 0x20C23: '',  # 𠰣
    # 0x20C24: '',  # 𠰤
    # 0x20C25: '',  # 𠰥
    # 0x20C26: '',  # 𠰦
    # 0x20C27: '',  # 𠰧
    # 0x20C28: '',  # 𠰨
    # 0x20C29: '',  # 𠰩
    # 0x20C2A: '',  # 𠰪
    # 0x20C2B: '',  # 𠰫
    # 0x20C2C: '',  # 𠰬
    # 0x20C2D: '',  # 𠰭
    # 0x20C2E: '',  # 𠰮
    # 0x20C2F: '',  # 𠰯
    # 0x20C30: '',  # 𠰰
    # 0x20C31: '',  # 𠰱
    # 0x20C32: '',  # 𠰲
    0x20C33: 'bǐng',  # 𠰳
    0x20C34: 'shí',  # 𠰴
    # 0x20C35: '',  # 𠰵
    # 0x20C36: '',  # 𠰶
    # 0x20C37: '',  # 𠰷
    # 0x20C38: '',  # 𠰸
    0x20C39: 'tuō',  # 𠰹
    0x20C3A: 'dài',  # 𠰺
    0x20C3B: 'wài,wai',  # 𠰻
    0x20C3C: 'pō',  # 𠰼
    0x20C3D: 'rǒng',  # 𠰽
    0x20C3E: 'jū',  # 𠰾
    # 0x20C3F: '',  # 𠰿
    0x20C40: 'bō',  # 𠱀
    # 0x20C41: '',  # 𠱁
    # 0x20C42: '',  # 𠱂
    0x20C43: 'āo',  # 𠱃
    # 0x20C44: '',  # 𠱄
    # 0x20C45: '',  # 𠱅
    # 0x20C46: '',  # 𠱆
    # 0x20C47: '',  # 𠱇
    # 0x20C48: '',  # 𠱈
    # 0x20C49: '',  # 𠱉
    # 0x20C4A: '',  # 𠱊
    # 0x20C4B: '',  # 𠱋
    # 0x20C4C: '',  # 𠱌
    # 0x20C4D: '',  # 𠱍
    # 0x20C4E: '',  # 𠱎
    # 0x20C4F: '',  # 𠱏
    0x20C50: 'yǔ',  # 𠱐
    0x20C51: 'dōu',  # 𠱑
    # 0x20C52: '',  # 𠱒
    0x20C53: 'guǐ',  # 𠱓
    0x20C54: 'shòu',  # 𠱔
    # 0x20C55: '',  # 𠱕
    # 0x20C56: '',  # 𠱖
    0x20C57: 'suō',  # 𠱗
    0x20C58: 'nì',  # 𠱘
    0x20C59: 'zhōu,yù,jì,cù',  # 𠱙
    0x20C5A: 'lòng',  # 𠱚
    0x20C5B: 'bǐng',  # 𠱛
    0x20C5C: 'zùn',  # 𠱜
    0x20C5D: 'yè',  # 𠱝
    0x20C5E: 'rǎn',  # 𠱞
    # 0x20C5F: '',  # 𠱟
    0x20C60: 'líng',  # 𠱠
    0x20C61: 'sà,shài',  # 𠱡
    # 0x20C62: '',  # 𠱢
    # 0x20C63: '',  # 𠱣
    0x20C64: 'lěi',  # 𠱤
    0x20C65: 'è,huì,zá',  # 𠱥
    # 0x20C66: '',  # 𠱦
    0x20C67: 'zhòng',  # 𠱧
    0x20C68: 'jǐ',  # 𠱨
    # 0x20C69: '',  # 𠱩
    # 0x20C6A: '',  # 𠱪
    0x20C6B: 'è',  # 𠱫
    # 0x20C6C: '',  # 𠱬
    # 0x20C6D: '',  # 𠱭
    # 0x20C6E: '',  # 𠱮
    0x20C6F: 'zuò',  # 𠱯
    # 0x20C70: '',  # 𠱰
    # 0x20C71: '',  # 𠱱
    0x20C72: 'nà',  # 𠱲
    0x20C73: 'yǔn',  # 𠱳
    # 0x20C74: '',  # 𠱴
    # 0x20C75: '',  # 𠱵
    # 0x20C76: '',  # 𠱶
    # 0x20C77: '',  # 𠱷
    # 0x20C78: '',  # 𠱸
    # 0x20C79: '',  # 𠱹
    # 0x20C7A: '',  # 𠱺
    # 0x20C7B: '',  # 𠱻
    # 0x20C7C: '',  # 𠱼
    # 0x20C7D: '',  # 𠱽
    # 0x20C7E: '',  # 𠱾
    # 0x20C7F: '',  # 𠱿
    # 0x20C80: '',  # 𠲀
    # 0x20C81: '',  # 𠲁
    # 0x20C82: '',  # 𠲂
    # 0x20C83: '',  # 𠲃
    # 0x20C84: '',  # 𠲄
    # 0x20C85: '',  # 𠲅
    # 0x20C86: '',  # 𠲆
    # 0x20C87: '',  # 𠲇
    # 0x20C88: '',  # 𠲈
    # 0x20C89: '',  # 𠲉
    0x20C8A: 'xiè',  # 𠲊
    0x20C8B: 'zuǐ',  # 𠲋
    0x20C8C: 'shù',  # 𠲌
    0x20C8D: 'diū',  # 𠲍
    0x20C8E: 'fèi,fá,wa',  # 𠲎
    0x20C8F: 'rěn',  # 𠲏
    # 0x20C90: '',  # 𠲐
    0x20C91: 'bāng',  # 𠲑
    0x20C92: 'hán',  # 𠲒
    0x20C93: 'hóng',  # 𠲓
    0x20C94: 'yī',  # 𠲔
    # 0x20C95: '',  # 𠲕
    0x20C96: 'yī',  # 𠲖
    # 0x20C97: '',  # 𠲗
    # 0x20C98: '',  # 𠲘
    0x20C99: 'kē',  # 𠲙
    0x20C9A: 'yì',  # 𠲚
    0x20C9B: 'huí',  # 𠲛
    0x20C9C: 'zhēng',  # 𠲜
    # 0x20C9D: '',  # 𠲝
    # 0x20C9E: '',  # 𠲞
    # 0x20C9F: '',  # 𠲟
    # 0x20CA0: '',  # 𠲠
    # 0x20CA1: '',  # 𠲡
    # 0x20CA2: '',  # 𠲢
    # 0x20CA3: '',  # 𠲣
    # 0x20CA4: '',  # 𠲤
    0x20CA5: 'lǐ',  # 𠲥
    # 0x20CA6: '',  # 𠲦
    # 0x20CA7: '',  # 𠲧
    # 0x20CA8: '',  # 𠲨
    # 0x20CA9: '',  # 𠲩
    # 0x20CAA: '',  # 𠲪
    # 0x20CAB: '',  # 𠲫
    # 0x20CAC: '',  # 𠲬
    # 0x20CAD: '',  # 𠲭
    0x20CAE: 'jìng',  # 𠲮
    # 0x20CAF: '',  # 𠲯
    # 0x20CB0: '',  # 𠲰
    0x20CB1: 'gé',  # 𠲱
    # 0x20CB2: '',  # 𠲲
    # 0x20CB3: '',  # 𠲳
    0x20CB4: 'nóu',  # 𠲴
    0x20CB5: 'qiè,jié',  # 𠲵
    # 0x20CB6: '',  # 𠲶
    0x20CB7: 'dié',  # 𠲷
    # 0x20CB8: '',  # 𠲸
    0x20CB9: 'jì',  # 𠲹
    0x20CBA: 'yì',  # 𠲺
    0x20CBB: 'yí',  # 𠲻
    # 0x20CBC: '',  # 𠲼
    0x20CBD: 'fú',  # 𠲽
    0x20CBE: 'shuò',  # 𠲾
    0x20CBF: 'shuò',  # 𠲿
    0x20CC0: 'yǒng',  # 𠳀
    0x20CC1: 'kěn',  # 𠳁
    0x20CC2: 'huá',  # 𠳂
    0x20CC3: 'hòng',  # 𠳃
    # 0x20CC4: '',  # 𠳄
    # 0x20CC5: '',  # 𠳅
    0x20CC6: 'zāi',  # 𠳆
    0x20CC7: 'hé',  # 𠳇
    # 0x20CC8: '',  # 𠳈
    # 0x20CC9: '',  # 𠳉
    0x20CCA: 'hē',  # 𠳊
    0x20CCB: 'qiǎn',  # 𠳋
    0x20CCC: 'qià',  # 𠳌
    # 0x20CCD: '',  # 𠳍
    0x20CCE: 'sì',  # 𠳎
    # 0x20CCF: '',  # 𠳏
    0x20CD0: 'bāng',  # 𠳐
    # 0x20CD1: '',  # 𠳑
    # 0x20CD2: '',  # 𠳒
    # 0x20CD3: '',  # 𠳓
    # 0x20CD4: '',  # 𠳔
    # 0x20CD5: '',  # 𠳕
    # 0x20CD6: '',  # 𠳖
    # 0x20CD7: '',  # 𠳗
    # 0x20CD8: '',  # 𠳘
    # 0x20CD9: '',  # 𠳙
    # 0x20CDA: '',  # 𠳚
    # 0x20CDB: '',  # 𠳛
    # 0x20CDC: '',  # 𠳜
    # 0x20CDD: '',  # 𠳝
    # 0x20CDE: '',  # 𠳞
    # 0x20CDF: '',  # 𠳟
    # 0x20CE0: '',  # 𠳠
    # 0x20CE1: '',  # 𠳡
    # 0x20CE2: '',  # 𠳢
    # 0x20CE3: '',  # 𠳣
    # 0x20CE4: '',  # 𠳤
    # 0x20CE5: '',  # 𠳥
    # 0x20CE6: '',  # 𠳦
    # 0x20CE7: '',  # 𠳧
    # 0x20CE8: '',  # 𠳨
    # 0x20CE9: '',  # 𠳩
    # 0x20CEA: '',  # 𠳪
    # 0x20CEB: '',  # 𠳫
    0x20CEC: 'jīng',  # 𠳬
    0x20CED: 'kè',  # 𠳭
    # 0x20CEE: '',  # 𠳮
    # 0x20CEF: '',  # 𠳯
    # 0x20CF0: '',  # 𠳰
    # 0x20CF1: '',  # 𠳱
    # 0x20CF2: '',  # 𠳲
    0x20CF3: 'āi',  # 𠳳
    0x20CF4: 'lóu',  # 𠳴
    # 0x20CF5: '',  # 𠳵
    0x20CF6: 'tū',  # 𠳶
    # 0x20CF7: '',  # 𠳷
    # 0x20CF8: '',  # 𠳸
    0x20CF9: 'chuáng',  # 𠳹
    # 0x20CFA: '',  # 𠳺
    # 0x20CFB: '',  # 𠳻
    0x20CFC: 'sòng',  # 𠳼
    0x20CFD: 'chéng',  # 𠳽
    0x20CFE: 'hǎn',  # 𠳾
    0x20CFF: 'wēi',  # 𠳿
    # 0x20D00: '',  # 𠴀
    # 0x20D01: '',  # 𠴁
    0x20D02: 'nǔ',  # 𠴂
    # 0x20D03: '',  # 𠴃
    0x20D04: 'jiǔ',  # 𠴄
    # 0x20D05: '',  # 𠴅
    # 0x20D06: '',  # 𠴆
    0x20D07: 'bīn',  # 𠴇
    # 0x20D08: '',  # 𠴈
    # 0x20D09: '',  # 𠴉
    # 0x20D0A: '',  # 𠴊
    # 0x20D0B: '',  # 𠴋
    # 0x20D0C: '',  # 𠴌
    # 0x20D0D: '',  # 𠴍
    # 0x20D0E: '',  # 𠴎
    # 0x20D0F: '',  # 𠴏
    # 0x20D10: '',  # 𠴐
    # 0x20D11: '',  # 𠴑
    # 0x20D12: '',  # 𠴒
    # 0x20D13: '',  # 𠴓
    # 0x20D14: '',  # 𠴔
    # 0x20D15: '',  # 𠴕
    # 0x20D16: '',  # 𠴖
    # 0x20D17: '',  # 𠴗
    # 0x20D18: '',  # 𠴘
    # 0x20D19: '',  # 𠴙
    # 0x20D1A: '',  # 𠴚
    # 0x20D1B: '',  # 𠴛
    # 0x20D1C: '',  # 𠴜
    # 0x20D1D: '',  # 𠴝
    # 0x20D1E: '',  # 𠴞
    # 0x20D1F: '',  # 𠴟
    # 0x20D20: '',  # 𠴠
    0x20D21: 'xiào',  # 𠴡
    0x20D22: 'shēng',  # 𠴢
    0x20D23: 'hǒu',  # 𠴣
    # 0x20D24: '',  # 𠴤
    # 0x20D25: '',  # 𠴥
    0x20D26: 'zhù',  # 𠴦
    # 0x20D27: '',  # 𠴧
    0x20D28: 'guān',  # 𠴨
    0x20D29: 'jī,qǐ',  # 𠴩
    # 0x20D2A: '',  # 𠴪
    0x20D2B: 'jì,cù,yù,zhù',  # 𠴫
    # 0x20D2C: '',  # 𠴬
    0x20D2D: 'xī',  # 𠴭
    # 0x20D2E: '',  # 𠴮
    0x20D2F: 'shè',  # 𠴯
    0x20D30: 'ǒu',  # 𠴰
    0x20D31: 'hú',  # 𠴱
    0x20D32: 'tà',  # 𠴲
    0x20D33: 'xiáo',  # 𠴳
    # 0x20D34: '',  # 𠴴
    0x20D35: 'zào',  # 𠴵
    # 0x20D36: '',  # 𠴶
    # 0x20D37: '',  # 𠴷
    0x20D38: 'bò',  # 𠴸
    0x20D39: 'qì',  # 𠴹
    0x20D3A: 'wā',  # 𠴺
    0x20D3B: 'tuō',  # 𠴻
    0x20D3C: 'dào',  # 𠴼
    # 0x20D3D: '',  # 𠴽
    0x20D3E: 'nà',  # 𠴾
    # 0x20D3F: '',  # 𠴿
    # 0x20D40: '',  # 𠵀
    # 0x20D41: '',  # 𠵁
    # 0x20D42: '',  # 𠵂
    # 0x20D43: '',  # 𠵃
    # 0x20D44: '',  # 𠵄
    # 0x20D45: '',  # 𠵅
    # 0x20D46: '',  # 𠵆
    # 0x20D47: '',  # 𠵇
    # 0x20D48: '',  # 𠵈
    # 0x20D49: '',  # 𠵉
    # 0x20D4A: '',  # 𠵊
    # 0x20D4B: '',  # 𠵋
    # 0x20D4C: '',  # 𠵌
    # 0x20D4D: '',  # 𠵍
    # 0x20D4E: '',  # 𠵎
    # 0x20D4F: '',  # 𠵏
    # 0x20D50: '',  # 𠵐
    # 0x20D51: '',  # 𠵑
    # 0x20D52: '',  # 𠵒
    0x20D53: 'xuán',  # 𠵓
    # 0x20D54: '',  # 𠵔
    # 0x20D55: '',  # 𠵕
    # 0x20D56: '',  # 𠵖
    # 0x20D57: '',  # 𠵗
    0x20D58: 'mèn',  # 𠵘
    # 0x20D59: '',  # 𠵙
    # 0x20D5A: '',  # 𠵚
    # 0x20D5B: '',  # 𠵛
    # 0x20D5C: '',  # 𠵜
    # 0x20D5D: '',  # 𠵝
    # 0x20D5E: '',  # 𠵞
    # 0x20D5F: '',  # 𠵟
    0x20D60: 'zhāi',  # 𠵠
    # 0x20D61: '',  # 𠵡
    # 0x20D62: '',  # 𠵢
    0x20D63: 'yà',  # 𠵣
    # 0x20D64: '',  # 𠵤
    # 0x20D65: '',  # 𠵥
    0x20D66: 'wǔ',  # 𠵦
    0x20D67: 'zhén,chún',  # 𠵧
    0x20D68: 'de',  # 𠵨
    0x20D69: 'hē',  # 𠵩
    # 0x20D6A: '',  # 𠵪
    0x20D6B: 'āng',  # 𠵫
    0x20D6C: 'pí',  # 𠵬
    0x20D6D: 'sè',  # 𠵭
    0x20D6E: 'fěn',  # 𠵮
    0x20D6F: 'guā',  # 𠵯
    # 0x20D70: '',  # 𠵰
    # 0x20D71: '',  # 𠵱
    # 0x20D72: '',  # 𠵲
    0x20D73: 'pǒ',  # 𠵳
    # 0x20D74: '',  # 𠵴
    # 0x20D75: '',  # 𠵵
    # 0x20D76: '',  # 𠵶
    0x20D77: 'xuàn',  # 𠵷
    0x20D78: 'hān,mí',  # 𠵸
    0x20D79: 'gāng',  # 𠵹
    0x20D7A: 'bā',  # 𠵺
    0x20D7B: 'zōng',  # 𠵻
    0x20D7C: 'mèng',  # 𠵼
    # 0x20D7D: '',  # 𠵽
    # 0x20D7E: '',  # 𠵾
    # 0x20D7F: '',  # 𠵿
    # 0x20D80: '',  # 𠶀
    # 0x20D81: '',  # 𠶁
    # 0x20D82: '',  # 𠶂
    # 0x20D83: '',  # 𠶃
    # 0x20D84: '',  # 𠶄
    # 0x20D85: '',  # 𠶅
    # 0x20D86: '',  # 𠶆
    # 0x20D87: '',  # 𠶇
    # 0x20D88: '',  # 𠶈
    # 0x20D89: '',  # 𠶉
    # 0x20D8A: '',  # 𠶊
    # 0x20D8B: '',  # 𠶋
    # 0x20D8C: '',  # 𠶌
    # 0x20D8D: '',  # 𠶍
    # 0x20D8E: '',  # 𠶎
    # 0x20D8F: '',  # 𠶏
    # 0x20D90: '',  # 𠶐
    # 0x20D91: '',  # 𠶑
    # 0x20D92: '',  # 𠶒
    # 0x20D93: '',  # 𠶓
    # 0x20D94: '',  # 𠶔
    # 0x20D95: '',  # 𠶕
    # 0x20D96: '',  # 𠶖
    # 0x20D97: '',  # 𠶗
    # 0x20D98: '',  # 𠶘
    # 0x20D99: '',  # 𠶙
    # 0x20D9A: '',  # 𠶚
    # 0x20D9B: '',  # 𠶛
    0x20D9C: 'zhì',  # 𠶜
    # 0x20D9D: '',  # 𠶝
    # 0x20D9E: '',  # 𠶞
    # 0x20D9F: '',  # 𠶟
    # 0x20DA0: '',  # 𠶠
    # 0x20DA1: '',  # 𠶡
    # 0x20DA2: '',  # 𠶢
    # 0x20DA3: '',  # 𠶣
    # 0x20DA4: '',  # 𠶤
    # 0x20DA5: '',  # 𠶥
    # 0x20DA6: '',  # 𠶦
    0x20DA7: 'diān',  # 𠶧
    0x20DA8: 'xī',  # 𠶨
    # 0x20DA9: '',  # 𠶩
    # 0x20DAA: '',  # 𠶪
    0x20DAB: 'dà',  # 𠶫
    0x20DAC: 'nàng',  # 𠶬
    # 0x20DAD: '',  # 𠶭
    # 0x20DAE: '',  # 𠶮
    # 0x20DAF: '',  # 𠶯
    0x20DB0: 'diāo',  # 𠶰
    0x20DB1: 'luò',  # 𠶱
    0x20DB2: 'kè',  # 𠶲
    # 0x20DB3: '',  # 𠶳
    # 0x20DB4: '',  # 𠶴
    # 0x20DB5: '',  # 𠶵
    # 0x20DB6: '',  # 𠶶
    0x20DB7: 'yì',  # 𠶷
    0x20DB8: 'jué',  # 𠶸
    0x20DB9: 'hé',  # 𠶹
    # 0x20DBA: '',  # 𠶺
    0x20DBB: 'jí',  # 𠶻
    # 0x20DBC: '',  # 𠶼
    # 0x20DBD: '',  # 𠶽
    0x20DBE: 'hè',  # 𠶾
    0x20DBF: 'niè,zá',  # 𠶿
    0x20DC0: 'rǔn',  # 𠷀
    0x20DC1: 'qián,jiān',  # 𠷁
    0x20DC2: 'dài',  # 𠷂
    0x20DC3: 'shāo,sù,shòu',  # 𠷃
    0x20DC4: 'kè',  # 𠷄
    0x20DC5: 'zhú',  # 𠷅
    # 0x20DC6: '',  # 𠷆
    0x20DC7: 'shī',  # 𠷇
    0x20DC8: 'lǜ,liè',  # 𠷈
    0x20DC9: 'jiā',  # 𠷉
    0x20DCA: 'pián',  # 𠷊
    0x20DCB: 'hòu',  # 𠷋
    0x20DCC: 'jī,zé',  # 𠷌
    0x20DCD: 'tà',  # 𠷍
    0x20DCE: 'chóu,shòu',  # 𠷎
    0x20DCF: 'wō',  # 𠷏
    0x20DD0: 'jìng,jiàng',  # 𠷐
    0x20DD1: 'pō',  # 𠷑
    0x20DD2: 'zhāi',  # 𠷒
    0x20DD3: 'xīn',  # 𠷓
    # 0x20DD4: '',  # 𠷔
    # 0x20DD5: '',  # 𠷕
    0x20DD6: 'biàn',  # 𠷖
    # 0x20DD7: '',  # 𠷗
    # 0x20DD8: '',  # 𠷘
    0x20DD9: 'xù',  # 𠷙
    # 0x20DDA: '',  # 𠷚
    # 0x20DDB: '',  # 𠷛
    # 0x20DDC: '',  # 𠷜
    # 0x20DDD: '',  # 𠷝
    0x20DDE: 'gū',  # 𠷞
    0x20DDF: 'jiè',  # 𠷟
    0x20DE0: 'qǐ',  # 𠷠
    # 0x20DE1: '',  # 𠷡
    0x20DE2: 'xián',  # 𠷢
    # 0x20DE3: '',  # 𠷣
    # 0x20DE4: '',  # 𠷤
    # 0x20DE5: '',  # 𠷥
    # 0x20DE6: '',  # 𠷦
    # 0x20DE7: '',  # 𠷧
    0x20DE8: 'biǎn',  # 𠷨
    # 0x20DE9: '',  # 𠷩
    # 0x20DEA: '',  # 𠷪
    # 0x20DEB: '',  # 𠷫
    # 0x20DEC: '',  # 𠷬
    # 0x20DED: '',  # 𠷭
    # 0x20DEE: '',  # 𠷮
    # 0x20DEF: '',  # 𠷯
    # 0x20DF0: '',  # 𠷰
    # 0x20DF1: '',  # 𠷱
    # 0x20DF2: '',  # 𠷲
    # 0x20DF3: '',  # 𠷳
    # 0x20DF4: '',  # 𠷴
    # 0x20DF5: '',  # 𠷵
    # 0x20DF6: '',  # 𠷶
    # 0x20DF7: '',  # 𠷷
    0x20DF8: 'é,yóng',  # 𠷸
    # 0x20DF9: '',  # 𠷹
    0x20DFA: 'bó',  # 𠷺
    0x20DFB: 'piāo',  # 𠷻
    # 0x20DFC: '',  # 𠷼
    # 0x20DFD: '',  # 𠷽
    # 0x20DFE: '',  # 𠷾
    0x20DFF: 'zǎ',  # 𠷿
    # 0x20E00: '',  # 𠸀
    0x20E01: 'pài',  # 𠸁
    0x20E02: 'tū',  # 𠸂
    # 0x20E03: '',  # 𠸃
    0x20E04: 'yīng',  # 𠸄
    # 0x20E05: '',  # 𠸅
    # 0x20E06: '',  # 𠸆
    # 0x20E07: '',  # 𠸇
    # 0x20E08: '',  # 𠸈
    # 0x20E09: '',  # 𠸉
    # 0x20E0A: '',  # 𠸊
    # 0x20E0B: '',  # 𠸋
    # 0x20E0C: '',  # 𠸌
    0x20E0D: 'xiào',  # 𠸍
    # 0x20E0E: '',  # 𠸎
    # 0x20E0F: '',  # 𠸏
    # 0x20E10: '',  # 𠸐
    # 0x20E11: '',  # 𠸑
    # 0x20E12: '',  # 𠸒
    # 0x20E13: '',  # 𠸓
    # 0x20E14: '',  # 𠸔
    # 0x20E15: '',  # 𠸕
    # 0x20E16: '',  # 𠸖
    # 0x20E17: '',  # 𠸗
    # 0x20E18: '',  # 𠸘
    # 0x20E19: '',  # 𠸙
    # 0x20E1A: '',  # 𠸚
    # 0x20E1B: '',  # 𠸛
    # 0x20E1C: '',  # 𠸜
    # 0x20E1D: '',  # 𠸝
    # 0x20E1E: '',  # 𠸞
    # 0x20E1F: '',  # 𠸟
    # 0x20E20: '',  # 𠸠
    # 0x20E21: '',  # 𠸡
    # 0x20E22: '',  # 𠸢
    # 0x20E23: '',  # 𠸣
    # 0x20E24: '',  # 𠸤
    # 0x20E25: '',  # 𠸥
    # 0x20E26: '',  # 𠸦
    # 0x20E27: '',  # 𠸧
    # 0x20E28: '',  # 𠸨
    # 0x20E29: '',  # 𠸩
    # 0x20E2A: '',  # 𠸪
    # 0x20E2B: '',  # 𠸫
    # 0x20E2C: '',  # 𠸬
    # 0x20E2D: '',  # 𠸭
    0x20E2E: 'xiǎng',  # 𠸮
    # 0x20E2F: '',  # 𠸯
    # 0x20E30: '',  # 𠸰
    0x20E31: 'nuò',  # 𠸱
    0x20E32: 'gē',  # 𠸲
    0x20E33: 'bó',  # 𠸳
    0x20E34: 'xiè',  # 𠸴
    # 0x20E35: '',  # 𠸵
    # 0x20E36: '',  # 𠸶
    # 0x20E37: '',  # 𠸷
    0x20E38: 'zhēn,chún',  # 𠸸
    0x20E39: 'yú',  # 𠸹
    0x20E3A: 'nì',  # 𠸺
    # 0x20E3B: '',  # 𠸻
    # 0x20E3C: '',  # 𠸼
    # 0x20E3D: '',  # 𠸽
    # 0x20E3E: '',  # 𠸾
    # 0x20E3F: '',  # 𠸿
    0x20E40: 'xùn',  # 𠹀
    0x20E41: 'wà',  # 𠹁
    # 0x20E42: '',  # 𠹂
    0x20E43: 'àng',  # 𠹃
    0x20E44: 'hàn',  # 𠹄
    0x20E45: 'hōng',  # 𠹅
    0x20E46: 'dān',  # 𠹆
    # 0x20E47: '',  # 𠹇
    0x20E48: 'nuó',  # 𠹈
    # 0x20E49: '',  # 𠹉
    0x20E4A: 'cǎo',  # 𠹊
    0x20E4B: 'jí',  # 𠹋
    0x20E4C: 'něng',  # 𠹌
    0x20E4D: 'yǒng,róng',  # 𠹍
    0x20E4E: 'xiāo',  # 𠹎
    # 0x20E4F: '',  # 𠹏
    0x20E50: 'chuǎ',  # 𠹐
    0x20E51: 'yào',  # 𠹑
    # 0x20E52: '',  # 𠹒
    0x20E53: 'gé',  # 𠹓
    0x20E54: 'táng',  # 𠹔
    0x20E55: 'bào',  # 𠹕
    0x20E56: 'chǎn',  # 𠹖
    # 0x20E57: '',  # 𠹗
    0x20E58: 'xù',  # 𠹘
    # 0x20E59: '',  # 𠹙
    # 0x20E5A: '',  # 𠹚
    0x20E5B: 'hái',  # 𠹛
    # 0x20E5C: '',  # 𠹜
    0x20E5D: 'chóu',  # 𠹝
    # 0x20E5E: '',  # 𠹞
    0x20E5F: 'jiǎn',  # 𠹟
    0x20E60: 'zuō',  # 𠹠
    # 0x20E61: '',  # 𠹡
    # 0x20E62: '',  # 𠹢
    # 0x20E63: '',  # 𠹣
    0x20E64: 'wèi',  # 𠹤
    0x20E65: 'dā',  # 𠹥
    0x20E66: 'pī',  # 𠹦
    # 0x20E67: '',  # 𠹧
    # 0x20E68: '',  # 𠹨
    # 0x20E69: '',  # 𠹩
    # 0x20E6A: '',  # 𠹪
    # 0x20E6B: '',  # 𠹫
    # 0x20E6C: '',  # 𠹬
    0x20E6D: 'gē',  # 𠹭
    # 0x20E6E: '',  # 𠹮
    # 0x20E6F: '',  # 𠹯
    # 0x20E70: '',  # 𠹰
    # 0x20E71: '',  # 𠹱
    # 0x20E72: '',  # 𠹲
    0x20E73: 'jié',  # 𠹳
    # 0x20E74: '',  # 𠹴
    # 0x20E75: '',  # 𠹵
    # 0x20E76: '',  # 𠹶
    # 0x20E77: '',  # 𠹷
    # 0x20E78: '',  # 𠹸
    # 0x20E79: '',  # 𠹹
    # 0x20E7A: '',  # 𠹺
    # 0x20E7B: '',  # 𠹻
    # 0x20E7C: '',  # 𠹼
    # 0x20E7D: '',  # 𠹽
    # 0x20E7E: '',  # 𠹾
    # 0x20E7F: '',  # 𠹿
    # 0x20E80: '',  # 𠺀
    # 0x20E81: '',  # 𠺁
    # 0x20E82: '',  # 𠺂
    # 0x20E83: '',  # 𠺃
    # 0x20E84: '',  # 𠺄
    # 0x20E85: '',  # 𠺅
    # 0x20E86: '',  # 𠺆
    # 0x20E87: '',  # 𠺇
    # 0x20E88: '',  # 𠺈
    # 0x20E89: '',  # 𠺉
    # 0x20E8A: '',  # 𠺊
    # 0x20E8B: '',  # 𠺋
    # 0x20E8C: '',  # 𠺌
    # 0x20E8D: '',  # 𠺍
    # 0x20E8E: '',  # 𠺎
    # 0x20E8F: '',  # 𠺏
    0x20E90: 'huàn',  # 𠺐
    # 0x20E91: '',  # 𠺑
    0x20E92: 'xī',  # 𠺒
    # 0x20E93: '',  # 𠺓
    0x20E94: 'pèn',  # 𠺔
    0x20E95: 'liū,liáo',  # 𠺕
    0x20E96: 'mǔ',  # 𠺖
    0x20E97: 'miē',  # 𠺗
    0x20E98: 'làng',  # 𠺘
    0x20E99: 'tuì',  # 𠺙
    0x20E9A: 'bān',  # 𠺚
    # 0x20E9B: '',  # 𠺛
    # 0x20E9C: '',  # 𠺜
    0x20E9D: 'gē',  # 𠺝
    # 0x20E9E: '',  # 𠺞
    0x20E9F: 'kù',  # 𠺟
    # 0x20EA0: '',  # 𠺠
    # 0x20EA1: '',  # 𠺡
    0x20EA2: 'jiā',  # 𠺢
    0x20EA3: 'bō',  # 𠺣
    # 0x20EA4: '',  # 𠺤
    # 0x20EA5: '',  # 𠺥
    # 0x20EA6: '',  # 𠺦
    # 0x20EA7: '',  # 𠺧
    # 0x20EA8: '',  # 𠺨
    # 0x20EA9: '',  # 𠺩
    # 0x20EAA: '',  # 𠺪
    # 0x20EAB: '',  # 𠺫
    # 0x20EAC: '',  # 𠺬
    # 0x20EAD: '',  # 𠺭
    # 0x20EAE: '',  # 𠺮
    # 0x20EAF: '',  # 𠺯
    # 0x20EB0: '',  # 𠺰
    # 0x20EB1: '',  # 𠺱
    # 0x20EB2: '',  # 𠺲
    # 0x20EB3: '',  # 𠺳
    # 0x20EB4: '',  # 𠺴
    # 0x20EB5: '',  # 𠺵
    # 0x20EB6: '',  # 𠺶
    # 0x20EB7: '',  # 𠺷
    # 0x20EB8: '',  # 𠺸
    # 0x20EB9: '',  # 𠺹
    # 0x20EBA: '',  # 𠺺
    # 0x20EBB: '',  # 𠺻
    # 0x20EBC: '',  # 𠺼
    # 0x20EBD: '',  # 𠺽
    # 0x20EBE: '',  # 𠺾
    # 0x20EBF: '',  # 𠺿
    # 0x20EC0: '',  # 𠻀
    # 0x20EC1: '',  # 𠻁
    # 0x20EC2: '',  # 𠻂
    # 0x20EC3: '',  # 𠻃
    # 0x20EC4: '',  # 𠻄
    # 0x20EC5: '',  # 𠻅
    # 0x20EC6: '',  # 𠻆
    # 0x20EC7: '',  # 𠻇
    # 0x20EC8: '',  # 𠻈
    # 0x20EC9: '',  # 𠻉
    # 0x20ECA: '',  # 𠻊
    # 0x20ECB: '',  # 𠻋
    # 0x20ECC: '',  # 𠻌
    0x20ECD: 'huàn',  # 𠻍
    # 0x20ECE: '',  # 𠻎
    0x20ECF: 'zú',  # 𠻏
    0x20ED0: 'luò',  # 𠻐
    # 0x20ED1: '',  # 𠻑
    # 0x20ED2: '',  # 𠻒
    # 0x20ED3: '',  # 𠻓
    # 0x20ED4: '',  # 𠻔
    # 0x20ED5: '',  # 𠻕
    # 0x20ED6: '',  # 𠻖
    0x20ED7: 'lí',  # 𠻗
    # 0x20ED8: '',  # 𠻘
    0x20ED9: 'hé',  # 𠻙
    0x20EDA: 'mó',  # 𠻚
    # 0x20EDB: '',  # 𠻛
    0x20EDC: 'shuì,lǜ,sū',  # 𠻜
    0x20EDD: 'shēn',  # 𠻝
    0x20EDE: 'kǎng',  # 𠻞
    0x20EDF: 'chì',  # 𠻟
    0x20EE0: 'líng',  # 𠻠
    0x20EE1: 'luǒ',  # 𠻡
    # 0x20EE2: '',  # 𠻢
    # 0x20EE3: '',  # 𠻣
    0x20EE4: 'yǎn',  # 𠻤
    0x20EE5: 'zhào',  # 𠻥
    0x20EE6: 'chuǎ',  # 𠻦
    0x20EE7: 'gǔ',  # 𠻧
    0x20EE8: 'qǐn',  # 𠻨
    # 0x20EE9: '',  # 𠻩
    0x20EEA: 'tán',  # 𠻪
    0x20EEB: 'fèn',  # 𠻫
    0x20EEC: 'tú',  # 𠻬
    # 0x20EED: '',  # 𠻭
    # 0x20EEE: '',  # 𠻮
    # 0x20EEF: '',  # 𠻯
    # 0x20EF0: '',  # 𠻰
    0x20EF1: 'líng',  # 𠻱
    # 0x20EF2: '',  # 𠻲
    0x20EF3: 'zuò',  # 𠻳
    0x20EF4: 'lǎng',  # 𠻴
    # 0x20EF5: '',  # 𠻵
    # 0x20EF6: '',  # 𠻶
    # 0x20EF7: '',  # 𠻷
    # 0x20EF8: '',  # 𠻸
    # 0x20EF9: '',  # 𠻹
    # 0x20EFA: '',  # 𠻺
    # 0x20EFB: '',  # 𠻻
    # 0x20EFC: '',  # 𠻼
    # 0x20EFD: '',  # 𠻽
    # 0x20EFE: '',  # 𠻾
    # 0x20EFF: '',  # 𠻿
    # 0x20F00: '',  # 𠼀
    # 0x20F01: '',  # 𠼁
    # 0x20F02: '',  # 𠼂
    # 0x20F03: '',  # 𠼃
    # 0x20F04: '',  # 𠼄
    # 0x20F05: '',  # 𠼅
    # 0x20F06: '',  # 𠼆
    # 0x20F07: '',  # 𠼇
    # 0x20F08: '',  # 𠼈
    # 0x20F09: '',  # 𠼉
    # 0x20F0A: '',  # 𠼊
    # 0x20F0B: '',  # 𠼋
    # 0x20F0C: '',  # 𠼌
    # 0x20F0D: '',  # 𠼍
    # 0x20F0E: '',  # 𠼎
    # 0x20F0F: '',  # 𠼏
    # 0x20F10: '',  # 𠼐
    # 0x20F11: '',  # 𠼑
    # 0x20F12: '',  # 𠼒
    # 0x20F13: '',  # 𠼓
    # 0x20F14: '',  # 𠼔
    # 0x20F15: '',  # 𠼕
    0x20F16: 'lán',  # 𠼖
    0x20F17: 'zàn',  # 𠼗
    0x20F18: 'wù',  # 𠼘
    # 0x20F19: '',  # 𠼙
    # 0x20F1A: '',  # 𠼚
    # 0x20F1B: '',  # 𠼛
    # 0x20F1C: '',  # 𠼜
    0x20F1D: 'lí',  # 𠼝
    0x20F1E: 'ā',  # 𠼞
    0x20F1F: 'lüè',  # 𠼟
    0x20F20: 'zhǐ',  # 𠼠
    0x20F21: 'chóu',  # 𠼡
    0x20F22: 'jiàng,qiàng',  # 𠼢
    # 0x20F23: '',  # 𠼣
    0x20F24: 'jiān',  # 𠼤
    # 0x20F25: '',  # 𠼥
    # 0x20F26: '',  # 𠼦
    # 0x20F27: '',  # 𠼧
    # 0x20F28: '',  # 𠼨
    0x20F29: 'lún',  # 𠼩
    0x20F2A: 'yí',  # 𠼪
    # 0x20F2B: '',  # 𠼫
    0x20F2C: 'shāng',  # 𠼬
    # 0x20F2D: '',  # 𠼭
    0x20F2E: 'ǎi',  # 𠼮
    # 0x20F2F: '',  # 𠼯
    # 0x20F30: '',  # 𠼰
    # 0x20F31: '',  # 𠼱
    # 0x20F32: '',  # 𠼲
    # 0x20F33: '',  # 𠼳
    # 0x20F34: '',  # 𠼴
    # 0x20F35: '',  # 𠼵
    # 0x20F36: '',  # 𠼶
    # 0x20F37: '',  # 𠼷
    # 0x20F38: '',  # 𠼸
    # 0x20F39: '',  # 𠼹
    # 0x20F3A: '',  # 𠼺
    0x20F3B: 'jī',  # 𠼻
    # 0x20F3C: '',  # 𠼼
    # 0x20F3D: '',  # 𠼽
    # 0x20F3E: '',  # 𠼾
    # 0x20F3F: '',  # 𠼿
    # 0x20F40: '',  # 𠽀
    # 0x20F41: '',  # 𠽁
    # 0x20F42: '',  # 𠽂
    # 0x20F43: '',  # 𠽃
    # 0x20F44: '',  # 𠽄
    # 0x20F45: '',  # 𠽅
    # 0x20F46: '',  # 𠽆
    # 0x20F47: '',  # 𠽇
    # 0x20F48: '',  # 𠽈
    # 0x20F49: '',  # 𠽉
    # 0x20F4A: '',  # 𠽊
    # 0x20F4B: '',  # 𠽋
    # 0x20F4C: '',  # 𠽌
    # 0x20F4D: '',  # 𠽍
    # 0x20F4E: '',  # 𠽎
    # 0x20F4F: '',  # 𠽏
    # 0x20F50: '',  # 𠽐
    # 0x20F51: '',  # 𠽑
    # 0x20F52: '',  # 𠽒
    # 0x20F53: '',  # 𠽓
    # 0x20F54: '',  # 𠽔
    # 0x20F55: '',  # 𠽕
    # 0x20F56: '',  # 𠽖
    # 0x20F57: '',  # 𠽗
    # 0x20F58: '',  # 𠽘
    # 0x20F59: '',  # 𠽙
    # 0x20F5A: '',  # 𠽚
    # 0x20F5B: '',  # 𠽛
    0x20F5C: 'yì',  # 𠽜
    0x20F5D: 'nín',  # 𠽝
    # 0x20F5E: '',  # 𠽞
    # 0x20F5F: '',  # 𠽟
    # 0x20F60: '',  # 𠽠
    0x20F61: 'huì',  # 𠽡
    # 0x20F62: '',  # 𠽢
    0x20F63: 'zhā',  # 𠽣
    # 0x20F64: '',  # 𠽤
    # 0x20F65: '',  # 𠽥
    0x20F66: 'hǎn',  # 𠽦
    # 0x20F67: '',  # 𠽧
    0x20F68: 'yǐn',  # 𠽨
    0x20F69: 'bì',  # 𠽩
    0x20F6A: 'ān',  # 𠽪
    0x20F6B: 'xiā,xiǎ',  # 𠽫
    0x20F6C: 'ní',  # 𠽬
    # 0x20F6D: '',  # 𠽭
    # 0x20F6E: '',  # 𠽮
    # 0x20F6F: '',  # 𠽯
    0x20F70: 'dī',  # 𠽰
    0x20F71: 'jiǎn',  # 𠽱
    0x20F72: 'pán',  # 𠽲
    # 0x20F73: '',  # 𠽳
    # 0x20F74: '',  # 𠽴
    0x20F75: 'yù',  # 𠽵
    0x20F76: 'chuài,cuì,chuò',  # 𠽶
    0x20F77: 'zā',  # 𠽷
    # 0x20F78: '',  # 𠽸
    0x20F79: 'chá',  # 𠽹
    # 0x20F7A: '',  # 𠽺
    0x20F7B: 'zhé',  # 𠽻
    0x20F7C: 'sè',  # 𠽼
    # 0x20F7D: '',  # 𠽽
    0x20F7E: 'pēn,pǔ',  # 𠽾
    0x20F7F: 'gū',  # 𠽿
    0x20F80: 'zhé',  # 𠾀
    # 0x20F81: '',  # 𠾁
    # 0x20F82: '',  # 𠾂
    # 0x20F83: '',  # 𠾃
    # 0x20F84: '',  # 𠾄
    # 0x20F85: '',  # 𠾅
    0x20F86: 'lí',  # 𠾆
    0x20F87: 'dōu',  # 𠾇
    # 0x20F88: '',  # 𠾈
    0x20F89: 'chóu',  # 𠾉
    # 0x20F8A: '',  # 𠾊
    0x20F8B: 'zuǐ',  # 𠾋
    0x20F8C: 'pò',  # 𠾌
    # 0x20F8D: '',  # 𠾍
    # 0x20F8E: '',  # 𠾎
    0x20F8F: 'shē',  # 𠾏
    0x20F90: 'lóng',  # 𠾐
    # 0x20F91: '',  # 𠾑
    # 0x20F92: '',  # 𠾒
    # 0x20F93: '',  # 𠾓
    # 0x20F94: '',  # 𠾔
    # 0x20F95: '',  # 𠾕
    # 0x20F96: '',  # 𠾖
    # 0x20F97: '',  # 𠾗
    # 0x20F98: '',  # 𠾘
    # 0x20F99: '',  # 𠾙
    # 0x20F9A: '',  # 𠾚
    # 0x20F9B: '',  # 𠾛
    # 0x20F9C: '',  # 𠾜
    # 0x20F9D: '',  # 𠾝
    # 0x20F9E: '',  # 𠾞
    # 0x20F9F: '',  # 𠾟
    # 0x20FA0: '',  # 𠾠
    # 0x20FA1: '',  # 𠾡
    0x20FA2: 'shù',  # 𠾢
    # 0x20FA3: '',  # 𠾣
    0x20FA4: 'jìn',  # 𠾤
    0x20FA5: 'líng',  # 𠾥
    # 0x20FA6: '',  # 𠾦
    # 0x20FA7: '',  # 𠾧
    0x20FA8: 'kāng',  # 𠾨
    0x20FA9: 'là',  # 𠾩
    # 0x20FAA: '',  # 𠾪
    0x20FAB: 'xū',  # 𠾫
    0x20FAC: 'jìn',  # 𠾬
    # 0x20FAD: '',  # 𠾭
    0x20FAE: 'chuān',  # 𠾮
    # 0x20FAF: '',  # 𠾯
    # 0x20FB0: '',  # 𠾰
    # 0x20FB1: '',  # 𠾱
    0x20FB2: 'yuè',  # 𠾲
    # 0x20FB3: '',  # 𠾳
    # 0x20FB4: '',  # 𠾴
    # 0x20FB5: '',  # 𠾵
    # 0x20FB6: '',  # 𠾶
    # 0x20FB7: '',  # 𠾷
    # 0x20FB8: '',  # 𠾸
    # 0x20FB9: '',  # 𠾹
    # 0x20FBA: '',  # 𠾺
    # 0x20FBB: '',  # 𠾻
    # 0x20FBC: '',  # 𠾼
    # 0x20FBD: '',  # 𠾽
    # 0x20FBE: '',  # 𠾾
    # 0x20FBF: '',  # 𠾿
    # 0x20FC0: '',  # 𠿀
    # 0x20FC1: '',  # 𠿁
    # 0x20FC2: '',  # 𠿂
    # 0x20FC3: '',  # 𠿃
    # 0x20FC4: '',  # 𠿄
    # 0x20FC5: '',  # 𠿅
    0x20FC6: 'mǎi',  # 𠿆
    0x20FC7: 'xiè',  # 𠿇
    0x20FC8: 'jiū',  # 𠿈
    0x20FC9: 'jì',  # 𠿉
    # 0x20FCA: '',  # 𠿊
    0x20FCB: 'yuè',  # 𠿋
    # 0x20FCC: '',  # 𠿌
    # 0x20FCD: '',  # 𠿍
    # 0x20FCE: '',  # 𠿎
    0x20FCF: 'jiān',  # 𠿏
    # 0x20FD0: '',  # 𠿐
    0x20FD1: 'hán,gǎn,ǎn,hǎn',  # 𠿑
    # 0x20FD2: '',  # 𠿒
    0x20FD3: 'sà',  # 𠿓
    0x20FD4: 'huì',  # 𠿔
    0x20FD5: 'qiào',  # 𠿕
    # 0x20FD6: '',  # 𠿖
    0x20FD7: 'sè',  # 𠿗
    0x20FD8: 'zuǐ',  # 𠿘
    # 0x20FD9: '',  # 𠿙
    # 0x20FDA: '',  # 𠿚
    0x20FDB: 'lǔ',  # 𠿛
    0x20FDC: 'huà',  # 𠿜
    0x20FDD: 'chū',  # 𠿝
    0x20FDE: 'shǎn',  # 𠿞
    0x20FDF: 'wò',  # 𠿟
    0x20FE0: 'jí',  # 𠿠
    0x20FE1: 'zhuó',  # 𠿡
    0x20FE2: 'xián,xiàn',  # 𠿢
    0x20FE3: 'yī',  # 𠿣
    0x20FE4: 'guó',  # 𠿤
    0x20FE5: 'kuì,guì',  # 𠿥
    # 0x20FE6: '',  # 𠿦
    # 0x20FE7: '',  # 𠿧
    # 0x20FE8: '',  # 𠿨
    # 0x20FE9: '',  # 𠿩
    # 0x20FEA: '',  # 𠿪
    # 0x20FEB: '',  # 𠿫
    # 0x20FEC: '',  # 𠿬
    # 0x20FED: '',  # 𠿭
    # 0x20FEE: '',  # 𠿮
    # 0x20FEF: '',  # 𠿯
    # 0x20FF0: '',  # 𠿰
    # 0x20FF1: '',  # 𠿱
    # 0x20FF2: '',  # 𠿲
    # 0x20FF3: '',  # 𠿳
    # 0x20FF4: '',  # 𠿴
    # 0x20FF5: '',  # 𠿵
    # 0x20FF6: '',  # 𠿶
    # 0x20FF7: '',  # 𠿷
    # 0x20FF8: '',  # 𠿸
    # 0x20FF9: '',  # 𠿹
    # 0x20FFA: '',  # 𠿺
    # 0x20FFB: '',  # 𠿻
    # 0x20FFC: '',  # 𠿼
    # 0x20FFD: '',  # 𠿽
    # 0x20FFE: '',  # 𠿾
    # 0x20FFF: '',  # 𠿿
    # 0x21000: '',  # 𡀀
    # 0x21001: '',  # 𡀁
    # 0x21002: '',  # 𡀂
    # 0x21003: '',  # 𡀃
    # 0x21004: '',  # 𡀄
    # 0x21005: '',  # 𡀅
    # 0x21006: '',  # 𡀆
    0x21007: 'dǒng',  # 𡀇
    # 0x21008: '',  # 𡀈
    # 0x21009: '',  # 𡀉
    # 0x2100A: '',  # 𡀊
    # 0x2100B: '',  # 𡀋
    # 0x2100C: '',  # 𡀌
    # 0x2100D: '',  # 𡀍
    # 0x2100E: '',  # 𡀎
    # 0x2100F: '',  # 𡀏
    # 0x21010: '',  # 𡀐
    0x21011: 'zhōu',  # 𡀑
    # 0x21012: '',  # 𡀒
    # 0x21013: '',  # 𡀓
    0x21014: 'lù,lou',  # 𡀔
    # 0x21015: '',  # 𡀕
    0x21016: 'bō',  # 𡀖
    0x21017: 'shí',  # 𡀗
    0x21018: 'yìng',  # 𡀘
    0x21019: 'kū',  # 𡀙
    # 0x2101A: '',  # 𡀚
    # 0x2101B: '',  # 𡀛
    # 0x2101C: '',  # 𡀜
    # 0x2101D: '',  # 𡀝
    # 0x2101E: '',  # 𡀞
    # 0x2101F: '',  # 𡀟
    # 0x21020: '',  # 𡀠
    # 0x21021: '',  # 𡀡
    # 0x21022: '',  # 𡀢
    # 0x21023: '',  # 𡀣
    # 0x21024: '',  # 𡀤
    # 0x21025: '',  # 𡀥
    # 0x21026: '',  # 𡀦
    # 0x21027: '',  # 𡀧
    # 0x21028: '',  # 𡀨
    # 0x21029: '',  # 𡀩
    # 0x2102A: '',  # 𡀪
    # 0x2102B: '',  # 𡀫
    # 0x2102C: '',  # 𡀬
    # 0x2102D: '',  # 𡀭
    # 0x2102E: '',  # 𡀮
    # 0x2102F: '',  # 𡀯
    # 0x21030: '',  # 𡀰
    # 0x21031: '',  # 𡀱
    # 0x21032: '',  # 𡀲
    # 0x21033: '',  # 𡀳
    # 0x21034: '',  # 𡀴
    # 0x21035: '',  # 𡀵
    # 0x21036: '',  # 𡀶
    # 0x21037: '',  # 𡀷
    # 0x21038: '',  # 𡀸
    0x21039: 'zhì',  # 𡀹
    0x2103A: 'xié',  # 𡀺
    # 0x2103B: '',  # 𡀻
    # 0x2103C: '',  # 𡀼
    0x2103D: 'yè,hè',  # 𡀽
    0x2103E: 'è',  # 𡀾
    0x2103F: 'lǜ',  # 𡀿
    0x21040: 'hàn',  # 𡁀
    0x21041: 'yè,kài',  # 𡁁
    # 0x21042: '',  # 𡁂
    # 0x21043: '',  # 𡁃
    # 0x21044: '',  # 𡁄
    # 0x21045: '',  # 𡁅
    0x21046: 'luò',  # 𡁆
    0x21047: 'chuò',  # 𡁇
    0x21048: 'fàn',  # 𡁈
    0x21049: 'zhí',  # 𡁉
    0x2104A: 'yìng',  # 𡁊
    0x2104B: 'wěn',  # 𡁋
    0x2104C: 'wā',  # 𡁌
    0x2104D: 'ài',  # 𡁍
    0x2104E: 'yú',  # 𡁎
    0x2104F: 'méng',  # 𡁏
    # 0x21050: '',  # 𡁐
    0x21051: 'huā',  # 𡁑
    # 0x21052: '',  # 𡁒
    0x21053: 'liè',  # 𡁓
    0x21054: 'jīng',  # 𡁔
    0x21055: 'zá',  # 𡁕
    # 0x21056: '',  # 𡁖
    # 0x21057: '',  # 𡁗
    # 0x21058: '',  # 𡁘
    # 0x21059: '',  # 𡁙
    # 0x2105A: '',  # 𡁚
    # 0x2105B: '',  # 𡁛
    # 0x2105C: '',  # 𡁜
    # 0x2105D: '',  # 𡁝
    # 0x2105E: '',  # 𡁞
    # 0x2105F: '',  # 𡁟
    # 0x21060: '',  # 𡁠
    # 0x21061: '',  # 𡁡
    # 0x21062: '',  # 𡁢
    # 0x21063: '',  # 𡁣
    # 0x21064: '',  # 𡁤
    # 0x21065: '',  # 𡁥
    # 0x21066: '',  # 𡁦
    0x21067: 'zāng',  # 𡁧
    0x21068: 'duì',  # 𡁨
    # 0x21069: '',  # 𡁩
    0x2106A: 'jì',  # 𡁪
    # 0x2106B: '',  # 𡁫
    # 0x2106C: '',  # 𡁬
    # 0x2106D: '',  # 𡁭
    0x2106E: 'wō',  # 𡁮
    # 0x2106F: '',  # 𡁯
    0x21070: 'jí',  # 𡁰
    0x21071: 'xī',  # 𡁱
    # 0x21072: '',  # 𡁲
    0x21073: 'zhàn',  # 𡁳
    0x21074: 'tuán',  # 𡁴
    # 0x21075: '',  # 𡁵
    0x21076: 'jiē',  # 𡁶
    # 0x21077: '',  # 𡁷
    # 0x21078: '',  # 𡁸
    # 0x21079: '',  # 𡁹
    # 0x2107A: '',  # 𡁺
    # 0x2107B: '',  # 𡁻
    # 0x2107C: '',  # 𡁼
    # 0x2107D: '',  # 𡁽
    # 0x2107E: '',  # 𡁾
    # 0x2107F: '',  # 𡁿
    # 0x21080: '',  # 𡂀
    # 0x21081: '',  # 𡂁
    # 0x21082: '',  # 𡂂
    # 0x21083: '',  # 𡂃
    # 0x21084: '',  # 𡂄
    # 0x21085: '',  # 𡂅
    # 0x21086: '',  # 𡂆
    # 0x21087: '',  # 𡂇
    # 0x21088: '',  # 𡂈
    # 0x21089: '',  # 𡂉
    0x2108A: 'yú',  # 𡂊
    # 0x2108B: '',  # 𡂋
    # 0x2108C: '',  # 𡂌
    # 0x2108D: '',  # 𡂍
    # 0x2108E: '',  # 𡂎
    0x2108F: 'liè',  # 𡂏
    # 0x21090: '',  # 𡂐
    # 0x21091: '',  # 𡂑
    0x21092: 'zhì',  # 𡂒
    0x21093: 'shī',  # 𡂓
    # 0x21094: '',  # 𡂔
    0x21095: 'lǎo',  # 𡂕
    0x21096: 'lài,tà',  # 𡂖
    0x21097: 'wěi',  # 𡂗
    0x21098: 'páo',  # 𡂘
    0x21099: 'chí',  # 𡂙
    0x2109A: 'yǐng',  # 𡂚
    0x2109B: 'dòu',  # 𡂛
    # 0x2109C: '',  # 𡂜
    0x2109D: 'dòu',  # 𡂝
    # 0x2109E: '',  # 𡂞
    0x2109F: 'bào',  # 𡂟
    0x210A0: 'qiè',  # 𡂠
    0x210A1: 'shù',  # 𡂡
    0x210A2: 'jiāo',  # 𡂢
    0x210A3: 'zhí',  # 𡂣
    # 0x210A4: '',  # 𡂤
    # 0x210A5: '',  # 𡂥
    # 0x210A6: '',  # 𡂦
    # 0x210A7: '',  # 𡂧
    # 0x210A8: '',  # 𡂨
    0x210A9: 'liè',  # 𡂩
    # 0x210AA: '',  # 𡂪
    0x210AB: 'péng',  # 𡂫
    # 0x210AC: '',  # 𡂬
    0x210AD: 'zhē',  # 𡂭
    # 0x210AE: '',  # 𡂮
    # 0x210AF: '',  # 𡂯
    # 0x210B0: '',  # 𡂰
    # 0x210B1: '',  # 𡂱
    # 0x210B2: '',  # 𡂲
    # 0x210B3: '',  # 𡂳
    # 0x210B4: '',  # 𡂴
    # 0x210B5: '',  # 𡂵
    # 0x210B6: '',  # 𡂶
    # 0x210B7: '',  # 𡂷
    # 0x210B8: '',  # 𡂸
    # 0x210B9: '',  # 𡂹
    # 0x210BA: '',  # 𡂺
    # 0x210BB: '',  # 𡂻
    # 0x210BC: '',  # 𡂼
    # 0x210BD: '',  # 𡂽
    # 0x210BE: '',  # 𡂾
    0x210BF: 'ōu,ou',  # 𡂿
    # 0x210C0: '',  # 𡃀
    # 0x210C1: '',  # 𡃁
    0x210C2: 'xiè',  # 𡃂
    0x210C3: 'jí',  # 𡃃
    0x210C4: 'lài',  # 𡃄
    0x210C5: 'yíng',  # 𡃅
    0x210C6: 'cēng',  # 𡃆
    0x210C7: 'bì',  # 𡃇
    0x210C8: 'kè',  # 𡃈
    # 0x210C9: '',  # 𡃉
    # 0x210CA: '',  # 𡃊
    # 0x210CB: '',  # 𡃋
    # 0x210CC: '',  # 𡃌
    # 0x210CD: '',  # 𡃍
    # 0x210CE: '',  # 𡃎
    # 0x210CF: '',  # 𡃏
    # 0x210D0: '',  # 𡃐
    # 0x210D1: '',  # 𡃑
    # 0x210D2: '',  # 𡃒
    0x210D3: 'bō',  # 𡃓
    # 0x210D4: '',  # 𡃔
    # 0x210D5: '',  # 𡃕
    0x210D6: 'lē',  # 𡃖
    # 0x210D7: '',  # 𡃗
    # 0x210D8: '',  # 𡃘
    # 0x210D9: '',  # 𡃙
    # 0x210DA: '',  # 𡃚
    # 0x210DB: '',  # 𡃛
    # 0x210DC: '',  # 𡃜
    0x210DD: 'lùn',  # 𡃝
    # 0x210DE: '',  # 𡃞
    # 0x210DF: '',  # 𡃟
    # 0x210E0: '',  # 𡃠
    0x210E1: 'lóng',  # 𡃡
    0x210E2: 'xì',  # 𡃢
    # 0x210E3: '',  # 𡃣
    0x210E4: 'lài',  # 𡃤
    # 0x210E5: '',  # 𡃥
    0x210E6: 'lìn',  # 𡃦
    # 0x210E7: '',  # 𡃧
    # 0x210E8: '',  # 𡃨
    0x210E9: 'guī',  # 𡃩
    # 0x210EA: '',  # 𡃪
    # 0x210EB: '',  # 𡃫
    # 0x210EC: '',  # 𡃬
    # 0x210ED: '',  # 𡃭
    # 0x210EE: '',  # 𡃮
    # 0x210EF: '',  # 𡃯
    # 0x210F0: '',  # 𡃰
    # 0x210F1: '',  # 𡃱
    # 0x210F2: '',  # 𡃲
    0x210F3: 'xīng',  # 𡃳
    0x210F4: 'chú',  # 𡃴
    0x210F5: 'yōng',  # 𡃵
    # 0x210F6: '',  # 𡃶
    0x210F7: 'lí',  # 𡃷
    0x210F8: 'cī',  # 𡃸
    # 0x210F9: '',  # 𡃹
    # 0x210FA: '',  # 𡃺
    # 0x210FB: '',  # 𡃻
    # 0x210FC: '',  # 𡃼
    # 0x210FD: '',  # 𡃽
    # 0x210FE: '',  # 𡃾
    # 0x210FF: '',  # 𡃿
    # 0x21100: '',  # 𡄀
    # 0x21101: '',  # 𡄁
    # 0x21102: '',  # 𡄂
    # 0x21103: '',  # 𡄃
    # 0x21104: '',  # 𡄄
    # 0x21105: '',  # 𡄅
    # 0x21106: '',  # 𡄆
    0x21107: 'qǐng',  # 𡄇
    # 0x21108: '',  # 𡄈
    # 0x21109: '',  # 𡄉
    # 0x2110A: '',  # 𡄊
    # 0x2110B: '',  # 𡄋
    # 0x2110C: '',  # 𡄌
    # 0x2110D: '',  # 𡄍
    # 0x2110E: '',  # 𡄎
    # 0x2110F: '',  # 𡄏
    # 0x21110: '',  # 𡄐
    0x21111: 'jiān',  # 𡄑
    0x21112: 'dào',  # 𡄒
    0x21113: 'jiǎn',  # 𡄓
    0x21114: 'qìng',  # 𡄔
    0x21115: 'xiè',  # 𡄕
    0x21116: 'yìng',  # 𡄖
    # 0x21117: '',  # 𡄗
    # 0x21118: '',  # 𡄘
    # 0x21119: '',  # 𡄙
    # 0x2111A: '',  # 𡄚
    # 0x2111B: '',  # 𡄛
    # 0x2111C: '',  # 𡄜
    # 0x2111D: '',  # 𡄝
    # 0x2111E: '',  # 𡄞
    0x2111F: 'há',  # 𡄟
    # 0x21120: '',  # 𡄠
    0x21121: 'zhe',  # 𡄡
    0x21122: 'shē',  # 𡄢
    0x21123: 'mí',  # 𡄣
    0x21124: 'huán',  # 𡄤
    # 0x21125: '',  # 𡄥
    # 0x21126: '',  # 𡄦
    # 0x21127: '',  # 𡄧
    # 0x21128: '',  # 𡄨
    # 0x21129: '',  # 𡄩
    # 0x2112A: '',  # 𡄪
    # 0x2112B: '',  # 𡄫
    # 0x2112C: '',  # 𡄬
    # 0x2112D: '',  # 𡄭
    # 0x2112E: '',  # 𡄮
    # 0x2112F: '',  # 𡄯
    # 0x21130: '',  # 𡄰
    0x21131: 'cù',  # 𡄱
    0x21132: 'rú',  # 𡄲
    0x21133: 'sǎ',  # 𡄳
    0x21134: 'huò',  # 𡄴
    0x21135: 'yī',  # 𡄵
    # 0x21136: '',  # 𡄶
    0x21137: 'dī',  # 𡄷
    # 0x21138: '',  # 𡄸
    0x21139: 'luàn',  # 𡄹
    # 0x2113A: '',  # 𡄺
    0x2113B: 'yì',  # 𡄻
    # 0x2113C: '',  # 𡄼
    # 0x2113D: '',  # 𡄽
    # 0x2113E: '',  # 𡄾
    # 0x2113F: '',  # 𡄿
    # 0x21140: '',  # 𡅀
    # 0x21141: '',  # 𡅁
    0x21142: 'bò',  # 𡅂
    0x21143: 'páng',  # 𡅃
    0x21144: 'tán',  # 𡅄
    0x21145: 'é,éi',  # 𡅅
    0x21146: 'zāng',  # 𡅆
    0x21147: 'cóng',  # 𡅇
    # 0x21148: '',  # 𡅈
    # 0x21149: '',  # 𡅉
    # 0x2114A: '',  # 𡅊
    # 0x2114B: '',  # 𡅋
    # 0x2114C: '',  # 𡅌
    # 0x2114D: '',  # 𡅍
    # 0x2114E: '',  # 𡅎
    # 0x2114F: '',  # 𡅏
    # 0x21150: '',  # 𡅐
    # 0x21151: '',  # 𡅑
    # 0x21152: '',  # 𡅒
    0x21153: 'zhāi',  # 𡅓
    # 0x21154: '',  # 𡅔
    0x21155: 'xǐ',  # 𡅕
    0x21156: 'mǎng',  # 𡅖
    # 0x21157: '',  # 𡅗
    0x21158: 'là',  # 𡅘
    0x21159: 'yùn',  # 𡅙
    # 0x2115A: '',  # 𡅚
    # 0x2115B: '',  # 𡅛
    # 0x2115C: '',  # 𡅜
    # 0x2115D: '',  # 𡅝
    # 0x2115E: '',  # 𡅞
    # 0x2115F: '',  # 𡅟
    # 0x21160: '',  # 𡅠
    0x21161: 'è',  # 𡅡
    # 0x21162: '',  # 𡅢
    # 0x21163: '',  # 𡅣
    # 0x21164: '',  # 𡅤
    0x21165: 'dié',  # 𡅥
    # 0x21166: '',  # 𡅦
    # 0x21167: '',  # 𡅧
    # 0x21168: '',  # 𡅨
    # 0x21169: '',  # 𡅩
    # 0x2116A: '',  # 𡅪
    # 0x2116B: '',  # 𡅫
    # 0x2116C: '',  # 𡅬
    0x2116D: 'guān',  # 𡅭
    # 0x2116E: '',  # 𡅮
    # 0x2116F: '',  # 𡅯
    # 0x21170: '',  # 𡅰
    0x21171: 'huàn',  # 𡅱
    # 0x21172: '',  # 𡅲
    # 0x21173: '',  # 𡅳
    # 0x21174: '',  # 𡅴
    0x21175: 'shì',  # 𡅵
    0x21176: 'jiǎn',  # 𡅶
    # 0x21177: '',  # 𡅷
    # 0x21178: '',  # 𡅸
    0x21179: 'zhān',  # 𡅹
    0x2117A: 'jí',  # 𡅺
    0x2117B: 'huàn',  # 𡅻
    # 0x2117C: '',  # 𡅼
    # 0x2117D: '',  # 𡅽
    # 0x2117E: '',  # 𡅾
    # 0x2117F: '',  # 𡅿
    # 0x21180: '',  # 𡆀
    # 0x21181: '',  # 𡆁
    # 0x21182: '',  # 𡆂
    # 0x21183: '',  # 𡆃
    # 0x21184: '',  # 𡆄
    0x21185: 'wàn',  # 𡆅
    0x21186: 'luǒ',  # 𡆆
    # 0x21187: '',  # 𡆇
    # 0x21188: '',  # 𡆈
    # 0x21189: '',  # 𡆉
    # 0x2118A: '',  # 𡆊
    # 0x2118B: '',  # 𡆋
    # 0x2118C: '',  # 𡆌
    # 0x2118D: '',  # 𡆍
    # 0x2118E: '',  # 𡆎
    0x2118F: 'dòu',  # 𡆏
    # 0x21190: '',  # 𡆐
    # 0x21191: '',  # 𡆑
    # 0x21192: '',  # 𡆒
    # 0x21193: '',  # 𡆓
    # 0x21194: '',  # 𡆔
    0x21195: 'liàn',  # 𡆕
    # 0x21196: '',  # 𡆖
    # 0x21197: '',  # 𡆗
    # 0x21198: '',  # 𡆘
    # 0x21199: '',  # 𡆙
    # 0x2119A: '',  # 𡆚
    # 0x2119B: '',  # 𡆛
    # 0x2119C: '',  # 𡆜
    # 0x2119D: '',  # 𡆝
    # 0x2119E: '',  # 𡆞
    # 0x2119F: '',  # 𡆟
    # 0x211A0: '',  # 𡆠
    # 0x211A1: '',  # 𡆡
    0x211A2: 'qiú',  # 𡆢
    0x211A3: 'niè,dí',  # 𡆣
    0x211A4: 'nǎn',  # 𡆤
    0x211A5: 'jiù',  # 𡆥
    0x211A6: 'yuè',  # 𡆦
    # 0x211A7: '',  # 𡆧
    # 0x211A8: '',  # 𡆨
    0x211A9: 'yāo,jiǒng',  # 𡆩
    0x211AA: 'chuāng',  # 𡆪
    # 0x211AB: '',  # 𡆫
    0x211AC: 'yīn',  # 𡆬
    # 0x211AD: '',  # 𡆭
    0x211AE: 'cǎn',  # 𡆮
    0x211AF: 'lǐ',  # 𡆯
    0x211B0: 'dùn',  # 𡆰
    0x211B1: 'nǎn',  # 𡆱
    0x211B2: 'nǎn',  # 𡆲
    # 0x211B3: '',  # 𡆳
    # 0x211B4: '',  # 𡆴
    # 0x211B5: '',  # 𡆵
    # 0x211B6: '',  # 𡆶
    # 0x211B7: '',  # 𡆷
    0x211B8: 'rì,guó',  # 𡆸
    # 0x211B9: '',  # 𡆹
    # 0x211BA: '',  # 𡆺
    # 0x211BB: '',  # 𡆻
    # 0x211BC: '',  # 𡆼
    0x211BD: 'yuè',  # 𡆽
    # 0x211BE: '',  # 𡆾
    # 0x211BF: '',  # 𡆿
    0x211C0: 'yóu',  # 𡇀
    # 0x211C1: '',  # 𡇁
    0x211C2: 'yīn',  # 𡇂
    # 0x211C3: '',  # 𡇃
    0x211C4: 'guó,niè',  # 𡇄
    0x211C5: 'guó',  # 𡇅
    # 0x211C6: '',  # 𡇆
    # 0x211C7: '',  # 𡇇
    0x211C8: 'dàng,tuó',  # 𡇈
    # 0x211C9: '',  # 𡇉
    # 0x211CA: '',  # 𡇊
    # 0x211CB: '',  # 𡇋
    # 0x211CC: '',  # 𡇌
    # 0x211CD: '',  # 𡇍
    # 0x211CE: '',  # 𡇎
    # 0x211CF: '',  # 𡇏
    # 0x211D0: '',  # 𡇐
    0x211D1: 'zhēn',  # 𡇑
    0x211D2: 'mí',  # 𡇒
    0x211D3: 'dié',  # 𡇓
    # 0x211D4: '',  # 𡇔
    # 0x211D5: '',  # 𡇕
    0x211D6: 'zhēn',  # 𡇖
    # 0x211D7: '',  # 𡇗
    # 0x211D8: '',  # 𡇘
    # 0x211D9: '',  # 𡇙
    0x211DA: 'kuā',  # 𡇚
    # 0x211DB: '',  # 𡇛
    0x211DC: 'hán',  # 𡇜
    0x211DD: 'sòng',  # 𡇝
    0x211DE: 'hé',  # 𡇞
    0x211DF: 'jī',  # 𡇟
    0x211E0: 'zhé',  # 𡇠
    # 0x211E1: '',  # 𡇡
    # 0x211E2: '',  # 𡇢
    # 0x211E3: '',  # 𡇣
    0x211E4: 'bǐng',  # 𡇤
    # 0x211E5: '',  # 𡇥
    0x211E6: 'wéi',  # 𡇦
    0x211E7: 'tōu',  # 𡇧
    # 0x211E8: '',  # 𡇨
    0x211E9: 'tú',  # 𡇩
    # 0x211EA: '',  # 𡇪
    # 0x211EB: '',  # 𡇫
    0x211EC: 'gāng',  # 𡇬
    0x211ED: 'lóu',  # 𡇭
    0x211EE: 'quán',  # 𡇮
    0x211EF: 'hùn',  # 𡇯
    0x211F0: 'zhuǎn',  # 𡇰
    0x211F1: 'què',  # 𡇱
    # 0x211F2: '',  # 𡇲
    0x211F3: 'hóng',  # 𡇳
    # 0x211F4: '',  # 𡇴
    0x211F5: 'dàng',  # 𡇵
    0x211F6: 'hé',  # 𡇶
    0x211F7: 'tài',  # 𡇷
    0x211F8: 'guāi',  # 𡇸
    # 0x211F9: '',  # 𡇹
    0x211FA: 'yù',  # 𡇺
    # 0x211FB: '',  # 𡇻
    0x211FC: 'yà',  # 𡇼
    # 0x211FD: '',  # 𡇽
    # 0x211FE: '',  # 𡇾
    0x211FF: 'wān',  # 𡇿
    0x21200: 'qūn',  # 𡈀
    # 0x21201: '',  # 𡈁
    # 0x21202: '',  # 𡈂
    # 0x21203: '',  # 𡈃
    # 0x21204: '',  # 𡈄
    0x21205: 'jué',  # 𡈅
    0x21206: 'ōu',  # 𡈆
    # 0x21207: '',  # 𡈇
    # 0x21208: '',  # 𡈈
    0x21209: 'quān',  # 𡈉
    0x2120A: 'zhí',  # 𡈊
    0x2120B: 'kǔn',  # 𡈋
    # 0x2120C: '',  # 𡈌
    0x2120D: 'líng',  # 𡈍
    0x2120E: 'wū,rì',  # 𡈎
    0x2120F: 'xìn',  # 𡈏
    0x21210: 'dá',  # 𡈐
    # 0x21211: '',  # 𡈑
    0x21212: 'yuān',  # 𡈒
    0x21213: 'yuàn',  # 𡈓
    # 0x21214: '',  # 𡈔
    # 0x21215: '',  # 𡈕
    # 0x21216: '',  # 𡈖
    0x21217: 'mò',  # 𡈗
    # 0x21218: '',  # 𡈘
    0x21219: 'yóu',  # 𡈙
    # 0x2121A: '',  # 𡈚
    # 0x2121B: '',  # 𡈛
    # 0x2121C: '',  # 𡈜
    # 0x2121D: '',  # 𡈝
    0x2121E: 'wǔ',  # 𡈞
    # 0x2121F: '',  # 𡈟
    0x21220: 'zhāng',  # 𡈠
    # 0x21221: '',  # 𡈡
    # 0x21222: '',  # 𡈢
    0x21223: 'xuān',  # 𡈣
    # 0x21224: '',  # 𡈤
    # 0x21225: '',  # 𡈥
    0x21226: 'rǎo',  # 𡈦
    0x21227: 'gǔn',  # 𡈧
    0x21228: 'yù',  # 𡈨
    # 0x21229: '',  # 𡈩
    # 0x2122A: '',  # 𡈪
    # 0x2122B: '',  # 𡈫
    # 0x2122C: '',  # 𡈬
    # 0x2122D: '',  # 𡈭
    0x2122E: 'xiá',  # 𡈮
    0x2122F: 'biǎn',  # 𡈯
    0x21230: 'yóu',  # 𡈰
    # 0x21231: '',  # 𡈱
    0x21232: 'yīn',  # 𡈲
    # 0x21233: '',  # 𡈳
    0x21234: 'xuán,rǔ',  # 𡈴
    0x21235: 'yóu',  # 𡈵
    0x21236: 'léi',  # 𡈶
    # 0x21237: '',  # 𡈷
    # 0x21238: '',  # 𡈸
    # 0x21239: '',  # 𡈹
    # 0x2123A: '',  # 𡈺
    # 0x2123B: '',  # 𡈻
    0x2123C: 'tǐng,tíng,zhēng,zhǐ',  # 𡈼
    # 0x2123D: '',  # 𡈽
    # 0x2123E: '',  # 𡈾
    0x2123F: 'zhēn',  # 𡈿
    # 0x21240: '',  # 𡉀
    # 0x21241: '',  # 𡉁
    0x21242: 'tǐng',  # 𡉂
    # 0x21243: '',  # 𡉃
    0x21244: 'zài,kū',  # 𡉄
    0x21245: 'gā',  # 𡉅
    0x21246: 'lá',  # 𡉆
    0x21247: 'kuài',  # 𡉇
    # 0x21248: '',  # 𡉈
    0x21249: 'què',  # 𡉉
    # 0x2124A: '',  # 𡉊
    # 0x2124B: '',  # 𡉋
    # 0x2124C: '',  # 𡉌
    # 0x2124D: '',  # 𡉍
    0x2124E: 'jú',  # 𡉎
    # 0x2124F: '',  # 𡉏
    0x21250: 'chūn',  # 𡉐
    0x21251: 'dā',  # 𡉑
    0x21252: 'tún',  # 𡉒
    0x21253: 'āi',  # 𡉓
    # 0x21254: '',  # 𡉔
    # 0x21255: '',  # 𡉕
    # 0x21256: '',  # 𡉖
    0x21257: 'zǐ',  # 𡉗
    # 0x21258: '',  # 𡉘
    # 0x21259: '',  # 𡉙
    0x2125A: 'huáng,fēng',  # 𡉚
    0x2125B: 'yì',  # 𡉛
    # 0x2125C: '',  # 𡉜
    # 0x2125D: '',  # 𡉝
    # 0x2125E: '',  # 𡉞
    # 0x2125F: '',  # 𡉟
    # 0x21260: '',  # 𡉠
    0x21261: 'zuò',  # 𡉡
    # 0x21262: '',  # 𡉢
    # 0x21263: '',  # 𡉣
    # 0x21264: '',  # 𡉤
    # 0x21265: '',  # 𡉥
    0x21266: 'wù',  # 𡉦
    # 0x21267: '',  # 𡉧
    # 0x21268: '',  # 𡉨
    0x21269: 'bào',  # 𡉩
    0x2126A: 'chí',  # 𡉪
    0x2126B: 'tún',  # 𡉫
    # 0x2126C: '',  # 𡉬
    0x2126D: 'rì',  # 𡉭
    # 0x2126E: '',  # 𡉮
    # 0x2126F: '',  # 𡉯
    # 0x21270: '',  # 𡉰
    # 0x21271: '',  # 𡉱
    # 0x21272: '',  # 𡉲
    # 0x21273: '',  # 𡉳
    0x21274: 'lú,hù',  # 𡉴
    # 0x21275: '',  # 𡉵
    # 0x21276: '',  # 𡉶
    0x21277: 'jié',  # 𡉷
    0x21278: 'shì',  # 𡉸
    # 0x21279: '',  # 𡉹
    0x2127A: 'zuān',  # 𡉺
    # 0x2127B: '',  # 𡉻
    # 0x2127C: '',  # 𡉼
    # 0x2127D: '',  # 𡉽
    # 0x2127E: '',  # 𡉾
    # 0x2127F: '',  # 𡉿
    # 0x21280: '',  # 𡊀
    0x21281: 'yì',  # 𡊁
    # 0x21282: '',  # 𡊂
    # 0x21283: '',  # 𡊃
    0x21284: 'fèn',  # 𡊄
    0x21285: 'fèn,biàn',  # 𡊅
    # 0x21286: '',  # 𡊆
    # 0x21287: '',  # 𡊇
    # 0x21288: '',  # 𡊈
    0x21289: 'mò',  # 𡊉
    # 0x2128A: '',  # 𡊊
    # 0x2128B: '',  # 𡊋
    # 0x2128C: '',  # 𡊌
    0x2128D: 'shù',  # 𡊍
    # 0x2128E: '',  # 𡊎
    # 0x2128F: '',  # 𡊏
    # 0x21290: '',  # 𡊐
    # 0x21291: '',  # 𡊑
    # 0x21292: '',  # 𡊒
    # 0x21293: '',  # 𡊓
    # 0x21294: '',  # 𡊔
    # 0x21295: '',  # 𡊕
    # 0x21296: '',  # 𡊖
    # 0x21297: '',  # 𡊗
    # 0x21298: '',  # 𡊘
    # 0x21299: '',  # 𡊙
    # 0x2129A: '',  # 𡊚
    0x2129B: 'áo',  # 𡊛
    # 0x2129C: '',  # 𡊜
    0x2129D: 'pǐ',  # 𡊝
    0x2129E: 'píng,pìng',  # 𡊞
    0x2129F: 'pō',  # 𡊟
    0x212A0: 'jiá',  # 𡊠
    0x212A1: 'zhóu',  # 𡊡
    # 0x212A2: '',  # 𡊢
    0x212A3: 'qiū',  # 𡊣
    # 0x212A4: '',  # 𡊤
    0x212A5: 'zhào',  # 𡊥
    # 0x212A6: '',  # 𡊦
    0x212A7: 'yǒu',  # 𡊧
    0x212A8: 'tán',  # 𡊨
    # 0x212A9: '',  # 𡊩
    # 0x212AA: '',  # 𡊪
    0x212AB: 'rǒng',  # 𡊫
    # 0x212AC: '',  # 𡊬
    0x212AD: 'mì',  # 𡊭
    # 0x212AE: '',  # 𡊮
    # 0x212AF: '',  # 𡊯
    # 0x212B0: '',  # 𡊰
    # 0x212B1: '',  # 𡊱
    # 0x212B2: '',  # 𡊲
    # 0x212B3: '',  # 𡊳
    # 0x212B4: '',  # 𡊴
    # 0x212B5: '',  # 𡊵
    0x212B6: 'yì',  # 𡊶
    # 0x212B7: '',  # 𡊷
    0x212B8: 'rǒng',  # 𡊸
    # 0x212B9: '',  # 𡊹
    # 0x212BA: '',  # 𡊺
    0x212BB: 'liè',  # 𡊻
    0x212BC: 'qióng',  # 𡊼
    # 0x212BD: '',  # 𡊽
    # 0x212BE: '',  # 𡊾
    # 0x212BF: '',  # 𡊿
    # 0x212C0: '',  # 𡋀
    # 0x212C1: '',  # 𡋁
    # 0x212C2: '',  # 𡋂
    # 0x212C3: '',  # 𡋃
    # 0x212C4: '',  # 𡋄
    # 0x212C5: '',  # 𡋅
    # 0x212C6: '',  # 𡋆
    # 0x212C7: '',  # 𡋇
    # 0x212C8: '',  # 𡋈
    # 0x212C9: '',  # 𡋉
    # 0x212CA: '',  # 𡋊
    # 0x212CB: '',  # 𡋋
    # 0x212CC: '',  # 𡋌
    # 0x212CD: '',  # 𡋍
    # 0x212CE: '',  # 𡋎
    # 0x212CF: '',  # 𡋏
    # 0x212D0: '',  # 𡋐
    # 0x212D1: '',  # 𡋑
    # 0x212D2: '',  # 𡋒
    # 0x212D3: '',  # 𡋓
    # 0x212D4: '',  # 𡋔
    # 0x212D5: '',  # 𡋕
    # 0x212D6: '',  # 𡋖
    # 0x212D7: '',  # 𡋗
    # 0x212D8: '',  # 𡋘
    0x212D9: 'huí',  # 𡋙
    0x212DA: 'jì',  # 𡋚
    # 0x212DB: '',  # 𡋛
    # 0x212DC: '',  # 𡋜
    # 0x212DD: '',  # 𡋝
    # 0x212DE: '',  # 𡋞
    0x212DF: 'gào',  # 𡋟
    # 0x212E0: '',  # 𡋠
    # 0x212E1: '',  # 𡋡
    # 0x212E2: '',  # 𡋢
    # 0x212E3: '',  # 𡋣
    # 0x212E4: '',  # 𡋤
    # 0x212E5: '',  # 𡋥
    # 0x212E6: '',  # 𡋦
    0x212E7: 'yóu',  # 𡋧
    0x212E8: 'chā',  # 𡋨
    0x212E9: 'dé',  # 𡋩
    0x212EA: 'yīn',  # 𡋪
    # 0x212EB: '',  # 𡋫
    0x212EC: 'yù',  # 𡋬
    0x212ED: 'bèi',  # 𡋭
    # 0x212EE: '',  # 𡋮
    0x212EF: 'bó',  # 𡋯
    # 0x212F0: '',  # 𡋰
    # 0x212F1: '',  # 𡋱
    0x212F2: 'zuò',  # 𡋲
    # 0x212F3: '',  # 𡋳
    # 0x212F4: '',  # 𡋴
    # 0x212F5: '',  # 𡋵
    # 0x212F6: '',  # 𡋶
    # 0x212F7: '',  # 𡋷
    # 0x212F8: '',  # 𡋸
    # 0x212F9: '',  # 𡋹
    # 0x212FA: '',  # 𡋺
    # 0x212FB: '',  # 𡋻
    # 0x212FC: '',  # 𡋼
    # 0x212FD: '',  # 𡋽
    # 0x212FE: '',  # 𡋾
    # 0x212FF: '',  # 𡋿
    # 0x21300: '',  # 𡌀
    # 0x21301: '',  # 𡌁
    # 0x21302: '',  # 𡌂
    # 0x21303: '',  # 𡌃
    # 0x21304: '',  # 𡌄
    # 0x21305: '',  # 𡌅
    # 0x21306: '',  # 𡌆
    # 0x21307: '',  # 𡌇
    # 0x21308: '',  # 𡌈
    # 0x21309: '',  # 𡌉
    # 0x2130A: '',  # 𡌊
    # 0x2130B: '',  # 𡌋
    # 0x2130C: '',  # 𡌌
    # 0x2130D: '',  # 𡌍
    # 0x2130E: '',  # 𡌎
    # 0x2130F: '',  # 𡌏
    # 0x21310: '',  # 𡌐
    # 0x21311: '',  # 𡌑
    # 0x21312: '',  # 𡌒
    # 0x21313: '',  # 𡌓
    0x21314: 'qiāo',  # 𡌔
    # 0x21315: '',  # 𡌕
    # 0x21316: '',  # 𡌖
    # 0x21317: '',  # 𡌗
    # 0x21318: '',  # 𡌘
    # 0x21319: '',  # 𡌙
    0x2131A: 'chǎ',  # 𡌚
    # 0x2131B: '',  # 𡌛
    0x2131C: 'xīn',  # 𡌜
    # 0x2131D: '',  # 𡌝
    0x2131E: 'chí',  # 𡌞
    # 0x2131F: '',  # 𡌟
    # 0x21320: '',  # 𡌠
    # 0x21321: '',  # 𡌡
    # 0x21322: '',  # 𡌢
    # 0x21323: '',  # 𡌣
    0x21324: 'kuí',  # 𡌤
    # 0x21325: '',  # 𡌥
    0x21326: 'fèi',  # 𡌦
    # 0x21327: '',  # 𡌧
    # 0x21328: '',  # 𡌨
    0x21329: 'tā,dá',  # 𡌩
    0x2132A: 'guài',  # 𡌪
    # 0x2132B: '',  # 𡌫
    # 0x2132C: '',  # 𡌬
    0x2132D: 'duō',  # 𡌭
    # 0x2132E: '',  # 𡌮
    # 0x2132F: '',  # 𡌯
    # 0x21330: '',  # 𡌰
    # 0x21331: '',  # 𡌱
    0x21332: 'guī',  # 𡌲
    # 0x21333: '',  # 𡌳
    # 0x21334: '',  # 𡌴
    # 0x21335: '',  # 𡌵
    # 0x21336: '',  # 𡌶
    # 0x21337: '',  # 𡌷
    # 0x21338: '',  # 𡌸
    # 0x21339: '',  # 𡌹
    # 0x2133A: '',  # 𡌺
    # 0x2133B: '',  # 𡌻
    # 0x2133C: '',  # 𡌼
    # 0x2133D: '',  # 𡌽
    # 0x2133E: '',  # 𡌾
    # 0x2133F: '',  # 𡌿
    # 0x21340: '',  # 𡍀
    # 0x21341: '',  # 𡍁
    # 0x21342: '',  # 𡍂
    # 0x21343: '',  # 𡍃
    # 0x21344: '',  # 𡍄
    # 0x21345: '',  # 𡍅
    # 0x21346: '',  # 𡍆
    # 0x21347: '',  # 𡍇
    # 0x21348: '',  # 𡍈
    # 0x21349: '',  # 𡍉
    # 0x2134A: '',  # 𡍊
    # 0x2134B: '',  # 𡍋
    0x2134C: 'chǎn',  # 𡍌
    0x2134D: 'nǎo',  # 𡍍
    # 0x2134E: '',  # 𡍎
    # 0x2134F: '',  # 𡍏
    0x21350: 'hú',  # 𡍐
    # 0x21351: '',  # 𡍑
    0x21352: 'táo',  # 𡍒
    # 0x21353: '',  # 𡍓
    # 0x21354: '',  # 𡍔
    # 0x21355: '',  # 𡍕
    # 0x21356: '',  # 𡍖
    # 0x21357: '',  # 𡍗
    # 0x21358: '',  # 𡍘
    # 0x21359: '',  # 𡍙
    # 0x2135A: '',  # 𡍚
    # 0x2135B: '',  # 𡍛
    # 0x2135C: '',  # 𡍜
    # 0x2135D: '',  # 𡍝
    # 0x2135E: '',  # 𡍞
    # 0x2135F: '',  # 𡍟
    # 0x21360: '',  # 𡍠
    0x21361: 'yì',  # 𡍡
    # 0x21362: '',  # 𡍢
    # 0x21363: '',  # 𡍣
    0x21364: 'niè',  # 𡍤
    0x21365: 'zhài',  # 𡍥
    0x21366: 'huán',  # 𡍦
    # 0x21367: '',  # 𡍧
    0x21368: 'dù',  # 𡍨
    # 0x21369: '',  # 𡍩
    0x2136A: 'qì',  # 𡍪
    0x2136B: 'cè',  # 𡍫
    # 0x2136C: '',  # 𡍬
    # 0x2136D: '',  # 𡍭
    0x2136E: 'chuí',  # 𡍮
    # 0x2136F: '',  # 𡍯
    # 0x21370: '',  # 𡍰
    # 0x21371: '',  # 𡍱
    0x21372: 'dā',  # 𡍲
    # 0x21373: '',  # 𡍳
    # 0x21374: '',  # 𡍴
    # 0x21375: '',  # 𡍵
    0x21376: 'zhì',  # 𡍶
    0x21377: 'gèng',  # 𡍷
    # 0x21378: '',  # 𡍸
    # 0x21379: '',  # 𡍹
    # 0x2137A: '',  # 𡍺
    0x2137B: 'wèng',  # 𡍻
    # 0x2137C: '',  # 𡍼
    # 0x2137D: '',  # 𡍽
    # 0x2137E: '',  # 𡍾
    # 0x2137F: '',  # 𡍿
    # 0x21380: '',  # 𡎀
    0x21381: 'hù',  # 𡎁
    # 0x21382: '',  # 𡎂
    # 0x21383: '',  # 𡎃
    # 0x21384: '',  # 𡎄
    # 0x21385: '',  # 𡎅
    # 0x21386: '',  # 𡎆
    # 0x21387: '',  # 𡎇
    # 0x21388: '',  # 𡎈
    0x21389: 'dù',  # 𡎉
    0x2138A: 'fàn',  # 𡎊
    # 0x2138B: '',  # 𡎋
    # 0x2138C: '',  # 𡎌
    0x2138D: 'chí',  # 𡎍
    # 0x2138E: '',  # 𡎎
    # 0x2138F: '',  # 𡎏
    0x21390: 'yì',  # 𡎐
    0x21391: 'àn',  # 𡎑
    0x21392: 'kuò',  # 𡎒
    0x21393: 'hè',  # 𡎓
    0x21394: 'wò',  # 𡎔
    # 0x21395: '',  # 𡎕
    # 0x21396: '',  # 𡎖
    # 0x21397: '',  # 𡎗
    0x21398: 'yīng',  # 𡎘
    # 0x21399: '',  # 𡎙
    0x2139A: 'piǎn',  # 𡎚
    # 0x2139B: '',  # 𡎛
    # 0x2139C: '',  # 𡎜
    # 0x2139D: '',  # 𡎝
    # 0x2139E: '',  # 𡎞
    # 0x2139F: '',  # 𡎟
    # 0x213A0: '',  # 𡎠
    # 0x213A1: '',  # 𡎡
    # 0x213A2: '',  # 𡎢
    # 0x213A3: '',  # 𡎣
    # 0x213A4: '',  # 𡎤
    # 0x213A5: '',  # 𡎥
    # 0x213A6: '',  # 𡎦
    # 0x213A7: '',  # 𡎧
    # 0x213A8: '',  # 𡎨
    # 0x213A9: '',  # 𡎩
    # 0x213AA: '',  # 𡎪
    0x213AB: 'zhá,qì',  # 𡎫
    0x213AC: 'zhuǎ',  # 𡎬
    # 0x213AD: '',  # 𡎭
    0x213AE: 'sù',  # 𡎮
    # 0x213AF: '',  # 𡎯
    # 0x213B0: '',  # 𡎰
    # 0x213B1: '',  # 𡎱
    # 0x213B2: '',  # 𡎲
    0x213B3: 'nì',  # 𡎳
    # 0x213B4: '',  # 𡎴
    # 0x213B5: '',  # 𡎵
    # 0x213B6: '',  # 𡎶
    # 0x213B7: '',  # 𡎷
    # 0x213B8: '',  # 𡎸
    # 0x213B9: '',  # 𡎹
    0x213BA: 'zhú',  # 𡎺
    0x213BB: 'chán',  # 𡎻
    # 0x213BC: '',  # 𡎼
    # 0x213BD: '',  # 𡎽
    0x213BE: 'bèng',  # 𡎾
    0x213BF: 'ní',  # 𡎿
    0x213C0: 'zhí',  # 𡏀
    0x213C1: 'huì',  # 𡏁
    # 0x213C2: '',  # 𡏂
    # 0x213C3: '',  # 𡏃
    # 0x213C4: '',  # 𡏄
    # 0x213C5: '',  # 𡏅
    # 0x213C6: '',  # 𡏆
    # 0x213C7: '',  # 𡏇
    # 0x213C8: '',  # 𡏈
    # 0x213C9: '',  # 𡏉
    # 0x213CA: '',  # 𡏊
    # 0x213CB: '',  # 𡏋
    # 0x213CC: '',  # 𡏌
    # 0x213CD: '',  # 𡏍
    # 0x213CE: '',  # 𡏎
    # 0x213CF: '',  # 𡏏
    # 0x213D0: '',  # 𡏐
    # 0x213D1: '',  # 𡏑
    # 0x213D2: '',  # 𡏒
    # 0x213D3: '',  # 𡏓
    # 0x213D4: '',  # 𡏔
    # 0x213D5: '',  # 𡏕
    0x213D6: 'ài',  # 𡏖
    # 0x213D7: '',  # 𡏗
    0x213D8: 'xià',  # 𡏘
    # 0x213D9: '',  # 𡏙
    0x213DA: 'zhì',  # 𡏚
    0x213DB: 'xī',  # 𡏛
    # 0x213DC: '',  # 𡏜
    # 0x213DD: '',  # 𡏝
    0x213DE: 'jiǎng',  # 𡏞
    # 0x213DF: '',  # 𡏟
    # 0x213E0: '',  # 𡏠
    # 0x213E1: '',  # 𡏡
    # 0x213E2: '',  # 𡏢
    # 0x213E3: '',  # 𡏣
    # 0x213E4: '',  # 𡏤
    # 0x213E5: '',  # 𡏥
    # 0x213E6: '',  # 𡏦
    # 0x213E7: '',  # 𡏧
    # 0x213E8: '',  # 𡏨
    0x213E9: 'duī',  # 𡏩
    0x213EA: 'fū',  # 𡏪
    # 0x213EB: '',  # 𡏫
    # 0x213EC: '',  # 𡏬
    0x213ED: 'jiāo',  # 𡏭
    0x213EE: 'cháo',  # 𡏮
    0x213EF: 'bài',  # 𡏯
    # 0x213F0: '',  # 𡏰
    # 0x213F1: '',  # 𡏱
    0x213F2: 'xì',  # 𡏲
    # 0x213F3: '',  # 𡏳
    # 0x213F4: '',  # 𡏴
    0x213F5: 'liè',  # 𡏵
    # 0x213F6: '',  # 𡏶
    # 0x213F7: '',  # 𡏷
    # 0x213F8: '',  # 𡏸
    # 0x213F9: '',  # 𡏹
    # 0x213FA: '',  # 𡏺
    # 0x213FB: '',  # 𡏻
    0x213FC: 'áo',  # 𡏼
    # 0x213FD: '',  # 𡏽
    # 0x213FE: '',  # 𡏾
    # 0x213FF: '',  # 𡏿
    # 0x21400: '',  # 𡐀
    # 0x21401: '',  # 𡐁
    # 0x21402: '',  # 𡐂
    # 0x21403: '',  # 𡐃
    # 0x21404: '',  # 𡐄
    # 0x21405: '',  # 𡐅
    # 0x21406: '',  # 𡐆
    # 0x21407: '',  # 𡐇
    # 0x21408: '',  # 𡐈
    # 0x21409: '',  # 𡐉
    # 0x2140A: '',  # 𡐊
    0x2140B: 'zāo',  # 𡐋
    0x2140C: 'chù',  # 𡐌
    # 0x2140D: '',  # 𡐍
    # 0x2140E: '',  # 𡐎
    0x2140F: 'tuǒ',  # 𡐏
    # 0x21410: '',  # 𡐐
    # 0x21411: '',  # 𡐑
    0x21412: 'háo,hào',  # 𡐒
    0x21413: 'kāng',  # 𡐓
    0x21414: 'yín',  # 𡐔
    # 0x21415: '',  # 𡐕
    0x21416: 'xiàn',  # 𡐖
    # 0x21417: '',  # 𡐗
    # 0x21418: '',  # 𡐘
    # 0x21419: '',  # 𡐙
    # 0x2141A: '',  # 𡐚
    # 0x2141B: '',  # 𡐛
    # 0x2141C: '',  # 𡐜
    0x2141D: 'fù',  # 𡐝
    0x2141E: 'biē',  # 𡐞
    # 0x2141F: '',  # 𡐟
    0x21420: 'kuī',  # 𡐠
    # 0x21421: '',  # 𡐡
    # 0x21422: '',  # 𡐢
    # 0x21423: '',  # 𡐣
    0x21424: 'qiè',  # 𡐤
    0x21425: 'sà',  # 𡐥
    # 0x21426: '',  # 𡐦
    # 0x21427: '',  # 𡐧
    # 0x21428: '',  # 𡐨
    # 0x21429: '',  # 𡐩
    # 0x2142A: '',  # 𡐪
    # 0x2142B: '',  # 𡐫
    # 0x2142C: '',  # 𡐬
    # 0x2142D: '',  # 𡐭
    # 0x2142E: '',  # 𡐮
    # 0x2142F: '',  # 𡐯
    # 0x21430: '',  # 𡐰
    # 0x21431: '',  # 𡐱
    # 0x21432: '',  # 𡐲
    # 0x21433: '',  # 𡐳
    # 0x21434: '',  # 𡐴
    # 0x21435: '',  # 𡐵
    # 0x21436: '',  # 𡐶
    # 0x21437: '',  # 𡐷
    # 0x21438: '',  # 𡐸
    # 0x21439: '',  # 𡐹
    # 0x2143A: '',  # 𡐺
    # 0x2143B: '',  # 𡐻
    # 0x2143C: '',  # 𡐼
    # 0x2143D: '',  # 𡐽
    # 0x2143E: '',  # 𡐾
    0x2143F: 'dā,da',  # 𡐿
    0x21440: 'yě,shù',  # 𡑀
    # 0x21441: '',  # 𡑁
    # 0x21442: '',  # 𡑂
    # 0x21443: '',  # 𡑃
    0x21444: 'zhǎng',  # 𡑄
    # 0x21445: '',  # 𡑅
    0x21446: 'liáng',  # 𡑆
    # 0x21447: '',  # 𡑇
    0x21448: 'duǐ',  # 𡑈
    # 0x21449: '',  # 𡑉
    # 0x2144A: '',  # 𡑊
    # 0x2144B: '',  # 𡑋
    # 0x2144C: '',  # 𡑌
    0x2144D: 'láo',  # 𡑍
    0x2144E: 'xūn',  # 𡑎
    # 0x2144F: '',  # 𡑏
    # 0x21450: '',  # 𡑐
    # 0x21451: '',  # 𡑑
    # 0x21452: '',  # 𡑒
    # 0x21453: '',  # 𡑓
    # 0x21454: '',  # 𡑔
    # 0x21455: '',  # 𡑕
    # 0x21456: '',  # 𡑖
    # 0x21457: '',  # 𡑗
    0x21458: 'zhì',  # 𡑘
    # 0x21459: '',  # 𡑙
    0x2145A: 'kū',  # 𡑚
    # 0x2145B: '',  # 𡑛
    # 0x2145C: '',  # 𡑜
    # 0x2145D: '',  # 𡑝
    0x2145E: 'suì',  # 𡑞
    0x2145F: 'wō',  # 𡑟
    # 0x21460: '',  # 𡑠
    # 0x21461: '',  # 𡑡
    0x21462: 'dié',  # 𡑢
    0x21463: 'kū',  # 𡑣
    0x21464: 'luǒ,yíng ',  # 𡑤
    # 0x21465: '',  # 𡑥
    # 0x21466: '',  # 𡑦
    # 0x21467: '',  # 𡑧
    # 0x21468: '',  # 𡑨
    # 0x21469: '',  # 𡑩
    # 0x2146A: '',  # 𡑪
    # 0x2146B: '',  # 𡑫
    # 0x2146C: '',  # 𡑬
    # 0x2146D: '',  # 𡑭
    # 0x2146E: '',  # 𡑮
    0x2146F: 'jiǎn',  # 𡑯
    # 0x21470: '',  # 𡑰
    # 0x21471: '',  # 𡑱
    # 0x21472: '',  # 𡑲
    # 0x21473: '',  # 𡑳
    # 0x21474: '',  # 𡑴
    # 0x21475: '',  # 𡑵
    0x21476: 'jiǎng',  # 𡑶
    # 0x21477: '',  # 𡑷
    # 0x21478: '',  # 𡑸
    # 0x21479: '',  # 𡑹
    # 0x2147A: '',  # 𡑺
    0x2147B: 'zhuì',  # 𡑻
    # 0x2147C: '',  # 𡑼
    0x2147D: 'shuǎng',  # 𡑽
    0x2147E: 'yú',  # 𡑾
    # 0x2147F: '',  # 𡑿
    # 0x21480: '',  # 𡒀
    0x21481: 'sà',  # 𡒁
    # 0x21482: '',  # 𡒂
    0x21483: 'yù,ào',  # 𡒃
    0x21484: 'lǎn',  # 𡒄
    # 0x21485: '',  # 𡒅
    # 0x21486: '',  # 𡒆
    # 0x21487: '',  # 𡒇
    # 0x21488: '',  # 𡒈
    # 0x21489: '',  # 𡒉
    0x2148A: 'yù',  # 𡒊
    # 0x2148B: '',  # 𡒋
    0x2148C: 'qiǎn',  # 𡒌
    0x2148D: 'jù',  # 𡒍
    # 0x2148E: '',  # 𡒎
    0x2148F: 'liè',  # 𡒏
    # 0x21490: '',  # 𡒐
    # 0x21491: '',  # 𡒑
    0x21492: 'shú',  # 𡒒
    0x21493: 'xiàn',  # 𡒓
    # 0x21494: '',  # 𡒔
    # 0x21495: '',  # 𡒕
    0x21496: 'gài',  # 𡒖
    # 0x21497: '',  # 𡒗
    # 0x21498: '',  # 𡒘
    # 0x21499: '',  # 𡒙
    # 0x2149A: '',  # 𡒚
    # 0x2149B: '',  # 𡒛
    # 0x2149C: '',  # 𡒜
    # 0x2149D: '',  # 𡒝
    # 0x2149E: '',  # 𡒞
    # 0x2149F: '',  # 𡒟
    # 0x214A0: '',  # 𡒠
    # 0x214A1: '',  # 𡒡
    0x214A2: 'tái',  # 𡒢
    # 0x214A3: '',  # 𡒣
    # 0x214A4: '',  # 𡒤
    # 0x214A5: '',  # 𡒥
    # 0x214A6: '',  # 𡒦
    0x214A7: 'tiǎn',  # 𡒧
    # 0x214A8: '',  # 𡒨
    0x214A9: 'gāo',  # 𡒩
    # 0x214AA: '',  # 𡒪
    # 0x214AB: '',  # 𡒫
    # 0x214AC: '',  # 𡒬
    # 0x214AD: '',  # 𡒭
    # 0x214AE: '',  # 𡒮
    0x214AF: 'mèng',  # 𡒯
    # 0x214B0: '',  # 𡒰
    0x214B1: 'dí',  # 𡒱
    # 0x214B2: '',  # 𡒲
    0x214B3: 'mián',  # 𡒳
    # 0x214B4: '',  # 𡒴
    # 0x214B5: '',  # 𡒵
    # 0x214B6: '',  # 𡒶
    # 0x214B7: '',  # 𡒷
    # 0x214B8: '',  # 𡒸
    # 0x214B9: '',  # 𡒹
    # 0x214BA: '',  # 𡒺
    # 0x214BB: '',  # 𡒻
    # 0x214BC: '',  # 𡒼
    # 0x214BD: '',  # 𡒽
    0x214BE: 'huī,kuì',  # 𡒾
    # 0x214BF: '',  # 𡒿
    # 0x214C0: '',  # 𡓀
    # 0x214C1: '',  # 𡓁
    # 0x214C2: '',  # 𡓂
    # 0x214C3: '',  # 𡓃
    # 0x214C4: '',  # 𡓄
    # 0x214C5: '',  # 𡓅
    # 0x214C6: '',  # 𡓆
    # 0x214C7: '',  # 𡓇
    # 0x214C8: '',  # 𡓈
    0x214C9: 'duò',  # 𡓉
    # 0x214CA: '',  # 𡓊
    # 0x214CB: '',  # 𡓋
    # 0x214CC: '',  # 𡓌
    0x214CD: 'liè',  # 𡓍
    # 0x214CE: '',  # 𡓎
    # 0x214CF: '',  # 𡓏
    # 0x214D0: '',  # 𡓐
    # 0x214D1: '',  # 𡓑
    0x214D2: 'lài',  # 𡓒
    0x214D3: 'yín,yīn',  # 𡓓
    0x214D4: 'lǎn',  # 𡓔
    # 0x214D5: '',  # 𡓕
    0x214D6: 'jiāo',  # 𡓖
    # 0x214D7: '',  # 𡓗
    0x214D8: 'huò',  # 𡓘
    # 0x214D9: '',  # 𡓙
    # 0x214DA: '',  # 𡓚
    # 0x214DB: '',  # 𡓛
    0x214DC: 'qiáng',  # 𡓜
    # 0x214DD: '',  # 𡓝
    # 0x214DE: '',  # 𡓞
    # 0x214DF: '',  # 𡓟
    # 0x214E0: '',  # 𡓠
    # 0x214E1: '',  # 𡓡
    # 0x214E2: '',  # 𡓢
    0x214E3: 'guō',  # 𡓣
    # 0x214E4: '',  # 𡓤
    # 0x214E5: '',  # 𡓥
    0x214E6: 'zhàn',  # 𡓦
    # 0x214E7: '',  # 𡓧
    # 0x214E8: '',  # 𡓨
    # 0x214E9: '',  # 𡓩
    # 0x214EA: '',  # 𡓪
    # 0x214EB: '',  # 𡓫
    # 0x214EC: '',  # 𡓬
    0x214ED: 'mǐ',  # 𡓭
    # 0x214EE: '',  # 𡓮
    # 0x214EF: '',  # 𡓯
    0x214F0: 'kuī',  # 𡓰
    # 0x214F1: '',  # 𡓱
    # 0x214F2: '',  # 𡓲
    # 0x214F3: '',  # 𡓳
    # 0x214F4: '',  # 𡓴
    # 0x214F5: '',  # 𡓵
    # 0x214F6: '',  # 𡓶
    0x214F7: 'duò',  # 𡓷
    # 0x214F8: '',  # 𡓸
    # 0x214F9: '',  # 𡓹
    # 0x214FA: '',  # 𡓺
    # 0x214FB: '',  # 𡓻
    # 0x214FC: '',  # 𡓼
    # 0x214FD: '',  # 𡓽
    # 0x214FE: '',  # 𡓾
    0x214FF: 'yín',  # 𡓿
    # 0x21500: '',  # 𡔀
    # 0x21501: '',  # 𡔁
    # 0x21502: '',  # 𡔂
    # 0x21503: '',  # 𡔃
    # 0x21504: '',  # 𡔄
    # 0x21505: '',  # 𡔅
    # 0x21506: '',  # 𡔆
    0x21507: 'lèi',  # 𡔇
    # 0x21508: '',  # 𡔈
    # 0x21509: '',  # 𡔉
    # 0x2150A: '',  # 𡔊
    # 0x2150B: '',  # 𡔋
    # 0x2150C: '',  # 𡔌
    # 0x2150D: '',  # 𡔍
    # 0x2150E: '',  # 𡔎
    # 0x2150F: '',  # 𡔏
    # 0x21510: '',  # 𡔐
    # 0x21511: '',  # 𡔑
    # 0x21512: '',  # 𡔒
    # 0x21513: '',  # 𡔓
    # 0x21514: '',  # 𡔔
    0x21515: 'gòng',  # 𡔕
    # 0x21516: '',  # 𡔖
    # 0x21517: '',  # 𡔗
    # 0x21518: '',  # 𡔘
    # 0x21519: '',  # 𡔙
    # 0x2151A: '',  # 𡔚
    0x2151B: 'tǐng',  # 𡔛
    0x2151C: 'yáo',  # 𡔜
    # 0x2151D: '',  # 𡔝
    0x2151E: 'wǎng',  # 𡔞
    # 0x2151F: '',  # 𡔟
    # 0x21520: '',  # 𡔠
    # 0x21521: '',  # 𡔡
    0x21522: 'jié',  # 𡔢
    0x21523: 'jié,qiè',  # 𡔣
    # 0x21524: '',  # 𡔤
    # 0x21525: '',  # 𡔥
    # 0x21526: '',  # 𡔦
    # 0x21527: '',  # 𡔧
    0x21528: 'xiū',  # 𡔨
    # 0x21529: '',  # 𡔩
    0x2152A: 'shù',  # 𡔪
    # 0x2152B: '',  # 𡔫
    # 0x2152C: '',  # 𡔬
    # 0x2152D: '',  # 𡔭
    # 0x2152E: '',  # 𡔮
    # 0x2152F: '',  # 𡔯
    # 0x21530: '',  # 𡔰
    0x21531: 'wèi',  # 𡔱
    # 0x21532: '',  # 𡔲
    # 0x21533: '',  # 𡔳
    0x21534: 'yù',  # 𡔴
    # 0x21535: '',  # 𡔵
    # 0x21536: '',  # 𡔶
    # 0x21537: '',  # 𡔷
    # 0x21538: '',  # 𡔸
    # 0x21539: '',  # 𡔹
    # 0x2153A: '',  # 𡔺
    # 0x2153B: '',  # 𡔻
    # 0x2153C: '',  # 𡔼
    # 0x2153D: '',  # 𡔽
    # 0x2153E: '',  # 𡔾
    # 0x2153F: '',  # 𡔿
    # 0x21540: '',  # 𡕀
    0x21541: 'zhān',  # 𡕁
    # 0x21542: '',  # 𡕂
    # 0x21543: '',  # 𡕃
    0x21544: 'yī',  # 𡕄
    # 0x21545: '',  # 𡕅
    # 0x21546: '',  # 𡕆
    # 0x21547: '',  # 𡕇
    # 0x21548: '',  # 𡕈
    0x21549: 'āng',  # 𡕉
    # 0x2154A: '',  # 𡕊
    # 0x2154B: '',  # 𡕋
    # 0x2154C: '',  # 𡕌
    # 0x2154D: '',  # 𡕍
    # 0x2154E: '',  # 𡕎
    0x2154F: 'sǎng',  # 𡕏
    0x21550: 'chóu',  # 𡕐
    # 0x21551: '',  # 𡕑
    0x21552: 'kuà',  # 𡕒
    # 0x21553: '',  # 𡕓
    # 0x21554: '',  # 𡕔
    # 0x21555: '',  # 𡕕
    0x21556: 'jǔ,féng',  # 𡕖
    0x21557: 'hài',  # 𡕗
    # 0x21558: '',  # 𡕘
    # 0x21559: '',  # 𡕙
    # 0x2155A: '',  # 𡕚
    # 0x2155B: '',  # 𡕛
    # 0x2155C: '',  # 𡕜
    # 0x2155D: '',  # 𡕝
    # 0x2155E: '',  # 𡕞
    # 0x2155F: '',  # 𡕟
    # 0x21560: '',  # 𡕠
    # 0x21561: '',  # 𡕡
    0x21562: 'miǎn,mǎn',  # 𡕢
    # 0x21563: '',  # 𡕣
    # 0x21564: '',  # 𡕤
    0x21565: 'xuè',  # 𡕥
    # 0x21566: '',  # 𡕦
    0x21567: 'hàng',  # 𡕧
    0x21568: 'fú',  # 𡕨
    # 0x21569: '',  # 𡕩
    0x2156A: 'chóu',  # 𡕪
    # 0x2156B: '',  # 𡕫
    # 0x2156C: '',  # 𡕬
    # 0x2156D: '',  # 𡕭
    0x2156E: 'líng',  # 𡕮
    # 0x2156F: '',  # 𡕯
    0x21570: 'zōng',  # 𡕰
    # 0x21571: '',  # 𡕱
    # 0x21572: '',  # 𡕲
    # 0x21573: '',  # 𡕳
    # 0x21574: '',  # 𡕴
    # 0x21575: '',  # 𡕵
    # 0x21576: '',  # 𡕶
    # 0x21577: '',  # 𡕷
    # 0x21578: '',  # 𡕸
    # 0x21579: '',  # 𡕹
    # 0x2157A: '',  # 𡕺
    # 0x2157B: '',  # 𡕻
    # 0x2157C: '',  # 𡕼
    # 0x2157D: '',  # 𡕽
    # 0x2157E: '',  # 𡕾
    # 0x2157F: '',  # 𡕿
    # 0x21580: '',  # 𡖀
    # 0x21581: '',  # 𡖁
    # 0x21582: '',  # 𡖂
    # 0x21583: '',  # 𡖃
    # 0x21584: '',  # 𡖄
    # 0x21585: '',  # 𡖅
    # 0x21586: '',  # 𡖆
    # 0x21587: '',  # 𡖇
    # 0x21588: '',  # 𡖈
    0x21589: 'kūn',  # 𡖉
    0x2158A: 'sù',  # 𡖊
    # 0x2158B: '',  # 𡖋
    0x2158C: 'zhōng',  # 𡖌
    # 0x2158D: '',  # 𡖍
    0x2158E: 'zhāo',  # 𡖎
    # 0x2158F: '',  # 𡖏
    0x21590: 'diě',  # 𡖐
    0x21591: 'gǒu',  # 𡖑
    0x21592: 'yún',  # 𡖒
    0x21593: 'dān',  # 𡖓
    0x21594: 'nuǒ',  # 𡖔
    # 0x21595: '',  # 𡖕
    # 0x21596: '',  # 𡖖
    0x21597: 'niǎo',  # 𡖗
    # 0x21598: '',  # 𡖘
    # 0x21599: '',  # 𡖙
    # 0x2159A: '',  # 𡖚
    0x2159B: 'bǐng',  # 𡖛
    # 0x2159C: '',  # 𡖜
    0x2159D: 'rán',  # 𡖝
    0x2159E: 'chān',  # 𡖞
    # 0x2159F: '',  # 𡖟
    # 0x215A0: '',  # 𡖠
    # 0x215A1: '',  # 𡖡
    0x215A2: 'rǒng',  # 𡖢
    0x215A3: 'yīn',  # 𡖣
    0x215A4: 'chān',  # 𡖤
    # 0x215A5: '',  # 𡖥
    # 0x215A6: '',  # 𡖦
    0x215A7: 'zhì',  # 𡖧
    # 0x215A8: '',  # 𡖨
    # 0x215A9: '',  # 𡖩
    0x215AA: 'guài',  # 𡖪
    0x215AB: 'nuó',  # 𡖫
    0x215AC: 'shēn',  # 𡖬
    # 0x215AD: '',  # 𡖭
    # 0x215AE: '',  # 𡖮
    0x215AF: 'sù',  # 𡖯
    # 0x215B0: '',  # 𡖰
    # 0x215B1: '',  # 𡖱
    0x215B2: 'wǒ',  # 𡖲
    0x215B3: 'chǐ',  # 𡖳
    # 0x215B4: '',  # 𡖴
    # 0x215B5: '',  # 𡖵
    0x215B6: 'mò',  # 𡖶
    # 0x215B7: '',  # 𡖷
    # 0x215B8: '',  # 𡖸
    # 0x215B9: '',  # 𡖹
    0x215BA: 'miè',  # 𡖺
    0x215BB: 'zhí',  # 𡖻
    # 0x215BC: '',  # 𡖼
    # 0x215BD: '',  # 𡖽
    0x215BE: 'qī',  # 𡖾
    # 0x215BF: '',  # 𡖿
    # 0x215C0: '',  # 𡗀
    0x215C1: 'gōu',  # 𡗁
    # 0x215C2: '',  # 𡗂
    # 0x215C3: '',  # 𡗃
    # 0x215C4: '',  # 𡗄
    # 0x215C5: '',  # 𡗅
    0x215C6: 'lǒu',  # 𡗆
    # 0x215C7: '',  # 𡗇
    0x215C8: 'zī',  # 𡗈
    # 0x215C9: '',  # 𡗉
    # 0x215CA: '',  # 𡗊
    # 0x215CB: '',  # 𡗋
    # 0x215CC: '',  # 𡗌
    0x215CD: 'dǎng',  # 𡗍
    # 0x215CE: '',  # 𡗎
    0x215CF: 'xiǎn',  # 𡗏
    # 0x215D0: '',  # 𡗐
    0x215D1: 'rǒu',  # 𡗑
    # 0x215D2: '',  # 𡗒
    # 0x215D3: '',  # 𡗓
    0x215D4: 'tài',  # 𡗔
    # 0x215D5: '',  # 𡗕
    # 0x215D6: '',  # 𡗖
    0x215D7: 'pěng',  # 𡗗
    # 0x215D8: '',  # 𡗘
    # 0x215D9: '',  # 𡗙
    # 0x215DA: '',  # 𡗚
    # 0x215DB: '',  # 𡗛
    # 0x215DC: '',  # 𡗜
    # 0x215DD: '',  # 𡗝
    0x215DE: 'xī',  # 𡗞
    # 0x215DF: '',  # 𡗟
    # 0x215E0: '',  # 𡗠
    # 0x215E1: '',  # 𡗡
    0x215E2: 'kuā,běn',  # 𡗢
    # 0x215E3: '',  # 𡗣
    0x215E4: 'guì',  # 𡗤
    0x215E5: 'chún',  # 𡗥
    0x215E6: 'jiè',  # 𡗦
    # 0x215E7: '',  # 𡗧
    # 0x215E8: '',  # 𡗨
    # 0x215E9: '',  # 𡗩
    # 0x215EA: '',  # 𡗪
    # 0x215EB: '',  # 𡗫
    # 0x215EC: '',  # 𡗬
    # 0x215ED: '',  # 𡗭
    # 0x215EE: '',  # 𡗮
    # 0x215EF: '',  # 𡗯
    # 0x215F0: '',  # 𡗰
    # 0x215F1: '',  # 𡗱
    0x215F2: 'jiè,bēn',  # 𡗲
    0x215F3: 'xī',  # 𡗳
    # 0x215F4: '',  # 𡗴
    0x215F5: 'kū',  # 𡗵
    # 0x215F6: '',  # 𡗶
    0x215F7: 'gū',  # 𡗷
    0x215F8: 'zhà,kuā',  # 𡗸
    0x215F9: 'fàn',  # 𡗹
    # 0x215FA: '',  # 𡗺
    # 0x215FB: '',  # 𡗻
    0x215FC: 'xiè',  # 𡗼
    # 0x215FD: '',  # 𡗽
    # 0x215FE: '',  # 𡗾
    # 0x215FF: '',  # 𡗿
    # 0x21600: '',  # 𡘀
    # 0x21601: '',  # 𡘁
    # 0x21602: '',  # 𡘂
    # 0x21603: '',  # 𡘃
    # 0x21604: '',  # 𡘄
    # 0x21605: '',  # 𡘅
    # 0x21606: '',  # 𡘆
    # 0x21607: '',  # 𡘇
    # 0x21608: '',  # 𡘈
    # 0x21609: '',  # 𡘉
    # 0x2160A: '',  # 𡘊
    # 0x2160B: '',  # 𡘋
    # 0x2160C: '',  # 𡘌
    0x2160D: 'huán,qié',  # 𡘍
    # 0x2160E: '',  # 𡘎
    0x2160F: 'niǎo',  # 𡘏
    0x21610: 'xì',  # 𡘐
    # 0x21611: '',  # 𡘑
    # 0x21612: '',  # 𡘒
    # 0x21613: '',  # 𡘓
    # 0x21614: '',  # 𡘔
    # 0x21615: '',  # 𡘕
    # 0x21616: '',  # 𡘖
    # 0x21617: '',  # 𡘗
    # 0x21618: '',  # 𡘘
    # 0x21619: '',  # 𡘙
    # 0x2161A: '',  # 𡘚
    0x2161B: 'cū',  # 𡘛
    # 0x2161C: '',  # 𡘜
    0x2161D: 'gǔn',  # 𡘝
    # 0x2161E: '',  # 𡘞
    # 0x2161F: '',  # 𡘟
    # 0x21620: '',  # 𡘠
    0x21621: 'xī',  # 𡘡
    # 0x21622: '',  # 𡘢
    # 0x21623: '',  # 𡘣
    # 0x21624: '',  # 𡘤
    # 0x21625: '',  # 𡘥
    # 0x21626: '',  # 𡘦
    0x21627: 'qiá',  # 𡘧
    # 0x21628: '',  # 𡘨
    # 0x21629: '',  # 𡘩
    0x2162A: 'māng',  # 𡘪
    # 0x2162B: '',  # 𡘫
    # 0x2162C: '',  # 𡘬
    0x2162D: 'zhé',  # 𡘭
    # 0x2162E: '',  # 𡘮
    # 0x2162F: '',  # 𡘯
    0x21630: 'juàn',  # 𡘰
    # 0x21631: '',  # 𡘱
    # 0x21632: '',  # 𡘲
    # 0x21633: '',  # 𡘳
    0x21634: 'biē',  # 𡘴
    # 0x21635: '',  # 𡘵
    # 0x21636: '',  # 𡘶
    # 0x21637: '',  # 𡘷
    # 0x21638: '',  # 𡘸
    # 0x21639: '',  # 𡘹
    # 0x2163A: '',  # 𡘺
    # 0x2163B: '',  # 𡘻
    # 0x2163C: '',  # 𡘼
    # 0x2163D: '',  # 𡘽
    # 0x2163E: '',  # 𡘾
    # 0x2163F: '',  # 𡘿
    0x21640: 'biē',  # 𡙀
    # 0x21641: '',  # 𡙁
    # 0x21642: '',  # 𡙂
    # 0x21643: '',  # 𡙃
    # 0x21644: '',  # 𡙄
    0x21645: 'quán',  # 𡙅
    # 0x21646: '',  # 𡙆
    # 0x21647: '',  # 𡙇
    # 0x21648: '',  # 𡙈
    # 0x21649: '',  # 𡙉
    # 0x2164A: '',  # 𡙊
    0x2164B: 'xì',  # 𡙋
    # 0x2164C: '',  # 𡙌
    # 0x2164D: '',  # 𡙍
    0x2164E: 'jiǎo,miǎo',  # 𡙎
    # 0x2164F: '',  # 𡙏
    0x21650: 'quán',  # 𡙐
    0x21651: 'zhǐ',  # 𡙑
    0x21652: 'tiān',  # 𡙒
    0x21653: 'kāi',  # 𡙓
    # 0x21654: '',  # 𡙔
    # 0x21655: '',  # 𡙕
    # 0x21656: '',  # 𡙖
    # 0x21657: '',  # 𡙗
    0x21658: 'sǎn,yì',  # 𡙘
    # 0x21659: '',  # 𡙙
    # 0x2165A: '',  # 𡙚
    0x2165B: 'zī',  # 𡙛
    # 0x2165C: '',  # 𡙜
    # 0x2165D: '',  # 𡙝
    # 0x2165E: '',  # 𡙞
    # 0x2165F: '',  # 𡙟
    # 0x21660: '',  # 𡙠
    # 0x21661: '',  # 𡙡
    # 0x21662: '',  # 𡙢
    0x21663: 'jié',  # 𡙣
    # 0x21664: '',  # 𡙤
    # 0x21665: '',  # 𡙥
    # 0x21666: '',  # 𡙦
    # 0x21667: '',  # 𡙧
    # 0x21668: '',  # 𡙨
    # 0x21669: '',  # 𡙩
    0x2166A: 'bié',  # 𡙪
    # 0x2166B: '',  # 𡙫
    0x2166C: 'dòu',  # 𡙬
    0x2166D: 'zuī',  # 𡙭
    # 0x2166E: '',  # 𡙮
    # 0x2166F: '',  # 𡙯
    # 0x21670: '',  # 𡙰
    # 0x21671: '',  # 𡙱
    # 0x21672: '',  # 𡙲
    0x21673: 'jú',  # 𡙳
    # 0x21674: '',  # 𡙴
    # 0x21675: '',  # 𡙵
    0x21676: 'yǎn',  # 𡙶
    # 0x21677: '',  # 𡙷
    # 0x21678: '',  # 𡙸
    # 0x21679: '',  # 𡙹
    # 0x2167A: '',  # 𡙺
    # 0x2167B: '',  # 𡙻
    # 0x2167C: '',  # 𡙼
    # 0x2167D: '',  # 𡙽
    # 0x2167E: '',  # 𡙾
    # 0x2167F: '',  # 𡙿
    # 0x21680: '',  # 𡚀
    0x21681: 'bì',  # 𡚁
    # 0x21682: '',  # 𡚂
    # 0x21683: '',  # 𡚃
    # 0x21684: '',  # 𡚄
    0x21685: 'kuǎi',  # 𡚅
    # 0x21686: '',  # 𡚆
    0x21687: 'yàn',  # 𡚇
    0x21688: 'wéi',  # 𡚈
    # 0x21689: '',  # 𡚉
    0x2168A: 'huān',  # 𡚊
    # 0x2168B: '',  # 𡚋
    0x2168C: 'hào',  # 𡚌
    0x2168D: 'lián',  # 𡚍
    # 0x2168E: '',  # 𡚎
    # 0x2168F: '',  # 𡚏
    # 0x21690: '',  # 𡚐
    0x21691: 'gōng',  # 𡚑
    # 0x21692: '',  # 𡚒
    # 0x21693: '',  # 𡚓
    0x21694: 'méng',  # 𡚔
    # 0x21695: '',  # 𡚕
    # 0x21696: '',  # 𡚖
    0x21697: 'lěi',  # 𡚗
    # 0x21698: '',  # 𡚘
    0x21699: 'dì',  # 𡚙
    # 0x2169A: '',  # 𡚚
    0x2169B: 'bǐng',  # 𡚛
    0x2169C: 'huān,kàn',  # 𡚜
    # 0x2169D: '',  # 𡚝
    # 0x2169E: '',  # 𡚞
    0x2169F: 'wā',  # 𡚟
    0x216A0: 'jué',  # 𡚠
    # 0x216A1: '',  # 𡚡
    # 0x216A2: '',  # 𡚢
    # 0x216A3: '',  # 𡚣
    0x216A4: 'bì',  # 𡚤
    # 0x216A5: '',  # 𡚥
    0x216A6: 'jī',  # 𡚦
    # 0x216A7: '',  # 𡚧
    0x216A8: 'chì',  # 𡚨
    # 0x216A9: '',  # 𡚩
    # 0x216AA: '',  # 𡚪
    # 0x216AB: '',  # 𡚫
    # 0x216AC: '',  # 𡚬
    0x216AD: 'bā',  # 𡚭
    0x216AE: 'jiǔ',  # 𡚮
    # 0x216AF: '',  # 𡚯
    # 0x216B0: '',  # 𡚰
    # 0x216B1: '',  # 𡚱
    # 0x216B2: '',  # 𡚲
    # 0x216B3: '',  # 𡚳
    # 0x216B4: '',  # 𡚴
    # 0x216B5: '',  # 𡚵
    # 0x216B6: '',  # 𡚶
    0x216B7: 'dì',  # 𡚷
    0x216B8: 'yāo',  # 𡚸
    0x216B9: 'zhàng',  # 𡚹
    # 0x216BA: '',  # 𡚺
    0x216BB: 'dà',  # 𡚻
    0x216BC: 'shí',  # 𡚼
    0x216BD: 'hào',  # 𡚽
    0x216BE: 'shū',  # 𡚾
    # 0x216BF: '',  # 𡚿
    # 0x216C0: '',  # 𡛀
    # 0x216C1: '',  # 𡛁
    # 0x216C2: '',  # 𡛂
    # 0x216C3: '',  # 𡛃
    # 0x216C4: '',  # 𡛄
    # 0x216C5: '',  # 𡛅
    # 0x216C6: '',  # 𡛆
    # 0x216C7: '',  # 𡛇
    # 0x216C8: '',  # 𡛈
    # 0x216C9: '',  # 𡛉
    # 0x216CA: '',  # 𡛊
    # 0x216CB: '',  # 𡛋
    0x216CC: 'yè',  # 𡛌
    # 0x216CD: '',  # 𡛍
    # 0x216CE: '',  # 𡛎
    # 0x216CF: '',  # 𡛏
    # 0x216D0: '',  # 𡛐
    # 0x216D1: '',  # 𡛑
    # 0x216D2: '',  # 𡛒
    # 0x216D3: '',  # 𡛓
    # 0x216D4: '',  # 𡛔
    # 0x216D5: '',  # 𡛕
    # 0x216D6: '',  # 𡛖
    0x216D7: 'bì',  # 𡛗
    0x216D8: 'pǐ',  # 𡛘
    0x216D9: 'yǎo,yāo',  # 𡛙
    # 0x216DA: '',  # 𡛚
    # 0x216DB: '',  # 𡛛
    0x216DC: 'dī',  # 𡛜
    0x216DD: 'càn',  # 𡛝
    0x216DE: 'pín',  # 𡛞
    0x216DF: 'yuè',  # 𡛟
    0x216E0: 'qiē',  # 𡛠
    0x216E1: 'pī',  # 𡛡
    # 0x216E2: '',  # 𡛢
    # 0x216E3: '',  # 𡛣
    # 0x216E4: '',  # 𡛤
    # 0x216E5: '',  # 𡛥
    # 0x216E6: '',  # 𡛦
    # 0x216E7: '',  # 𡛧
    # 0x216E8: '',  # 𡛨
    # 0x216E9: '',  # 𡛩
    # 0x216EA: '',  # 𡛪
    # 0x216EB: '',  # 𡛫
    # 0x216EC: '',  # 𡛬
    # 0x216ED: '',  # 𡛭
    # 0x216EE: '',  # 𡛮
    # 0x216EF: '',  # 𡛯
    0x216F0: 'zhí',  # 𡛰
    # 0x216F1: '',  # 𡛱
    # 0x216F2: '',  # 𡛲
    # 0x216F3: '',  # 𡛳
    # 0x216F4: '',  # 𡛴
    0x216F5: 'tuǒ',  # 𡛵
    0x216F6: 'xiè',  # 𡛶
    # 0x216F7: '',  # 𡛷
    # 0x216F8: '',  # 𡛸
    # 0x216F9: '',  # 𡛹
    # 0x216FA: '',  # 𡛺
    # 0x216FB: '',  # 𡛻
    # 0x216FC: '',  # 𡛼
    0x216FD: 'yè',  # 𡛽
    # 0x216FE: '',  # 𡛾
    # 0x216FF: '',  # 𡛿
    0x21700: 'fàn',  # 𡜀
    0x21701: 'guā',  # 𡜁
    0x21702: 'hù',  # 𡜂
    0x21703: 'rǔ',  # 𡜃
    # 0x21704: '',  # 𡜄
    # 0x21705: '',  # 𡜅
    # 0x21706: '',  # 𡜆
    # 0x21707: '',  # 𡜇
    # 0x21708: '',  # 𡜈
    0x21709: 'rǎn,ràn',  # 𡜉
    0x2170A: 'fǒu',  # 𡜊
    0x2170B: 'huāng',  # 𡜋
    # 0x2170C: '',  # 𡜌
    # 0x2170D: '',  # 𡜍
    # 0x2170E: '',  # 𡜎
    # 0x2170F: '',  # 𡜏
    # 0x21710: '',  # 𡜐
    # 0x21711: '',  # 𡜑
    # 0x21712: '',  # 𡜒
    # 0x21713: '',  # 𡜓
    # 0x21714: '',  # 𡜔
    # 0x21715: '',  # 𡜕
    # 0x21716: '',  # 𡜖
    # 0x21717: '',  # 𡜗
    # 0x21718: '',  # 𡜘
    # 0x21719: '',  # 𡜙
    0x2171A: 'rú',  # 𡜚
    # 0x2171B: '',  # 𡜛
    # 0x2171C: '',  # 𡜜
    0x2171D: 'dòng',  # 𡜝
    # 0x2171E: '',  # 𡜞
    # 0x2171F: '',  # 𡜟
    # 0x21720: '',  # 𡜠
    # 0x21721: '',  # 𡜡
    0x21722: 'mǎo',  # 𡜢
    # 0x21723: '',  # 𡜣
    # 0x21724: '',  # 𡜤
    0x21725: 'duī',  # 𡜥
    0x21726: 'huì',  # 𡜦
    0x21727: 'xì',  # 𡜧
    0x21728: 'xiū',  # 𡜨
    # 0x21729: '',  # 𡜩
    0x2172A: 'nǎo',  # 𡜪
    0x2172B: 'rǎn',  # 𡜫
    0x2172C: 'yī',  # 𡜬
    # 0x2172D: '',  # 𡜭
    # 0x2172E: '',  # 𡜮
    0x2172F: 'zhé',  # 𡜯
    # 0x21730: '',  # 𡜰
    0x21731: 'jì',  # 𡜱
    0x21732: 'gào',  # 𡜲
    0x21733: 'yòu',  # 𡜳
    # 0x21734: '',  # 𡜴
    0x21735: 'pū',  # 𡜵
    # 0x21736: '',  # 𡜶
    # 0x21737: '',  # 𡜷
    # 0x21738: '',  # 𡜸
    # 0x21739: '',  # 𡜹
    # 0x2173A: '',  # 𡜺
    # 0x2173B: '',  # 𡜻
    # 0x2173C: '',  # 𡜼
    # 0x2173D: '',  # 𡜽
    # 0x2173E: '',  # 𡜾
    0x2173F: 'mǔ',  # 𡜿
    # 0x21740: '',  # 𡝀
    # 0x21741: '',  # 𡝁
    # 0x21742: '',  # 𡝂
    # 0x21743: '',  # 𡝃
    # 0x21744: '',  # 𡝄
    # 0x21745: '',  # 𡝅
    # 0x21746: '',  # 𡝆
    # 0x21747: '',  # 𡝇
    0x21748: 'chù',  # 𡝈
    0x21749: 'cū',  # 𡝉
    0x2174A: 'zhé',  # 𡝊
    0x2174B: 'niǎo',  # 𡝋
    # 0x2174C: '',  # 𡝌
    0x2174D: 'qiè',  # 𡝍
    # 0x2174E: '',  # 𡝎
    0x2174F: 'pín',  # 𡝏
    0x21750: 'chá',  # 𡝐
    # 0x21751: '',  # 𡝑
    0x21752: 'niǎo',  # 𡝒
    0x21753: 'suī',  # 𡝓
    # 0x21754: '',  # 𡝔
    # 0x21755: '',  # 𡝕
    # 0x21756: '',  # 𡝖
    0x21757: 'qún',  # 𡝗
    # 0x21758: '',  # 𡝘
    0x21759: 'chá',  # 𡝙
    0x2175A: 'chéng',  # 𡝚
    0x2175B: 'yáo',  # 𡝛
    0x2175C: 'dù',  # 𡝜
    0x2175D: 'wāng',  # 𡝝
    # 0x2175E: '',  # 𡝞
    0x2175F: 'niàn',  # 𡝟
    # 0x21760: '',  # 𡝠
    # 0x21761: '',  # 𡝡
    # 0x21762: '',  # 𡝢
    # 0x21763: '',  # 𡝣
    # 0x21764: '',  # 𡝤
    # 0x21765: '',  # 𡝥
    0x21766: 'nǒu',  # 𡝦
    0x21767: 'xì',  # 𡝧
    # 0x21768: '',  # 𡝨
    0x21769: 'yāo',  # 𡝩
    # 0x2176A: '',  # 𡝪
    0x2176B: 'chān',  # 𡝫
    # 0x2176C: '',  # 𡝬
    # 0x2176D: '',  # 𡝭
    # 0x2176E: '',  # 𡝮
    # 0x2176F: '',  # 𡝯
    # 0x21770: '',  # 𡝰
    # 0x21771: '',  # 𡝱
    # 0x21772: '',  # 𡝲
    # 0x21773: '',  # 𡝳
    # 0x21774: '',  # 𡝴
    # 0x21775: '',  # 𡝵
    # 0x21776: '',  # 𡝶
    # 0x21777: '',  # 𡝷
    # 0x21778: '',  # 𡝸
    # 0x21779: '',  # 𡝹
    # 0x2177A: '',  # 𡝺
    # 0x2177B: '',  # 𡝻
    # 0x2177C: '',  # 𡝼
    # 0x2177D: '',  # 𡝽
    # 0x2177E: '',  # 𡝾
    # 0x2177F: '',  # 𡝿
    # 0x21780: '',  # 𡞀
    # 0x21781: '',  # 𡞁
    # 0x21782: '',  # 𡞂
    # 0x21783: '',  # 𡞃
    # 0x21784: '',  # 𡞄
    # 0x21785: '',  # 𡞅
    # 0x21786: '',  # 𡞆
    # 0x21787: '',  # 𡞇
    # 0x21788: '',  # 𡞈
    # 0x21789: '',  # 𡞉
    # 0x2178A: '',  # 𡞊
    # 0x2178B: '',  # 𡞋
    # 0x2178C: '',  # 𡞌
    # 0x2178D: '',  # 𡞍
    # 0x2178E: '',  # 𡞎
    0x2178F: 'nài',  # 𡞏
    # 0x21790: '',  # 𡞐
    # 0x21791: '',  # 𡞑
    # 0x21792: '',  # 𡞒
    # 0x21793: '',  # 𡞓
    # 0x21794: '',  # 𡞔
    # 0x21795: '',  # 𡞕
    # 0x21796: '',  # 𡞖
    # 0x21797: '',  # 𡞗
    0x21798: 'xiè',  # 𡞘
    0x21799: 'miè',  # 𡞙
    0x2179A: 'kěng',  # 𡞚
    # 0x2179B: '',  # 𡞛
    0x2179C: 'cù',  # 𡞜
    # 0x2179D: '',  # 𡞝
    0x2179E: 'shěng',  # 𡞞
    0x2179F: 'pàn',  # 𡞟
    0x217A0: 'hù',  # 𡞠
    # 0x217A1: '',  # 𡞡
    0x217A2: 'kè',  # 𡞢
    0x217A3: 'xiàn',  # 𡞣
    # 0x217A4: '',  # 𡞤
    0x217A5: 'hóu',  # 𡞥
    0x217A6: 'qióng',  # 𡞦
    0x217A7: 'zōng',  # 𡞧
    # 0x217A8: '',  # 𡞨
    # 0x217A9: '',  # 𡞩
    0x217AA: 'fú',  # 𡞪
    0x217AB: 'nài',  # 𡞫
    # 0x217AC: '',  # 𡞬
    0x217AD: 'nì',  # 𡞭
    # 0x217AE: '',  # 𡞮
    0x217AF: 'kǔ',  # 𡞯
    # 0x217B0: '',  # 𡞰
    # 0x217B1: '',  # 𡞱
    # 0x217B2: '',  # 𡞲
    # 0x217B3: '',  # 𡞳
    # 0x217B4: '',  # 𡞴
    # 0x217B5: '',  # 𡞵
    # 0x217B6: '',  # 𡞶
    # 0x217B7: '',  # 𡞷
    # 0x217B8: '',  # 𡞸
    # 0x217B9: '',  # 𡞹
    # 0x217BA: '',  # 𡞺
    # 0x217BB: '',  # 𡞻
    # 0x217BC: '',  # 𡞼
    # 0x217BD: '',  # 𡞽
    0x217BE: 'nèn',  # 𡞾
    # 0x217BF: '',  # 𡞿
    # 0x217C0: '',  # 𡟀
    # 0x217C1: '',  # 𡟁
    # 0x217C2: '',  # 𡟂
    # 0x217C3: '',  # 𡟃
    # 0x217C4: '',  # 𡟄
    # 0x217C5: '',  # 𡟅
    # 0x217C6: '',  # 𡟆
    # 0x217C7: '',  # 𡟇
    # 0x217C8: '',  # 𡟈
    # 0x217C9: '',  # 𡟉
    # 0x217CA: '',  # 𡟊
    # 0x217CB: '',  # 𡟋
    # 0x217CC: '',  # 𡟌
    0x217CD: 'gē',  # 𡟍
    # 0x217CE: '',  # 𡟎
    # 0x217CF: '',  # 𡟏
    # 0x217D0: '',  # 𡟐
    0x217D1: 'hóu',  # 𡟑
    # 0x217D2: '',  # 𡟒
    0x217D3: 'āi',  # 𡟓
    # 0x217D4: '',  # 𡟔
    0x217D5: 'shī',  # 𡟕
    # 0x217D6: '',  # 𡟖
    # 0x217D7: '',  # 𡟗
    # 0x217D8: '',  # 𡟘
    # 0x217D9: '',  # 𡟙
    # 0x217DA: '',  # 𡟚
    # 0x217DB: '',  # 𡟛
    # 0x217DC: '',  # 𡟜
    # 0x217DD: '',  # 𡟝
    0x217DE: 'xiū',  # 𡟞
    0x217DF: 'cōng',  # 𡟟
    0x217E0: 'jiāo',  # 𡟠
    # 0x217E1: '',  # 𡟡
    0x217E2: 'zhá',  # 𡟢
    0x217E3: 'xiāo',  # 𡟣
    0x217E4: 'liàn',  # 𡟤
    0x217E5: 'qǔ',  # 𡟥
    # 0x217E6: '',  # 𡟦
    # 0x217E7: '',  # 𡟧
    0x217E8: 'shǎn',  # 𡟨
    0x217E9: 'xiè',  # 𡟩
    # 0x217EA: '',  # 𡟪
    0x217EB: 'gòng',  # 𡟫
    0x217EC: 'miè',  # 𡟬
    0x217ED: 'chái',  # 𡟭
    # 0x217EE: '',  # 𡟮
    0x217EF: 'ēn',  # 𡟯
    0x217F0: 'wǎn',  # 𡟰
    # 0x217F1: '',  # 𡟱
    # 0x217F2: '',  # 𡟲
    0x217F3: 'dòu',  # 𡟳
    # 0x217F4: '',  # 𡟴
    # 0x217F5: '',  # 𡟵
    # 0x217F6: '',  # 𡟶
    # 0x217F7: '',  # 𡟷
    # 0x217F8: '',  # 𡟸
    # 0x217F9: '',  # 𡟹
    # 0x217FA: '',  # 𡟺
    # 0x217FB: '',  # 𡟻
    # 0x217FC: '',  # 𡟼
    # 0x217FD: '',  # 𡟽
    # 0x217FE: '',  # 𡟾
    # 0x217FF: '',  # 𡟿
    # 0x21800: '',  # 𡠀
    # 0x21801: '',  # 𡠁
    # 0x21802: '',  # 𡠂
    # 0x21803: '',  # 𡠃
    # 0x21804: '',  # 𡠄
    # 0x21805: '',  # 𡠅
    0x21806: 'kòu',  # 𡠆
    # 0x21807: '',  # 𡠇
    # 0x21808: '',  # 𡠈
    0x21809: 'lí',  # 𡠉
    0x2180A: 'tiáo',  # 𡠊
    0x2180B: 'shī',  # 𡠋
    # 0x2180C: '',  # 𡠌
    # 0x2180D: '',  # 𡠍
    # 0x2180E: '',  # 𡠎
    0x2180F: 'sāng',  # 𡠏
    # 0x21810: '',  # 𡠐
    # 0x21811: '',  # 𡠑
    0x21812: 'guān',  # 𡠒
    # 0x21813: '',  # 𡠓
    # 0x21814: '',  # 𡠔
    # 0x21815: '',  # 𡠕
    0x21816: 'hào',  # 𡠖
    0x21817: 'zhì',  # 𡠗
    0x21818: 'yàng',  # 𡠘
    0x21819: 'tōng',  # 𡠙
    0x2181A: 'bì',  # 𡠚
    # 0x2181B: '',  # 𡠛
    0x2181C: 'mó,mò',  # 𡠜
    # 0x2181D: '',  # 𡠝
    0x2181E: 'fú',  # 𡠞
    # 0x2181F: '',  # 𡠟
    # 0x21820: '',  # 𡠠
    # 0x21821: '',  # 𡠡
    # 0x21822: '',  # 𡠢
    # 0x21823: '',  # 𡠣
    # 0x21824: '',  # 𡠤
    0x21825: 'qiáng',  # 𡠥
    # 0x21826: '',  # 𡠦
    # 0x21827: '',  # 𡠧
    # 0x21828: '',  # 𡠨
    # 0x21829: '',  # 𡠩
    # 0x2182A: '',  # 𡠪
    # 0x2182B: '',  # 𡠫
    # 0x2182C: '',  # 𡠬
    # 0x2182D: '',  # 𡠭
    # 0x2182E: '',  # 𡠮
    # 0x2182F: '',  # 𡠯
    # 0x21830: '',  # 𡠰
    # 0x21831: '',  # 𡠱
    # 0x21832: '',  # 𡠲
    # 0x21833: '',  # 𡠳
    # 0x21834: '',  # 𡠴
    # 0x21835: '',  # 𡠵
    # 0x21836: '',  # 𡠶
    # 0x21837: '',  # 𡠷
    # 0x21838: '',  # 𡠸
    0x21839: 'zhì',  # 𡠹
    # 0x2183A: '',  # 𡠺
    # 0x2183B: '',  # 𡠻
    0x2183C: 'sōu',  # 𡠼
    # 0x2183D: '',  # 𡠽
    # 0x2183E: '',  # 𡠾
    0x2183F: 'niǎo',  # 𡠿
    0x21840: 'juàn',  # 𡡀
    # 0x21841: '',  # 𡡁
    0x21842: 'yàng',  # 𡡂
    # 0x21843: '',  # 𡡃
    0x21844: 'huāng',  # 𡡄
    # 0x21845: '',  # 𡡅
    # 0x21846: '',  # 𡡆
    # 0x21847: '',  # 𡡇
    0x21848: 'bēng',  # 𡡈
    0x21849: 'mó',  # 𡡉
    0x2184A: 'cháo',  # 𡡊
    # 0x2184B: '',  # 𡡋
    # 0x2184C: '',  # 𡡌
    # 0x2184D: '',  # 𡡍
    0x2184E: 'lǚ,lóu',  # 𡡎
    0x2184F: 'shāo',  # 𡡏
    0x21850: 'bǔ',  # 𡡐
    0x21851: 'zēng',  # 𡡑
    0x21852: 'sī,xī',  # 𡡒
    0x21853: 'xū',  # 𡡓
    0x21854: 'zuì',  # 𡡔
    0x21855: 'yuē',  # 𡡕
    0x21856: 'zān,cān',  # 𡡖
    0x21857: 'luǎn,luàn',  # 𡡗
    # 0x21858: '',  # 𡡘
    # 0x21859: '',  # 𡡙
    # 0x2185A: '',  # 𡡚
    # 0x2185B: '',  # 𡡛
    # 0x2185C: '',  # 𡡜
    # 0x2185D: '',  # 𡡝
    # 0x2185E: '',  # 𡡞
    # 0x2185F: '',  # 𡡟
    # 0x21860: '',  # 𡡠
    # 0x21861: '',  # 𡡡
    # 0x21862: '',  # 𡡢
    # 0x21863: '',  # 𡡣
    # 0x21864: '',  # 𡡤
    0x21865: 'qú',  # 𡡥
    # 0x21866: '',  # 𡡦
    # 0x21867: '',  # 𡡧
    # 0x21868: '',  # 𡡨
    # 0x21869: '',  # 𡡩
    # 0x2186A: '',  # 𡡪
    # 0x2186B: '',  # 𡡫
    # 0x2186C: '',  # 𡡬
    # 0x2186D: '',  # 𡡭
    # 0x2186E: '',  # 𡡮
    # 0x2186F: '',  # 𡡯
    # 0x21870: '',  # 𡡰
    # 0x21871: '',  # 𡡱
    # 0x21872: '',  # 𡡲
    # 0x21873: '',  # 𡡳
    # 0x21874: '',  # 𡡴
    # 0x21875: '',  # 𡡵
    # 0x21876: '',  # 𡡶
    # 0x21877: '',  # 𡡷
    # 0x21878: '',  # 𡡸
    # 0x21879: '',  # 𡡹
    0x2187A: 'miǎo',  # 𡡺
    # 0x2187B: '',  # 𡡻
    # 0x2187C: '',  # 𡡼
    # 0x2187D: '',  # 𡡽
    # 0x2187E: '',  # 𡡾
    # 0x2187F: '',  # 𡡿
    0x21880: 'zhuàn',  # 𡢀
    # 0x21881: '',  # 𡢁
    # 0x21882: '',  # 𡢂
    # 0x21883: '',  # 𡢃
    # 0x21884: '',  # 𡢄
    # 0x21885: '',  # 𡢅
    # 0x21886: '',  # 𡢆
    # 0x21887: '',  # 𡢇
    0x21888: 'dàng',  # 𡢈
    # 0x21889: '',  # 𡢉
    0x2188A: 'yuān',  # 𡢊
    # 0x2188B: '',  # 𡢋
    # 0x2188C: '',  # 𡢌
    # 0x2188D: '',  # 𡢍
    0x2188E: 'fàn',  # 𡢎
    # 0x2188F: '',  # 𡢏
    # 0x21890: '',  # 𡢐
    # 0x21891: '',  # 𡢑
    0x21892: 'jǔ',  # 𡢒
    # 0x21893: '',  # 𡢓
    # 0x21894: '',  # 𡢔
    0x21895: 'huǐ',  # 𡢕
    0x21896: 'qì',  # 𡢖
    # 0x21897: '',  # 𡢗
    0x21898: 'yùn,yíng',  # 𡢘
    # 0x21899: '',  # 𡢙
    0x2189A: 'màn',  # 𡢚
    # 0x2189B: '',  # 𡢛
    0x2189C: 'mǒ',  # 𡢜
    # 0x2189D: '',  # 𡢝
    # 0x2189E: '',  # 𡢞
    # 0x2189F: '',  # 𡢟
    # 0x218A0: '',  # 𡢠
    # 0x218A1: '',  # 𡢡
    # 0x218A2: '',  # 𡢢
    # 0x218A3: '',  # 𡢣
    # 0x218A4: '',  # 𡢤
    # 0x218A5: '',  # 𡢥
    # 0x218A6: '',  # 𡢦
    # 0x218A7: '',  # 𡢧
    # 0x218A8: '',  # 𡢨
    # 0x218A9: '',  # 𡢩
    # 0x218AA: '',  # 𡢪
    # 0x218AB: '',  # 𡢫
    # 0x218AC: '',  # 𡢬
    # 0x218AD: '',  # 𡢭
    # 0x218AE: '',  # 𡢮
    # 0x218AF: '',  # 𡢯
    # 0x218B0: '',  # 𡢰
    0x218B1: 'piāo',  # 𡢱
    # 0x218B2: '',  # 𡢲
    0x218B3: 'jìn',  # 𡢳
    # 0x218B4: '',  # 𡢴
    # 0x218B5: '',  # 𡢵
    # 0x218B6: '',  # 𡢶
    # 0x218B7: '',  # 𡢷
    # 0x218B8: '',  # 𡢸
    0x218B9: 'yāo',  # 𡢹
    # 0x218BA: '',  # 𡢺
    # 0x218BB: '',  # 𡢻
    # 0x218BC: '',  # 𡢼
    # 0x218BD: '',  # 𡢽
    # 0x218BE: '',  # 𡢾
    # 0x218BF: '',  # 𡢿
    0x218C0: 'chì',  # 𡣀
    0x218C1: 'nì',  # 𡣁
    0x218C2: 'sōu',  # 𡣂
    # 0x218C3: '',  # 𡣃
    # 0x218C4: '',  # 𡣄
    # 0x218C5: '',  # 𡣅
    # 0x218C6: '',  # 𡣆
    # 0x218C7: '',  # 𡣇
    0x218C8: 'shù',  # 𡣈
    # 0x218C9: '',  # 𡣉
    # 0x218CA: '',  # 𡣊
    0x218CB: 'piāo',  # 𡣋
    # 0x218CC: '',  # 𡣌
    # 0x218CD: '',  # 𡣍
    # 0x218CE: '',  # 𡣎
    # 0x218CF: '',  # 𡣏
    # 0x218D0: '',  # 𡣐
    # 0x218D1: '',  # 𡣑
    # 0x218D2: '',  # 𡣒
    # 0x218D3: '',  # 𡣓
    0x218D4: 'hàn',  # 𡣔
    0x218D5: 'pín',  # 𡣕
    # 0x218D6: '',  # 𡣖
    # 0x218D7: '',  # 𡣗
    # 0x218D8: '',  # 𡣘
    # 0x218D9: '',  # 𡣙
    # 0x218DA: '',  # 𡣚
    # 0x218DB: '',  # 𡣛
    # 0x218DC: '',  # 𡣜
    # 0x218DD: '',  # 𡣝
    # 0x218DE: '',  # 𡣞
    # 0x218DF: '',  # 𡣟
    0x218E0: 'yāo',  # 𡣠
    # 0x218E1: '',  # 𡣡
    0x218E2: 'néi',  # 𡣢
    # 0x218E3: '',  # 𡣣
    # 0x218E4: '',  # 𡣤
    # 0x218E5: '',  # 𡣥
    # 0x218E6: '',  # 𡣦
    # 0x218E7: '',  # 𡣧
    # 0x218E8: '',  # 𡣨
    # 0x218E9: '',  # 𡣩
    0x218EA: 'shì',  # 𡣪
    # 0x218EB: '',  # 𡣫
    0x218EC: 'yuān',  # 𡣬
    # 0x218ED: '',  # 𡣭
    0x218EE: 'cài',  # 𡣮
    0x218EF: 'jié',  # 𡣯
    # 0x218F0: '',  # 𡣰
    # 0x218F1: '',  # 𡣱
    # 0x218F2: '',  # 𡣲
    # 0x218F3: '',  # 𡣳
    # 0x218F4: '',  # 𡣴
    # 0x218F5: '',  # 𡣵
    # 0x218F6: '',  # 𡣶
    # 0x218F7: '',  # 𡣷
    # 0x218F8: '',  # 𡣸
    0x218F9: 'xiè',  # 𡣹
    # 0x218FA: '',  # 𡣺
    # 0x218FB: '',  # 𡣻
    # 0x218FC: '',  # 𡣼
    0x218FD: 'yán',  # 𡣽
    0x218FE: 'xiāo',  # 𡣾
    # 0x218FF: '',  # 𡣿
    # 0x21900: '',  # 𡤀
    # 0x21901: '',  # 𡤁
    # 0x21902: '',  # 𡤂
    # 0x21903: '',  # 𡤃
    # 0x21904: '',  # 𡤄
    # 0x21905: '',  # 𡤅
    # 0x21906: '',  # 𡤆
    # 0x21907: '',  # 𡤇
    # 0x21908: '',  # 𡤈
    # 0x21909: '',  # 𡤉
    # 0x2190A: '',  # 𡤊
    0x2190B: 'xiè',  # 𡤋
    0x2190C: 'lì',  # 𡤌
    # 0x2190D: '',  # 𡤍
    0x2190E: 'fàn',  # 𡤎
    # 0x2190F: '',  # 𡤏
    # 0x21910: '',  # 𡤐
    # 0x21911: '',  # 𡤑
    # 0x21912: '',  # 𡤒
    # 0x21913: '',  # 𡤓
    # 0x21914: '',  # 𡤔
    # 0x21915: '',  # 𡤕
    # 0x21916: '',  # 𡤖
    0x21917: 'zhù',  # 𡤗
    # 0x21918: '',  # 𡤘
    0x21919: 'nà',  # 𡤙
    # 0x2191A: '',  # 𡤚
    0x2191B: 'zhuǎn',  # 𡤛
    # 0x2191C: '',  # 𡤜
    # 0x2191D: '',  # 𡤝
    0x2191E: 'kuī',  # 𡤞
    # 0x2191F: '',  # 𡤟
    # 0x21920: '',  # 𡤠
    # 0x21921: '',  # 𡤡
    0x21922: 'luó',  # 𡤢
    # 0x21923: '',  # 𡤣
    # 0x21924: '',  # 𡤤
    # 0x21925: '',  # 𡤥
    # 0x21926: '',  # 𡤦
    # 0x21927: '',  # 𡤧
    # 0x21928: '',  # 𡤨
    # 0x21929: '',  # 𡤩
    # 0x2192A: '',  # 𡤪
    0x2192B: 'qiā',  # 𡤫
    # 0x2192C: '',  # 𡤬
    # 0x2192D: '',  # 𡤭
    # 0x2192E: '',  # 𡤮
    # 0x2192F: '',  # 𡤯
    # 0x21930: '',  # 𡤰
    # 0x21931: '',  # 𡤱
    # 0x21932: '',  # 𡤲
    # 0x21933: '',  # 𡤳
    # 0x21934: '',  # 𡤴
    # 0x21935: '',  # 𡤵
    0x21936: 'wān',  # 𡤶
    # 0x21937: '',  # 𡤷
    # 0x21938: '',  # 𡤸
    # 0x21939: '',  # 𡤹
    # 0x2193A: '',  # 𡤺
    # 0x2193B: '',  # 𡤻
    # 0x2193C: '',  # 𡤼
    0x2193D: 'shǔ',  # 𡤽
    # 0x2193E: '',  # 𡤾
    0x2193F: 'chèng,kǒng',  # 𡤿
    # 0x21940: '',  # 𡥀
    0x21941: 'yì',  # 𡥁
    # 0x21942: '',  # 𡥂
    # 0x21943: '',  # 𡥃
    # 0x21944: '',  # 𡥄
    # 0x21945: '',  # 𡥅
    0x21946: 'hǎo,hào',  # 𡥆
    # 0x21947: '',  # 𡥇
    0x21948: 'jiào',  # 𡥈
    # 0x21949: '',  # 𡥉
    # 0x2194A: '',  # 𡥊
    0x2194B: 'huì',  # 𡥋
    # 0x2194C: '',  # 𡥌
    0x2194D: 'xiào',  # 𡥍
    0x2194E: 'cí,zǐ',  # 𡥎
    # 0x2194F: '',  # 𡥏
    # 0x21950: '',  # 𡥐
    # 0x21951: '',  # 𡥑
    # 0x21952: '',  # 𡥒
    # 0x21953: '',  # 𡥓
    # 0x21954: '',  # 𡥔
    # 0x21955: '',  # 𡥕
    # 0x21956: '',  # 𡥖
    # 0x21957: '',  # 𡥗
    0x21958: 'chuā',  # 𡥘
    # 0x21959: '',  # 𡥙
    # 0x2195A: '',  # 𡥚
    # 0x2195B: '',  # 𡥛
    # 0x2195C: '',  # 𡥜
    # 0x2195D: '',  # 𡥝
    0x2195E: 'jì,bèi',  # 𡥞
    # 0x2195F: '',  # 𡥟
    # 0x21960: '',  # 𡥠
    # 0x21961: '',  # 𡥡
    # 0x21962: '',  # 𡥢
    # 0x21963: '',  # 𡥣
    # 0x21964: '',  # 𡥤
    # 0x21965: '',  # 𡥥
    0x21966: 'nǐ,jìn',  # 𡥦
    0x21967: 'jìn',  # 𡥧
    0x21968: 'nǐ,jìn',  # 𡥨
    0x21969: 'tǐ',  # 𡥩
    # 0x2196A: '',  # 𡥪
    # 0x2196B: '',  # 𡥫
    # 0x2196C: '',  # 𡥬
    # 0x2196D: '',  # 𡥭
    # 0x2196E: '',  # 𡥮
    # 0x2196F: '',  # 𡥯
    # 0x21970: '',  # 𡥰
    # 0x21971: '',  # 𡥱
    # 0x21972: '',  # 𡥲
    # 0x21973: '',  # 𡥳
    # 0x21974: '',  # 𡥴
    # 0x21975: '',  # 𡥵
    0x21976: 'jù,rú',  # 𡥶
    # 0x21977: '',  # 𡥷
    0x21978: 'mìng',  # 𡥸
    # 0x21979: '',  # 𡥹
    # 0x2197A: '',  # 𡥺
    # 0x2197B: '',  # 𡥻
    # 0x2197C: '',  # 𡥼
    0x2197D: 'lí',  # 𡥽
    # 0x2197E: '',  # 𡥾
    0x2197F: 'zhòng',  # 𡥿
    # 0x21980: '',  # 𡦀
    0x21981: 'xù',  # 𡦁
    # 0x21982: '',  # 𡦂
    0x21983: 'qióng',  # 𡦃
    0x21984: 'fú',  # 𡦄
    # 0x21985: '',  # 𡦅
    0x21986: 'bìn',  # 𡦆
    # 0x21987: '',  # 𡦇
    # 0x21988: '',  # 𡦈
    # 0x21989: '',  # 𡦉
    0x2198A: 'jì',  # 𡦊
    # 0x2198B: '',  # 𡦋
    # 0x2198C: '',  # 𡦌
    0x2198D: 'qí',  # 𡦍
    0x2198E: 'xì',  # 𡦎
    # 0x2198F: '',  # 𡦏
    # 0x21990: '',  # 𡦐
    # 0x21991: '',  # 𡦑
    # 0x21992: '',  # 𡦒
    # 0x21993: '',  # 𡦓
    0x21994: 'dèng',  # 𡦔
    0x21995: 'ér',  # 𡦕
    # 0x21996: '',  # 𡦖
    # 0x21997: '',  # 𡦗
    # 0x21998: '',  # 𡦘
    # 0x21999: '',  # 𡦙
    # 0x2199A: '',  # 𡦚
    0x2199B: 'shú',  # 𡦛
    0x2199C: 'tóng',  # 𡦜
    0x2199D: 'xiáo',  # 𡦝
    # 0x2199E: '',  # 𡦞
    0x2199F: 'pí',  # 𡦟
    # 0x219A0: '',  # 𡦠
    # 0x219A1: '',  # 𡦡
    # 0x219A2: '',  # 𡦢
    # 0x219A3: '',  # 𡦣
    # 0x219A4: '',  # 𡦤
    # 0x219A5: '',  # 𡦥
    # 0x219A6: '',  # 𡦦
    # 0x219A7: '',  # 𡦧
    0x219A8: 'dǎn',  # 𡦨
    # 0x219A9: '',  # 𡦩
    0x219AA: 'jí',  # 𡦪
    # 0x219AB: '',  # 𡦫
    # 0x219AC: '',  # 𡦬
    # 0x219AD: '',  # 𡦭
    # 0x219AE: '',  # 𡦮
    # 0x219AF: '',  # 𡦯
    # 0x219B0: '',  # 𡦰
    # 0x219B1: '',  # 𡦱
    # 0x219B2: '',  # 𡦲
    0x219B3: 'xiào',  # 𡦳
    # 0x219B4: '',  # 𡦴
    # 0x219B5: '',  # 𡦵
    # 0x219B6: '',  # 𡦶
    0x219B7: 'cóng',  # 𡦷
    # 0x219B8: '',  # 𡦸
    0x219B9: 'guān',  # 𡦹
    # 0x219BA: '',  # 𡦺
    0x219BB: 'bīn',  # 𡦻
    0x219BC: 'rǒng',  # 𡦼
    # 0x219BD: '',  # 𡦽
    # 0x219BE: '',  # 𡦾
    # 0x219BF: '',  # 𡦿
    # 0x219C0: '',  # 𡧀
    # 0x219C1: '',  # 𡧁
    # 0x219C2: '',  # 𡧂
    # 0x219C3: '',  # 𡧃
    # 0x219C4: '',  # 𡧄
    # 0x219C5: '',  # 𡧅
    # 0x219C6: '',  # 𡧆
    # 0x219C7: '',  # 𡧇
    # 0x219C8: '',  # 𡧈
    # 0x219C9: '',  # 𡧉
    # 0x219CA: '',  # 𡧊
    # 0x219CB: '',  # 𡧋
    # 0x219CC: '',  # 𡧌
    0x219CD: 'miàn,bīn',  # 𡧍
    # 0x219CE: '',  # 𡧎
    # 0x219CF: '',  # 𡧏
    # 0x219D0: '',  # 𡧐
    # 0x219D1: '',  # 𡧑
    0x219D2: 'miàn',  # 𡧒
    # 0x219D3: '',  # 𡧓
    0x219D4: 'shū',  # 𡧔
    0x219D5: 'xiáo,shǒu',  # 𡧕
    0x219D6: 'bǎo',  # 𡧖
    0x219D7: 'wà',  # 𡧗
    # 0x219D8: '',  # 𡧘
    0x219D9: 'pào',  # 𡧙
    # 0x219DA: '',  # 𡧚
    # 0x219DB: '',  # 𡧛
    # 0x219DC: '',  # 𡧜
    # 0x219DD: '',  # 𡧝
    # 0x219DE: '',  # 𡧞
    # 0x219DF: '',  # 𡧟
    # 0x219E0: '',  # 𡧠
    # 0x219E1: '',  # 𡧡
    # 0x219E2: '',  # 𡧢
    0x219E3: 'gǎi',  # 𡧣
    # 0x219E4: '',  # 𡧤
    0x219E5: 'hū',  # 𡧥
    0x219E6: 'héng',  # 𡧦
    # 0x219E7: '',  # 𡧧
    0x219E8: 'zhú',  # 𡧨
    0x219E9: 'guāi',  # 𡧩
    # 0x219EA: '',  # 𡧪
    # 0x219EB: '',  # 𡧫
    # 0x219EC: '',  # 𡧬
    0x219ED: 'guì,guǐ',  # 𡧭
    0x219EE: 'yǎo',  # 𡧮
    0x219EF: 'jì',  # 𡧯
    # 0x219F0: '',  # 𡧰
    0x219F1: 'hài',  # 𡧱
    # 0x219F2: '',  # 𡧲
    # 0x219F3: '',  # 𡧳
    # 0x219F4: '',  # 𡧴
    # 0x219F5: '',  # 𡧵
    # 0x219F6: '',  # 𡧶
    # 0x219F7: '',  # 𡧷
    # 0x219F8: '',  # 𡧸
    0x219F9: 'dài',  # 𡧹
    # 0x219FA: '',  # 𡧺
    # 0x219FB: '',  # 𡧻
    0x219FC: 'bīn',  # 𡧼
    0x219FD: 'huǎng,huāng',  # 𡧽
    # 0x219FE: '',  # 𡧾
    # 0x219FF: '',  # 𡧿
    0x21A00: 'chá',  # 𡨀
    # 0x21A01: '',  # 𡨁
    0x21A02: 'wù',  # 𡨂
    # 0x21A03: '',  # 𡨃
    0x21A04: 'xià,sāi',  # 𡨄
    0x21A05: 'jú',  # 𡨅
    # 0x21A06: '',  # 𡨆
    0x21A07: 'yǎo,xiǎng',  # 𡨇
    # 0x21A08: '',  # 𡨈
    # 0x21A09: '',  # 𡨉
    # 0x21A0A: '',  # 𡨊
    # 0x21A0B: '',  # 𡨋
    # 0x21A0C: '',  # 𡨌
    # 0x21A0D: '',  # 𡨍
    # 0x21A0E: '',  # 𡨎
    # 0x21A0F: '',  # 𡨏
    # 0x21A10: '',  # 𡨐
    # 0x21A11: '',  # 𡨑
    # 0x21A12: '',  # 𡨒
    # 0x21A13: '',  # 𡨓
    # 0x21A14: '',  # 𡨔
    # 0x21A15: '',  # 𡨕
    0x21A16: 'fěn',  # 𡨖
    0x21A17: 'zào',  # 𡨗
    # 0x21A18: '',  # 𡨘
    # 0x21A19: '',  # 𡨙
    # 0x21A1A: '',  # 𡨚
    0x21A1B: 'fēng',  # 𡨛
    0x21A1C: 'jì',  # 𡨜
    # 0x21A1D: '',  # 𡨝
    # 0x21A1E: '',  # 𡨞
    # 0x21A1F: '',  # 𡨟
    # 0x21A20: '',  # 𡨠
    # 0x21A21: '',  # 𡨡
    0x21A22: 'jū',  # 𡨢
    0x21A23: 'yù',  # 𡨣
    # 0x21A24: '',  # 𡨤
    # 0x21A25: '',  # 𡨥
    # 0x21A26: '',  # 𡨦
    0x21A27: 'zǎi',  # 𡨧
    # 0x21A28: '',  # 𡨨
    0x21A29: 'hūn',  # 𡨩
    # 0x21A2A: '',  # 𡨪
    # 0x21A2B: '',  # 𡨫
    # 0x21A2C: '',  # 𡨬
    # 0x21A2D: '',  # 𡨭
    # 0x21A2E: '',  # 𡨮
    # 0x21A2F: '',  # 𡨯
    # 0x21A30: '',  # 𡨰
    # 0x21A31: '',  # 𡨱
    0x21A32: 'jié',  # 𡨲
    0x21A33: 'xiòng,hùn',  # 𡨳
    # 0x21A34: '',  # 𡨴
    0x21A35: 'nài',  # 𡨵
    # 0x21A36: '',  # 𡨶
    # 0x21A37: '',  # 𡨷
    # 0x21A38: '',  # 𡨸
    # 0x21A39: '',  # 𡨹
    # 0x21A3A: '',  # 𡨺
    0x21A3B: 'nǒu',  # 𡨻
    # 0x21A3C: '',  # 𡨼
    0x21A3D: 'shěng',  # 𡨽
    # 0x21A3E: '',  # 𡨾
    0x21A3F: 'yù',  # 𡨿
    # 0x21A40: '',  # 𡩀
    # 0x21A41: '',  # 𡩁
    0x21A42: 'huán',  # 𡩂
    0x21A43: 'gěng',  # 𡩃
    0x21A44: 'wǎn',  # 𡩄
    # 0x21A45: '',  # 𡩅
    0x21A46: 'tuó',  # 𡩆
    0x21A47: 'qiāo',  # 𡩇
    # 0x21A48: '',  # 𡩈
    # 0x21A49: '',  # 𡩉
    # 0x21A4A: '',  # 𡩊
    # 0x21A4B: '',  # 𡩋
    # 0x21A4C: '',  # 𡩌
    # 0x21A4D: '',  # 𡩍
    # 0x21A4E: '',  # 𡩎
    # 0x21A4F: '',  # 𡩏
    # 0x21A50: '',  # 𡩐
    # 0x21A51: '',  # 𡩑
    # 0x21A52: '',  # 𡩒
    # 0x21A53: '',  # 𡩓
    # 0x21A54: '',  # 𡩔
    # 0x21A55: '',  # 𡩕
    # 0x21A56: '',  # 𡩖
    # 0x21A57: '',  # 𡩗
    0x21A58: 'yìn',  # 𡩘
    # 0x21A59: '',  # 𡩙
    0x21A5A: 'jiā,zhuàn',  # 𡩚
    # 0x21A5B: '',  # 𡩛
    # 0x21A5C: '',  # 𡩜
    # 0x21A5D: '',  # 𡩝
    # 0x21A5E: '',  # 𡩞
    # 0x21A5F: '',  # 𡩟
    # 0x21A60: '',  # 𡩠
    0x21A61: 'suǒ',  # 𡩡
    # 0x21A62: '',  # 𡩢
    0x21A63: 'jié',  # 𡩣
    0x21A64: 'xī',  # 𡩤
    0x21A65: 'wěng',  # 𡩥
    # 0x21A66: '',  # 𡩦
    # 0x21A67: '',  # 𡩧
    # 0x21A68: '',  # 𡩨
    0x21A69: 'máng',  # 𡩩
    # 0x21A6A: '',  # 𡩪
    # 0x21A6B: '',  # 𡩫
    # 0x21A6C: '',  # 𡩬
    # 0x21A6D: '',  # 𡩭
    # 0x21A6E: '',  # 𡩮
    # 0x21A6F: '',  # 𡩯
    # 0x21A70: '',  # 𡩰
    # 0x21A71: '',  # 𡩱
    # 0x21A72: '',  # 𡩲
    # 0x21A73: '',  # 𡩳
    # 0x21A74: '',  # 𡩴
    # 0x21A75: '',  # 𡩵
    0x21A76: 'yáng',  # 𡩶
    # 0x21A77: '',  # 𡩷
    0x21A78: 'yáo',  # 𡩸
    # 0x21A79: '',  # 𡩹
    # 0x21A7A: '',  # 𡩺
    # 0x21A7B: '',  # 𡩻
    # 0x21A7C: '',  # 𡩼
    0x21A7D: 'máng',  # 𡩽
    0x21A7E: 'ōu',  # 𡩾
    # 0x21A7F: '',  # 𡩿
    # 0x21A80: '',  # 𡪀
    0x21A81: 'án',  # 𡪁
    # 0x21A82: '',  # 𡪂
    # 0x21A83: '',  # 𡪃
    # 0x21A84: '',  # 𡪄
    0x21A85: 'lòu',  # 𡪅
    # 0x21A86: '',  # 𡪆
    # 0x21A87: '',  # 𡪇
    # 0x21A88: '',  # 𡪈
    # 0x21A89: '',  # 𡪉
    # 0x21A8A: '',  # 𡪊
    # 0x21A8B: '',  # 𡪋
    # 0x21A8C: '',  # 𡪌
    # 0x21A8D: '',  # 𡪍
    # 0x21A8E: '',  # 𡪎
    # 0x21A8F: '',  # 𡪏
    0x21A90: 'diàn',  # 𡪐
    0x21A91: 'è',  # 𡪑
    0x21A92: 'zǐ',  # 𡪒
    # 0x21A93: '',  # 𡪓
    # 0x21A94: '',  # 𡪔
    # 0x21A95: '',  # 𡪕
    # 0x21A96: '',  # 𡪖
    0x21A97: 'è',  # 𡪗
    # 0x21A98: '',  # 𡪘
    0x21A99: 'àn',  # 𡪙
    # 0x21A9A: '',  # 𡪚
    # 0x21A9B: '',  # 𡪛
    # 0x21A9C: '',  # 𡪜
    # 0x21A9D: '',  # 𡪝
    0x21A9E: 'huò',  # 𡪞
    # 0x21A9F: '',  # 𡪟
    0x21AA0: 'céng',  # 𡪠
    # 0x21AA1: '',  # 𡪡
    # 0x21AA2: '',  # 𡪢
    # 0x21AA3: '',  # 𡪣
    # 0x21AA4: '',  # 𡪤
    # 0x21AA5: '',  # 𡪥
    # 0x21AA6: '',  # 𡪦
    # 0x21AA7: '',  # 𡪧
    # 0x21AA8: '',  # 𡪨
    # 0x21AA9: '',  # 𡪩
    # 0x21AAA: '',  # 𡪪
    # 0x21AAB: '',  # 𡪫
    # 0x21AAC: '',  # 𡪬
    # 0x21AAD: '',  # 𡪭
    # 0x21AAE: '',  # 𡪮
    # 0x21AAF: '',  # 𡪯
    0x21AB0: 'xiòng',  # 𡪰
    0x21AB1: 'jì',  # 𡪱
    # 0x21AB2: '',  # 𡪲
    0x21AB3: 'zuó',  # 𡪳
    # 0x21AB4: '',  # 𡪴
    0x21AB5: 'qí',  # 𡪵
    # 0x21AB6: '',  # 𡪶
    # 0x21AB7: '',  # 𡪷
    # 0x21AB8: '',  # 𡪸
    0x21AB9: 'liáo',  # 𡪹
    0x21ABA: 'zhēng',  # 𡪺
    # 0x21ABB: '',  # 𡪻
    # 0x21ABC: '',  # 𡪼
    # 0x21ABD: '',  # 𡪽
    # 0x21ABE: '',  # 𡪾
    # 0x21ABF: '',  # 𡪿
    0x21AC0: 'jī',  # 𡫀
    0x21AC1: 'qī,chèn',  # 𡫁
    0x21AC2: 'juǎn',  # 𡫂
    0x21AC3: 'níng',  # 𡫃
    # 0x21AC4: '',  # 𡫄
    # 0x21AC5: '',  # 𡫅
    # 0x21AC6: '',  # 𡫆
    # 0x21AC7: '',  # 𡫇
    # 0x21AC8: '',  # 𡫈
    # 0x21AC9: '',  # 𡫉
    # 0x21ACA: '',  # 𡫊
    # 0x21ACB: '',  # 𡫋
    # 0x21ACC: '',  # 𡫌
    # 0x21ACD: '',  # 𡫍
    # 0x21ACE: '',  # 𡫎
    # 0x21ACF: '',  # 𡫏
    # 0x21AD0: '',  # 𡫐
    # 0x21AD1: '',  # 𡫑
    # 0x21AD2: '',  # 𡫒
    # 0x21AD3: '',  # 𡫓
    # 0x21AD4: '',  # 𡫔
    # 0x21AD5: '',  # 𡫕
    # 0x21AD6: '',  # 𡫖
    # 0x21AD7: '',  # 𡫗
    # 0x21AD8: '',  # 𡫘
    # 0x21AD9: '',  # 𡫙
    # 0x21ADA: '',  # 𡫚
    0x21ADB: 'mián',  # 𡫛
    # 0x21ADC: '',  # 𡫜
    # 0x21ADD: '',  # 𡫝
    # 0x21ADE: '',  # 𡫞
    0x21ADF: 'sè',  # 𡫟
    # 0x21AE0: '',  # 𡫠
    # 0x21AE1: '',  # 𡫡
    # 0x21AE2: '',  # 𡫢
    # 0x21AE3: '',  # 𡫣
    # 0x21AE4: '',  # 𡫤
    0x21AE5: 'hè',  # 𡫥
    0x21AE6: 'rǒng',  # 𡫦
    0x21AE7: 'qǐn',  # 𡫧
    # 0x21AE8: '',  # 𡫨
    # 0x21AE9: '',  # 𡫩
    # 0x21AEA: '',  # 𡫪
    # 0x21AEB: '',  # 𡫫
    0x21AEC: 'jū',  # 𡫬
    # 0x21AED: '',  # 𡫭
    # 0x21AEE: '',  # 𡫮
    0x21AEF: 'lì',  # 𡫯
    # 0x21AF0: '',  # 𡫰
    # 0x21AF1: '',  # 𡫱
    # 0x21AF2: '',  # 𡫲
    0x21AF3: 'sè',  # 𡫳
    # 0x21AF4: '',  # 𡫴
    0x21AF5: 'shí',  # 𡫵
    # 0x21AF6: '',  # 𡫶
    # 0x21AF7: '',  # 𡫷
    0x21AF8: 'nì',  # 𡫸
    0x21AF9: 'xián',  # 𡫹
    0x21AFA: 'fū',  # 𡫺
    # 0x21AFB: '',  # 𡫻
    # 0x21AFC: '',  # 𡫼
    0x21AFD: 'rǔ,yù',  # 𡫽
    # 0x21AFE: '',  # 𡫾
    # 0x21AFF: '',  # 𡫿
    # 0x21B00: '',  # 𡬀
    0x21B01: 'xiòng',  # 𡬁
    0x21B02: 'guì',  # 𡬂
    # 0x21B03: '',  # 𡬃
    0x21B04: 'jì',  # 𡬄
    # 0x21B05: '',  # 𡬅
    0x21B06: 'měng,mèng',  # 𡬆
    0x21B07: 'fū',  # 𡬇
    # 0x21B08: '',  # 𡬈
    0x21B09: 'sài',  # 𡬉
    0x21B0A: 'yù',  # 𡬊
    0x21B0B: 'jiào',  # 𡬋
    0x21B0C: 'mèng',  # 𡬌
    0x21B0D: 'lóng',  # 𡬍
    0x21B0E: 'qiāng',  # 𡬎
    # 0x21B0F: '',  # 𡬏
    0x21B10: 'mí,mǐ',  # 𡬐
    # 0x21B11: '',  # 𡬑
    # 0x21B12: '',  # 𡬒
    0x21B13: 'yí',  # 𡬓
    # 0x21B14: '',  # 𡬔
    # 0x21B15: '',  # 𡬕
    0x21B16: 'hān',  # 𡬖
    0x21B17: 'nì',  # 𡬗
    0x21B18: 'lào',  # 𡬘
    0x21B19: 'sèng',  # 𡬙
    # 0x21B1A: '',  # 𡬚
    # 0x21B1B: '',  # 𡬛
    0x21B1C: 'lǐn',  # 𡬜
    # 0x21B1D: '',  # 𡬝
    0x21B1E: 'yù',  # 𡬞
    # 0x21B1F: '',  # 𡬟
    # 0x21B20: '',  # 𡬠
    # 0x21B21: '',  # 𡬡
    # 0x21B22: '',  # 𡬢
    # 0x21B23: '',  # 𡬣
    # 0x21B24: '',  # 𡬤
    0x21B25: 'nuó',  # 𡬥
    # 0x21B26: '',  # 𡬦
    # 0x21B27: '',  # 𡬧
    # 0x21B28: '',  # 𡬨
    # 0x21B29: '',  # 𡬩
    # 0x21B2A: '',  # 𡬪
    0x21B2B: 'wù',  # 𡬫
    # 0x21B2C: '',  # 𡬬
    # 0x21B2D: '',  # 𡬭
    # 0x21B2E: '',  # 𡬮
    0x21B2F: 'biǎn',  # 𡬯
    # 0x21B30: '',  # 𡬰
    # 0x21B31: '',  # 𡬱
    0x21B32: 'biǎn',  # 𡬲
    0x21B33: 'xuān,shòu',  # 𡬳
    # 0x21B34: '',  # 𡬴
    0x21B35: 'jiān',  # 𡬵
    # 0x21B36: '',  # 𡬶
    # 0x21B37: '',  # 𡬷
    0x21B38: 'biǎn',  # 𡬸
    # 0x21B39: '',  # 𡬹
    # 0x21B3A: '',  # 𡬺
    # 0x21B3B: '',  # 𡬻
    # 0x21B3C: '',  # 𡬼
    # 0x21B3D: '',  # 𡬽
    # 0x21B3E: '',  # 𡬾
    # 0x21B3F: '',  # 𡬿
    # 0x21B40: '',  # 𡭀
    # 0x21B41: '',  # 𡭁
    0x21B42: 'dé',  # 𡭂
    # 0x21B43: '',  # 𡭃
    # 0x21B44: '',  # 𡭄
    # 0x21B45: '',  # 𡭅
    # 0x21B46: '',  # 𡭆
    0x21B47: 'zhuān',  # 𡭇
    # 0x21B48: '',  # 𡭈
    # 0x21B49: '',  # 𡭉
    # 0x21B4A: '',  # 𡭊
    0x21B4B: 'rǒng',  # 𡭋
    # 0x21B4C: '',  # 𡭌
    # 0x21B4D: '',  # 𡭍
    # 0x21B4E: '',  # 𡭎
    # 0x21B4F: '',  # 𡭏
    0x21B50: 'shuàn',  # 𡭐
    # 0x21B51: '',  # 𡭑
    # 0x21B52: '',  # 𡭒
    # 0x21B53: '',  # 𡭓
    # 0x21B54: '',  # 𡭔
    # 0x21B55: '',  # 𡭕
    # 0x21B56: '',  # 𡭖
    # 0x21B57: '',  # 𡭗
    0x21B58: 'jiā',  # 𡭘
    # 0x21B59: '',  # 𡭙
    0x21B5A: 'mó',  # 𡭚
    0x21B5B: 'huǐ',  # 𡭛
    # 0x21B5C: '',  # 𡭜
    # 0x21B5D: '',  # 𡭝
    0x21B5E: 'zhān',  # 𡭞
    # 0x21B5F: '',  # 𡭟
    # 0x21B60: '',  # 𡭠
    # 0x21B61: '',  # 𡭡
    0x21B62: 'bài',  # 𡭢
    0x21B63: 'liè',  # 𡭣
    # 0x21B64: '',  # 𡭤
    0x21B65: 'xiē',  # 𡭥
    # 0x21B66: '',  # 𡭦
    # 0x21B67: '',  # 𡭧
    # 0x21B68: '',  # 𡭨
    # 0x21B69: '',  # 𡭩
    # 0x21B6A: '',  # 𡭪
    # 0x21B6B: '',  # 𡭫
    # 0x21B6C: '',  # 𡭬
    0x21B6D: 'jiǎn',  # 𡭭
    0x21B6E: 'shǒu',  # 𡭮
    # 0x21B6F: '',  # 𡭯
    # 0x21B70: '',  # 𡭰
    # 0x21B71: '',  # 𡭱
    # 0x21B72: '',  # 𡭲
    0x21B73: 'kào',  # 𡭳
    0x21B74: 'xì',  # 𡭴
    # 0x21B75: '',  # 𡭵
    # 0x21B76: '',  # 𡭶
    0x21B77: 'guān',  # 𡭷
    0x21B78: 'luàn',  # 𡭸
    # 0x21B79: '',  # 𡭹
    # 0x21B7A: '',  # 𡭺
    # 0x21B7B: '',  # 𡭻
    # 0x21B7C: '',  # 𡭼
    0x21B7D: 'xì',  # 𡭽
    0x21B7E: 'nǒu',  # 𡭾
    0x21B7F: 'chǎng',  # 𡭿
    # 0x21B80: '',  # 𡮀
    # 0x21B81: '',  # 𡮁
    # 0x21B82: '',  # 𡮂
    # 0x21B83: '',  # 𡮃
    # 0x21B84: '',  # 𡮄
    # 0x21B85: '',  # 𡮅
    # 0x21B86: '',  # 𡮆
    # 0x21B87: '',  # 𡮇
    # 0x21B88: '',  # 𡮈
    # 0x21B89: '',  # 𡮉
    # 0x21B8A: '',  # 𡮊
    # 0x21B8B: '',  # 𡮋
    # 0x21B8C: '',  # 𡮌
    # 0x21B8D: '',  # 𡮍
    0x21B8E: 'liáng',  # 𡮎
    # 0x21B8F: '',  # 𡮏
    # 0x21B90: '',  # 𡮐
    # 0x21B91: '',  # 𡮑
    # 0x21B92: '',  # 𡮒
    # 0x21B93: '',  # 𡮓
    # 0x21B94: '',  # 𡮔
    # 0x21B95: '',  # 𡮕
    # 0x21B96: '',  # 𡮖
    # 0x21B97: '',  # 𡮗
    # 0x21B98: '',  # 𡮘
    0x21B99: 'nài',  # 𡮙
    0x21B9A: 'rǔ',  # 𡮚
    # 0x21B9B: '',  # 𡮛
    # 0x21B9C: '',  # 𡮜
    # 0x21B9D: '',  # 𡮝
    0x21B9E: 'zhì',  # 𡮞
    # 0x21B9F: '',  # 𡮟
    # 0x21BA0: '',  # 𡮠
    # 0x21BA1: '',  # 𡮡
    # 0x21BA2: '',  # 𡮢
    # 0x21BA3: '',  # 𡮣
    # 0x21BA4: '',  # 𡮤
    # 0x21BA5: '',  # 𡮥
    0x21BA6: 'cáo',  # 𡮦
    # 0x21BA7: '',  # 𡮧
    # 0x21BA8: '',  # 𡮨
    # 0x21BA9: '',  # 𡮩
    # 0x21BAA: '',  # 𡮪
    # 0x21BAB: '',  # 𡮫
    # 0x21BAC: '',  # 𡮬
    # 0x21BAD: '',  # 𡮭
    # 0x21BAE: '',  # 𡮮
    # 0x21BAF: '',  # 𡮯
    0x21BB0: 'lì',  # 𡮰
    # 0x21BB1: '',  # 𡮱
    # 0x21BB2: '',  # 𡮲
    # 0x21BB3: '',  # 𡮳
    # 0x21BB4: '',  # 𡮴
    # 0x21BB5: '',  # 𡮵
    # 0x21BB6: '',  # 𡮶
    # 0x21BB7: '',  # 𡮷
    # 0x21BB8: '',  # 𡮸
    # 0x21BB9: '',  # 𡮹
    # 0x21BBA: '',  # 𡮺
    0x21BBB: 'lán',  # 𡮻
    # 0x21BBC: '',  # 𡮼
    # 0x21BBD: '',  # 𡮽
    # 0x21BBE: '',  # 𡮾
    0x21BBF: 'chān',  # 𡮿
    # 0x21BC0: '',  # 𡯀
    0x21BC1: 'wāng',  # 𡯁
    # 0x21BC2: '',  # 𡯂
    # 0x21BC3: '',  # 𡯃
    0x21BC4: 'lì',  # 𡯄
    # 0x21BC5: '',  # 𡯅
    # 0x21BC6: '',  # 𡯆
    0x21BC7: 'wù',  # 𡯇
    0x21BC8: 'páo',  # 𡯈
    0x21BC9: 'yòu',  # 𡯉
    # 0x21BCA: '',  # 𡯊
    0x21BCB: 'gān',  # 𡯋
    # 0x21BCC: '',  # 𡯌
    # 0x21BCD: '',  # 𡯍
    # 0x21BCE: '',  # 𡯎
    0x21BCF: 'ān',  # 𡯏
    0x21BD0: 'xiū',  # 𡯐
    0x21BD1: 'shuǐ,zhuǐ',  # 𡯑
    0x21BD2: 'ruǐ',  # 𡯒
    # 0x21BD3: '',  # 𡯓
    # 0x21BD4: '',  # 𡯔
    # 0x21BD5: '',  # 𡯕
    # 0x21BD6: '',  # 𡯖
    # 0x21BD7: '',  # 𡯗
    0x21BD8: 'bǎn',  # 𡯘
    0x21BD9: 'yóu',  # 𡯙
    # 0x21BDA: '',  # 𡯚
    0x21BDB: 'zuǒ',  # 𡯛
    # 0x21BDC: '',  # 𡯜
    # 0x21BDD: '',  # 𡯝
    # 0x21BDE: '',  # 𡯞
    # 0x21BDF: '',  # 𡯟
    # 0x21BE0: '',  # 𡯠
    # 0x21BE1: '',  # 𡯡
    0x21BE2: 'huó',  # 𡯢
    0x21BE3: 'yào',  # 𡯣
    # 0x21BE4: '',  # 𡯤
    0x21BE5: 'huī',  # 𡯥
    # 0x21BE6: '',  # 𡯦
    # 0x21BE7: '',  # 𡯧
    0x21BE8: 'zuò',  # 𡯨
    0x21BE9: 'xiāo',  # 𡯩
    # 0x21BEA: '',  # 𡯪
    0x21BEB: 'mián',  # 𡯫
    # 0x21BEC: '',  # 𡯬
    # 0x21BED: '',  # 𡯭
    # 0x21BEE: '',  # 𡯮
    # 0x21BEF: '',  # 𡯯
    0x21BF0: 'gà',  # 𡯰
    0x21BF1: 'yuǎn',  # 𡯱
    # 0x21BF2: '',  # 𡯲
    0x21BF3: 'bò',  # 𡯳
    0x21BF4: 'chào',  # 𡯴
    0x21BF5: 'tuǐ,kuì',  # 𡯵
    # 0x21BF6: '',  # 𡯶
    0x21BF7: 'bò,kòu',  # 𡯷
    # 0x21BF8: '',  # 𡯸
    # 0x21BF9: '',  # 𡯹
    # 0x21BFA: '',  # 𡯺
    # 0x21BFB: '',  # 𡯻
    # 0x21BFC: '',  # 𡯼
    0x21BFD: 'gà',  # 𡯽
    # 0x21BFE: '',  # 𡯾
    0x21BFF: 'tiāo',  # 𡯿
    0x21C00: 'ná',  # 𡰀
    # 0x21C01: '',  # 𡰁
    0x21C02: 'kuī',  # 𡰂
    # 0x21C03: '',  # 𡰃
    # 0x21C04: '',  # 𡰄
    0x21C05: 'hú',  # 𡰅
    0x21C06: 'niè',  # 𡰆
    # 0x21C07: '',  # 𡰇
    # 0x21C08: '',  # 𡰈
    # 0x21C09: '',  # 𡰉
    # 0x21C0A: '',  # 𡰊
    0x21C0B: 'huí',  # 𡰋
    0x21C0C: 'lǒu',  # 𡰌
    # 0x21C0D: '',  # 𡰍
    0x21C0E: 'tí',  # 𡰎
    # 0x21C0F: '',  # 𡰏
    0x21C10: 'qiào',  # 𡰐
    0x21C11: 'qiáo',  # 𡰑
    0x21C12: 'zhǒng',  # 𡰒
    # 0x21C13: '',  # 𡰓
    # 0x21C14: '',  # 𡰔
    # 0x21C15: '',  # 𡰕
    0x21C16: 'dī',  # 𡰖
    # 0x21C17: '',  # 𡰗
    # 0x21C18: '',  # 𡰘
    # 0x21C19: '',  # 𡰙
    0x21C1A: 'lín',  # 𡰚
    # 0x21C1B: '',  # 𡰛
    # 0x21C1C: '',  # 𡰜
    0x21C1D: 'quán',  # 𡰝
    0x21C1E: 'zhuān',  # 𡰞
    # 0x21C1F: '',  # 𡰟
    0x21C20: 'léi,luán',  # 𡰠
    # 0x21C21: '',  # 𡰡
    0x21C22: 'xié',  # 𡰢
    0x21C23: 'shī',  # 𡰣
    # 0x21C24: '',  # 𡰤
    0x21C25: 'rén,yí',  # 𡰥
    # 0x21C26: '',  # 𡰦
    # 0x21C27: '',  # 𡰧
    0x21C28: 'dāng',  # 𡰨
    # 0x21C29: '',  # 𡰩
    # 0x21C2A: '',  # 𡰪
    0x21C2B: 'niǎn',  # 𡰫
    # 0x21C2C: '',  # 𡰬
    # 0x21C2D: '',  # 𡰭
    # 0x21C2E: '',  # 𡰮
    0x21C2F: 'shǐ,diǎo,běi',  # 𡰯
    # 0x21C30: '',  # 𡰰
    # 0x21C31: '',  # 𡰱
    0x21C32: 'xián',  # 𡰲
    # 0x21C33: '',  # 𡰳
    # 0x21C34: '',  # 𡰴
    0x21C35: 'jī',  # 𡰵
    # 0x21C36: '',  # 𡰶
    # 0x21C37: '',  # 𡰷
    0x21C38: 'jī',  # 𡰸
    0x21C39: 'zhí',  # 𡰹
    # 0x21C3A: '',  # 𡰺
    # 0x21C3B: '',  # 𡰻
    # 0x21C3C: '',  # 𡰼
    0x21C3D: 'ài',  # 𡰽
    0x21C3E: 'cī',  # 𡰾
    0x21C3F: 'pú',  # 𡰿
    # 0x21C40: '',  # 𡱀
    0x21C41: 'shǐ',  # 𡱁
    0x21C42: 'tún',  # 𡱂
    # 0x21C43: '',  # 𡱃
    # 0x21C44: '',  # 𡱄
    0x21C45: 'qū',  # 𡱅
    0x21C46: 'shǔ',  # 𡱆
    0x21C47: 'diān',  # 𡱇
    # 0x21C48: '',  # 𡱈
    0x21C49: 'xiǎo',  # 𡱉
    0x21C4A: 'shuǐ',  # 𡱊
    # 0x21C4B: '',  # 𡱋
    0x21C4C: 'huán',  # 𡱌
    # 0x21C4D: '',  # 𡱍
    # 0x21C4E: '',  # 𡱎
    # 0x21C4F: '',  # 𡱏
    0x21C50: 'yí',  # 𡱐
    0x21C51: 'juān',  # 𡱑
    # 0x21C52: '',  # 𡱒
    # 0x21C53: '',  # 𡱓
    0x21C54: 'zhǐ,qì',  # 𡱔
    # 0x21C55: '',  # 𡱕
    # 0x21C56: '',  # 𡱖
    # 0x21C57: '',  # 𡱗
    # 0x21C58: '',  # 𡱘
    # 0x21C59: '',  # 𡱙
    # 0x21C5A: '',  # 𡱚
    # 0x21C5B: '',  # 𡱛
    0x21C5C: 'zhào',  # 𡱜
    # 0x21C5D: '',  # 𡱝
    # 0x21C5E: '',  # 𡱞
    # 0x21C5F: '',  # 𡱟
    # 0x21C60: '',  # 𡱠
    # 0x21C61: '',  # 𡱡
    # 0x21C62: '',  # 𡱢
    0x21C63: 'xù',  # 𡱣
    # 0x21C64: '',  # 𡱤
    # 0x21C65: '',  # 𡱥
    # 0x21C66: '',  # 𡱦
    # 0x21C67: '',  # 𡱧
    # 0x21C68: '',  # 𡱨
    # 0x21C69: '',  # 𡱩
    # 0x21C6A: '',  # 𡱪
    # 0x21C6B: '',  # 𡱫
    # 0x21C6C: '',  # 𡱬
    # 0x21C6D: '',  # 𡱭
    # 0x21C6E: '',  # 𡱮
    0x21C6F: 'lòng',  # 𡱯
    # 0x21C70: '',  # 𡱰
    0x21C71: 'zhù',  # 𡱱
    # 0x21C72: '',  # 𡱲
    0x21C73: 'suǒ',  # 𡱳
    # 0x21C74: '',  # 𡱴
    # 0x21C75: '',  # 𡱵
    # 0x21C76: '',  # 𡱶
    0x21C77: 'dié',  # 𡱷
    # 0x21C78: '',  # 𡱸
    # 0x21C79: '',  # 𡱹
    0x21C7A: 'qú',  # 𡱺
    # 0x21C7B: '',  # 𡱻
    0x21C7C: 'kè,kuà',  # 𡱼
    0x21C7D: 'hū',  # 𡱽
    0x21C7E: 'jū',  # 𡱾
    # 0x21C7F: '',  # 𡱿
    0x21C80: 'qǐng',  # 𡲀
    # 0x21C81: '',  # 𡲁
    # 0x21C82: '',  # 𡲂
    # 0x21C83: '',  # 𡲃
    # 0x21C84: '',  # 𡲄
    # 0x21C85: '',  # 𡲅
    0x21C86: 'jī',  # 𡲆
    # 0x21C87: '',  # 𡲇
    # 0x21C88: '',  # 𡲈
    # 0x21C89: '',  # 𡲉
    # 0x21C8A: '',  # 𡲊
    # 0x21C8B: '',  # 𡲋
    # 0x21C8C: '',  # 𡲌
    0x21C8D: 'bīng',  # 𡲍
    # 0x21C8E: '',  # 𡲎
    # 0x21C8F: '',  # 𡲏
    # 0x21C90: '',  # 𡲐
    # 0x21C91: '',  # 𡲑
    # 0x21C92: '',  # 𡲒
    # 0x21C93: '',  # 𡲓
    # 0x21C94: '',  # 𡲔
    0x21C95: 'tì',  # 𡲕
    # 0x21C96: '',  # 𡲖
    0x21C97: 'jué',  # 𡲗
    # 0x21C98: '',  # 𡲘
    # 0x21C99: '',  # 𡲙
    0x21C9A: 'qiú',  # 𡲚
    # 0x21C9B: '',  # 𡲛
    # 0x21C9C: '',  # 𡲜
    # 0x21C9D: '',  # 𡲝
    # 0x21C9E: '',  # 𡲞
    # 0x21C9F: '',  # 𡲟
    # 0x21CA0: '',  # 𡲠
    # 0x21CA1: '',  # 𡲡
    # 0x21CA2: '',  # 𡲢
    0x21CA3: 'jiàng',  # 𡲣
    # 0x21CA4: '',  # 𡲤
    # 0x21CA5: '',  # 𡲥
    # 0x21CA6: '',  # 𡲦
    # 0x21CA7: '',  # 𡲧
    # 0x21CA8: '',  # 𡲨
    # 0x21CA9: '',  # 𡲩
    0x21CAA: 'yùn',  # 𡲪
    # 0x21CAB: '',  # 𡲫
    # 0x21CAC: '',  # 𡲬
    0x21CAD: 'mèi',  # 𡲭
    0x21CAE: 'pī',  # 𡲮
    # 0x21CAF: '',  # 𡲯
    0x21CB0: 'qú',  # 𡲰
    # 0x21CB1: '',  # 𡲱
    # 0x21CB2: '',  # 𡲲
    # 0x21CB3: '',  # 𡲳
    # 0x21CB4: '',  # 𡲴
    # 0x21CB5: '',  # 𡲵
    # 0x21CB6: '',  # 𡲶
    # 0x21CB7: '',  # 𡲷
    # 0x21CB8: '',  # 𡲸
    # 0x21CB9: '',  # 𡲹
    # 0x21CBA: '',  # 𡲺
    # 0x21CBB: '',  # 𡲻
    0x21CBC: 'mì',  # 𡲼
    # 0x21CBD: '',  # 𡲽
    0x21CBE: 'tuī',  # 𡲾
    0x21CBF: 'tì',  # 𡲿
    # 0x21CC0: '',  # 𡳀
    # 0x21CC1: '',  # 𡳁
    0x21CC2: 'kài',  # 𡳂
    # 0x21CC3: '',  # 𡳃
    0x21CC4: 'bǐ',  # 𡳄
    # 0x21CC5: '',  # 𡳅
    0x21CC6: 'qū,qù',  # 𡳆
    # 0x21CC7: '',  # 𡳇
    # 0x21CC8: '',  # 𡳈
    # 0x21CC9: '',  # 𡳉
    # 0x21CCA: '',  # 𡳊
    # 0x21CCB: '',  # 𡳋
    # 0x21CCC: '',  # 𡳌
    # 0x21CCD: '',  # 𡳍
    # 0x21CCE: '',  # 𡳎
    0x21CCF: 'tiāo',  # 𡳏
    # 0x21CD0: '',  # 𡳐
    0x21CD1: 'chù',  # 𡳑
    # 0x21CD2: '',  # 𡳒
    # 0x21CD3: '',  # 𡳓
    # 0x21CD4: '',  # 𡳔
    # 0x21CD5: '',  # 𡳕
    # 0x21CD6: '',  # 𡳖
    # 0x21CD7: '',  # 𡳗
    0x21CD8: 'jú',  # 𡳘
    # 0x21CD9: '',  # 𡳙
    0x21CDA: 'xī',  # 𡳚
    # 0x21CDB: '',  # 𡳛
    # 0x21CDC: '',  # 𡳜
    # 0x21CDD: '',  # 𡳝
    0x21CDE: 'lìn',  # 𡳞
    # 0x21CDF: '',  # 𡳟
    # 0x21CE0: '',  # 𡳠
    # 0x21CE1: '',  # 𡳡
    # 0x21CE2: '',  # 𡳢
    # 0x21CE3: '',  # 𡳣
    # 0x21CE4: '',  # 𡳤
    # 0x21CE5: '',  # 𡳥
    # 0x21CE6: '',  # 𡳦
    # 0x21CE7: '',  # 𡳧
    # 0x21CE8: '',  # 𡳨
    # 0x21CE9: '',  # 𡳩
    # 0x21CEA: '',  # 𡳪
    # 0x21CEB: '',  # 𡳫
    # 0x21CEC: '',  # 𡳬
    0x21CED: 'chǐ',  # 𡳭
    0x21CEE: 'jī',  # 𡳮
    # 0x21CEF: '',  # 𡳯
    # 0x21CF0: '',  # 𡳰
    # 0x21CF1: '',  # 𡳱
    # 0x21CF2: '',  # 𡳲
    # 0x21CF3: '',  # 𡳳
    0x21CF4: 'lú',  # 𡳴
    # 0x21CF5: '',  # 𡳵
    # 0x21CF6: '',  # 𡳶
    # 0x21CF7: '',  # 𡳷
    0x21CF8: 'lì',  # 𡳸
    # 0x21CF9: '',  # 𡳹
    # 0x21CFA: '',  # 𡳺
    # 0x21CFB: '',  # 𡳻
    # 0x21CFC: '',  # 𡳼
    # 0x21CFD: '',  # 𡳽
    0x21CFE: 'jué',  # 𡳾
    # 0x21CFF: '',  # 𡳿
    # 0x21D00: '',  # 𡴀
    # 0x21D01: '',  # 𡴁
    # 0x21D02: '',  # 𡴂
    # 0x21D03: '',  # 𡴃
    # 0x21D04: '',  # 𡴄
    0x21D05: 'zhū',  # 𡴅
    0x21D06: 'lù',  # 𡴆
    # 0x21D07: '',  # 𡴇
    # 0x21D08: '',  # 𡴈
    # 0x21D09: '',  # 𡴉
    # 0x21D0A: '',  # 𡴊
    # 0x21D0B: '',  # 𡴋
    # 0x21D0C: '',  # 𡴌
    # 0x21D0D: '',  # 𡴍
    0x21D0E: 'niè',  # 𡴎
    # 0x21D0F: '',  # 𡴏
    # 0x21D10: '',  # 𡴐
    # 0x21D11: '',  # 𡴑
    # 0x21D12: '',  # 𡴒
    # 0x21D13: '',  # 𡴓
    0x21D14: 'quán',  # 𡴔
    # 0x21D15: '',  # 𡴕
    # 0x21D16: '',  # 𡴖
    # 0x21D17: '',  # 𡴗
    0x21D18: 'xìng',  # 𡴘
    # 0x21D19: '',  # 𡴙
    # 0x21D1A: '',  # 𡴚
    # 0x21D1B: '',  # 𡴛
    # 0x21D1C: '',  # 𡴜
    # 0x21D1D: '',  # 𡴝
    0x21D1E: 'yǔn',  # 𡴞
    # 0x21D1F: '',  # 𡴟
    # 0x21D20: '',  # 𡴠
    # 0x21D21: '',  # 𡴡
    # 0x21D22: '',  # 𡴢
    # 0x21D23: '',  # 𡴣
    # 0x21D24: '',  # 𡴤
    # 0x21D25: '',  # 𡴥
    # 0x21D26: '',  # 𡴦
    # 0x21D27: '',  # 𡴧
    # 0x21D28: '',  # 𡴨
    # 0x21D29: '',  # 𡴩
    # 0x21D2A: '',  # 𡴪
    # 0x21D2B: '',  # 𡴫
    # 0x21D2C: '',  # 𡴬
    0x21D2D: 'yà',  # 𡴭
    # 0x21D2E: '',  # 𡴮
    0x21D2F: 'è',  # 𡴯
    # 0x21D30: '',  # 𡴰
    0x21D31: 'hù,jié',  # 𡴱
    # 0x21D32: '',  # 𡴲
    # 0x21D33: '',  # 𡴳
    # 0x21D34: '',  # 𡴴
    # 0x21D35: '',  # 𡴵
    # 0x21D36: '',  # 𡴶
    # 0x21D37: '',  # 𡴷
    # 0x21D38: '',  # 𡴸
    0x21D39: 'jié',  # 𡴹
    # 0x21D3A: '',  # 𡴺
    # 0x21D3B: '',  # 𡴻
    # 0x21D3C: '',  # 𡴼
    # 0x21D3D: '',  # 𡴽
    # 0x21D3E: '',  # 𡴾
    # 0x21D3F: '',  # 𡴿
    0x21D40: 'máng',  # 𡵀
    # 0x21D41: '',  # 𡵁
    # 0x21D42: '',  # 𡵂
    # 0x21D43: '',  # 𡵃
    # 0x21D44: '',  # 𡵄
    # 0x21D45: '',  # 𡵅
    # 0x21D46: '',  # 𡵆
    # 0x21D47: '',  # 𡵇
    # 0x21D48: '',  # 𡵈
    0x21D49: 'wù',  # 𡵉
    # 0x21D4A: '',  # 𡵊
    # 0x21D4B: '',  # 𡵋
    0x21D4C: 'chā',  # 𡵌
    # 0x21D4D: '',  # 𡵍
    # 0x21D4E: '',  # 𡵎
    # 0x21D4F: '',  # 𡵏
    # 0x21D50: '',  # 𡵐
    0x21D51: 'qīn',  # 𡵑
    0x21D52: 'jié,qǐ',  # 𡵒
    0x21D53: 'hóng',  # 𡵓
    # 0x21D54: '',  # 𡵔
    0x21D55: 'dān',  # 𡵕
    0x21D56: 'ěn',  # 𡵖
    0x21D57: 'zè',  # 𡵗
    0x21D58: 'hù',  # 𡵘
    0x21D59: 'àng',  # 𡵙
    0x21D5A: 'jiè',  # 𡵚
    0x21D5B: 'fù',  # 𡵛
    0x21D5C: 'yòng',  # 𡵜
    # 0x21D5D: '',  # 𡵝
    0x21D5E: 'fēng',  # 𡵞
    # 0x21D5F: '',  # 𡵟
    # 0x21D60: '',  # 𡵠
    # 0x21D61: '',  # 𡵡
    # 0x21D62: '',  # 𡵢
    # 0x21D63: '',  # 𡵣
    # 0x21D64: '',  # 𡵤
    # 0x21D65: '',  # 𡵥
    # 0x21D66: '',  # 𡵦
    # 0x21D67: '',  # 𡵧
    # 0x21D68: '',  # 𡵨
    # 0x21D69: '',  # 𡵩
    # 0x21D6A: '',  # 𡵪
    # 0x21D6B: '',  # 𡵫
    0x21D6C: 'mù',  # 𡵬
    0x21D6D: 'cūn',  # 𡵭
    # 0x21D6E: '',  # 𡵮
    # 0x21D6F: '',  # 𡵯
    # 0x21D70: '',  # 𡵰
    # 0x21D71: '',  # 𡵱
    # 0x21D72: '',  # 𡵲
    # 0x21D73: '',  # 𡵳
    # 0x21D74: '',  # 𡵴
    # 0x21D75: '',  # 𡵵
    0x21D76: 'sè',  # 𡵶
    0x21D77: 'cóng',  # 𡵷
    # 0x21D78: '',  # 𡵸
    # 0x21D79: '',  # 𡵹
    # 0x21D7A: '',  # 𡵺
    0x21D7B: 'kāng',  # 𡵻
    # 0x21D7C: '',  # 𡵼
    # 0x21D7D: '',  # 𡵽
    # 0x21D7E: '',  # 𡵾
    # 0x21D7F: '',  # 𡵿
    # 0x21D80: '',  # 𡶀
    # 0x21D81: '',  # 𡶁
    0x21D82: 'yào',  # 𡶂
    0x21D83: 'ài',  # 𡶃
    0x21D84: 'bāo',  # 𡶄
    # 0x21D85: '',  # 𡶅
    0x21D86: 'pǒ',  # 𡶆
    # 0x21D87: '',  # 𡶇
    0x21D88: 'shǐ',  # 𡶈
    0x21D89: 'fàn',  # 𡶉
    # 0x21D8A: '',  # 𡶊
    0x21D8B: 'jú',  # 𡶋
    0x21D8C: 'pí',  # 𡶌
    # 0x21D8D: '',  # 𡶍
    0x21D8E: 'wèi',  # 𡶎
    0x21D8F: 'kū',  # 𡶏
    0x21D90: 'qié',  # 𡶐
    0x21D91: 'gān',  # 𡶑
    # 0x21D92: '',  # 𡶒
    # 0x21D93: '',  # 𡶓
    # 0x21D94: '',  # 𡶔
    # 0x21D95: '',  # 𡶕
    # 0x21D96: '',  # 𡶖
    # 0x21D97: '',  # 𡶗
    # 0x21D98: '',  # 𡶘
    # 0x21D99: '',  # 𡶙
    # 0x21D9A: '',  # 𡶚
    # 0x21D9B: '',  # 𡶛
    # 0x21D9C: '',  # 𡶜
    # 0x21D9D: '',  # 𡶝
    # 0x21D9E: '',  # 𡶞
    # 0x21D9F: '',  # 𡶟
    # 0x21DA0: '',  # 𡶠
    # 0x21DA1: '',  # 𡶡
    0x21DA2: 'kuàng',  # 𡶢
    0x21DA3: 'suì',  # 𡶣
    0x21DA4: 'bēng,yòng',  # 𡶤
    0x21DA5: 'jiā',  # 𡶥
    0x21DA6: 'yà',  # 𡶦
    # 0x21DA7: '',  # 𡶧
    # 0x21DA8: '',  # 𡶨
    # 0x21DA9: '',  # 𡶩
    0x21DAA: 'kàn',  # 𡶪
    0x21DAB: 'niè',  # 𡶫
    # 0x21DAC: '',  # 𡶬
    0x21DAD: 'xíng',  # 𡶭
    # 0x21DAE: '',  # 𡶮
    0x21DAF: 'xì',  # 𡶯
    # 0x21DB0: '',  # 𡶰
    0x21DB1: 'lìn',  # 𡶱
    0x21DB2: 'duǒ',  # 𡶲
    # 0x21DB3: '',  # 𡶳
    # 0x21DB4: '',  # 𡶴
    # 0x21DB5: '',  # 𡶵
    # 0x21DB6: '',  # 𡶶
    # 0x21DB7: '',  # 𡶷
    # 0x21DB8: '',  # 𡶸
    # 0x21DB9: '',  # 𡶹
    # 0x21DBA: '',  # 𡶺
    # 0x21DBB: '',  # 𡶻
    # 0x21DBC: '',  # 𡶼
    # 0x21DBD: '',  # 𡶽
    0x21DBE: 'shí',  # 𡶾
    # 0x21DBF: '',  # 𡶿
    # 0x21DC0: '',  # 𡷀
    # 0x21DC1: '',  # 𡷁
    # 0x21DC2: '',  # 𡷂
    # 0x21DC3: '',  # 𡷃
    # 0x21DC4: '',  # 𡷄
    # 0x21DC5: '',  # 𡷅
    # 0x21DC6: '',  # 𡷆
    # 0x21DC7: '',  # 𡷇
    0x21DC8: 'shì',  # 𡷈
    # 0x21DC9: '',  # 𡷉
    # 0x21DCA: '',  # 𡷊
    0x21DCB: 'duì',  # 𡷋
    # 0x21DCC: '',  # 𡷌
    0x21DCD: 'jiāng',  # 𡷍
    0x21DCE: 'yǔ',  # 𡷎
    0x21DCF: 'lù',  # 𡷏
    0x21DD0: 'ěn',  # 𡷐
    # 0x21DD1: '',  # 𡷑
    # 0x21DD2: '',  # 𡷒
    0x21DD3: 'gǔ',  # 𡷓
    # 0x21DD4: '',  # 𡷔
    0x21DD5: 'wěi',  # 𡷕
    0x21DD6: 'chē',  # 𡷖
    0x21DD7: 'huàn,huán',  # 𡷗
    0x21DD8: 'bié',  # 𡷘
    # 0x21DD9: '',  # 𡷙
    # 0x21DDA: '',  # 𡷚
    0x21DDB: 'hàn',  # 𡷛
    0x21DDC: 'tuí',  # 𡷜
    0x21DDD: 'nà',  # 𡷝
    0x21DDE: 'qǐ',  # 𡷞
    # 0x21DDF: '',  # 𡷟
    0x21DE0: 'tóu',  # 𡷠
    0x21DE1: 'yuān',  # 𡷡
    0x21DE2: 'wáng',  # 𡷢
    # 0x21DE3: '',  # 𡷣
    0x21DE4: 'wú',  # 𡷤
    0x21DE5: 'gào',  # 𡷥
    # 0x21DE6: '',  # 𡷦
    # 0x21DE7: '',  # 𡷧
    0x21DE8: 'kēng,xíng',  # 𡷨
    # 0x21DE9: '',  # 𡷩
    0x21DEA: 'yí,níng',  # 𡷪
    0x21DEB: 'chéng',  # 𡷫
    # 0x21DEC: '',  # 𡷬
    # 0x21DED: '',  # 𡷭
    # 0x21DEE: '',  # 𡷮
    # 0x21DEF: '',  # 𡷯
    # 0x21DF0: '',  # 𡷰
    # 0x21DF1: '',  # 𡷱
    # 0x21DF2: '',  # 𡷲
    # 0x21DF3: '',  # 𡷳
    # 0x21DF4: '',  # 𡷴
    # 0x21DF5: '',  # 𡷵
    # 0x21DF6: '',  # 𡷶
    # 0x21DF7: '',  # 𡷷
    0x21DF8: 'xiāo',  # 𡷸
    # 0x21DF9: '',  # 𡷹
    0x21DFA: 'guǐ',  # 𡷺
    0x21DFB: 'yà',  # 𡷻
    0x21DFC: 'suì',  # 𡷼
    0x21DFD: 'sǒng',  # 𡷽
    # 0x21DFE: '',  # 𡷾
    0x21DFF: 'zhuó',  # 𡷿
    # 0x21E00: '',  # 𡸀
    # 0x21E01: '',  # 𡸁
    0x21E02: 'tū,tú',  # 𡸂
    0x21E03: 'jiǎn',  # 𡸃
    # 0x21E04: '',  # 𡸄
    0x21E05: 'tāo',  # 𡸅
    # 0x21E06: '',  # 𡸆
    # 0x21E07: '',  # 𡸇
    0x21E08: 'zè',  # 𡸈
    0x21E09: 'lì',  # 𡸉
    # 0x21E0A: '',  # 𡸊
    # 0x21E0B: '',  # 𡸋
    0x21E0C: 'zhù',  # 𡸌
    # 0x21E0D: '',  # 𡸍
    0x21E0E: 'jié',  # 𡸎
    # 0x21E0F: '',  # 𡸏
    # 0x21E10: '',  # 𡸐
    0x21E11: 'tì',  # 𡸑
    # 0x21E12: '',  # 𡸒
    # 0x21E13: '',  # 𡸓
    0x21E14: 'xié',  # 𡸔
    0x21E15: 'qióng',  # 𡸕
    # 0x21E16: '',  # 𡸖
    0x21E17: 'yà',  # 𡸗
    0x21E18: 'jū',  # 𡸘
    # 0x21E19: '',  # 𡸙
    # 0x21E1A: '',  # 𡸚
    0x21E1B: 'yín',  # 𡸛
    0x21E1C: 'zhí',  # 𡸜
    # 0x21E1D: '',  # 𡸝
    0x21E1E: 'kǎn',  # 𡸞
    0x21E1F: 'zī',  # 𡸟
    # 0x21E20: '',  # 𡸠
    0x21E21: 'kē',  # 𡸡
    # 0x21E22: '',  # 𡸢
    0x21E23: 'niè',  # 𡸣
    0x21E24: 'qiáng',  # 𡸤
    0x21E25: 'wǎn',  # 𡸥
    0x21E26: 'zé',  # 𡸦
    # 0x21E27: '',  # 𡸧
    0x21E28: 'jū',  # 𡸨
    # 0x21E29: '',  # 𡸩
    0x21E2A: 'zì',  # 𡸪
    0x21E2B: 'pīn',  # 𡸫
    # 0x21E2C: '',  # 𡸬
    # 0x21E2D: '',  # 𡸭
    # 0x21E2E: '',  # 𡸮
    # 0x21E2F: '',  # 𡸯
    # 0x21E30: '',  # 𡸰
    # 0x21E31: '',  # 𡸱
    # 0x21E32: '',  # 𡸲
    # 0x21E33: '',  # 𡸳
    # 0x21E34: '',  # 𡸴
    # 0x21E35: '',  # 𡸵
    # 0x21E36: '',  # 𡸶
    # 0x21E37: '',  # 𡸷
    # 0x21E38: '',  # 𡸸
    # 0x21E39: '',  # 𡸹
    # 0x21E3A: '',  # 𡸺
    # 0x21E3B: '',  # 𡸻
    # 0x21E3C: '',  # 𡸼
    # 0x21E3D: '',  # 𡸽
    # 0x21E3E: '',  # 𡸾
    # 0x21E3F: '',  # 𡸿
    # 0x21E40: '',  # 𡹀
    # 0x21E41: '',  # 𡹁
    # 0x21E42: '',  # 𡹂
    # 0x21E43: '',  # 𡹃
    0x21E44: 'yà',  # 𡹄
    # 0x21E45: '',  # 𡹅
    # 0x21E46: '',  # 𡹆
    0x21E47: 'lín',  # 𡹇
    # 0x21E48: '',  # 𡹈
    0x21E49: 'qí',  # 𡹉
    # 0x21E4A: '',  # 𡹊
    # 0x21E4B: '',  # 𡹋
    # 0x21E4C: '',  # 𡹌
    # 0x21E4D: '',  # 𡹍
    0x21E4E: 'huí',  # 𡹎
    # 0x21E4F: '',  # 𡹏
    # 0x21E50: '',  # 𡹐
    # 0x21E51: '',  # 𡹑
    # 0x21E52: '',  # 𡹒
    0x21E53: 'qì',  # 𡹓
    0x21E54: 'bēng',  # 𡹔
    0x21E55: 'yáng',  # 𡹕
    0x21E56: 'suì',  # 𡹖
    # 0x21E57: '',  # 𡹗
    0x21E58: 'qǐ',  # 𡹘
    0x21E59: 'guī',  # 𡹙
    # 0x21E5A: '',  # 𡹚
    # 0x21E5B: '',  # 𡹛
    # 0x21E5C: '',  # 𡹜
    # 0x21E5D: '',  # 𡹝
    # 0x21E5E: '',  # 𡹞
    # 0x21E5F: '',  # 𡹟
    # 0x21E60: '',  # 𡹠
    # 0x21E61: '',  # 𡹡
    0x21E62: 'qìn',  # 𡹢
    0x21E63: 'ē',  # 𡹣
    # 0x21E64: '',  # 𡹤
    0x21E65: 'zuò',  # 𡹥
    # 0x21E66: '',  # 𡹦
    # 0x21E67: '',  # 𡹧
    0x21E68: 'zè',  # 𡹨
    0x21E69: 'qì',  # 𡹩
    0x21E6A: 'jí',  # 𡹪
    # 0x21E6B: '',  # 𡹫
    0x21E6C: 'tuó',  # 𡹬
    0x21E6D: 'dié',  # 𡹭
    # 0x21E6E: '',  # 𡹮
    0x21E6F: 'huì',  # 𡹯
    0x21E70: 'máo',  # 𡹰
    # 0x21E71: '',  # 𡹱
    0x21E72: 'xǔ',  # 𡹲
    # 0x21E73: '',  # 𡹳
    # 0x21E74: '',  # 𡹴
    0x21E75: 'hóu',  # 𡹵
    0x21E76: 'yǎn',  # 𡹶
    0x21E77: 'xiáng',  # 𡹷
    0x21E78: 'cōng',  # 𡹸
    0x21E79: 'hú',  # 𡹹
    # 0x21E7A: '',  # 𡹺
    # 0x21E7B: '',  # 𡹻
    0x21E7C: 'àn,yǎn',  # 𡹼
    # 0x21E7D: '',  # 𡹽
    0x21E7E: 'bǐng',  # 𡹾
    # 0x21E7F: '',  # 𡹿
    # 0x21E80: '',  # 𡺀
    # 0x21E81: '',  # 𡺁
    # 0x21E82: '',  # 𡺂
    # 0x21E83: '',  # 𡺃
    # 0x21E84: '',  # 𡺄
    # 0x21E85: '',  # 𡺅
    # 0x21E86: '',  # 𡺆
    0x21E87: 'duǒ',  # 𡺇
    # 0x21E88: '',  # 𡺈
    # 0x21E89: '',  # 𡺉
    # 0x21E8A: '',  # 𡺊
    # 0x21E8B: '',  # 𡺋
    # 0x21E8C: '',  # 𡺌
    # 0x21E8D: '',  # 𡺍
    # 0x21E8E: '',  # 𡺎
    # 0x21E8F: '',  # 𡺏
    0x21E90: 'zhǔ',  # 𡺐
    0x21E91: 'dié',  # 𡺑
    0x21E92: 'yōu',  # 𡺒
    0x21E93: 'qǐ',  # 𡺓
    0x21E94: 'shí',  # 𡺔
    0x21E95: 'xūn',  # 𡺕
    0x21E96: 'yōu',  # 𡺖
    0x21E97: 'kān',  # 𡺗
    0x21E98: 'qiǎo',  # 𡺘
    # 0x21E99: '',  # 𡺙
    # 0x21E9A: '',  # 𡺚
    0x21E9B: 'qiāng,huà',  # 𡺛
    0x21E9C: 'pén',  # 𡺜
    # 0x21E9D: '',  # 𡺝
    0x21E9E: 'shí',  # 𡺞
    0x21E9F: 'quán',  # 𡺟
    # 0x21EA0: '',  # 𡺠
    0x21EA1: 'yíng',  # 𡺡
    # 0x21EA2: '',  # 𡺢
    # 0x21EA3: '',  # 𡺣
    # 0x21EA4: '',  # 𡺤
    # 0x21EA5: '',  # 𡺥
    # 0x21EA6: '',  # 𡺦
    0x21EA7: 'shā',  # 𡺧
    # 0x21EA8: '',  # 𡺨
    # 0x21EA9: '',  # 𡺩
    # 0x21EAA: '',  # 𡺪
    0x21EAB: 'tāo',  # 𡺫
    # 0x21EAC: '',  # 𡺬
    0x21EAD: 'hòng',  # 𡺭
    0x21EAE: 'pǐ',  # 𡺮
    0x21EAF: 'yáo',  # 𡺯
    # 0x21EB0: '',  # 𡺰
    # 0x21EB1: '',  # 𡺱
    0x21EB2: 'jùn',  # 𡺲
    # 0x21EB3: '',  # 𡺳
    0x21EB4: 'tú',  # 𡺴
    0x21EB5: 'chái',  # 𡺵
    # 0x21EB6: '',  # 𡺶
    0x21EB7: 'xià',  # 𡺷
    0x21EB8: 'qí',  # 𡺸
    # 0x21EB9: '',  # 𡺹
    0x21EBA: 'qióng',  # 𡺺
    # 0x21EBB: '',  # 𡺻
    # 0x21EBC: '',  # 𡺼
    0x21EBD: 'jìn',  # 𡺽
    # 0x21EBE: '',  # 𡺾
    # 0x21EBF: '',  # 𡺿
    # 0x21EC0: '',  # 𡻀
    # 0x21EC1: '',  # 𡻁
    # 0x21EC2: '',  # 𡻂
    # 0x21EC3: '',  # 𡻃
    # 0x21EC4: '',  # 𡻄
    # 0x21EC5: '',  # 𡻅
    # 0x21EC6: '',  # 𡻆
    # 0x21EC7: '',  # 𡻇
    0x21EC8: 'zhēn',  # 𡻈
    # 0x21EC9: '',  # 𡻉
    # 0x21ECA: '',  # 𡻊
    # 0x21ECB: '',  # 𡻋
    0x21ECC: 'zhū',  # 𡻌
    # 0x21ECD: '',  # 𡻍
    0x21ECE: 'xī',  # 𡻎
    # 0x21ECF: '',  # 𡻏
    0x21ED0: 'wēng',  # 𡻐
    0x21ED1: 'zhǒng',  # 𡻑
    0x21ED2: 'wù,máo',  # 𡻒
    # 0x21ED3: '',  # 𡻓
    # 0x21ED4: '',  # 𡻔
    # 0x21ED5: '',  # 𡻕
    # 0x21ED6: '',  # 𡻖
    # 0x21ED7: '',  # 𡻗
    0x21ED8: 'kē',  # 𡻘
    0x21ED9: 'kuò',  # 𡻙
    0x21EDA: 'kǎng',  # 𡻚
    # 0x21EDB: '',  # 𡻛
    # 0x21EDC: '',  # 𡻜
    0x21EDD: 'cháo',  # 𡻝
    0x21EDE: 'bì',  # 𡻞
    0x21EDF: 'mò',  # 𡻟
    0x21EE0: 'zhù',  # 𡻠
    0x21EE1: 'hàn,yán',  # 𡻡
    0x21EE2: 'yǔ',  # 𡻢
    0x21EE3: 'yí',  # 𡻣
    0x21EE4: 'má',  # 𡻤
    # 0x21EE5: '',  # 𡻥
    # 0x21EE6: '',  # 𡻦
    0x21EE7: 'qì',  # 𡻧
    0x21EE8: 'gùn',  # 𡻨
    0x21EE9: 'màn',  # 𡻩
    0x21EEA: 'liáo,liù',  # 𡻪
    0x21EEB: 'lín',  # 𡻫
    0x21EEC: 'zú',  # 𡻬
    0x21EED: 'lěi',  # 𡻭
    0x21EEE: 'hù',  # 𡻮
    0x21EEF: 'chuǎng',  # 𡻯
    0x21EF0: 'qì',  # 𡻰
    0x21EF1: 'léi',  # 𡻱
    # 0x21EF2: '',  # 𡻲
    # 0x21EF3: '',  # 𡻳
    # 0x21EF4: '',  # 𡻴
    # 0x21EF5: '',  # 𡻵
    # 0x21EF6: '',  # 𡻶
    # 0x21EF7: '',  # 𡻷
    # 0x21EF8: '',  # 𡻸
    # 0x21EF9: '',  # 𡻹
    # 0x21EFA: '',  # 𡻺
    # 0x21EFB: '',  # 𡻻
    # 0x21EFC: '',  # 𡻼
    # 0x21EFD: '',  # 𡻽
    # 0x21EFE: '',  # 𡻾
    # 0x21EFF: '',  # 𡻿
    0x21F00: 'huà',  # 𡼀
    0x21F01: 'chī',  # 𡼁
    # 0x21F02: '',  # 𡼂
    0x21F03: 'pó',  # 𡼃
    0x21F04: 'dié',  # 𡼄
    # 0x21F05: '',  # 𡼅
    # 0x21F06: '',  # 𡼆
    # 0x21F07: '',  # 𡼇
    # 0x21F08: '',  # 𡼈
    # 0x21F09: '',  # 𡼉
    0x21F0A: 'lěi',  # 𡼊
    # 0x21F0B: '',  # 𡼋
    # 0x21F0C: '',  # 𡼌
    # 0x21F0D: '',  # 𡼍
    0x21F0E: 'yǐ',  # 𡼎
    # 0x21F0F: '',  # 𡼏
    0x21F10: 'mín',  # 𡼐
    # 0x21F11: '',  # 𡼑
    # 0x21F12: '',  # 𡼒
    0x21F13: 'diàn',  # 𡼓
    # 0x21F14: '',  # 𡼔
    # 0x21F15: '',  # 𡼕
    0x21F16: 'dūn',  # 𡼖
    0x21F17: 'gāo',  # 𡼗
    0x21F18: 'hū',  # 𡼘
    # 0x21F19: '',  # 𡼙
    0x21F1A: 'xiāo',  # 𡼚
    0x21F1B: 'gá',  # 𡼛
    0x21F1C: 'pēng',  # 𡼜
    # 0x21F1D: '',  # 𡼝
    # 0x21F1E: '',  # 𡼞
    # 0x21F1F: '',  # 𡼟
    # 0x21F20: '',  # 𡼠
    # 0x21F21: '',  # 𡼡
    # 0x21F22: '',  # 𡼢
    # 0x21F23: '',  # 𡼣
    # 0x21F24: '',  # 𡼤
    # 0x21F25: '',  # 𡼥
    # 0x21F26: '',  # 𡼦
    # 0x21F27: '',  # 𡼧
    # 0x21F28: '',  # 𡼨
    # 0x21F29: '',  # 𡼩
    # 0x21F2A: '',  # 𡼪
    # 0x21F2B: '',  # 𡼫
    0x21F2C: 'shěn',  # 𡼬
    # 0x21F2D: '',  # 𡼭
    # 0x21F2E: '',  # 𡼮
    # 0x21F2F: '',  # 𡼯
    # 0x21F30: '',  # 𡼰
    0x21F31: 'wéi',  # 𡼱
    # 0x21F32: '',  # 𡼲
    # 0x21F33: '',  # 𡼳
    # 0x21F34: '',  # 𡼴
    # 0x21F35: '',  # 𡼵
    # 0x21F36: '',  # 𡼶
    # 0x21F37: '',  # 𡼷
    # 0x21F38: '',  # 𡼸
    # 0x21F39: '',  # 𡼹
    # 0x21F3A: '',  # 𡼺
    0x21F3B: 'duì',  # 𡼻
    0x21F3C: 'cháo',  # 𡼼
    0x21F3D: 'yǐn',  # 𡼽
    0x21F3E: 'kuài',  # 𡼾
    0x21F3F: 'kū',  # 𡼿
    # 0x21F40: '',  # 𡽀
    0x21F41: 'zuì',  # 𡽁
    0x21F42: 'gǔ',  # 𡽂
    0x21F43: 'duò',  # 𡽃
    # 0x21F44: '',  # 𡽄
    0x21F45: 'yùn',  # 𡽅
    0x21F46: 'zhì',  # 𡽆
    # 0x21F47: '',  # 𡽇
    # 0x21F48: '',  # 𡽈
    0x21F49: 'jì',  # 𡽉
    0x21F4A: 'chēng',  # 𡽊
    # 0x21F4B: '',  # 𡽋
    # 0x21F4C: '',  # 𡽌
    # 0x21F4D: '',  # 𡽍
    # 0x21F4E: '',  # 𡽎
    # 0x21F4F: '',  # 𡽏
    # 0x21F50: '',  # 𡽐
    # 0x21F51: '',  # 𡽑
    # 0x21F52: '',  # 𡽒
    # 0x21F53: '',  # 𡽓
    # 0x21F54: '',  # 𡽔
    0x21F55: 'zuì',  # 𡽕
    0x21F56: 'xiè',  # 𡽖
    # 0x21F57: '',  # 𡽗
    # 0x21F58: '',  # 𡽘
    # 0x21F59: '',  # 𡽙
    # 0x21F5A: '',  # 𡽚
    0x21F5B: 'zuǐ',  # 𡽛
    0x21F5C: 'án',  # 𡽜
    0x21F5D: 'hāo',  # 𡽝
    # 0x21F5E: '',  # 𡽞
    # 0x21F5F: '',  # 𡽟
    0x21F60: 'pǒ',  # 𡽠
    # 0x21F61: '',  # 𡽡
    0x21F62: 'dí',  # 𡽢
    0x21F63: 'yè',  # 𡽣
    # 0x21F64: '',  # 𡽤
    # 0x21F65: '',  # 𡽥
    # 0x21F66: '',  # 𡽦
    0x21F67: 'náo',  # 𡽧
    # 0x21F68: '',  # 𡽨
    # 0x21F69: '',  # 𡽩
    # 0x21F6A: '',  # 𡽪
    # 0x21F6B: '',  # 𡽫
    # 0x21F6C: '',  # 𡽬
    # 0x21F6D: '',  # 𡽭
    # 0x21F6E: '',  # 𡽮
    # 0x21F6F: '',  # 𡽯
    # 0x21F70: '',  # 𡽰
    0x21F71: 'jié',  # 𡽱
    0x21F72: 'bàng',  # 𡽲
    0x21F73: 'lǎn',  # 𡽳
    0x21F74: 'cáng',  # 𡽴
    # 0x21F75: '',  # 𡽵
    0x21F76: 'bì',  # 𡽶
    # 0x21F77: '',  # 𡽷
    # 0x21F78: '',  # 𡽸
    # 0x21F79: '',  # 𡽹
    # 0x21F7A: '',  # 𡽺
    0x21F7B: 'zhǎn',  # 𡽻
    0x21F7C: 'qì',  # 𡽼
    # 0x21F7D: '',  # 𡽽
    # 0x21F7E: '',  # 𡽾
    # 0x21F7F: '',  # 𡽿
    # 0x21F80: '',  # 𡾀
    # 0x21F81: '',  # 𡾁
    0x21F82: 'náo',  # 𡾂
    # 0x21F83: '',  # 𡾃
    # 0x21F84: '',  # 𡾄
    0x21F85: 'lǜ',  # 𡾅
    # 0x21F86: '',  # 𡾆
    0x21F87: 'kuàng',  # 𡾇
    # 0x21F88: '',  # 𡾈
    0x21F89: 'mó',  # 𡾉
    # 0x21F8A: '',  # 𡾊
    0x21F8B: 'lěi,léi',  # 𡾋
    0x21F8C: 'páo',  # 𡾌
    # 0x21F8D: '',  # 𡾍
    # 0x21F8E: '',  # 𡾎
    # 0x21F8F: '',  # 𡾏
    # 0x21F90: '',  # 𡾐
    # 0x21F91: '',  # 𡾑
    0x21F92: 'lì',  # 𡾒
    0x21F93: 'céng',  # 𡾓
    # 0x21F94: '',  # 𡾔
    0x21F95: 'dàng',  # 𡾕
    0x21F96: 'lěi',  # 𡾖
    # 0x21F97: '',  # 𡾗
    # 0x21F98: '',  # 𡾘
    0x21F99: 'è',  # 𡾙
    # 0x21F9A: '',  # 𡾚
    0x21F9B: 'bèng',  # 𡾛
    0x21F9C: 'jué,huò',  # 𡾜
    0x21F9D: 'huái',  # 𡾝
    # 0x21F9E: '',  # 𡾞
    # 0x21F9F: '',  # 𡾟
    # 0x21FA0: '',  # 𡾠
    # 0x21FA1: '',  # 𡾡
    # 0x21FA2: '',  # 𡾢
    # 0x21FA3: '',  # 𡾣
    # 0x21FA4: '',  # 𡾤
    0x21FA5: 'xuán',  # 𡾥
    0x21FA6: 'niè',  # 𡾦
    # 0x21FA7: '',  # 𡾧
    0x21FA8: 'hài',  # 𡾨
    # 0x21FA9: '',  # 𡾩
    # 0x21FAA: '',  # 𡾪
    # 0x21FAB: '',  # 𡾫
    # 0x21FAC: '',  # 𡾬
    # 0x21FAD: '',  # 𡾭
    0x21FAE: 'xiǎn',  # 𡾮
    # 0x21FAF: '',  # 𡾯
    0x21FB0: 'jiǎn',  # 𡾰
    0x21FB1: 'mí',  # 𡾱
    0x21FB2: 'niè',  # 𡾲
    # 0x21FB3: '',  # 𡾳
    # 0x21FB4: '',  # 𡾴
    # 0x21FB5: '',  # 𡾵
    # 0x21FB6: '',  # 𡾶
    # 0x21FB7: '',  # 𡾷
    # 0x21FB8: '',  # 𡾸
    # 0x21FB9: '',  # 𡾹
    # 0x21FBA: '',  # 𡾺
    0x21FBB: 'cáng',  # 𡾻
    0x21FBC: 'sǒng',  # 𡾼
    0x21FBD: 'zēng',  # 𡾽
    0x21FBE: 'yì',  # 𡾾
    # 0x21FBF: '',  # 𡾿
    # 0x21FC0: '',  # 𡿀
    # 0x21FC1: '',  # 𡿁
    0x21FC2: 'chóng',  # 𡿂
    # 0x21FC3: '',  # 𡿃
    0x21FC4: 'cáng',  # 𡿄
    # 0x21FC5: '',  # 𡿅
    # 0x21FC6: '',  # 𡿆
    # 0x21FC7: '',  # 𡿇
    # 0x21FC8: '',  # 𡿈
    0x21FC9: 'lěi',  # 𡿉
    0x21FCA: 'nuó',  # 𡿊
    0x21FCB: 'lì',  # 𡿋
    # 0x21FCC: '',  # 𡿌
    # 0x21FCD: '',  # 𡿍
    0x21FCE: 'lí',  # 𡿎
    0x21FCF: 'luó',  # 𡿏
    # 0x21FD0: '',  # 𡿐
    # 0x21FD1: '',  # 𡿑
    # 0x21FD2: '',  # 𡿒
    0x21FD3: 'tǎng',  # 𡿓
    # 0x21FD4: '',  # 𡿔
    # 0x21FD5: '',  # 𡿕
    0x21FD6: 'niè,yà',  # 𡿖
    0x21FD7: 'niè',  # 𡿗
    # 0x21FD8: '',  # 𡿘
    0x21FD9: 'jī',  # 𡿙
    # 0x21FDA: '',  # 𡿚
    0x21FDB: 'lěi',  # 𡿛
    # 0x21FDC: '',  # 𡿜
    0x21FDD: 'nàng',  # 𡿝
    # 0x21FDE: '',  # 𡿞
    # 0x21FDF: '',  # 𡿟
    0x21FE0: 'lín',  # 𡿠
    0x21FE1: 'líng',  # 𡿡
    # 0x21FE2: '',  # 𡿢
    # 0x21FE3: '',  # 𡿣
    0x21FE4: 'xián',  # 𡿤
    0x21FE5: 'yù',  # 𡿥
    # 0x21FE6: '',  # 𡿦
    0x21FE7: 'zāi',  # 𡿧
    0x21FE8: 'quǎn',  # 𡿨
    0x21FE9: 'liè',  # 𡿩
    0x21FEA: 'liè',  # 𡿪
    # 0x21FEB: '',  # 𡿫
    # 0x21FEC: '',  # 𡿬
    # 0x21FED: '',  # 𡿭
    # 0x21FEE: '',  # 𡿮
    0x21FEF: 'yù',  # 𡿯
    0x21FF0: 'huāng',  # 𡿰
    # 0x21FF1: '',  # 𡿱
    # 0x21FF2: '',  # 𡿲
    # 0x21FF3: '',  # 𡿳
    # 0x21FF4: '',  # 𡿴
    # 0x21FF5: '',  # 𡿵
    # 0x21FF6: '',  # 𡿶
    # 0x21FF7: '',  # 𡿷
    # 0x21FF8: '',  # 𡿸
    # 0x21FF9: '',  # 𡿹
    0x21FFA: 'nǎo',  # 𡿺
    # 0x21FFB: '',  # 𡿻
    0x21FFC: 'xùn',  # 𡿼
    # 0x21FFD: '',  # 𡿽
    0x21FFE: 'jú',  # 𡿾
    0x21FFF: 'huò',  # 𡿿
    # 0x22000: '',  # 𢀀
    0x22001: 'yì',  # 𢀁
    # 0x22002: '',  # 𢀂
    # 0x22003: '',  # 𢀃
    # 0x22004: '',  # 𢀄
    # 0x22005: '',  # 𢀅
    # 0x22006: '',  # 𢀆
    # 0x22007: '',  # 𢀇
    # 0x22008: '',  # 𢀈
    # 0x22009: '',  # 𢀉
    0x2200A: 'xī',  # 𢀊
    0x2200B: 'sè',  # 𢀋
    0x2200C: 'jiǎo',  # 𢀌
    0x2200D: 'yōng',  # 𢀍
    # 0x2200E: '',  # 𢀎
    # 0x2200F: '',  # 𢀏
    # 0x22010: '',  # 𢀐
    # 0x22011: '',  # 𢀑
    # 0x22012: '',  # 𢀒
    0x22013: 'jù',  # 𢀓
    # 0x22014: '',  # 𢀔
    0x22015: 'shī',  # 𢀕
    0x22016: 'jīng',  # 𢀖
    0x22017: 'wàn',  # 𢀗
    0x22018: 'yě',  # 𢀘
    0x22019: 'jiū',  # 𢀙
    # 0x2201A: '',  # 𢀚
    # 0x2201B: '',  # 𢀛
    0x2201C: 'gǒng',  # 𢀜
    # 0x2201D: '',  # 𢀝
    # 0x2201E: '',  # 𢀞
    # 0x2201F: '',  # 𢀟
    # 0x22020: '',  # 𢀠
    0x22021: 'huī,zuǒ',  # 𢀡
    # 0x22022: '',  # 𢀢
    # 0x22023: '',  # 𢀣
    # 0x22024: '',  # 𢀤
    # 0x22025: '',  # 𢀥
    # 0x22026: '',  # 𢀦
    # 0x22027: '',  # 𢀧
    # 0x22028: '',  # 𢀨
    # 0x22029: '',  # 𢀩
    0x2202A: 'ěr',  # 𢀪
    # 0x2202B: '',  # 𢀫
    # 0x2202C: '',  # 𢀬
    # 0x2202D: '',  # 𢀭
    # 0x2202E: '',  # 𢀮
    # 0x2202F: '',  # 𢀯
    # 0x22030: '',  # 𢀰
    # 0x22031: '',  # 𢀱
    # 0x22032: '',  # 𢀲
    # 0x22033: '',  # 𢀳
    # 0x22034: '',  # 𢀴
    0x22035: 'hàn',  # 𢀵
    # 0x22036: '',  # 𢀶
    # 0x22037: '',  # 𢀷
    # 0x22038: '',  # 𢀸
    # 0x22039: '',  # 𢀹
    # 0x2203A: '',  # 𢀺
    # 0x2203B: '',  # 𢀻
    0x2203C: 'fú',  # 𢀼
    # 0x2203D: '',  # 𢀽
    # 0x2203E: '',  # 𢀾
    # 0x2203F: '',  # 𢀿
    0x22040: 'fú',  # 𢁀
    0x22041: 'zhuó',  # 𢁁
    0x22042: 'jī,jì',  # 𢁂
    # 0x22043: '',  # 𢁃
    # 0x22044: '',  # 𢁄
    # 0x22045: '',  # 𢁅
    # 0x22046: '',  # 𢁆
    # 0x22047: '',  # 𢁇
    # 0x22048: '',  # 𢁈
    # 0x22049: '',  # 𢁉
    # 0x2204A: '',  # 𢁊
    # 0x2204B: '',  # 𢁋
    # 0x2204C: '',  # 𢁌
    # 0x2204D: '',  # 𢁍
    # 0x2204E: '',  # 𢁎
    0x2204F: 'bāng',  # 𢁏
    # 0x22050: '',  # 𢁐
    # 0x22051: '',  # 𢁑
    0x22052: 'qí',  # 𢁒
    0x22053: 'shǐ,hài',  # 𢁓
    # 0x22054: '',  # 𢁔
    0x22055: 'diǎo',  # 𢁕
    0x22056: 'pèi',  # 𢁖
    0x22057: 'xiǎn,gàn',  # 𢁗
    0x22058: 'sān',  # 𢁘
    # 0x22059: '',  # 𢁙
    # 0x2205A: '',  # 𢁚
    # 0x2205B: '',  # 𢁛
    # 0x2205C: '',  # 𢁜
    0x2205D: 'cháng',  # 𢁝
    0x2205E: 'yuē',  # 𢁞
    # 0x2205F: '',  # 𢁟
    0x22060: 'gōng',  # 𢁠
    # 0x22061: '',  # 𢁡
    0x22062: 'wū',  # 𢁢
    # 0x22063: '',  # 𢁣
    0x22064: 'fēn',  # 𢁤
    0x22065: 'fēn',  # 𢁥
    # 0x22066: '',  # 𢁦
    0x22067: 'chǎn',  # 𢁧
    # 0x22068: '',  # 𢁨
    0x22069: 'nèi',  # 𢁩
    0x2206A: 'jué',  # 𢁪
    # 0x2206B: '',  # 𢁫
    0x2206C: 'zhǎo',  # 𢁬
    # 0x2206D: '',  # 𢁭
    0x2206E: 'qián',  # 𢁮
    # 0x2206F: '',  # 𢁯
    # 0x22070: '',  # 𢁰
    0x22071: 'ǎo',  # 𢁱
    # 0x22072: '',  # 𢁲
    # 0x22073: '',  # 𢁳
    # 0x22074: '',  # 𢁴
    # 0x22075: '',  # 𢁵
    0x22076: 'wǎng',  # 𢁶
    0x22077: 'zhōng',  # 𢁷
    # 0x22078: '',  # 𢁸
    0x22079: 'huāng',  # 𢁹
    # 0x2207A: '',  # 𢁺
    0x2207B: 'bù',  # 𢁻
    0x2207C: 'zhǔ',  # 𢁼
    0x2207D: 'bì',  # 𢁽
    0x2207E: 'chāo',  # 𢁾
    0x2207F: 'zhēng',  # 𢁿
    0x22080: 'fú',  # 𢂀
    0x22081: 'kōu,qú',  # 𢂁
    # 0x22082: '',  # 𢂂
    0x22083: 'zuó',  # 𢂃
    0x22084: 'xuàn',  # 𢂄
    # 0x22085: '',  # 𢂅
    0x22086: 'fù',  # 𢂆
    # 0x22087: '',  # 𢂇
    # 0x22088: '',  # 𢂈
    # 0x22089: '',  # 𢂉
    0x2208A: 'yǎo',  # 𢂊
    # 0x2208B: '',  # 𢂋
    # 0x2208C: '',  # 𢂌
    0x2208D: 'bō',  # 𢂍
    # 0x2208E: '',  # 𢂎
    0x2208F: 'bèi',  # 𢂏
    0x22090: 'xié',  # 𢂐
    0x22091: 'shì',  # 𢂑
    0x22092: 'yí',  # 𢂒
    # 0x22093: '',  # 𢂓
    0x22094: 'hóng',  # 𢂔
    0x22095: 'cuì',  # 𢂕
    # 0x22096: '',  # 𢂖
    0x22097: 'yì',  # 𢂗
    0x22098: 'zhuān',  # 𢂘
    # 0x22099: '',  # 𢂙
    # 0x2209A: '',  # 𢂚
    # 0x2209B: '',  # 𢂛
    # 0x2209C: '',  # 𢂜
    0x2209D: 'chì',  # 𢂝
    # 0x2209E: '',  # 𢂞
    # 0x2209F: '',  # 𢂟
    # 0x220A0: '',  # 𢂠
    # 0x220A1: '',  # 𢂡
    # 0x220A2: '',  # 𢂢
    # 0x220A3: '',  # 𢂣
    0x220A4: 'pō,lù',  # 𢂤
    # 0x220A5: '',  # 𢂥
    # 0x220A6: '',  # 𢂦
    # 0x220A7: '',  # 𢂧
    0x220A8: 'yín',  # 𢂨
    # 0x220A9: '',  # 𢂩
    # 0x220AA: '',  # 𢂪
    # 0x220AB: '',  # 𢂫
    # 0x220AC: '',  # 𢂬
    # 0x220AD: '',  # 𢂭
    # 0x220AE: '',  # 𢂮
    # 0x220AF: '',  # 𢂯
    # 0x220B0: '',  # 𢂰
    0x220B1: 'yuàn',  # 𢂱
    # 0x220B2: '',  # 𢂲
    # 0x220B3: '',  # 𢂳
    # 0x220B4: '',  # 𢂴
    # 0x220B5: '',  # 𢂵
    0x220B6: 'jiōng',  # 𢂶
    0x220B7: 'jiá',  # 𢂷
    # 0x220B8: '',  # 𢂸
    0x220B9: 'mào',  # 𢂹
    0x220BA: 'qiàn',  # 𢂺
    # 0x220BB: '',  # 𢂻
    0x220BC: 'yì',  # 𢂼
    # 0x220BD: '',  # 𢂽
    # 0x220BE: '',  # 𢂾
    # 0x220BF: '',  # 𢂿
    0x220C0: 'wú',  # 𢃀
    # 0x220C1: '',  # 𢃁
    # 0x220C2: '',  # 𢃂
    # 0x220C3: '',  # 𢃃
    # 0x220C4: '',  # 𢃄
    # 0x220C5: '',  # 𢃅
    # 0x220C6: '',  # 𢃆
    # 0x220C7: '',  # 𢃇
    # 0x220C8: '',  # 𢃈
    # 0x220C9: '',  # 𢃉
    # 0x220CA: '',  # 𢃊
    # 0x220CB: '',  # 𢃋
    # 0x220CC: '',  # 𢃌
    0x220CD: 'bēi',  # 𢃍
    0x220CE: 'huò',  # 𢃎
    0x220CF: 'cóng',  # 𢃏
    0x220D0: 'kōng',  # 𢃐
    # 0x220D1: '',  # 𢃑
    # 0x220D2: '',  # 𢃒
    # 0x220D3: '',  # 𢃓
    # 0x220D4: '',  # 𢃔
    0x220D5: 'tà',  # 𢃕
    # 0x220D6: '',  # 𢃖
    0x220D7: 'hàn',  # 𢃗
    0x220D8: 'qiàn',  # 𢃘
    # 0x220D9: '',  # 𢃙
    # 0x220DA: '',  # 𢃚
    0x220DB: 'qí',  # 𢃛
    0x220DC: 'zhí',  # 𢃜
    # 0x220DD: '',  # 𢃝
    # 0x220DE: '',  # 𢃞
    # 0x220DF: '',  # 𢃟
    # 0x220E0: '',  # 𢃠
    # 0x220E1: '',  # 𢃡
    0x220E2: 'sè',  # 𢃢
    # 0x220E3: '',  # 𢃣
    # 0x220E4: '',  # 𢃤
    0x220E5: 'qiān',  # 𢃥
    0x220E6: 'guǒ',  # 𢃦
    # 0x220E7: '',  # 𢃧
    # 0x220E8: '',  # 𢃨
    0x220E9: 'gǔn,juǎn',  # 𢃩
    # 0x220EA: '',  # 𢃪
    # 0x220EB: '',  # 𢃫
    0x220EC: 'jiān',  # 𢃬
    0x220ED: 'zhōng',  # 𢃭
    0x220EE: 'miǎn',  # 𢃮
    0x220EF: 'guǐ',  # 𢃯
    0x220F0: 'shì',  # 𢃰
    0x220F1: 'móu',  # 𢃱
    0x220F2: 'è',  # 𢃲
    0x220F3: 'bǎ',  # 𢃳
    0x220F4: 'là',  # 𢃴
    # 0x220F5: '',  # 𢃵
    # 0x220F6: '',  # 𢃶
    # 0x220F7: '',  # 𢃷
    0x220F8: 'zhòu',  # 𢃸
    # 0x220F9: '',  # 𢃹
    0x220FA: 'jí',  # 𢃺
    # 0x220FB: '',  # 𢃻
    # 0x220FC: '',  # 𢃼
    # 0x220FD: '',  # 𢃽
    # 0x220FE: '',  # 𢃾
    # 0x220FF: '',  # 𢃿
    0x22100: 'zǎo',  # 𢄀
    # 0x22101: '',  # 𢄁
    # 0x22102: '',  # 𢄂
    # 0x22103: '',  # 𢄃
    0x22104: 'zhā',  # 𢄄
    0x22105: 'yì',  # 𢄅
    # 0x22106: '',  # 𢄆
    0x22107: 'gǒu',  # 𢄇
    # 0x22108: '',  # 𢄈
    # 0x22109: '',  # 𢄉
    0x2210A: 'guī',  # 𢄊
    0x2210B: 'yīng',  # 𢄋
    0x2210C: 'shǎi',  # 𢄌
    0x2210D: 'hé,gé',  # 𢄍
    0x2210E: 'bàng',  # 𢄎
    0x2210F: 'mò',  # 𢄏
    0x22110: 'méng',  # 𢄐
    # 0x22111: '',  # 𢄑
    # 0x22112: '',  # 𢄒
    0x22113: 'wù',  # 𢄓
    0x22114: 'dài',  # 𢄔
    # 0x22115: '',  # 𢄕
    # 0x22116: '',  # 𢄖
    0x22117: 'jiǒng',  # 𢄗
    # 0x22118: '',  # 𢄘
    # 0x22119: '',  # 𢄙
    # 0x2211A: '',  # 𢄚
    # 0x2211B: '',  # 𢄛
    0x2211C: 'hàn',  # 𢄜
    # 0x2211D: '',  # 𢄝
    # 0x2211E: '',  # 𢄞
    0x2211F: 'tōng',  # 𢄟
    0x22120: 'kōu',  # 𢄠
    0x22121: 'lí',  # 𢄡
    0x22122: 'zhì',  # 𢄢
    0x22123: 'huì',  # 𢄣
    0x22124: 'zǎn',  # 𢄤
    0x22125: 'yì',  # 𢄥
    0x22126: 'diǎo',  # 𢄦
    0x22127: 'cù',  # 𢄧
    # 0x22128: '',  # 𢄨
    # 0x22129: '',  # 𢄩
    # 0x2212A: '',  # 𢄪
    # 0x2212B: '',  # 𢄫
    # 0x2212C: '',  # 𢄬
    # 0x2212D: '',  # 𢄭
    # 0x2212E: '',  # 𢄮
    # 0x2212F: '',  # 𢄯
    # 0x22130: '',  # 𢄰
    0x22131: 'zhì',  # 𢄱
    # 0x22132: '',  # 𢄲
    0x22133: 'kuǎ',  # 𢄳
    # 0x22134: '',  # 𢄴
    0x22135: 'xiàng',  # 𢄵
    0x22136: 'huà',  # 𢄶
    0x22137: 'liáo',  # 𢄷
    0x22138: 'cuì',  # 𢄸
    0x22139: 'qiāo',  # 𢄹
    0x2213A: 'jiǎo',  # 𢄺
    # 0x2213B: '',  # 𢄻
    0x2213C: 'xū',  # 𢄼
    0x2213D: 'èr',  # 𢄽
    # 0x2213E: '',  # 𢄾
    0x2213F: 'tuō',  # 𢄿
    0x22140: 'tán',  # 𢅀
    0x22141: 'zhì',  # 𢅁
    # 0x22142: '',  # 𢅂
    # 0x22143: '',  # 𢅃
    # 0x22144: '',  # 𢅄
    # 0x22145: '',  # 𢅅
    # 0x22146: '',  # 𢅆
    # 0x22147: '',  # 𢅇
    0x22148: 'nǎo',  # 𢅈
    0x22149: 'mào',  # 𢅉
    0x2214A: 'dì',  # 𢅊
    0x2214B: 'céng',  # 𢅋
    # 0x2214C: '',  # 𢅌
    # 0x2214D: '',  # 𢅍
    0x2214E: 'jiǎo',  # 𢅎
    0x2214F: 'lián',  # 𢅏
    # 0x22150: '',  # 𢅐
    0x22151: 'shā',  # 𢅑
    0x22152: 'dàn',  # 𢅒
    # 0x22153: '',  # 𢅓
    # 0x22154: '',  # 𢅔
    0x22155: 'suì',  # 𢅕
    # 0x22156: '',  # 𢅖
    0x22157: 'guò',  # 𢅗
    # 0x22158: '',  # 𢅘
    # 0x22159: '',  # 𢅙
    0x2215A: 'biǎo,biāo',  # 𢅚
    # 0x2215B: '',  # 𢅛
    0x2215C: 'cì',  # 𢅜
    0x2215D: 'diàn',  # 𢅝
    0x2215E: 'lǜ',  # 𢅞
    0x2215F: 'nǐ',  # 𢅟
    0x22160: 'yǎn',  # 𢅠
    0x22161: 'lán',  # 𢅡
    # 0x22162: '',  # 𢅢
    # 0x22163: '',  # 𢅣
    0x22164: 'gài',  # 𢅤
    0x22165: 'chú',  # 𢅥
    # 0x22166: '',  # 𢅦
    # 0x22167: '',  # 𢅧
    # 0x22168: '',  # 𢅨
    0x22169: 'bì',  # 𢅩
    0x2216A: 'zú',  # 𢅪
    0x2216B: 'huì',  # 𢅫
    # 0x2216C: '',  # 𢅬
    0x2216D: 'lǎi',  # 𢅭
    0x2216E: 'xián',  # 𢅮
    0x2216F: 'fèn',  # 𢅯
    0x22170: 'hè',  # 𢅰
    # 0x22171: '',  # 𢅱
    # 0x22172: '',  # 𢅲
    # 0x22173: '',  # 𢅳
    # 0x22174: '',  # 𢅴
    # 0x22175: '',  # 𢅵
    # 0x22176: '',  # 𢅶
    # 0x22177: '',  # 𢅷
    # 0x22178: '',  # 𢅸
    0x22179: 'yào',  # 𢅹
    0x2217A: 'zhǎn',  # 𢅺
    # 0x2217B: '',  # 𢅻
    0x2217C: 'néi',  # 𢅼
    # 0x2217D: '',  # 𢅽
    0x2217E: 'luǒ',  # 𢅾
    # 0x2217F: '',  # 𢅿
    0x22180: 'yuán',  # 𢆀
    # 0x22181: '',  # 𢆁
    0x22182: 'néng',  # 𢆂
    # 0x22183: '',  # 𢆃
    # 0x22184: '',  # 𢆄
    # 0x22185: '',  # 𢆅
    # 0x22186: '',  # 𢆆
    # 0x22187: '',  # 𢆇
    # 0x22188: '',  # 𢆈
    0x22189: 'rěn',  # 𢆉
    # 0x2218A: '',  # 𢆊
    # 0x2218B: '',  # 𢆋
    # 0x2218C: '',  # 𢆌
    0x2218D: 'chā',  # 𢆍
    # 0x2218E: '',  # 𢆎
    # 0x2218F: '',  # 𢆏
    # 0x22190: '',  # 𢆐
    # 0x22191: '',  # 𢆑
    # 0x22192: '',  # 𢆒
    # 0x22193: '',  # 𢆓
    # 0x22194: '',  # 𢆔
    # 0x22195: '',  # 𢆕
    # 0x22196: '',  # 𢆖
    # 0x22197: '',  # 𢆗
    # 0x22198: '',  # 𢆘
    # 0x22199: '',  # 𢆙
    # 0x2219A: '',  # 𢆚
    # 0x2219B: '',  # 𢆛
    0x2219C: 'gé',  # 𢆜
    # 0x2219D: '',  # 𢆝
    0x2219E: 'jiǎn',  # 𢆞
    0x2219F: 'píng',  # 𢆟
    # 0x221A0: '',  # 𢆠
    0x221A1: 'niān',  # 𢆡
    # 0x221A2: '',  # 𢆢
    0x221A3: 'biè',  # 𢆣
    # 0x221A4: '',  # 𢆤
    # 0x221A5: '',  # 𢆥
    0x221A6: 'jiàn',  # 𢆦
    # 0x221A7: '',  # 𢆧
    # 0x221A8: '',  # 𢆨
    0x221A9: 'bìng',  # 𢆩
    # 0x221AA: '',  # 𢆪
    # 0x221AB: '',  # 𢆫
    # 0x221AC: '',  # 𢆬
    # 0x221AD: '',  # 𢆭
    # 0x221AE: '',  # 𢆮
    0x221AF: 'mì,xuán',  # 𢆯
    0x221B0: 'hù',  # 𢆰
    # 0x221B1: '',  # 𢆱
    # 0x221B2: '',  # 𢆲
    # 0x221B3: '',  # 𢆳
    0x221B4: 'diǎo',  # 𢆴
    # 0x221B5: '',  # 𢆵
    0x221B6: 'yōu,zī',  # 𢆶
    0x221B7: 'yāo,miào',  # 𢆷
    0x221B8: 'bēng',  # 𢆸
    # 0x221B9: '',  # 𢆹
    0x221BA: 'chén',  # 𢆺
    0x221BB: 'jī,duì',  # 𢆻
    # 0x221BC: '',  # 𢆼
    0x221BD: 'yāo',  # 𢆽
    # 0x221BE: '',  # 𢆾
    # 0x221BF: '',  # 𢆿
    # 0x221C0: '',  # 𢇀
    # 0x221C1: '',  # 𢇁
    # 0x221C2: '',  # 𢇂
    # 0x221C3: '',  # 𢇃
    # 0x221C4: '',  # 𢇄
    0x221C5: 'guān',  # 𢇅
    # 0x221C6: '',  # 𢇆
    0x221C7: 'guān',  # 𢇇
    0x221C8: 'yàn',  # 𢇈
    # 0x221C9: '',  # 𢇉
    # 0x221CA: '',  # 𢇊
    # 0x221CB: '',  # 𢇋
    # 0x221CC: '',  # 𢇌
    # 0x221CD: '',  # 𢇍
    # 0x221CE: '',  # 𢇎
    # 0x221CF: '',  # 𢇏
    # 0x221D0: '',  # 𢇐
    # 0x221D1: '',  # 𢇑
    # 0x221D2: '',  # 𢇒
    # 0x221D3: '',  # 𢇓
    # 0x221D4: '',  # 𢇔
    0x221D5: 'chǐ',  # 𢇕
    # 0x221D6: '',  # 𢇖
    0x221D7: 'shà',  # 𢇗
    0x221D8: 'yǎn',  # 𢇘
    0x221D9: 'yì',  # 𢇙
    0x221DA: 'yì',  # 𢇚
    0x221DB: 'chè,chǐ',  # 𢇛
    # 0x221DC: '',  # 𢇜
    # 0x221DD: '',  # 𢇝
    0x221DE: 'hàn',  # 𢇞
    0x221DF: 'huāng',  # 𢇟
    # 0x221E0: '',  # 𢇠
    # 0x221E1: '',  # 𢇡
    # 0x221E2: '',  # 𢇢
    # 0x221E3: '',  # 𢇣
    0x221E4: 'shuì',  # 𢇤
    0x221E5: 'suì',  # 𢇥
    0x221E6: 'rén',  # 𢇦
    0x221E7: 'tán',  # 𢇧
    0x221E8: 'zhǐ',  # 𢇨
    # 0x221E9: '',  # 𢇩
    0x221EA: 'fàn',  # 𢇪
    0x221EB: 'fěng',  # 𢇫
    # 0x221EC: '',  # 𢇬
    # 0x221ED: '',  # 𢇭
    # 0x221EE: '',  # 𢇮
    # 0x221EF: '',  # 𢇯
    0x221F0: 'tán',  # 𢇰
    # 0x221F1: '',  # 𢇱
    0x221F2: 'mí',  # 𢇲
    0x221F3: 'pí',  # 𢇳
    0x221F4: 'bù',  # 𢇴
    0x221F5: 'nà',  # 𢇵
    0x221F6: 'tián',  # 𢇶
    0x221F7: 'bá',  # 𢇷
    0x221F8: 'yì',  # 𢇸
    # 0x221F9: '',  # 𢇹
    # 0x221FA: '',  # 𢇺
    # 0x221FB: '',  # 𢇻
    # 0x221FC: '',  # 𢇼
    # 0x221FD: '',  # 𢇽
    # 0x221FE: '',  # 𢇾
    # 0x221FF: '',  # 𢇿
    # 0x22200: '',  # 𢈀
    # 0x22201: '',  # 𢈁
    0x22202: 'yǎn',  # 𢈂
    # 0x22203: '',  # 𢈃
    0x22204: 'tiāo',  # 𢈄
    # 0x22205: '',  # 𢈅
    0x22206: 'yáo',  # 𢈆
    0x22207: 'shěn',  # 𢈇
    0x22208: 'kē,wā',  # 𢈈
    0x22209: 'tóng',  # 𢈉
    # 0x2220A: '',  # 𢈊
    0x2220B: 'xuǎn',  # 𢈋
    # 0x2220C: '',  # 𢈌
    # 0x2220D: '',  # 𢈍
    # 0x2220E: '',  # 𢈎
    # 0x2220F: '',  # 𢈏
    # 0x22210: '',  # 𢈐
    # 0x22211: '',  # 𢈑
    # 0x22212: '',  # 𢈒
    0x22213: 'yòu',  # 𢈓
    # 0x22214: '',  # 𢈔
    0x22215: 'bài',  # 𢈕
    # 0x22216: '',  # 𢈖
    # 0x22217: '',  # 𢈗
    # 0x22218: '',  # 𢈘
    0x22219: 'xiá',  # 𢈙
    0x2221A: 'lǚ',  # 𢈚
    0x2221B: 'kùn',  # 𢈛
    0x2221C: 'zāng',  # 𢈜
    0x2221D: 'qiú',  # 𢈝
    # 0x2221E: '',  # 𢈞
    # 0x2221F: '',  # 𢈟
    0x22220: 'cù,là',  # 𢈠
    0x22221: 'zuī',  # 𢈡
    0x22222: 'lǒu',  # 𢈢
    # 0x22223: '',  # 𢈣
    0x22224: 'xiá',  # 𢈤
    # 0x22225: '',  # 𢈥
    # 0x22226: '',  # 𢈦
    # 0x22227: '',  # 𢈧
    # 0x22228: '',  # 𢈨
    # 0x22229: '',  # 𢈩
    # 0x2222A: '',  # 𢈪
    # 0x2222B: '',  # 𢈫
    # 0x2222C: '',  # 𢈬
    # 0x2222D: '',  # 𢈭
    # 0x2222E: '',  # 𢈮
    0x2222F: 'shēn',  # 𢈯
    # 0x22230: '',  # 𢈰
    # 0x22231: '',  # 𢈱
    0x22232: 'pú',  # 𢈲
    # 0x22233: '',  # 𢈳
    0x22234: 'jīng',  # 𢈴
    0x22235: 'qiāng',  # 𢈵
    0x22236: 'yì,sī',  # 𢈶
    # 0x22237: '',  # 𢈷
    0x22238: 'niè',  # 𢈸
    0x22239: 'duī,tuí',  # 𢈹
    # 0x2223A: '',  # 𢈺
    0x2223B: 'jié',  # 𢈻
    0x2223C: 'suì',  # 𢈼
    0x2223D: 'zhàn',  # 𢈽
    0x2223E: 'cōu',  # 𢈾
    # 0x2223F: '',  # 𢈿
    # 0x22240: '',  # 𢉀
    0x22241: 'bēng',  # 𢉁
    0x22242: 'guān',  # 𢉂
    0x22243: 'shě',  # 𢉃
    # 0x22244: '',  # 𢉄
    0x22245: 'jìn',  # 𢉅
    0x22246: 'dì',  # 𢉆
    # 0x22247: '',  # 𢉇
    # 0x22248: '',  # 𢉈
    # 0x22249: '',  # 𢉉
    # 0x2224A: '',  # 𢉊
    # 0x2224B: '',  # 𢉋
    # 0x2224C: '',  # 𢉌
    # 0x2224D: '',  # 𢉍
    # 0x2224E: '',  # 𢉎
    # 0x2224F: '',  # 𢉏
    # 0x22250: '',  # 𢉐
    0x22251: 'dān',  # 𢉑
    # 0x22252: '',  # 𢉒
    0x22253: 'nǎi',  # 𢉓
    # 0x22254: '',  # 𢉔
    0x22255: 'nóu',  # 𢉕
    # 0x22256: '',  # 𢉖
    0x22257: 'jí',  # 𢉗
    0x22258: 'yán',  # 𢉘
    # 0x22259: '',  # 𢉙
    0x2225A: 'nòu',  # 𢉚
    # 0x2225B: '',  # 𢉛
    0x2225C: 'dù,tú',  # 𢉜
    0x2225D: 'wèi',  # 𢉝
    0x2225E: 'piān',  # 𢉞
    # 0x2225F: '',  # 𢉟
    # 0x22260: '',  # 𢉠
    # 0x22261: '',  # 𢉡
    0x22262: 'hú',  # 𢉢
    # 0x22263: '',  # 𢉣
    0x22264: 'jià',  # 𢉤
    0x22265: 'yè',  # 𢉥
    0x22266: 'jǔn',  # 𢉦
    0x22267: 'lán,lián',  # 𢉧
    0x22268: 'là',  # 𢉨
    0x22269: 'yīn',  # 𢉩
    # 0x2226A: '',  # 𢉪
    # 0x2226B: '',  # 𢉫
    # 0x2226C: '',  # 𢉬
    0x2226D: 'tuí',  # 𢉭
    # 0x2226E: '',  # 𢉮
    # 0x2226F: '',  # 𢉯
    # 0x22270: '',  # 𢉰
    # 0x22271: '',  # 𢉱
    # 0x22272: '',  # 𢉲
    # 0x22273: '',  # 𢉳
    # 0x22274: '',  # 𢉴
    0x22275: 'nǎo',  # 𢉵
    # 0x22276: '',  # 𢉶
    # 0x22277: '',  # 𢉷
    # 0x22278: '',  # 𢉸
    # 0x22279: '',  # 𢉹
    0x2227A: 'zǔ',  # 𢉺
    # 0x2227B: '',  # 𢉻
    # 0x2227C: '',  # 𢉼
    # 0x2227D: '',  # 𢉽
    # 0x2227E: '',  # 𢉾
    0x2227F: 'mà',  # 𢉿
    0x22280: 'sī,mà',  # 𢊀
    0x22281: 'zhì',  # 𢊁
    # 0x22282: '',  # 𢊂
    # 0x22283: '',  # 𢊃
    0x22284: 'huī',  # 𢊄
    0x22285: 'zhuì',  # 𢊅
    0x22286: 'lì',  # 𢊆
    0x22287: 'huì',  # 𢊇
    # 0x22288: '',  # 𢊈
    # 0x22289: '',  # 𢊉
    # 0x2228A: '',  # 𢊊
    # 0x2228B: '',  # 𢊋
    # 0x2228C: '',  # 𢊌
    0x2228D: 'chú',  # 𢊍
    # 0x2228E: '',  # 𢊎
    0x2228F: 'chè',  # 𢊏
    # 0x22290: '',  # 𢊐
    # 0x22291: '',  # 𢊑
    0x22292: 'xiū',  # 𢊒
    0x22293: 'lán',  # 𢊓
    # 0x22294: '',  # 𢊔
    0x22295: 'cōng',  # 𢊕
    0x22296: 'shèn',  # 𢊖
    0x22297: 'mò',  # 𢊗
    0x22298: 'yī',  # 𢊘
    0x22299: 'yáo',  # 𢊙
    0x2229A: 'xǐ',  # 𢊚
    0x2229B: 'zuǐ',  # 𢊛
    0x2229C: 'bìng',  # 𢊜
    # 0x2229D: '',  # 𢊝
    # 0x2229E: '',  # 𢊞
    # 0x2229F: '',  # 𢊟
    # 0x222A0: '',  # 𢊠
    # 0x222A1: '',  # 𢊡
    # 0x222A2: '',  # 𢊢
    # 0x222A3: '',  # 𢊣
    # 0x222A4: '',  # 𢊤
    # 0x222A5: '',  # 𢊥
    # 0x222A6: '',  # 𢊦
    0x222A7: 'yú',  # 𢊧
    # 0x222A8: '',  # 𢊨
    0x222A9: 'lù',  # 𢊩
    # 0x222AA: '',  # 𢊪
    # 0x222AB: '',  # 𢊫
    # 0x222AC: '',  # 𢊬
    # 0x222AD: '',  # 𢊭
    0x222AE: 'tuí',  # 𢊮
    0x222AF: 'wěi',  # 𢊯
    # 0x222B0: '',  # 𢊰
    0x222B1: 'fén',  # 𢊱
    0x222B2: 'shěn',  # 𢊲
    # 0x222B3: '',  # 𢊳
    # 0x222B4: '',  # 𢊴
    # 0x222B5: '',  # 𢊵
    # 0x222B6: '',  # 𢊶
    # 0x222B7: '',  # 𢊷
    # 0x222B8: '',  # 𢊸
    # 0x222B9: '',  # 𢊹
    0x222BA: 'liù',  # 𢊺
    0x222BB: 'liáo',  # 𢊻
    # 0x222BC: '',  # 𢊼
    # 0x222BD: '',  # 𢊽
    # 0x222BE: '',  # 𢊾
    # 0x222BF: '',  # 𢊿
    # 0x222C0: '',  # 𢋀
    # 0x222C1: '',  # 𢋁
    0x222C2: 'shǔ',  # 𢋂
    0x222C3: 'dǎn',  # 𢋃
    0x222C4: 'juǎn',  # 𢋄
    0x222C5: 'yú',  # 𢋅
    0x222C6: 'xìn',  # 𢋆
    0x222C7: 'yáo',  # 𢋇
    # 0x222C8: '',  # 𢋈
    # 0x222C9: '',  # 𢋉
    # 0x222CA: '',  # 𢋊
    # 0x222CB: '',  # 𢋋
    # 0x222CC: '',  # 𢋌
    # 0x222CD: '',  # 𢋍
    # 0x222CE: '',  # 𢋎
    # 0x222CF: '',  # 𢋏
    # 0x222D0: '',  # 𢋐
    # 0x222D1: '',  # 𢋑
    0x222D2: 'huó',  # 𢋒
    # 0x222D3: '',  # 𢋓
    0x222D4: 'qiān',  # 𢋔
    # 0x222D5: '',  # 𢋕
    # 0x222D6: '',  # 𢋖
    # 0x222D7: '',  # 𢋗
    # 0x222D8: '',  # 𢋘
    # 0x222D9: '',  # 𢋙
    0x222DA: 'má',  # 𢋚
    # 0x222DB: '',  # 𢋛
    # 0x222DC: '',  # 𢋜
    0x222DD: 'kǎi',  # 𢋝
    # 0x222DE: '',  # 𢋞
    # 0x222DF: '',  # 𢋟
    # 0x222E0: '',  # 𢋠
    0x222E1: 'lǔ',  # 𢋡
    # 0x222E2: '',  # 𢋢
    0x222E3: 'yōu',  # 𢋣
    # 0x222E4: '',  # 𢋤
    # 0x222E5: '',  # 𢋥
    # 0x222E6: '',  # 𢋦
    # 0x222E7: '',  # 𢋧
    # 0x222E8: '',  # 𢋨
    # 0x222E9: '',  # 𢋩
    # 0x222EA: '',  # 𢋪
    # 0x222EB: '',  # 𢋫
    # 0x222EC: '',  # 𢋬
    # 0x222ED: '',  # 𢋭
    0x222EE: 'xiàn',  # 𢋮
    # 0x222EF: '',  # 𢋯
    # 0x222F0: '',  # 𢋰
    # 0x222F1: '',  # 𢋱
    # 0x222F2: '',  # 𢋲
    # 0x222F3: '',  # 𢋳
    # 0x222F4: '',  # 𢋴
    # 0x222F5: '',  # 𢋵
    # 0x222F6: '',  # 𢋶
    # 0x222F7: '',  # 𢋷
    # 0x222F8: '',  # 𢋸
    0x222F9: 'wú',  # 𢋹
    # 0x222FA: '',  # 𢋺
    0x222FB: 'yǐn',  # 𢋻
    0x222FC: 'xī',  # 𢋼
    # 0x222FD: '',  # 𢋽
    0x222FE: 'qiáng',  # 𢋾
    0x222FF: 'zhāi',  # 𢋿
    0x22300: 'xiè',  # 𢌀
    # 0x22301: '',  # 𢌁
    # 0x22302: '',  # 𢌂
    # 0x22303: '',  # 𢌃
    0x22304: 'qú',  # 𢌄
    # 0x22305: '',  # 𢌅
    # 0x22306: '',  # 𢌆
    # 0x22307: '',  # 𢌇
    0x22308: 'lí',  # 𢌈
    # 0x22309: '',  # 𢌉
    # 0x2230A: '',  # 𢌊
    # 0x2230B: '',  # 𢌋
    # 0x2230C: '',  # 𢌌
    0x2230D: 'qiān',  # 𢌍
    # 0x2230E: '',  # 𢌎
    # 0x2230F: '',  # 𢌏
    # 0x22310: '',  # 𢌐
    # 0x22311: '',  # 𢌑
    # 0x22312: '',  # 𢌒
    # 0x22313: '',  # 𢌓
    0x22314: 'líng',  # 𢌔
    0x22315: 'luán',  # 𢌕
    # 0x22316: '',  # 𢌖
    # 0x22317: '',  # 𢌗
    # 0x22318: '',  # 𢌘
    # 0x22319: '',  # 𢌙
    0x2231A: 'chān',  # 𢌚
    0x2231B: 'zhēng',  # 𢌛
    # 0x2231C: '',  # 𢌜
    # 0x2231D: '',  # 𢌝
    # 0x2231E: '',  # 𢌞
    # 0x2231F: '',  # 𢌟
    # 0x22320: '',  # 𢌠
    # 0x22321: '',  # 𢌡
    # 0x22322: '',  # 𢌢
    # 0x22323: '',  # 𢌣
    # 0x22324: '',  # 𢌤
    # 0x22325: '',  # 𢌥
    0x22326: 'zhèng',  # 𢌦
    # 0x22327: '',  # 𢌧
    0x22328: 'yán',  # 𢌨
    # 0x22329: '',  # 𢌩
    # 0x2232A: '',  # 𢌪
    # 0x2232B: '',  # 𢌫
    # 0x2232C: '',  # 𢌬
    # 0x2232D: '',  # 𢌭
    # 0x2232E: '',  # 𢌮
    # 0x2232F: '',  # 𢌯
    # 0x22330: '',  # 𢌰
    # 0x22331: '',  # 𢌱
    0x22332: 'yìn',  # 𢌲
    0x22333: 'kuí',  # 𢌳
    # 0x22334: '',  # 𢌴
    # 0x22335: '',  # 𢌵
    # 0x22336: '',  # 𢌶
    0x22337: 'qū',  # 𢌷
    # 0x22338: '',  # 𢌸
    0x22339: 'fú',  # 𢌹
    # 0x2233A: '',  # 𢌺
    0x2233B: 'yù',  # 𢌻
    # 0x2233C: '',  # 𢌼
    # 0x2233D: '',  # 𢌽
    # 0x2233E: '',  # 𢌾
    # 0x2233F: '',  # 𢌿
    # 0x22340: '',  # 𢍀
    0x22341: 'qí,bì',  # 𢍁
    # 0x22342: '',  # 𢍂
    # 0x22343: '',  # 𢍃
    # 0x22344: '',  # 𢍄
    # 0x22345: '',  # 𢍅
    0x22346: 'qì,qiè',  # 𢍆
    0x22347: 'jì',  # 𢍇
    0x22348: 'yuān,zàng',  # 𢍈
    0x22349: 'qí',  # 𢍉
    # 0x2234A: '',  # 𢍊
    # 0x2234B: '',  # 𢍋
    # 0x2234C: '',  # 𢍌
    # 0x2234D: '',  # 𢍍
    0x2234E: 'gào',  # 𢍎
    0x2234F: 'juàn',  # 𢍏
    # 0x22350: '',  # 𢍐
    0x22351: 'qí',  # 𢍑
    # 0x22352: '',  # 𢍒
    0x22353: 'gǎi',  # 𢍓
    # 0x22354: '',  # 𢍔
    0x22355: 'quàn',  # 𢍕
    # 0x22356: '',  # 𢍖
    # 0x22357: '',  # 𢍗
    # 0x22358: '',  # 𢍘
    # 0x22359: '',  # 𢍙
    0x2235A: 'wèi',  # 𢍚
    # 0x2235B: '',  # 𢍛
    0x2235C: 'zūn',  # 𢍜
    # 0x2235D: '',  # 𢍝
    # 0x2235E: '',  # 𢍞
    # 0x2235F: '',  # 𢍟
    # 0x22360: '',  # 𢍠
    # 0x22361: '',  # 𢍡
    # 0x22362: '',  # 𢍢
    # 0x22363: '',  # 𢍣
    # 0x22364: '',  # 𢍤
    # 0x22365: '',  # 𢍥
    # 0x22366: '',  # 𢍦
    0x22367: 'zhì',  # 𢍧
    # 0x22368: '',  # 𢍨
    0x22369: 'shèn',  # 𢍩
    0x2236A: 'dēng',  # 𢍪
    0x2236B: 'jiǎn',  # 𢍫
    # 0x2236C: '',  # 𢍬
    0x2236D: 'sì',  # 𢍭
    # 0x2236E: '',  # 𢍮
    # 0x2236F: '',  # 𢍯
    0x22370: 'yì,zé',  # 𢍰
    0x22371: 'qiān',  # 𢍱
    # 0x22372: '',  # 𢍲
    # 0x22373: '',  # 𢍳
    # 0x22374: '',  # 𢍴
    # 0x22375: '',  # 𢍵
    # 0x22376: '',  # 𢍶
    # 0x22377: '',  # 𢍷
    # 0x22378: '',  # 𢍸
    # 0x22379: '',  # 𢍹
    # 0x2237A: '',  # 𢍺
    # 0x2237B: '',  # 𢍻
    0x2237C: 'lì',  # 𢍼
    # 0x2237D: '',  # 𢍽
    # 0x2237E: '',  # 𢍾
    0x2237F: 'zāng',  # 𢍿
    0x22380: 'yì',  # 𢎀
    # 0x22381: '',  # 𢎁
    0x22382: 'cái',  # 𢎂
    0x22383: 'yì',  # 𢎃
    0x22384: 'gē',  # 𢎄
    # 0x22385: '',  # 𢎅
    0x22386: 'dié',  # 𢎆
    # 0x22387: '',  # 𢎇
    0x22388: 'zhī',  # 𢎈
    0x22389: 'yì',  # 𢎉
    # 0x2238A: '',  # 𢎊
    0x2238B: 'zāi',  # 𢎋
    0x2238C: 'dài',  # 𢎌
    # 0x2238D: '',  # 𢎍
    0x2238E: 'sù',  # 𢎎
    # 0x2238F: '',  # 𢎏
    # 0x22390: '',  # 𢎐
    # 0x22391: '',  # 𢎑
    # 0x22392: '',  # 𢎒
    # 0x22393: '',  # 𢎓
    0x22394: 'jié',  # 𢎔
    0x22395: 'chèn',  # 𢎕
    0x22396: 'qú',  # 𢎖
    # 0x22397: '',  # 𢎗
    0x22398: 'hàn',  # 𢎘
    0x22399: 'xián',  # 𢎙
    # 0x2239A: '',  # 𢎚
    0x2239B: 'jié',  # 𢎛
    # 0x2239C: '',  # 𢎜
    # 0x2239D: '',  # 𢎝
    # 0x2239E: '',  # 𢎞
    0x2239F: 'dàn',  # 𢎟
    0x223A0: 'quán,juàn',  # 𢎠
    0x223A1: 'jié',  # 𢎡
    # 0x223A2: '',  # 𢎢
    # 0x223A3: '',  # 𢎣
    # 0x223A4: '',  # 𢎤
    0x223A5: 'juàn',  # 𢎥
    # 0x223A6: '',  # 𢎦
    # 0x223A7: '',  # 𢎧
    # 0x223A8: '',  # 𢎨
    # 0x223A9: '',  # 𢎩
    0x223AA: 'dàn',  # 𢎪
    # 0x223AB: '',  # 𢎫
    # 0x223AC: '',  # 𢎬
    0x223AD: 'jīn',  # 𢎭
    # 0x223AE: '',  # 𢎮
    0x223AF: 'yí',  # 𢎯
    # 0x223B0: '',  # 𢎰
    # 0x223B1: '',  # 𢎱
    # 0x223B2: '',  # 𢎲
    # 0x223B3: '',  # 𢎳
    0x223B4: 'bīng',  # 𢎴
    0x223B5: 'hú',  # 𢎵
    # 0x223B6: '',  # 𢎶
    # 0x223B7: '',  # 𢎷
    # 0x223B8: '',  # 𢎸
    0x223B9: 'jué',  # 𢎹
    # 0x223BA: '',  # 𢎺
    0x223BB: 'yú',  # 𢎻
    # 0x223BC: '',  # 𢎼
    # 0x223BD: '',  # 𢎽
    # 0x223BE: '',  # 𢎾
    # 0x223BF: '',  # 𢎿
    # 0x223C0: '',  # 𢏀
    # 0x223C1: '',  # 𢏁
    # 0x223C2: '',  # 𢏂
    0x223C3: 'lǐ',  # 𢏃
    0x223C4: 'qiáng',  # 𢏄
    0x223C5: 'shuǐ',  # 𢏅
    0x223C6: 'kū',  # 𢏆
    # 0x223C7: '',  # 𢏇
    0x223C8: 'zhěn',  # 𢏈
    # 0x223C9: '',  # 𢏉
    # 0x223CA: '',  # 𢏊
    # 0x223CB: '',  # 𢏋
    # 0x223CC: '',  # 𢏌
    0x223CD: 'fú',  # 𢏍
    0x223CE: 'shēn',  # 𢏎
    # 0x223CF: '',  # 𢏏
    # 0x223D0: '',  # 𢏐
    # 0x223D1: '',  # 𢏑
    0x223D2: 'chuí',  # 𢏒
    # 0x223D3: '',  # 𢏓
    # 0x223D4: '',  # 𢏔
    0x223D5: 'tóng',  # 𢏕
    # 0x223D6: '',  # 𢏖
    0x223D7: 'yì',  # 𢏗
    # 0x223D8: '',  # 𢏘
    0x223D9: 'yáng',  # 𢏙
    # 0x223DA: '',  # 𢏚
    # 0x223DB: '',  # 𢏛
    0x223DC: 'tuó',  # 𢏜
    0x223DD: 'zhōu',  # 𢏝
    0x223DE: 'jí',  # 𢏞
    # 0x223DF: '',  # 𢏟
    # 0x223E0: '',  # 𢏠
    # 0x223E1: '',  # 𢏡
    # 0x223E2: '',  # 𢏢
    # 0x223E3: '',  # 𢏣
    0x223E4: 'xùn',  # 𢏤
    # 0x223E5: '',  # 𢏥
    0x223E6: 'shěn',  # 𢏦
    0x223E7: 'xuān',  # 𢏧
    # 0x223E8: '',  # 𢏨
    # 0x223E9: '',  # 𢏩
    # 0x223EA: '',  # 𢏪
    # 0x223EB: '',  # 𢏫
    # 0x223EC: '',  # 𢏬
    0x223ED: 'liú',  # 𢏭
    0x223EE: 'yuān',  # 𢏮
    0x223EF: 'hú,shǐ',  # 𢏯
    0x223F0: 'zhèng',  # 𢏰
    # 0x223F1: '',  # 𢏱
    # 0x223F2: '',  # 𢏲
    0x223F3: 'pēng,bēng',  # 𢏳
    # 0x223F4: '',  # 𢏴
    # 0x223F5: '',  # 𢏵
    # 0x223F6: '',  # 𢏶
    0x223F7: 'jué',  # 𢏷
    # 0x223F8: '',  # 𢏸
    # 0x223F9: '',  # 𢏹
    # 0x223FA: '',  # 𢏺
    # 0x223FB: '',  # 𢏻
    # 0x223FC: '',  # 𢏼
    # 0x223FD: '',  # 𢏽
    # 0x223FE: '',  # 𢏾
    # 0x223FF: '',  # 𢏿
    # 0x22400: '',  # 𢐀
    # 0x22401: '',  # 𢐁
    0x22402: 'zhì',  # 𢐂
    0x22403: 'piān',  # 𢐃
    0x22404: 'yuàn',  # 𢐄
    # 0x22405: '',  # 𢐅
    0x22406: 'jiān',  # 𢐆
    # 0x22407: '',  # 𢐇
    # 0x22408: '',  # 𢐈
    # 0x22409: '',  # 𢐉
    0x2240A: 'páng',  # 𢐊
    # 0x2240B: '',  # 𢐋
    # 0x2240C: '',  # 𢐌
    # 0x2240D: '',  # 𢐍
    0x2240E: 'zhuàn',  # 𢐎
    # 0x2240F: '',  # 𢐏
    0x22410: 'xián',  # 𢐐
    # 0x22411: '',  # 𢐑
    0x22412: 'bēng',  # 𢐒
    # 0x22413: '',  # 𢐓
    0x22414: 'cōng',  # 𢐔
    # 0x22415: '',  # 𢐕
    0x22416: 'mò',  # 𢐖
    # 0x22417: '',  # 𢐗
    # 0x22418: '',  # 𢐘
    # 0x22419: '',  # 𢐙
    0x2241A: 'guó',  # 𢐚
    # 0x2241B: '',  # 𢐛
    # 0x2241C: '',  # 𢐜
    # 0x2241D: '',  # 𢐝
    0x2241E: 'chéng',  # 𢐞
    0x2241F: 'qiāo',  # 𢐟
    # 0x22420: '',  # 𢐠
    # 0x22421: '',  # 𢐡
    # 0x22422: '',  # 𢐢
    # 0x22423: '',  # 𢐣
    # 0x22424: '',  # 𢐤
    # 0x22425: '',  # 𢐥
    0x22426: 'bì',  # 𢐦
    # 0x22427: '',  # 𢐧
    # 0x22428: '',  # 𢐨
    0x22429: 'qiǎng',  # 𢐩
    # 0x2242A: '',  # 𢐪
    0x2242B: 'zhōu',  # 𢐫
    # 0x2242C: '',  # 𢐬
    # 0x2242D: '',  # 𢐭
    # 0x2242E: '',  # 𢐮
    # 0x2242F: '',  # 𢐯
    # 0x22430: '',  # 𢐰
    # 0x22431: '',  # 𢐱
    0x22432: 'fán',  # 𢐲
    0x22433: 'biē',  # 𢐳
    0x22434: 'fèng',  # 𢐴
    # 0x22435: '',  # 𢐵
    # 0x22436: '',  # 𢐶
    # 0x22437: '',  # 𢐷
    # 0x22438: '',  # 𢐸
    # 0x22439: '',  # 𢐹
    # 0x2243A: '',  # 𢐺
    # 0x2243B: '',  # 𢐻
    # 0x2243C: '',  # 𢐼
    # 0x2243D: '',  # 𢐽
    0x2243E: 'bó',  # 𢐾
    0x2243F: 'rǒng',  # 𢐿
    # 0x22440: '',  # 𢑀
    # 0x22441: '',  # 𢑁
    # 0x22442: '',  # 𢑂
    # 0x22443: '',  # 𢑃
    # 0x22444: '',  # 𢑄
    0x22445: 'dǐng',  # 𢑅
    0x22446: 'quán',  # 𢑆
    0x22447: 'jiù',  # 𢑇
    0x22448: 'yáo',  # 𢑈
    # 0x22449: '',  # 𢑉
    # 0x2244A: '',  # 𢑊
    # 0x2244B: '',  # 𢑋
    # 0x2244C: '',  # 𢑌
    # 0x2244D: '',  # 𢑍
    # 0x2244E: '',  # 𢑎
    0x2244F: 'yì',  # 𢑏
    # 0x22450: '',  # 𢑐
    # 0x22451: '',  # 𢑑
    # 0x22452: '',  # 𢑒
    0x22453: 'xiá',  # 𢑓
    # 0x22454: '',  # 𢑔
    # 0x22455: '',  # 𢑕
    0x22456: 'zǎo',  # 𢑖
    # 0x22457: '',  # 𢑗
    # 0x22458: '',  # 𢑘
    # 0x22459: '',  # 𢑙
    0x2245A: 'shēn',  # 𢑚
    # 0x2245B: '',  # 𢑛
    # 0x2245C: '',  # 𢑜
    0x2245D: 'dān',  # 𢑝
    0x2245E: 'yì',  # 𢑞
    0x2245F: 'wǔ',  # 𢑟
    0x22460: 'tuó',  # 𢑠
    # 0x22461: '',  # 𢑡
    0x22462: 'hū',  # 𢑢
    # 0x22463: '',  # 𢑣
    # 0x22464: '',  # 𢑤
    # 0x22465: '',  # 𢑥
    # 0x22466: '',  # 𢑦
    0x22467: 'xī',  # 𢑧
    # 0x22468: '',  # 𢑨
    # 0x22469: '',  # 𢑩
    # 0x2246A: '',  # 𢑪
    # 0x2246B: '',  # 𢑫
    0x2246C: 'lái',  # 𢑬
    0x2246D: 'wèi',  # 𢑭
    0x2246E: 'fēi',  # 𢑮
    # 0x2246F: '',  # 𢑯
    # 0x22470: '',  # 𢑰
    0x22471: 'yí',  # 𢑱
    # 0x22472: '',  # 𢑲
    # 0x22473: '',  # 𢑳
    # 0x22474: '',  # 𢑴
    # 0x22475: '',  # 𢑵
    # 0x22476: '',  # 𢑶
    # 0x22477: '',  # 𢑷
    # 0x22478: '',  # 𢑸
    0x22479: 'hú',  # 𢑹
    # 0x2247A: '',  # 𢑺
    # 0x2247B: '',  # 𢑻
    # 0x2247C: '',  # 𢑼
    # 0x2247D: '',  # 𢑽
    # 0x2247E: '',  # 𢑾
    # 0x2247F: '',  # 𢑿
    # 0x22480: '',  # 𢒀
    # 0x22481: '',  # 𢒁
    # 0x22482: '',  # 𢒂
    # 0x22483: '',  # 𢒃
    # 0x22484: '',  # 𢒄
    # 0x22485: '',  # 𢒅
    0x22486: 'xiān',  # 𢒆
    # 0x22487: '',  # 𢒇
    # 0x22488: '',  # 𢒈
    0x22489: 'shǎn',  # 𢒉
    # 0x2248A: '',  # 𢒊
    # 0x2248B: '',  # 𢒋
    # 0x2248C: '',  # 𢒌
    0x2248D: 'fèi',  # 𢒍
    # 0x2248E: '',  # 𢒎
    # 0x2248F: '',  # 𢒏
    0x22490: 'cuò',  # 𢒐
    # 0x22491: '',  # 𢒑
    0x22492: 'fú',  # 𢒒
    # 0x22493: '',  # 𢒓
    0x22494: 'chù',  # 𢒔
    # 0x22495: '',  # 𢒕
    # 0x22496: '',  # 𢒖
    # 0x22497: '',  # 𢒗
    # 0x22498: '',  # 𢒘
    # 0x22499: '',  # 𢒙
    # 0x2249A: '',  # 𢒚
    # 0x2249B: '',  # 𢒛
    # 0x2249C: '',  # 𢒜
    0x2249D: 'diū',  # 𢒝
    0x2249E: 'làn',  # 𢒞
    # 0x2249F: '',  # 𢒟
    # 0x224A0: '',  # 𢒠
    # 0x224A1: '',  # 𢒡
    # 0x224A2: '',  # 𢒢
    # 0x224A3: '',  # 𢒣
    # 0x224A4: '',  # 𢒤
    # 0x224A5: '',  # 𢒥
    # 0x224A6: '',  # 𢒦
    # 0x224A7: '',  # 𢒧
    # 0x224A8: '',  # 𢒨
    0x224A9: 'xǐ',  # 𢒩
    # 0x224AA: '',  # 𢒪
    0x224AB: 'xún',  # 𢒫
    # 0x224AC: '',  # 𢒬
    # 0x224AD: '',  # 𢒭
    # 0x224AE: '',  # 𢒮
    0x224AF: 'biāo',  # 𢒯
    0x224B0: 'yù',  # 𢒰
    0x224B1: 'suì',  # 𢒱
    0x224B2: 'xǐ',  # 𢒲
    # 0x224B3: '',  # 𢒳
    # 0x224B4: '',  # 𢒴
    # 0x224B5: '',  # 𢒵
    # 0x224B6: '',  # 𢒶
    0x224B7: 'póu',  # 𢒷
    # 0x224B8: '',  # 𢒸
    # 0x224B9: '',  # 𢒹
    # 0x224BA: '',  # 𢒺
    # 0x224BB: '',  # 𢒻
    # 0x224BC: '',  # 𢒼
    # 0x224BD: '',  # 𢒽
    0x224BE: 'jiào',  # 𢒾
    # 0x224BF: '',  # 𢒿
    0x224C0: 'yì',  # 𢓀
    # 0x224C1: '',  # 𢓁
    # 0x224C2: '',  # 𢓂
    0x224C3: 'wán',  # 𢓃
    0x224C4: 'jǐ',  # 𢓄
    # 0x224C5: '',  # 𢓅
    0x224C6: 'wán',  # 𢓆
    0x224C7: 'tuì,nà',  # 𢓇
    0x224C8: 'xùn',  # 𢓈
    # 0x224C9: '',  # 𢓉
    # 0x224CA: '',  # 𢓊
    0x224CB: 'àng',  # 𢓋
    # 0x224CC: '',  # 𢓌
    0x224CD: 'tiān',  # 𢓍
    0x224CE: 'chí',  # 𢓎
    # 0x224CF: '',  # 𢓏
    # 0x224D0: '',  # 𢓐
    # 0x224D1: '',  # 𢓑
    0x224D2: 'rán',  # 𢓒
    # 0x224D3: '',  # 𢓓
    0x224D4: 'sà',  # 𢓔
    0x224D5: 'yín',  # 𢓕
    0x224D6: 'pī',  # 𢓖
    0x224D7: 'cǐ',  # 𢓗
    0x224D8: 'tóng,tāo',  # 𢓘
    0x224D9: 'yǐn',  # 𢓙
    # 0x224DA: '',  # 𢓚
    # 0x224DB: '',  # 𢓛
    0x224DC: 'gé',  # 𢓜
    0x224DD: 'tiāo',  # 𢓝
    0x224DE: 'zhēng',  # 𢓞
    0x224DF: 'zhòu',  # 𢓟
    # 0x224E0: '',  # 𢓠
    0x224E1: 'yí,tí',  # 𢓡
    0x224E2: 'kuà',  # 𢓢
    0x224E3: 'sōng',  # 𢓣
    # 0x224E4: '',  # 𢓤
    # 0x224E5: '',  # 𢓥
    # 0x224E6: '',  # 𢓦
    0x224E7: 'dì',  # 𢓧
    # 0x224E8: '',  # 𢓨
    # 0x224E9: '',  # 𢓩
    # 0x224EA: '',  # 𢓪
    # 0x224EB: '',  # 𢓫
    0x224EC: 'xié',  # 𢓬
    # 0x224ED: '',  # 𢓭
    0x224EE: 'xiāo',  # 𢓮
    0x224EF: 'guàng,wǎng',  # 𢓯
    0x224F0: 'tuǒ',  # 𢓰
    0x224F1: 'fēng,fèng',  # 𢓱
    0x224F2: 'wú,hú',  # 𢓲
    # 0x224F3: '',  # 𢓳
    0x224F4: 'tuì',  # 𢓴
    0x224F5: 'xiù',  # 𢓵
    # 0x224F6: '',  # 𢓶
    # 0x224F7: '',  # 𢓷
    # 0x224F8: '',  # 𢓸
    # 0x224F9: '',  # 𢓹
    # 0x224FA: '',  # 𢓺
    # 0x224FB: '',  # 𢓻
    # 0x224FC: '',  # 𢓼
    # 0x224FD: '',  # 𢓽
    # 0x224FE: '',  # 𢓾
    0x224FF: 'yóu',  # 𢓿
    # 0x22500: '',  # 𢔀
    0x22501: 'líng',  # 𢔁
    0x22502: 'yàn',  # 𢔂
    # 0x22503: '',  # 𢔃
    # 0x22504: '',  # 𢔄
    0x22505: 'dōng',  # 𢔅
    0x22506: 'qì',  # 𢔆
    0x22507: 'táo',  # 𢔇
    0x22508: 'hán',  # 𢔈
    # 0x22509: '',  # 𢔉
    0x2250A: 'chí',  # 𢔊
    0x2250B: 'sōng',  # 𢔋
    # 0x2250C: '',  # 𢔌
    # 0x2250D: '',  # 𢔍
    # 0x2250E: '',  # 𢔎
    # 0x2250F: '',  # 𢔏
    # 0x22510: '',  # 𢔐
    0x22511: 'quǎn',  # 𢔑
    # 0x22512: '',  # 𢔒
    # 0x22513: '',  # 𢔓
    0x22514: 'hàn,jí',  # 𢔔
    # 0x22515: '',  # 𢔕
    # 0x22516: '',  # 𢔖
    # 0x22517: '',  # 𢔗
    # 0x22518: '',  # 𢔘
    # 0x22519: '',  # 𢔙
    # 0x2251A: '',  # 𢔚
    # 0x2251B: '',  # 𢔛
    # 0x2251C: '',  # 𢔜
    # 0x2251D: '',  # 𢔝
    # 0x2251E: '',  # 𢔞
    0x2251F: 'rǒu,niǔ',  # 𢔟
    0x22520: 'qì',  # 𢔠
    0x22521: 'kāi',  # 𢔡
    0x22522: 'yú',  # 𢔢
    0x22523: 'chā,shà',  # 𢔣
    0x22524: 'chèng',  # 𢔤
    0x22525: 'yù',  # 𢔥
    # 0x22526: '',  # 𢔦
    0x22527: 'bìng',  # 𢔧
    # 0x22528: '',  # 𢔨
    0x22529: 'cōng,sǒng',  # 𢔩
    0x2252A: 'zhū',  # 𢔪
    # 0x2252B: '',  # 𢔫
    0x2252C: 'yù',  # 𢔬
    # 0x2252D: '',  # 𢔭
    # 0x2252E: '',  # 𢔮
    0x2252F: 'là',  # 𢔯
    # 0x22530: '',  # 𢔰
    0x22531: 'jué,què',  # 𢔱
    0x22532: 'liù',  # 𢔲
    0x22533: 'sāo',  # 𢔳
    0x22534: 'yù',  # 𢔴
    # 0x22535: '',  # 𢔵
    # 0x22536: '',  # 𢔶
    # 0x22537: '',  # 𢔷
    # 0x22538: '',  # 𢔸
    # 0x22539: '',  # 𢔹
    # 0x2253A: '',  # 𢔺
    # 0x2253B: '',  # 𢔻
    # 0x2253C: '',  # 𢔼
    # 0x2253D: '',  # 𢔽
    # 0x2253E: '',  # 𢔾
    # 0x2253F: '',  # 𢔿
    # 0x22540: '',  # 𢕀
    # 0x22541: '',  # 𢕁
    # 0x22542: '',  # 𢕂
    # 0x22543: '',  # 𢕃
    # 0x22544: '',  # 𢕄
    0x22545: 'shuài',  # 𢕅
    # 0x22546: '',  # 𢕆
    # 0x22547: '',  # 𢕇
    0x22548: 'sǒng',  # 𢕈
    # 0x22549: '',  # 𢕉
    # 0x2254A: '',  # 𢕊
    0x2254B: 'yuàn',  # 𢕋
    # 0x2254C: '',  # 𢕌
    # 0x2254D: '',  # 𢕍
    0x2254E: 'zhāng',  # 𢕎
    # 0x2254F: '',  # 𢕏
    # 0x22550: '',  # 𢕐
    0x22551: 'shuài',  # 𢕑
    # 0x22552: '',  # 𢕒
    0x22553: 'chǔ',  # 𢕓
    0x22554: 'zhāng,zhàng',  # 𢕔
    0x22555: 'sǎn,sàn',  # 𢕕
    0x22556: 'xiān',  # 𢕖
    # 0x22557: '',  # 𢕗
    0x22558: 'cuī',  # 𢕘
    0x22559: 'měng',  # 𢕙
    0x2255A: 'dí',  # 𢕚
    # 0x2255B: '',  # 𢕛
    # 0x2255C: '',  # 𢕜
    # 0x2255D: '',  # 𢕝
    0x2255E: 'zhì',  # 𢕞
    0x2255F: 'ào',  # 𢕟
    # 0x22560: '',  # 𢕠
    # 0x22561: '',  # 𢕡
    # 0x22562: '',  # 𢕢
    # 0x22563: '',  # 𢕣
    # 0x22564: '',  # 𢕤
    # 0x22565: '',  # 𢕥
    0x22566: 'xiū',  # 𢕦
    # 0x22567: '',  # 𢕧
    0x22568: 'pián',  # 𢕨
    # 0x22569: '',  # 𢕩
    0x2256A: 'jiào',  # 𢕪
    0x2256B: 'kuǎn',  # 𢕫
    0x2256C: 'sà',  # 𢕬
    0x2256D: 'xiàn',  # 𢕭
    0x2256E: 'zhà',  # 𢕮
    0x2256F: 'diàn',  # 𢕯
    # 0x22570: '',  # 𢕰
    # 0x22571: '',  # 𢕱
    # 0x22572: '',  # 𢕲
    # 0x22573: '',  # 𢕳
    # 0x22574: '',  # 𢕴
    # 0x22575: '',  # 𢕵
    # 0x22576: '',  # 𢕶
    0x22577: 'yí',  # 𢕷
    # 0x22578: '',  # 𢕸
    # 0x22579: '',  # 𢕹
    0x2257A: 'huì',  # 𢕺
    0x2257B: 'shàn',  # 𢕻
    # 0x2257C: '',  # 𢕼
    # 0x2257D: '',  # 𢕽
    # 0x2257E: '',  # 𢕾
    # 0x2257F: '',  # 𢕿
    # 0x22580: '',  # 𢖀
    # 0x22581: '',  # 𢖁
    # 0x22582: '',  # 𢖂
    # 0x22583: '',  # 𢖃
    0x22584: 'chóng',  # 𢖄
    0x22585: 'yí',  # 𢖅
    0x22586: 'xiè',  # 𢖆
    0x22587: 'zhì',  # 𢖇
    0x22588: 'tiào',  # 𢖈
    # 0x22589: '',  # 𢖉
    0x2258A: 'pīng',  # 𢖊
    0x2258B: 'xián',  # 𢖋
    # 0x2258C: '',  # 𢖌
    # 0x2258D: '',  # 𢖍
    0x2258E: 'xiān',  # 𢖎
    0x2258F: 'sù',  # 𢖏
    # 0x22590: '',  # 𢖐
    0x22591: 'cuán',  # 𢖑
    # 0x22592: '',  # 𢖒
    # 0x22593: '',  # 𢖓
    # 0x22594: '',  # 𢖔
    # 0x22595: '',  # 𢖕
    # 0x22596: '',  # 𢖖
    0x22597: 'sǒng',  # 𢖗
    # 0x22598: '',  # 𢖘
    # 0x22599: '',  # 𢖙
    # 0x2259A: '',  # 𢖚
    0x2259B: 'hēi',  # 𢖛
    # 0x2259C: '',  # 𢖜
    0x2259D: 'xiàn',  # 𢖝
    # 0x2259E: '',  # 𢖞
    0x2259F: 'yóu',  # 𢖟
    # 0x225A0: '',  # 𢖠
    0x225A1: 'yù',  # 𢖡
    # 0x225A2: '',  # 𢖢
    # 0x225A3: '',  # 𢖣
    0x225A4: 'tái',  # 𢖤
    # 0x225A5: '',  # 𢖥
    0x225A6: 'jué',  # 𢖦
    0x225A7: 'nàng',  # 𢖧
    # 0x225A8: '',  # 𢖨
    0x225A9: 'diān',  # 𢖩
    # 0x225AA: '',  # 𢖪
    0x225AB: 'yì',  # 𢖫
    0x225AC: 'bì',  # 𢖬
    # 0x225AD: '',  # 𢖭
    # 0x225AE: '',  # 𢖮
    # 0x225AF: '',  # 𢖯
    # 0x225B0: '',  # 𢖰
    # 0x225B1: '',  # 𢖱
    0x225B2: 'chà',  # 𢖲
    0x225B3: 'xū',  # 𢖳
    0x225B4: 'yì',  # 𢖴
    0x225B5: 'rù',  # 𢖵
    # 0x225B6: '',  # 𢖶
    0x225B7: 'gōng',  # 𢖷
    # 0x225B8: '',  # 𢖸
    # 0x225B9: '',  # 𢖹
    0x225BA: 'yì',  # 𢖺
    0x225BB: 'ài',  # 𢖻
    0x225BC: 'tè',  # 𢖼
    0x225BD: 'zhì',  # 𢖽
    # 0x225BE: '',  # 𢖾
    0x225BF: 'zhì',  # 𢖿
    0x225C0: 'xīn',  # 𢗀
    # 0x225C1: '',  # 𢗁
    0x225C2: 'jì',  # 𢗂
    # 0x225C3: '',  # 𢗃
    0x225C4: 'xià',  # 𢗄
    # 0x225C5: '',  # 𢗅
    # 0x225C6: '',  # 𢗆
    # 0x225C7: '',  # 𢗇
    0x225C8: 'zhāo',  # 𢗈
    0x225C9: 'nè',  # 𢗉
    0x225CA: 'xiè,jiá',  # 𢗊
    # 0x225CB: '',  # 𢗋
    # 0x225CC: '',  # 𢗌
    # 0x225CD: '',  # 𢗍
    0x225CE: 'yì',  # 𢗎
    # 0x225CF: '',  # 𢗏
    # 0x225D0: '',  # 𢗐
    # 0x225D1: '',  # 𢗑
    # 0x225D2: '',  # 𢗒
    # 0x225D3: '',  # 𢗓
    # 0x225D4: '',  # 𢗔
    # 0x225D5: '',  # 𢗕
    # 0x225D6: '',  # 𢗖
    # 0x225D7: '',  # 𢗗
    # 0x225D8: '',  # 𢗘
    # 0x225D9: '',  # 𢗙
    # 0x225DA: '',  # 𢗚
    # 0x225DB: '',  # 𢗛
    # 0x225DC: '',  # 𢗜
    0x225DD: 'dì',  # 𢗝
    # 0x225DE: '',  # 𢗞
    # 0x225DF: '',  # 𢗟
    # 0x225E0: '',  # 𢗠
    # 0x225E1: '',  # 𢗡
    # 0x225E2: '',  # 𢗢
    # 0x225E3: '',  # 𢗣
    # 0x225E4: '',  # 𢗤
    # 0x225E5: '',  # 𢗥
    # 0x225E6: '',  # 𢗦
    # 0x225E7: '',  # 𢗧
    # 0x225E8: '',  # 𢗨
    # 0x225E9: '',  # 𢗩
    # 0x225EA: '',  # 𢗪
    0x225EB: 'fǔ',  # 𢗫
    # 0x225EC: '',  # 𢗬
    0x225ED: 'shè',  # 𢗭
    # 0x225EE: '',  # 𢗮
    0x225EF: 'yuán',  # 𢗯
    0x225F0: 'fǎn',  # 𢗰
    # 0x225F1: '',  # 𢗱
    0x225F2: 'fū',  # 𢗲
    0x225F3: 'wù',  # 𢗳
    0x225F4: 'xī',  # 𢗴
    0x225F5: 'hǒng',  # 𢗵
    # 0x225F6: '',  # 𢗶
    # 0x225F7: '',  # 𢗷
    # 0x225F8: '',  # 𢗸
    0x225F9: 'jì',  # 𢗹
    0x225FA: 'chàng',  # 𢗺
    # 0x225FB: '',  # 𢗻
    # 0x225FC: '',  # 𢗼
    # 0x225FD: '',  # 𢗽
    # 0x225FE: '',  # 𢗾
    0x225FF: 'mò',  # 𢗿
    0x22600: 'pèi',  # 𢘀
    0x22601: 'xiān',  # 𢘁
    # 0x22602: '',  # 𢘂
    0x22603: 'mú,wǔ',  # 𢘃
    0x22604: 'qiú',  # 𢘄
    0x22605: 'mào,róu',  # 𢘅
    # 0x22606: '',  # 𢘆
    0x22607: 'dá,dàn',  # 𢘇
    # 0x22608: '',  # 𢘈
    0x22609: 'xiá',  # 𢘉
    0x2260A: 'shēn',  # 𢘊
    0x2260B: 'tè',  # 𢘋
    0x2260C: 'hóng',  # 𢘌
    0x2260D: 'bì,fú',  # 𢘍
    # 0x2260E: '',  # 𢘎
    # 0x2260F: '',  # 𢘏
    # 0x22610: '',  # 𢘐
    # 0x22611: '',  # 𢘑
    # 0x22612: '',  # 𢘒
    # 0x22613: '',  # 𢘓
    # 0x22614: '',  # 𢘔
    # 0x22615: '',  # 𢘕
    # 0x22616: '',  # 𢘖
    # 0x22617: '',  # 𢘗
    # 0x22618: '',  # 𢘘
    # 0x22619: '',  # 𢘙
    # 0x2261A: '',  # 𢘚
    # 0x2261B: '',  # 𢘛
    # 0x2261C: '',  # 𢘜
    # 0x2261D: '',  # 𢘝
    # 0x2261E: '',  # 𢘞
    0x2261F: 'qiáo',  # 𢘟
    # 0x22620: '',  # 𢘠
    # 0x22621: '',  # 𢘡
    # 0x22622: '',  # 𢘢
    # 0x22623: '',  # 𢘣
    # 0x22624: '',  # 𢘤
    0x22625: 'shì',  # 𢘥
    # 0x22626: '',  # 𢘦
    0x22627: 'ruǎn',  # 𢘧
    # 0x22628: '',  # 𢘨
    # 0x22629: '',  # 𢘩
    # 0x2262A: '',  # 𢘪
    0x2262B: 'zhèng',  # 𢘫
    # 0x2262C: '',  # 𢘬
    # 0x2262D: '',  # 𢘭
    # 0x2262E: '',  # 𢘮
    # 0x2262F: '',  # 𢘯
    # 0x22630: '',  # 𢘰
    # 0x22631: '',  # 𢘱
    # 0x22632: '',  # 𢘲
    # 0x22633: '',  # 𢘳
    # 0x22634: '',  # 𢘴
    # 0x22635: '',  # 𢘵
    # 0x22636: '',  # 𢘶
    # 0x22637: '',  # 𢘷
    0x22638: 'jiàng',  # 𢘸
    0x22639: 'chā',  # 𢘹
    0x2263A: 'mǐ,mí',  # 𢘺
    # 0x2263B: '',  # 𢘻
    # 0x2263C: '',  # 𢘼
    0x2263D: 'yì',  # 𢘽
    # 0x2263E: '',  # 𢘾
    0x2263F: 'suō',  # 𢘿
    # 0x22640: '',  # 𢙀
    0x22641: 'wù',  # 𢙁
    0x22642: 'xuān',  # 𢙂
    # 0x22643: '',  # 𢙃
    # 0x22644: '',  # 𢙄
    0x22645: 'xí',  # 𢙅
    # 0x22646: '',  # 𢙆
    0x22647: 'yǐ',  # 𢙇
    # 0x22648: '',  # 𢙈
    0x22649: 'nǎo',  # 𢙉
    # 0x2264A: '',  # 𢙊
    # 0x2264B: '',  # 𢙋
    # 0x2264C: '',  # 𢙌
    # 0x2264D: '',  # 𢙍
    # 0x2264E: '',  # 𢙎
    # 0x2264F: '',  # 𢙏
    0x22650: 'náo',  # 𢙐
    # 0x22651: '',  # 𢙑
    # 0x22652: '',  # 𢙒
    # 0x22653: '',  # 𢙓
    # 0x22654: '',  # 𢙔
    # 0x22655: '',  # 𢙕
    # 0x22656: '',  # 𢙖
    # 0x22657: '',  # 𢙗
    # 0x22658: '',  # 𢙘
    # 0x22659: '',  # 𢙙
    # 0x2265A: '',  # 𢙚
    # 0x2265B: '',  # 𢙛
    # 0x2265C: '',  # 𢙜
    # 0x2265D: '',  # 𢙝
    # 0x2265E: '',  # 𢙞
    # 0x2265F: '',  # 𢙟
    0x22660: 'yín',  # 𢙠
    # 0x22661: '',  # 𢙡
    0x22662: 'kǒng',  # 𢙢
    # 0x22663: '',  # 𢙣
    # 0x22664: '',  # 𢙤
    # 0x22665: '',  # 𢙥
    # 0x22666: '',  # 𢙦
    0x22667: 'piàn',  # 𢙧
    # 0x22668: '',  # 𢙨
    # 0x22669: '',  # 𢙩
    # 0x2266A: '',  # 𢙪
    # 0x2266B: '',  # 𢙫
    # 0x2266C: '',  # 𢙬
    # 0x2266D: '',  # 𢙭
    0x2266E: 'kàn',  # 𢙮
    # 0x2266F: '',  # 𢙯
    # 0x22670: '',  # 𢙰
    0x22671: 'lòng',  # 𢙱
    0x22672: 'lǚ',  # 𢙲
    0x22673: 'zhuǎng',  # 𢙳
    0x22674: 'ài',  # 𢙴
    # 0x22675: '',  # 𢙵
    # 0x22676: '',  # 𢙶
    # 0x22677: '',  # 𢙷
    # 0x22678: '',  # 𢙸
    # 0x22679: '',  # 𢙹
    0x2267A: 'zhì',  # 𢙺
    # 0x2267B: '',  # 𢙻
    0x2267C: 'xìng',  # 𢙼
    # 0x2267D: '',  # 𢙽
    0x2267E: 'gěng',  # 𢙾
    0x2267F: 'jìn',  # 𢙿
    0x22680: 'xiàn',  # 𢚀
    0x22681: 'jì',  # 𢚁
    0x22682: 'cuò',  # 𢚂
    # 0x22683: '',  # 𢚃
    0x22684: 'láo',  # 𢚄
    0x22685: 'fěn',  # 𢚅
    0x22686: 'jù',  # 𢚆
    # 0x22687: '',  # 𢚇
    # 0x22688: '',  # 𢚈
    # 0x22689: '',  # 𢚉
    # 0x2268A: '',  # 𢚊
    0x2268B: 'miào',  # 𢚋
    0x2268C: 'xiá',  # 𢚌
    # 0x2268D: '',  # 𢚍
    # 0x2268E: '',  # 𢚎
    # 0x2268F: '',  # 𢚏
    # 0x22690: '',  # 𢚐
    0x22691: 'sù',  # 𢚑
    # 0x22692: '',  # 𢚒
    # 0x22693: '',  # 𢚓
    # 0x22694: '',  # 𢚔
    # 0x22695: '',  # 𢚕
    # 0x22696: '',  # 𢚖
    0x22697: 'sàn',  # 𢚗
    # 0x22698: '',  # 𢚘
    # 0x22699: '',  # 𢚙
    # 0x2269A: '',  # 𢚚
    # 0x2269B: '',  # 𢚛
    # 0x2269C: '',  # 𢚜
    # 0x2269D: '',  # 𢚝
    # 0x2269E: '',  # 𢚞
    # 0x2269F: '',  # 𢚟
    # 0x226A0: '',  # 𢚠
    # 0x226A1: '',  # 𢚡
    # 0x226A2: '',  # 𢚢
    # 0x226A3: '',  # 𢚣
    # 0x226A4: '',  # 𢚤
    # 0x226A5: '',  # 𢚥
    # 0x226A6: '',  # 𢚦
    # 0x226A7: '',  # 𢚧
    0x226A8: 'zhì',  # 𢚨
    # 0x226A9: '',  # 𢚩
    0x226AA: 'hù',  # 𢚪
    0x226AB: 'kòu',  # 𢚫
    # 0x226AC: '',  # 𢚬
    0x226AD: 'suǒ',  # 𢚭
    0x226AE: 'nì',  # 𢚮
    # 0x226AF: '',  # 𢚯
    # 0x226B0: '',  # 𢚰
    # 0x226B1: '',  # 𢚱
    # 0x226B2: '',  # 𢚲
    # 0x226B3: '',  # 𢚳
    # 0x226B4: '',  # 𢚴
    # 0x226B5: '',  # 𢚵
    # 0x226B6: '',  # 𢚶
    # 0x226B7: '',  # 𢚷
    # 0x226B8: '',  # 𢚸
    # 0x226B9: '',  # 𢚹
    0x226BA: 'tēng',  # 𢚺
    0x226BB: 'zhù',  # 𢚻
    # 0x226BC: '',  # 𢚼
    # 0x226BD: '',  # 𢚽
    # 0x226BE: '',  # 𢚾
    # 0x226BF: '',  # 𢚿
    # 0x226C0: '',  # 𢛀
    0x226C1: 'dá,chè',  # 𢛁
    # 0x226C2: '',  # 𢛂
    0x226C3: 'qiú',  # 𢛃
    0x226C4: 'yà',  # 𢛄
    # 0x226C5: '',  # 𢛅
    0x226C6: 'xián',  # 𢛆
    # 0x226C7: '',  # 𢛇
    # 0x226C8: '',  # 𢛈
    0x226C9: 'nèi',  # 𢛉
    # 0x226CA: '',  # 𢛊
    # 0x226CB: '',  # 𢛋
    # 0x226CC: '',  # 𢛌
    0x226CD: 'zhǐ',  # 𢛍
    0x226CE: 'bié',  # 𢛎
    # 0x226CF: '',  # 𢛏
    # 0x226D0: '',  # 𢛐
    # 0x226D1: '',  # 𢛑
    0x226D2: 'chǒng',  # 𢛒
    0x226D3: 'lán',  # 𢛓
    0x226D4: 'dōng',  # 𢛔
    0x226D5: 'qūn',  # 𢛕
    0x226D6: 'xiàng',  # 𢛖
    # 0x226D7: '',  # 𢛗
    0x226D8: 'xiáo',  # 𢛘
    0x226D9: 'wǎn',  # 𢛙
    0x226DA: 'rù',  # 𢛚
    0x226DB: 'wàng',  # 𢛛
    0x226DC: 'nì',  # 𢛜
    # 0x226DD: '',  # 𢛝
    0x226DE: 'bāi',  # 𢛞
    0x226DF: 'yà',  # 𢛟
    # 0x226E0: '',  # 𢛠
    # 0x226E1: '',  # 𢛡
    # 0x226E2: '',  # 𢛢
    # 0x226E3: '',  # 𢛣
    # 0x226E4: '',  # 𢛤
    0x226E5: 'sī',  # 𢛥
    0x226E6: 'yǐn',  # 𢛦
    # 0x226E7: '',  # 𢛧
    0x226E8: 'yù',  # 𢛨
    # 0x226E9: '',  # 𢛩
    # 0x226EA: '',  # 𢛪
    # 0x226EB: '',  # 𢛫
    # 0x226EC: '',  # 𢛬
    # 0x226ED: '',  # 𢛭
    0x226EE: 'lí',  # 𢛮
    # 0x226EF: '',  # 𢛯
    # 0x226F0: '',  # 𢛰
    # 0x226F1: '',  # 𢛱
    # 0x226F2: '',  # 𢛲
    # 0x226F3: '',  # 𢛳
    # 0x226F4: '',  # 𢛴
    # 0x226F5: '',  # 𢛵
    # 0x226F6: '',  # 𢛶
    # 0x226F7: '',  # 𢛷
    # 0x226F8: '',  # 𢛸
    # 0x226F9: '',  # 𢛹
    # 0x226FA: '',  # 𢛺
    # 0x226FB: '',  # 𢛻
    # 0x226FC: '',  # 𢛼
    # 0x226FD: '',  # 𢛽
    # 0x226FE: '',  # 𢛾
    # 0x226FF: '',  # 𢛿
    # 0x22700: '',  # 𢜀
    # 0x22701: '',  # 𢜁
    # 0x22702: '',  # 𢜂
    # 0x22703: '',  # 𢜃
    # 0x22704: '',  # 𢜄
    # 0x22705: '',  # 𢜅
    # 0x22706: '',  # 𢜆
    # 0x22707: '',  # 𢜇
    # 0x22708: '',  # 𢜈
    # 0x22709: '',  # 𢜉
    # 0x2270A: '',  # 𢜊
    # 0x2270B: '',  # 𢜋
    # 0x2270C: '',  # 𢜌
    # 0x2270D: '',  # 𢜍
    # 0x2270E: '',  # 𢜎
    # 0x2270F: '',  # 𢜏
    # 0x22710: '',  # 𢜐
    # 0x22711: '',  # 𢜑
    # 0x22712: '',  # 𢜒
    # 0x22713: '',  # 𢜓
    # 0x22714: '',  # 𢜔
    # 0x22715: '',  # 𢜕
    # 0x22716: '',  # 𢜖
    0x22717: 'bàng',  # 𢜗
    0x22718: 'bèn',  # 𢜘
    # 0x22719: '',  # 𢜙
    # 0x2271A: '',  # 𢜚
    # 0x2271B: '',  # 𢜛
    # 0x2271C: '',  # 𢜜
    # 0x2271D: '',  # 𢜝
    # 0x2271E: '',  # 𢜞
    # 0x2271F: '',  # 𢜟
    # 0x22720: '',  # 𢜠
    # 0x22721: '',  # 𢜡
    # 0x22722: '',  # 𢜢
    0x22723: 'xī',  # 𢜣
    # 0x22724: '',  # 𢜤
    0x22725: 'jiū',  # 𢜥
    # 0x22726: '',  # 𢜦
    # 0x22727: '',  # 𢜧
    0x22728: 'xiè,dié',  # 𢜨
    0x22729: 'qiān',  # 𢜩
    0x2272A: 'nuò,ruò',  # 𢜪
    0x2272B: 'xǐng',  # 𢜫
    0x2272C: 'duó',  # 𢜬
    0x2272D: 'jǐ',  # 𢜭
    0x2272E: 'wǔ',  # 𢜮
    0x2272F: 'mú,móu,mǔ',  # 𢜯
    0x22730: 'yàn,yǎn',  # 𢜰
    0x22731: 'qì',  # 𢜱
    0x22732: 'ná',  # 𢜲
    0x22733: 'chì',  # 𢜳
    0x22734: 'hóu',  # 𢜴
    # 0x22735: '',  # 𢜵
    0x22736: 'sào',  # 𢜶
    # 0x22737: '',  # 𢜷
    0x22738: 'náo',  # 𢜸
    # 0x22739: '',  # 𢜹
    # 0x2273A: '',  # 𢜺
    0x2273B: 'chěng',  # 𢜻
    0x2273C: 'chěng',  # 𢜼
    0x2273D: 'kuǐ',  # 𢜽
    # 0x2273E: '',  # 𢜾
    0x2273F: 'jià',  # 𢜿
    0x22740: 'tú',  # 𢝀
    # 0x22741: '',  # 𢝁
    0x22742: 'dú',  # 𢝂
    # 0x22743: '',  # 𢝃
    # 0x22744: '',  # 𢝄
    0x22745: 'xiá',  # 𢝅
    0x22746: 'zhòng',  # 𢝆
    0x22747: 'huò',  # 𢝇
    0x22748: 'chóng',  # 𢝈
    0x22749: 'dá',  # 𢝉
    0x2274A: 'yōu',  # 𢝊
    # 0x2274B: '',  # 𢝋
    0x2274C: 'mào',  # 𢝌
    0x2274D: 'yào',  # 𢝍
    # 0x2274E: '',  # 𢝎
    # 0x2274F: '',  # 𢝏
    # 0x22750: '',  # 𢝐
    # 0x22751: '',  # 𢝑
    # 0x22752: '',  # 𢝒
    0x22753: 'juān',  # 𢝓
    # 0x22754: '',  # 𢝔
    # 0x22755: '',  # 𢝕
    # 0x22756: '',  # 𢝖
    # 0x22757: '',  # 𢝗
    # 0x22758: '',  # 𢝘
    # 0x22759: '',  # 𢝙
    # 0x2275A: '',  # 𢝚
    # 0x2275B: '',  # 𢝛
    # 0x2275C: '',  # 𢝜
    # 0x2275D: '',  # 𢝝
    # 0x2275E: '',  # 𢝞
    # 0x2275F: '',  # 𢝟
    # 0x22760: '',  # 𢝠
    # 0x22761: '',  # 𢝡
    # 0x22762: '',  # 𢝢
    # 0x22763: '',  # 𢝣
    # 0x22764: '',  # 𢝤
    # 0x22765: '',  # 𢝥
    # 0x22766: '',  # 𢝦
    # 0x22767: '',  # 𢝧
    # 0x22768: '',  # 𢝨
    # 0x22769: '',  # 𢝩
    # 0x2276A: '',  # 𢝪
    # 0x2276B: '',  # 𢝫
    0x2276C: 'shì',  # 𢝬
    # 0x2276D: '',  # 𢝭
    # 0x2276E: '',  # 𢝮
    0x2276F: 'yín',  # 𢝯
    # 0x22770: '',  # 𢝰
    # 0x22771: '',  # 𢝱
    0x22772: 'chóu',  # 𢝲
    0x22773: 'gǔ',  # 𢝳
    0x22774: 'wù',  # 𢝴
    # 0x22775: '',  # 𢝵
    # 0x22776: '',  # 𢝶
    # 0x22777: '',  # 𢝷
    0x22778: 'guò',  # 𢝸
    0x22779: 'tì',  # 𢝹
    # 0x2277A: '',  # 𢝺
    0x2277B: 'hōng',  # 𢝻
    # 0x2277C: '',  # 𢝼
    # 0x2277D: '',  # 𢝽
    # 0x2277E: '',  # 𢝾
    # 0x2277F: '',  # 𢝿
    # 0x22780: '',  # 𢞀
    # 0x22781: '',  # 𢞁
    # 0x22782: '',  # 𢞂
    # 0x22783: '',  # 𢞃
    # 0x22784: '',  # 𢞄
    # 0x22785: '',  # 𢞅
    # 0x22786: '',  # 𢞆
    0x22787: 'rě',  # 𢞇
    # 0x22788: '',  # 𢞈
    0x22789: 'yí',  # 𢞉
    # 0x2278A: '',  # 𢞊
    0x2278B: 'tǔn',  # 𢞋
    # 0x2278C: '',  # 𢞌
    # 0x2278D: '',  # 𢞍
    # 0x2278E: '',  # 𢞎
    0x2278F: 'qióng',  # 𢞏
    0x22790: 'hài',  # 𢞐
    # 0x22791: '',  # 𢞑
    0x22792: 'qì',  # 𢞒
    # 0x22793: '',  # 𢞓
    # 0x22794: '',  # 𢞔
    0x22795: 'huò',  # 𢞕
    0x22796: 'tì',  # 𢞖
    0x22797: 'pī,bī',  # 𢞗
    # 0x22798: '',  # 𢞘
    # 0x22799: '',  # 𢞙
    0x2279A: 'gěng',  # 𢞚
    # 0x2279B: '',  # 𢞛
    0x2279C: 'xiè',  # 𢞜
    # 0x2279D: '',  # 𢞝
    0x2279E: 'mì,mí',  # 𢞞
    0x2279F: 'gào',  # 𢞟
    0x227A0: 'tā',  # 𢞠
    0x227A1: 'xiǎng',  # 𢞡
    # 0x227A2: '',  # 𢞢
    0x227A3: 'shū',  # 𢞣
    # 0x227A4: '',  # 𢞤
    # 0x227A5: '',  # 𢞥
    0x227A6: 'fú',  # 𢞦
    # 0x227A7: '',  # 𢞧
    # 0x227A8: '',  # 𢞨
    # 0x227A9: '',  # 𢞩
    # 0x227AA: '',  # 𢞪
    # 0x227AB: '',  # 𢞫
    0x227AC: 'zhuān',  # 𢞬
    0x227AD: 'liù',  # 𢞭
    # 0x227AE: '',  # 𢞮
    # 0x227AF: '',  # 𢞯
    # 0x227B0: '',  # 𢞰
    # 0x227B1: '',  # 𢞱
    # 0x227B2: '',  # 𢞲
    # 0x227B3: '',  # 𢞳
    # 0x227B4: '',  # 𢞴
    # 0x227B5: '',  # 𢞵
    # 0x227B6: '',  # 𢞶
    # 0x227B7: '',  # 𢞷
    # 0x227B8: '',  # 𢞸
    # 0x227B9: '',  # 𢞹
    # 0x227BA: '',  # 𢞺
    # 0x227BB: '',  # 𢞻
    # 0x227BC: '',  # 𢞼
    # 0x227BD: '',  # 𢞽
    # 0x227BE: '',  # 𢞾
    # 0x227BF: '',  # 𢞿
    # 0x227C0: '',  # 𢟀
    # 0x227C1: '',  # 𢟁
    # 0x227C2: '',  # 𢟂
    # 0x227C3: '',  # 𢟃
    # 0x227C4: '',  # 𢟄
    0x227C5: 'yóu',  # 𢟅
    # 0x227C6: '',  # 𢟆
    # 0x227C7: '',  # 𢟇
    # 0x227C8: '',  # 𢟈
    # 0x227C9: '',  # 𢟉
    0x227CA: 'chěng',  # 𢟊
    0x227CB: 'duī',  # 𢟋
    # 0x227CC: '',  # 𢟌
    # 0x227CD: '',  # 𢟍
    # 0x227CE: '',  # 𢟎
    # 0x227CF: '',  # 𢟏
    # 0x227D0: '',  # 𢟐
    # 0x227D1: '',  # 𢟑
    # 0x227D2: '',  # 𢟒
    # 0x227D3: '',  # 𢟓
    # 0x227D4: '',  # 𢟔
    # 0x227D5: '',  # 𢟕
    # 0x227D6: '',  # 𢟖
    # 0x227D7: '',  # 𢟗
    # 0x227D8: '',  # 𢟘
    # 0x227D9: '',  # 𢟙
    # 0x227DA: '',  # 𢟚
    # 0x227DB: '',  # 𢟛
    # 0x227DC: '',  # 𢟜
    # 0x227DD: '',  # 𢟝
    # 0x227DE: '',  # 𢟞
    # 0x227DF: '',  # 𢟟
    # 0x227E0: '',  # 𢟠
    0x227E1: 'bèi',  # 𢟡
    0x227E2: 'lí',  # 𢟢
    0x227E3: 'yàng',  # 𢟣
    0x227E4: 'lí',  # 𢟤
    # 0x227E5: '',  # 𢟥
    # 0x227E6: '',  # 𢟦
    0x227E7: 'lǔ',  # 𢟧
    0x227E8: 'mǔ',  # 𢟨
    0x227E9: 'suì',  # 𢟩
    0x227EA: 'ài,xì',  # 𢟪
    # 0x227EB: '',  # 𢟫
    # 0x227EC: '',  # 𢟬
    0x227ED: 'kòu',  # 𢟭
    # 0x227EE: '',  # 𢟮
    0x227EF: 'zhé,shì',  # 𢟯
    0x227F0: 'ài',  # 𢟰
    0x227F1: 'téng',  # 𢟱
    # 0x227F2: '',  # 𢟲
    0x227F3: 'lǜ',  # 𢟳
    0x227F4: 'tuí',  # 𢟴
    0x227F5: 'bī',  # 𢟵
    # 0x227F6: '',  # 𢟶
    # 0x227F7: '',  # 𢟷
    # 0x227F8: '',  # 𢟸
    # 0x227F9: '',  # 𢟹
    # 0x227FA: '',  # 𢟺
    # 0x227FB: '',  # 𢟻
    # 0x227FC: '',  # 𢟼
    0x227FD: 'mù',  # 𢟽
    0x227FE: 'huì',  # 𢟾
    0x227FF: 'huán',  # 𢟿
    # 0x22800: '',  # 𢠀
    # 0x22801: '',  # 𢠁
    # 0x22802: '',  # 𢠂
    # 0x22803: '',  # 𢠃
    # 0x22804: '',  # 𢠄
    # 0x22805: '',  # 𢠅
    # 0x22806: '',  # 𢠆
    # 0x22807: '',  # 𢠇
    # 0x22808: '',  # 𢠈
    # 0x22809: '',  # 𢠉
    # 0x2280A: '',  # 𢠊
    # 0x2280B: '',  # 𢠋
    # 0x2280C: '',  # 𢠌
    # 0x2280D: '',  # 𢠍
    # 0x2280E: '',  # 𢠎
    # 0x2280F: '',  # 𢠏
    # 0x22810: '',  # 𢠐
    # 0x22811: '',  # 𢠑
    # 0x22812: '',  # 𢠒
    # 0x22813: '',  # 𢠓
    # 0x22814: '',  # 𢠔
    # 0x22815: '',  # 𢠕
    # 0x22816: '',  # 𢠖
    # 0x22817: '',  # 𢠗
    # 0x22818: '',  # 𢠘
    # 0x22819: '',  # 𢠙
    # 0x2281A: '',  # 𢠚
    0x2281B: 'kuò',  # 𢠛
    # 0x2281C: '',  # 𢠜
    0x2281D: 'xīn',  # 𢠝
    # 0x2281E: '',  # 𢠞
    # 0x2281F: '',  # 𢠟
    # 0x22820: '',  # 𢠠
    0x22821: 'sào',  # 𢠡
    # 0x22822: '',  # 𢠢
    # 0x22823: '',  # 𢠣
    # 0x22824: '',  # 𢠤
    # 0x22825: '',  # 𢠥
    # 0x22826: '',  # 𢠦
    # 0x22827: '',  # 𢠧
    # 0x22828: '',  # 𢠨
    # 0x22829: '',  # 𢠩
    # 0x2282A: '',  # 𢠪
    0x2282B: 'shù',  # 𢠫
    0x2282C: 'què',  # 𢠬
    0x2282D: 'bā',  # 𢠭
    0x2282E: 'tuì',  # 𢠮
    # 0x2282F: '',  # 𢠯
    0x22830: 'sǒng',  # 𢠰
    # 0x22831: '',  # 𢠱
    0x22832: 'fù',  # 𢠲
    0x22833: 'biē',  # 𢠳
    # 0x22834: '',  # 𢠴
    0x22835: 'chǎng,tǎng',  # 𢠵
    # 0x22836: '',  # 𢠶
    0x22837: 'xiàng',  # 𢠷
    # 0x22838: '',  # 𢠸
    0x22839: 'sī,xī',  # 𢠹
    0x2283A: 'bó',  # 𢠺
    # 0x2283B: '',  # 𢠻
    0x2283C: 'mái',  # 𢠼
    0x2283D: 'dàng',  # 𢠽
    # 0x2283E: '',  # 𢠾
    0x2283F: 'guì',  # 𢠿
    0x22840: 'hēi',  # 𢡀
    0x22841: 'xī',  # 𢡁
    0x22842: 'dàng',  # 𢡂
    0x22843: 'yì',  # 𢡃
    # 0x22844: '',  # 𢡄
    0x22845: 'bī',  # 𢡅
    0x22846: 'kěn',  # 𢡆
    0x22847: 'gū',  # 𢡇
    0x22848: 'cuì',  # 𢡈
    0x22849: 'sè',  # 𢡉
    # 0x2284A: '',  # 𢡊
    # 0x2284B: '',  # 𢡋
    # 0x2284C: '',  # 𢡌
    0x2284D: 'gé',  # 𢡍
    0x2284E: 'yù',  # 𢡎
    0x2284F: 'nǎ',  # 𢡏
    # 0x22850: '',  # 𢡐
    0x22851: 'lì',  # 𢡑
    0x22852: 'zhì',  # 𢡒
    # 0x22853: '',  # 𢡓
    # 0x22854: '',  # 𢡔
    # 0x22855: '',  # 𢡕
    # 0x22856: '',  # 𢡖
    # 0x22857: '',  # 𢡗
    # 0x22858: '',  # 𢡘
    # 0x22859: '',  # 𢡙
    # 0x2285A: '',  # 𢡚
    # 0x2285B: '',  # 𢡛
    # 0x2285C: '',  # 𢡜
    # 0x2285D: '',  # 𢡝
    # 0x2285E: '',  # 𢡞
    # 0x2285F: '',  # 𢡟
    # 0x22860: '',  # 𢡠
    # 0x22861: '',  # 𢡡
    # 0x22862: '',  # 𢡢
    # 0x22863: '',  # 𢡣
    # 0x22864: '',  # 𢡤
    # 0x22865: '',  # 𢡥
    # 0x22866: '',  # 𢡦
    # 0x22867: '',  # 𢡧
    # 0x22868: '',  # 𢡨
    # 0x22869: '',  # 𢡩
    # 0x2286A: '',  # 𢡪
    # 0x2286B: '',  # 𢡫
    # 0x2286C: '',  # 𢡬
    # 0x2286D: '',  # 𢡭
    # 0x2286E: '',  # 𢡮
    # 0x2286F: '',  # 𢡯
    0x22870: 'zhào',  # 𢡰
    # 0x22871: '',  # 𢡱
    # 0x22872: '',  # 𢡲
    # 0x22873: '',  # 𢡳
    0x22874: 'jī',  # 𢡴
    0x22875: 'ruǎn',  # 𢡵
    # 0x22876: '',  # 𢡶
    # 0x22877: '',  # 𢡷
    # 0x22878: '',  # 𢡸
    0x22879: 'chòng',  # 𢡹
    # 0x2287A: '',  # 𢡺
    # 0x2287B: '',  # 𢡻
    # 0x2287C: '',  # 𢡼
    # 0x2287D: '',  # 𢡽
    # 0x2287E: '',  # 𢡾
    # 0x2287F: '',  # 𢡿
    # 0x22880: '',  # 𢢀
    # 0x22881: '',  # 𢢁
    0x22882: 'jié',  # 𢢂
    # 0x22883: '',  # 𢢃
    # 0x22884: '',  # 𢢄
    # 0x22885: '',  # 𢢅
    # 0x22886: '',  # 𢢆
    # 0x22887: '',  # 𢢇
    # 0x22888: '',  # 𢢈
    # 0x22889: '',  # 𢢉
    # 0x2288A: '',  # 𢢊
    # 0x2288B: '',  # 𢢋
    0x2288C: 'chàng',  # 𢢌
    0x2288D: 'zhé',  # 𢢍
    # 0x2288E: '',  # 𢢎
    # 0x2288F: '',  # 𢢏
    # 0x22890: '',  # 𢢐
    # 0x22891: '',  # 𢢑
    0x22892: 'sù',  # 𢢒
    0x22893: 'yōng',  # 𢢓
    # 0x22894: '',  # 𢢔
    # 0x22895: '',  # 𢢕
    0x22896: 'qì',  # 𢢖
    0x22897: 'zhuó',  # 𢢗
    # 0x22898: '',  # 𢢘
    # 0x22899: '',  # 𢢙
    0x2289A: 'kài',  # 𢢚
    # 0x2289B: '',  # 𢢛
    0x2289C: 'yè',  # 𢢜
    # 0x2289D: '',  # 𢢝
    0x2289E: 'qì,jì,kuài',  # 𢢞
    # 0x2289F: '',  # 𢢟
    # 0x228A0: '',  # 𢢠
    # 0x228A1: '',  # 𢢡
    # 0x228A2: '',  # 𢢢
    # 0x228A3: '',  # 𢢣
    # 0x228A4: '',  # 𢢤
    # 0x228A5: '',  # 𢢥
    # 0x228A6: '',  # 𢢦
    # 0x228A7: '',  # 𢢧
    # 0x228A8: '',  # 𢢨
    # 0x228A9: '',  # 𢢩
    # 0x228AA: '',  # 𢢪
    # 0x228AB: '',  # 𢢫
    # 0x228AC: '',  # 𢢬
    # 0x228AD: '',  # 𢢭
    # 0x228AE: '',  # 𢢮
    # 0x228AF: '',  # 𢢯
    # 0x228B0: '',  # 𢢰
    # 0x228B1: '',  # 𢢱
    # 0x228B2: '',  # 𢢲
    # 0x228B3: '',  # 𢢳
    # 0x228B4: '',  # 𢢴
    # 0x228B5: '',  # 𢢵
    # 0x228B6: '',  # 𢢶
    # 0x228B7: '',  # 𢢷
    # 0x228B8: '',  # 𢢸
    0x228B9: 'xiòng',  # 𢢹
    # 0x228BA: '',  # 𢢺
    # 0x228BB: '',  # 𢢻
    0x228BC: 'biāo',  # 𢢼
    # 0x228BD: '',  # 𢢽
    # 0x228BE: '',  # 𢢾
    # 0x228BF: '',  # 𢢿
    # 0x228C0: '',  # 𢣀
    # 0x228C1: '',  # 𢣁
    # 0x228C2: '',  # 𢣂
    # 0x228C3: '',  # 𢣃
    # 0x228C4: '',  # 𢣄
    # 0x228C5: '',  # 𢣅
    # 0x228C6: '',  # 𢣆
    # 0x228C7: '',  # 𢣇
    # 0x228C8: '',  # 𢣈
    0x228C9: 'yī',  # 𢣉
    0x228CA: 'chǒu',  # 𢣊
    # 0x228CB: '',  # 𢣋
    # 0x228CC: '',  # 𢣌
    # 0x228CD: '',  # 𢣍
    0x228CE: 'tuǎn',  # 𢣎
    0x228CF: 'ài',  # 𢣏
    0x228D0: 'pīn',  # 𢣐
    # 0x228D1: '',  # 𢣑
    # 0x228D2: '',  # 𢣒
    0x228D3: 'liè',  # 𢣓
    0x228D4: 'mián',  # 𢣔
    0x228D5: 'ài,chī',  # 𢣕
    # 0x228D6: '',  # 𢣖
    0x228D7: 'mǒ',  # 𢣗
    0x228D8: 'wèi',  # 𢣘
    0x228D9: 'yìng',  # 𢣙
    0x228DA: 'nǐ',  # 𢣚
    # 0x228DB: '',  # 𢣛
    # 0x228DC: '',  # 𢣜
    # 0x228DD: '',  # 𢣝
    0x228DE: 'bó',  # 𢣞
    # 0x228DF: '',  # 𢣟
    0x228E0: 'liù',  # 𢣠
    # 0x228E1: '',  # 𢣡
    0x228E2: 'xié',  # 𢣢
    # 0x228E3: '',  # 𢣣
    # 0x228E4: '',  # 𢣤
    # 0x228E5: '',  # 𢣥
    # 0x228E6: '',  # 𢣦
    # 0x228E7: '',  # 𢣧
    # 0x228E8: '',  # 𢣨
    # 0x228E9: '',  # 𢣩
    # 0x228EA: '',  # 𢣪
    # 0x228EB: '',  # 𢣫
    # 0x228EC: '',  # 𢣬
    # 0x228ED: '',  # 𢣭
    # 0x228EE: '',  # 𢣮
    # 0x228EF: '',  # 𢣯
    # 0x228F0: '',  # 𢣰
    # 0x228F1: '',  # 𢣱
    # 0x228F2: '',  # 𢣲
    0x228F3: 'ruì',  # 𢣳
    # 0x228F4: '',  # 𢣴
    # 0x228F5: '',  # 𢣵
    # 0x228F6: '',  # 𢣶
    # 0x228F7: '',  # 𢣷
    # 0x228F8: '',  # 𢣸
    # 0x228F9: '',  # 𢣹
    # 0x228FA: '',  # 𢣺
    0x228FB: 'lǘ',  # 𢣻
    0x228FC: 'chá',  # 𢣼
    # 0x228FD: '',  # 𢣽
    # 0x228FE: '',  # 𢣾
    0x228FF: 'chù',  # 𢣿
    # 0x22900: '',  # 𢤀
    0x22901: 'sào',  # 𢤁
    0x22902: 'lí',  # 𢤂
    # 0x22903: '',  # 𢤃
    0x22904: 'sōng',  # 𢤄
    # 0x22905: '',  # 𢤅
    0x22906: 'lì,là',  # 𢤆
    # 0x22907: '',  # 𢤇
    # 0x22908: '',  # 𢤈
    # 0x22909: '',  # 𢤉
    # 0x2290A: '',  # 𢤊
    0x2290B: 'xì',  # 𢤋
    # 0x2290C: '',  # 𢤌
    0x2290D: 'yān',  # 𢤍
    0x2290E: 'cuō,zuǒ',  # 𢤎
    # 0x2290F: '',  # 𢤏
    0x22910: 'liú',  # 𢤐
    # 0x22911: '',  # 𢤑
    # 0x22912: '',  # 𢤒
    # 0x22913: '',  # 𢤓
    # 0x22914: '',  # 𢤔
    # 0x22915: '',  # 𢤕
    # 0x22916: '',  # 𢤖
    # 0x22917: '',  # 𢤗
    0x22918: 'méng',  # 𢤘
    # 0x22919: '',  # 𢤙
    0x2291A: 'zhàn',  # 𢤚
    # 0x2291B: '',  # 𢤛
    # 0x2291C: '',  # 𢤜
    # 0x2291D: '',  # 𢤝
    # 0x2291E: '',  # 𢤞
    # 0x2291F: '',  # 𢤟
    # 0x22920: '',  # 𢤠
    # 0x22921: '',  # 𢤡
    # 0x22922: '',  # 𢤢
    # 0x22923: '',  # 𢤣
    0x22924: 'zhuàng',  # 𢤤
    # 0x22925: '',  # 𢤥
    # 0x22926: '',  # 𢤦
    0x22927: 'miǎo',  # 𢤧
    # 0x22928: '',  # 𢤨
    0x22929: 'lì',  # 𢤩
    # 0x2292A: '',  # 𢤪
    0x2292B: 'jǔ',  # 𢤫
    # 0x2292C: '',  # 𢤬
    # 0x2292D: '',  # 𢤭
    # 0x2292E: '',  # 𢤮
    0x2292F: 'xiè',  # 𢤯
    0x22930: 'xiè',  # 𢤰
    0x22931: 'lǒng',  # 𢤱
    0x22932: 'lóng',  # 𢤲
    # 0x22933: '',  # 𢤳
    # 0x22934: '',  # 𢤴
    # 0x22935: '',  # 𢤵
    # 0x22936: '',  # 𢤶
    # 0x22937: '',  # 𢤷
    # 0x22938: '',  # 𢤸
    # 0x22939: '',  # 𢤹
    # 0x2293A: '',  # 𢤺
    # 0x2293B: '',  # 𢤻
    # 0x2293C: '',  # 𢤼
    # 0x2293D: '',  # 𢤽
    # 0x2293E: '',  # 𢤾
    # 0x2293F: '',  # 𢤿
    # 0x22940: '',  # 𢥀
    # 0x22941: '',  # 𢥁
    0x22942: 'téng',  # 𢥂
    0x22943: 'zhù',  # 𢥃
    # 0x22944: '',  # 𢥄
    # 0x22945: '',  # 𢥅
    # 0x22946: '',  # 𢥆
    # 0x22947: '',  # 𢥇
    # 0x22948: '',  # 𢥈
    # 0x22949: '',  # 𢥉
    # 0x2294A: '',  # 𢥊
    0x2294B: 'chán',  # 𢥋
    0x2294C: 'xiǎn',  # 𢥌
    # 0x2294D: '',  # 𢥍
    # 0x2294E: '',  # 𢥎
    0x2294F: 'yíng',  # 𢥏
    0x22950: 'pèi',  # 𢥐
    # 0x22951: '',  # 𢥑
    # 0x22952: '',  # 𢥒
    # 0x22953: '',  # 𢥓
    # 0x22954: '',  # 𢥔
    # 0x22955: '',  # 𢥕
    # 0x22956: '',  # 𢥖
    # 0x22957: '',  # 𢥗
    0x22958: 'xié',  # 𢥘
    # 0x22959: '',  # 𢥙
    0x2295A: 'jiào',  # 𢥚
    0x2295B: 'sè',  # 𢥛
    # 0x2295C: '',  # 𢥜
    # 0x2295D: '',  # 𢥝
    0x2295E: 'chōng',  # 𢥞
    # 0x2295F: '',  # 𢥟
    0x22960: 'sǒng',  # 𢥠
    # 0x22961: '',  # 𢥡
    # 0x22962: '',  # 𢥢
    # 0x22963: '',  # 𢥣
    # 0x22964: '',  # 𢥤
    # 0x22965: '',  # 𢥥
    # 0x22966: '',  # 𢥦
    # 0x22967: '',  # 𢥧
    # 0x22968: '',  # 𢥨
    # 0x22969: '',  # 𢥩
    # 0x2296A: '',  # 𢥪
    # 0x2296B: '',  # 𢥫
    # 0x2296C: '',  # 𢥬
    # 0x2296D: '',  # 𢥭
    # 0x2296E: '',  # 𢥮
    # 0x2296F: '',  # 𢥯
    # 0x22970: '',  # 𢥰
    # 0x22971: '',  # 𢥱
    # 0x22972: '',  # 𢥲
    0x22973: 'hē',  # 𢥳
    # 0x22974: '',  # 𢥴
    # 0x22975: '',  # 𢥵
    # 0x22976: '',  # 𢥶
    # 0x22977: '',  # 𢥷
    # 0x22978: '',  # 𢥸
    # 0x22979: '',  # 𢥹
    # 0x2297A: '',  # 𢥺
    # 0x2297B: '',  # 𢥻
    # 0x2297C: '',  # 𢥼
    0x2297D: 'tǔn',  # 𢥽
    # 0x2297E: '',  # 𢥾
    # 0x2297F: '',  # 𢥿
    # 0x22980: '',  # 𢦀
    # 0x22981: '',  # 𢦁
    # 0x22982: '',  # 𢦂
    # 0x22983: '',  # 𢦃
    # 0x22984: '',  # 𢦄
    0x22985: 'hǒng,zhuàng',  # 𢦅
    # 0x22986: '',  # 𢦆
    # 0x22987: '',  # 𢦇
    0x22988: 'mán',  # 𢦈
    # 0x22989: '',  # 𢦉
    0x2298A: 'jīn',  # 𢦊
    # 0x2298B: '',  # 𢦋
    0x2298C: 'qú',  # 𢦌
    0x2298D: 'dǒu',  # 𢦍
    0x2298E: 'qiú',  # 𢦎
    0x2298F: 'zāi',  # 𢦏
    # 0x22990: '',  # 𢦐
    0x22991: 'shēng',  # 𢦑
    0x22992: 'zāi',  # 𢦒
    # 0x22993: '',  # 𢦓
    0x22994: 'zāi',  # 𢦔
    0x22995: 'yǐ,zhí',  # 𢦕
    # 0x22996: '',  # 𢦖
    # 0x22997: '',  # 𢦗
    # 0x22998: '',  # 𢦘
    # 0x22999: '',  # 𢦙
    0x2299A: 'huà',  # 𢦚
    # 0x2299B: '',  # 𢦛
    # 0x2299C: '',  # 𢦜
    # 0x2299D: '',  # 𢦝
    # 0x2299E: '',  # 𢦞
    0x2299F: 'kān',  # 𢦟
    # 0x229A0: '',  # 𢦠
    # 0x229A1: '',  # 𢦡
    # 0x229A2: '',  # 𢦢
    0x229A3: 'yè',  # 𢦣
    # 0x229A4: '',  # 𢦤
    # 0x229A5: '',  # 𢦥
    0x229A6: 'róng',  # 𢦦
    # 0x229A7: '',  # 𢦧
    # 0x229A8: '',  # 𢦨
    # 0x229A9: '',  # 𢦩
    # 0x229AA: '',  # 𢦪
    # 0x229AB: '',  # 𢦫
    # 0x229AC: '',  # 𢦬
    # 0x229AD: '',  # 𢦭
    # 0x229AE: '',  # 𢦮
    # 0x229AF: '',  # 𢦯
    0x229B0: 'yuè',  # 𢦰
    0x229B1: 'nì',  # 𢦱
    0x229B2: 'sī',  # 𢦲
    # 0x229B3: '',  # 𢦳
    0x229B4: 'wǒ',  # 𢦴
    # 0x229B5: '',  # 𢦵
    # 0x229B6: '',  # 𢦶
    # 0x229B7: '',  # 𢦷
    0x229B8: 'cán',  # 𢦸
    # 0x229B9: '',  # 𢦹
    0x229BA: 'jiān',  # 𢦺
    # 0x229BB: '',  # 𢦻
    0x229BC: 'miè',  # 𢦼
    0x229BD: 'sháo,qī',  # 𢦽
    # 0x229BE: '',  # 𢦾
    0x229BF: 'rǒng',  # 𢦿
    0x229C0: 'gān',  # 𢧀
    # 0x229C1: '',  # 𢧁
    # 0x229C2: '',  # 𢧂
    # 0x229C3: '',  # 𢧃
    0x229C4: 'dié',  # 𢧄
    0x229C5: 'qiáng',  # 𢧅
    # 0x229C6: '',  # 𢧆
    0x229C7: 'shú',  # 𢧇
    0x229C8: 'zhuó',  # 𢧈
    # 0x229C9: '',  # 𢧉
    # 0x229CA: '',  # 𢧊
    # 0x229CB: '',  # 𢧋
    # 0x229CC: '',  # 𢧌
    # 0x229CD: '',  # 𢧍
    # 0x229CE: '',  # 𢧎
    0x229CF: 'shī',  # 𢧏
    # 0x229D0: '',  # 𢧐
    0x229D1: 'tì',  # 𢧑
    # 0x229D2: '',  # 𢧒
    # 0x229D3: '',  # 𢧓
    # 0x229D4: '',  # 𢧔
    # 0x229D5: '',  # 𢧕
    0x229D6: 'zhá',  # 𢧖
    0x229D7: 'zhān',  # 𢧗
    # 0x229D8: '',  # 𢧘
    # 0x229D9: '',  # 𢧙
    # 0x229DA: '',  # 𢧚
    # 0x229DB: '',  # 𢧛
    0x229DC: 'zhì',  # 𢧜
    0x229DD: 'fèn',  # 𢧝
    0x229DE: 'miè',  # 𢧞
    # 0x229DF: '',  # 𢧟
    0x229E0: 'zè',  # 𢧠
    # 0x229E1: '',  # 𢧡
    0x229E2: 'jǐ',  # 𢧢
    # 0x229E3: '',  # 𢧣
    0x229E4: 'zhì',  # 𢧤
    0x229E5: 'qiān',  # 𢧥
    0x229E6: 'hàn',  # 𢧦
    0x229E7: 'gé',  # 𢧧
    # 0x229E8: '',  # 𢧨
    # 0x229E9: '',  # 𢧩
    # 0x229EA: '',  # 𢧪
    # 0x229EB: '',  # 𢧫
    # 0x229EC: '',  # 𢧬
    # 0x229ED: '',  # 𢧭
    0x229EE: 'cán',  # 𢧮
    # 0x229EF: '',  # 𢧯
    0x229F0: 'guó',  # 𢧰
    0x229F1: 'jiāo',  # 𢧱
    # 0x229F2: '',  # 𢧲
    0x229F3: 'yōng',  # 𢧳
    0x229F4: 'áo',  # 𢧴
    0x229F5: 'jié',  # 𢧵
    # 0x229F6: '',  # 𢧶
    # 0x229F7: '',  # 𢧷
    # 0x229F8: '',  # 𢧸
    # 0x229F9: '',  # 𢧹
    # 0x229FA: '',  # 𢧺
    0x229FB: 'zhá',  # 𢧻
    # 0x229FC: '',  # 𢧼
    0x229FD: 'xì',  # 𢧽
    # 0x229FE: '',  # 𢧾
    # 0x229FF: '',  # 𢧿
    # 0x22A00: '',  # 𢨀
    0x22A01: 'xū',  # 𢨁
    0x22A02: 'wǔ',  # 𢨂
    # 0x22A03: '',  # 𢨃
    # 0x22A04: '',  # 𢨄
    # 0x22A05: '',  # 𢨅
    # 0x22A06: '',  # 𢨆
    # 0x22A07: '',  # 𢨇
    # 0x22A08: '',  # 𢨈
    # 0x22A09: '',  # 𢨉
    # 0x22A0A: '',  # 𢨊
    # 0x22A0B: '',  # 𢨋
    # 0x22A0C: '',  # 𢨌
    # 0x22A0D: '',  # 𢨍
    # 0x22A0E: '',  # 𢨎
    0x22A0F: 'jué',  # 𢨏
    0x22A10: 'jī',  # 𢨐
    # 0x22A11: '',  # 𢨑
    0x22A12: 'chì',  # 𢨒
    # 0x22A13: '',  # 𢨓
    0x22A14: 'wǎn',  # 𢨔
    # 0x22A15: '',  # 𢨕
    0x22A16: 'miè',  # 𢨖
    0x22A17: 'zéi',  # 𢨗
    # 0x22A18: '',  # 𢨘
    # 0x22A19: '',  # 𢨙
    # 0x22A1A: '',  # 𢨚
    # 0x22A1B: '',  # 𢨛
    0x22A1C: 'jié',  # 𢨜
    0x22A1D: 'shí',  # 𢨝
    # 0x22A1E: '',  # 𢨞
    0x22A1F: 'xī,xì',  # 𢨟
    # 0x22A20: '',  # 𢨠
    0x22A21: 'è',  # 𢨡
    # 0x22A22: '',  # 𢨢
    # 0x22A23: '',  # 𢨣
    # 0x22A24: '',  # 𢨤
    0x22A25: 'hù',  # 𢨥
    0x22A26: 'hù',  # 𢨦
    # 0x22A27: '',  # 𢨧
    0x22A28: 'lì',  # 𢨨
    # 0x22A29: '',  # 𢨩
    # 0x22A2A: '',  # 𢨪
    0x22A2B: 'chù',  # 𢨫
    # 0x22A2C: '',  # 𢨬
    # 0x22A2D: '',  # 𢨭
    0x22A2E: 'yī',  # 𢨮
    0x22A2F: 'mǎo',  # 𢨯
    0x22A30: 'xū',  # 𢨰
    0x22A31: 'zhōng',  # 𢨱
    0x22A32: 'fáng',  # 𢨲
    0x22A33: 'yì',  # 𢨳
    # 0x22A34: '',  # 𢨴
    # 0x22A35: '',  # 𢨵
    # 0x22A36: '',  # 𢨶
    # 0x22A37: '',  # 𢨷
    # 0x22A38: '',  # 𢨸
    # 0x22A39: '',  # 𢨹
    0x22A3A: 'liáo',  # 𢨺
    # 0x22A3B: '',  # 𢨻
    # 0x22A3C: '',  # 𢨼
    # 0x22A3D: '',  # 𢨽
    # 0x22A3E: '',  # 𢨾
    0x22A3F: 'jiān',  # 𢨿
    0x22A40: 'jiǎn',  # 𢩀
    0x22A41: 'jú',  # 𢩁
    # 0x22A42: '',  # 𢩂
    # 0x22A43: '',  # 𢩃
    0x22A44: 'zhù',  # 𢩄
    # 0x22A45: '',  # 𢩅
    # 0x22A46: '',  # 𢩆
    # 0x22A47: '',  # 𢩇
    0x22A48: 'wǔ',  # 𢩈
    # 0x22A49: '',  # 𢩉
    # 0x22A4A: '',  # 𢩊
    # 0x22A4B: '',  # 𢩋
    # 0x22A4C: '',  # 𢩌
    # 0x22A4D: '',  # 𢩍
    # 0x22A4E: '',  # 𢩎
    0x22A4F: 'kè',  # 𢩏
    0x22A50: 'kě',  # 𢩐
    0x22A51: 'lì',  # 𢩑
    0x22A52: 'bǐ',  # 𢩒
    0x22A53: 'gé',  # 𢩓
    # 0x22A54: '',  # 𢩔
    0x22A55: 'xū',  # 𢩕
    0x22A56: 'shā',  # 𢩖
    0x22A57: 'líng',  # 𢩗
    0x22A58: 'kē',  # 𢩘
    # 0x22A59: '',  # 𢩙
    # 0x22A5A: '',  # 𢩚
    # 0x22A5B: '',  # 𢩛
    # 0x22A5C: '',  # 𢩜
    # 0x22A5D: '',  # 𢩝
    0x22A5E: 'bó',  # 𢩞
    0x22A5F: 'biān',  # 𢩟
    0x22A60: 'shuān',  # 𢩠
    0x22A61: 'qí',  # 𢩡
    0x22A62: 'shàn',  # 𢩢
    # 0x22A63: '',  # 𢩣
    # 0x22A64: '',  # 𢩤
    # 0x22A65: '',  # 𢩥
    0x22A66: 'jī',  # 𢩦
    # 0x22A67: '',  # 𢩧
    0x22A68: 'qiǎo,xiǔ',  # 𢩨
    # 0x22A69: '',  # 𢩩
    0x22A6A: 'liāo',  # 𢩪
    # 0x22A6B: '',  # 𢩫
    # 0x22A6C: '',  # 𢩬
    # 0x22A6D: '',  # 𢩭
    0x22A6E: 'yì',  # 𢩮
    0x22A6F: 'jué',  # 𢩯
    0x22A70: 'zhǎng',  # 𢩰
    # 0x22A71: '',  # 𢩱
    0x22A72: 'xìn',  # 𢩲
    # 0x22A73: '',  # 𢩳
    # 0x22A74: '',  # 𢩴
    # 0x22A75: '',  # 𢩵
    # 0x22A76: '',  # 𢩶
    0x22A77: 'tuō',  # 𢩷
    0x22A78: 'hài',  # 𢩸
    0x22A79: 'xià',  # 𢩹
    # 0x22A7A: '',  # 𢩺
    0x22A7B: 'tuó',  # 𢩻
    0x22A7C: 'yí',  # 𢩼
    # 0x22A7D: '',  # 𢩽
    # 0x22A7E: '',  # 𢩾
    # 0x22A7F: '',  # 𢩿
    # 0x22A80: '',  # 𢪀
    # 0x22A81: '',  # 𢪁
    0x22A82: 'xuǎn',  # 𢪂
    0x22A83: 'cù',  # 𢪃
    # 0x22A84: '',  # 𢪄
    # 0x22A85: '',  # 𢪅
    # 0x22A86: '',  # 𢪆
    0x22A87: 'jiāng',  # 𢪇
    0x22A88: 'nán',  # 𢪈
    # 0x22A89: '',  # 𢪉
    # 0x22A8A: '',  # 𢪊
    0x22A8B: 'pěng,féng,bàng',  # 𢪋
    # 0x22A8C: '',  # 𢪌
    0x22A8D: 'jié,jiā',  # 𢪍
    0x22A8E: 'xuē',  # 𢪎
    0x22A8F: 'hú,gǔ',  # 𢪏
    # 0x22A90: '',  # 𢪐
    0x22A91: 'gài',  # 𢪑
    # 0x22A92: '',  # 𢪒
    # 0x22A93: '',  # 𢪓
    # 0x22A94: '',  # 𢪔
    # 0x22A95: '',  # 𢪕
    # 0x22A96: '',  # 𢪖
    # 0x22A97: '',  # 𢪗
    # 0x22A98: '',  # 𢪘
    # 0x22A99: '',  # 𢪙
    # 0x22A9A: '',  # 𢪚
    # 0x22A9B: '',  # 𢪛
    # 0x22A9C: '',  # 𢪜
    # 0x22A9D: '',  # 𢪝
    # 0x22A9E: '',  # 𢪞
    # 0x22A9F: '',  # 𢪟
    0x22AA0: 'chōng',  # 𢪠
    # 0x22AA1: '',  # 𢪡
    # 0x22AA2: '',  # 𢪢
    # 0x22AA3: '',  # 𢪣
    # 0x22AA4: '',  # 𢪤
    0x22AA5: 'yǒu',  # 𢪥
    0x22AA6: 'nǔ',  # 𢪦
    0x22AA7: 'yè',  # 𢪧
    # 0x22AA8: '',  # 𢪨
    # 0x22AA9: '',  # 𢪩
    0x22AAA: 'yìn',  # 𢪪
    # 0x22AAB: '',  # 𢪫
    0x22AAC: 'kǒng',  # 𢪬
    # 0x22AAD: '',  # 𢪭
    # 0x22AAE: '',  # 𢪮
    # 0x22AAF: '',  # 𢪯
    # 0x22AB0: '',  # 𢪰
    0x22AB1: 'wù',  # 𢪱
    # 0x22AB2: '',  # 𢪲
    # 0x22AB3: '',  # 𢪳
    # 0x22AB4: '',  # 𢪴
    # 0x22AB5: '',  # 𢪵
    0x22AB6: 'xiāo',  # 𢪶
    0x22AB7: 'xiāng',  # 𢪷
    # 0x22AB8: '',  # 𢪸
    # 0x22AB9: '',  # 𢪹
    # 0x22ABA: '',  # 𢪺
    # 0x22ABB: '',  # 𢪻
    0x22ABC: 'náo',  # 𢪼
    # 0x22ABD: '',  # 𢪽
    0x22ABE: 'zhàng',  # 𢪾
    # 0x22ABF: '',  # 𢪿
    # 0x22AC0: '',  # 𢫀
    # 0x22AC1: '',  # 𢫁
    # 0x22AC2: '',  # 𢫂
    # 0x22AC3: '',  # 𢫃
    # 0x22AC4: '',  # 𢫄
    # 0x22AC5: '',  # 𢫅
    0x22AC6: 'bō',  # 𢫆
    # 0x22AC7: '',  # 𢫇
    0x22AC8: 'gū,gǔ',  # 𢫈
    # 0x22AC9: '',  # 𢫉
    # 0x22ACA: '',  # 𢫊
    # 0x22ACB: '',  # 𢫋
    # 0x22ACC: '',  # 𢫌
    # 0x22ACD: '',  # 𢫍
    # 0x22ACE: '',  # 𢫎
    # 0x22ACF: '',  # 𢫏
    0x22AD0: 'jié',  # 𢫐
    # 0x22AD1: '',  # 𢫑
    # 0x22AD2: '',  # 𢫒
    0x22AD3: 'nǔ',  # 𢫓
    0x22AD4: 'shàn,quán',  # 𢫔
    0x22AD5: 'yǒng',  # 𢫕
    # 0x22AD6: '',  # 𢫖
    # 0x22AD7: '',  # 𢫗
    0x22AD8: 'lú',  # 𢫘
    # 0x22AD9: '',  # 𢫙
    # 0x22ADA: '',  # 𢫚
    # 0x22ADB: '',  # 𢫛
    # 0x22ADC: '',  # 𢫜
    # 0x22ADD: '',  # 𢫝
    # 0x22ADE: '',  # 𢫞
    # 0x22ADF: '',  # 𢫟
    # 0x22AE0: '',  # 𢫠
    # 0x22AE1: '',  # 𢫡
    0x22AE2: 'jiá',  # 𢫢
    # 0x22AE3: '',  # 𢫣
    # 0x22AE4: '',  # 𢫤
    # 0x22AE5: '',  # 𢫥
    0x22AE6: 'pāi',  # 𢫦
    0x22AE7: 'zhǒu',  # 𢫧
    0x22AE8: 'rǒng,rēng',  # 𢫨
    0x22AE9: 'hāo',  # 𢫩
    # 0x22AEA: '',  # 𢫪
    0x22AEB: 'lù',  # 𢫫
    0x22AEC: 'cuō',  # 𢫬
    0x22AED: 'nù',  # 𢫭
    # 0x22AEE: '',  # 𢫮
    0x22AEF: 'bó',  # 𢫯
    0x22AF0: 'zhé',  # 𢫰
    # 0x22AF1: '',  # 𢫱
    0x22AF2: 'qǐn',  # 𢫲
    # 0x22AF3: '',  # 𢫳
    0x22AF4: 'cī',  # 𢫴
    0x22AF5: 'zú',  # 𢫵
    # 0x22AF6: '',  # 𢫶
    0x22AF7: 'wǒ',  # 𢫷
    0x22AF8: 'wǔ,wū',  # 𢫸
    # 0x22AF9: '',  # 𢫹
    # 0x22AFA: '',  # 𢫺
    0x22AFB: 'nié',  # 𢫻
    # 0x22AFC: '',  # 𢫼
    # 0x22AFD: '',  # 𢫽
    # 0x22AFE: '',  # 𢫾
    0x22AFF: 'xiān',  # 𢫿
    0x22B00: 'hóng',  # 𢬀
    # 0x22B01: '',  # 𢬁
    # 0x22B02: '',  # 𢬂
    # 0x22B03: '',  # 𢬃
    # 0x22B04: '',  # 𢬄
    # 0x22B05: '',  # 𢬅
    # 0x22B06: '',  # 𢬆
    # 0x22B07: '',  # 𢬇
    # 0x22B08: '',  # 𢬈
    # 0x22B09: '',  # 𢬉
    # 0x22B0A: '',  # 𢬊
    # 0x22B0B: '',  # 𢬋
    # 0x22B0C: '',  # 𢬌
    # 0x22B0D: '',  # 𢬍
    # 0x22B0E: '',  # 𢬎
    # 0x22B0F: '',  # 𢬏
    # 0x22B10: '',  # 𢬐
    # 0x22B11: '',  # 𢬑
    # 0x22B12: '',  # 𢬒
    # 0x22B13: '',  # 𢬓
    # 0x22B14: '',  # 𢬔
    # 0x22B15: '',  # 𢬕
    # 0x22B16: '',  # 𢬖
    # 0x22B17: '',  # 𢬗
    # 0x22B18: '',  # 𢬘
    # 0x22B19: '',  # 𢬙
    # 0x22B1A: '',  # 𢬚
    # 0x22B1B: '',  # 𢬛
    # 0x22B1C: '',  # 𢬜
    # 0x22B1D: '',  # 𢬝
    # 0x22B1E: '',  # 𢬞
    # 0x22B1F: '',  # 𢬟
    # 0x22B20: '',  # 𢬠
    # 0x22B21: '',  # 𢬡
    # 0x22B22: '',  # 𢬢
    # 0x22B23: '',  # 𢬣
    # 0x22B24: '',  # 𢬤
    # 0x22B25: '',  # 𢬥
    # 0x22B26: '',  # 𢬦
    # 0x22B27: '',  # 𢬧
    # 0x22B28: '',  # 𢬨
    # 0x22B29: '',  # 𢬩
    # 0x22B2A: '',  # 𢬪
    0x22B2B: 'tìng',  # 𢬫
    0x22B2C: 'jǐn',  # 𢬬
    # 0x22B2D: '',  # 𢬭
    # 0x22B2E: '',  # 𢬮
    # 0x22B2F: '',  # 𢬯
    # 0x22B30: '',  # 𢬰
    0x22B31: 'jié',  # 𢬱
    0x22B32: 'hè',  # 𢬲
    0x22B33: 'tū',  # 𢬳
    0x22B34: 'zhé,niè,dié',  # 𢬴
    0x22B35: 'pīn,pān,biàn,fān',  # 𢬵
    0x22B36: 'jìn',  # 𢬶
    0x22B37: 'nàn',  # 𢬷
    # 0x22B38: '',  # 𢬸
    # 0x22B39: '',  # 𢬹
    # 0x22B3A: '',  # 𢬺
    # 0x22B3B: '',  # 𢬻
    0x22B3C: 'dùn',  # 𢬼
    # 0x22B3D: '',  # 𢬽
    0x22B3E: 'xī',  # 𢬾
    0x22B3F: 'xiè',  # 𢬿
    # 0x22B40: '',  # 𢭀
    0x22B41: 'xì',  # 𢭁
    0x22B42: 'láo',  # 𢭂
    0x22B43: 'duǎn,dòu',  # 𢭃
    0x22B44: 'jì',  # 𢭄
    0x22B45: 'chā',  # 𢭅
    0x22B46: 'chōu',  # 𢭆
    # 0x22B47: '',  # 𢭇
    0x22B48: 'gāng',  # 𢭈
    # 0x22B49: '',  # 𢭉
    # 0x22B4A: '',  # 𢭊
    # 0x22B4B: '',  # 𢭋
    # 0x22B4C: '',  # 𢭌
    # 0x22B4D: '',  # 𢭍
    0x22B4E: 'xiáng',  # 𢭎
    0x22B4F: 'dǎo',  # 𢭏
    # 0x22B50: '',  # 𢭐
    # 0x22B51: '',  # 𢭑
    # 0x22B52: '',  # 𢭒
    # 0x22B53: '',  # 𢭓
    # 0x22B54: '',  # 𢭔
    # 0x22B55: '',  # 𢭕
    # 0x22B56: '',  # 𢭖
    # 0x22B57: '',  # 𢭗
    # 0x22B58: '',  # 𢭘
    # 0x22B59: '',  # 𢭙
    # 0x22B5A: '',  # 𢭚
    # 0x22B5B: '',  # 𢭛
    # 0x22B5C: '',  # 𢭜
    # 0x22B5D: '',  # 𢭝
    # 0x22B5E: '',  # 𢭞
    # 0x22B5F: '',  # 𢭟
    # 0x22B60: '',  # 𢭠
    # 0x22B61: '',  # 𢭡
    # 0x22B62: '',  # 𢭢
    # 0x22B63: '',  # 𢭣
    # 0x22B64: '',  # 𢭤
    0x22B65: 'biàn',  # 𢭥
    0x22B66: 'xiāo',  # 𢭦
    0x22B67: 'xīn',  # 𢭧
    # 0x22B68: '',  # 𢭨
    # 0x22B69: '',  # 𢭩
    # 0x22B6A: '',  # 𢭪
    # 0x22B6B: '',  # 𢭫
    # 0x22B6C: '',  # 𢭬
    # 0x22B6D: '',  # 𢭭
    # 0x22B6E: '',  # 𢭮
    # 0x22B6F: '',  # 𢭯
    # 0x22B70: '',  # 𢭰
    # 0x22B71: '',  # 𢭱
    # 0x22B72: '',  # 𢭲
    # 0x22B73: '',  # 𢭳
    # 0x22B74: '',  # 𢭴
    # 0x22B75: '',  # 𢭵
    # 0x22B76: '',  # 𢭶
    # 0x22B77: '',  # 𢭷
    # 0x22B78: '',  # 𢭸
    # 0x22B79: '',  # 𢭹
    # 0x22B7A: '',  # 𢭺
    # 0x22B7B: '',  # 𢭻
    # 0x22B7C: '',  # 𢭼
    # 0x22B7D: '',  # 𢭽
    # 0x22B7E: '',  # 𢭾
    # 0x22B7F: '',  # 𢭿
    # 0x22B80: '',  # 𢮀
    0x22B81: 'yǔ',  # 𢮁
    0x22B82: 'xián',  # 𢮂
    0x22B83: 'lí',  # 𢮃
    0x22B84: 'qiǎn',  # 𢮄
    # 0x22B85: '',  # 𢮅
    # 0x22B86: '',  # 𢮆
    0x22B87: 'měi',  # 𢮇
    # 0x22B88: '',  # 𢮈
    0x22B89: 'qiāo',  # 𢮉
    0x22B8A: 'yà',  # 𢮊
    # 0x22B8B: '',  # 𢮋
    0x22B8C: 'qiā,jié',  # 𢮌
    0x22B8D: 'qiòng',  # 𢮍
    # 0x22B8E: '',  # 𢮎
    0x22B8F: 'bàng',  # 𢮏
    0x22B90: 'zhēng',  # 𢮐
    # 0x22B91: '',  # 𢮑
    # 0x22B92: '',  # 𢮒
    # 0x22B93: '',  # 𢮓
    # 0x22B94: '',  # 𢮔
    # 0x22B95: '',  # 𢮕
    # 0x22B96: '',  # 𢮖
    # 0x22B97: '',  # 𢮗
    # 0x22B98: '',  # 𢮘
    # 0x22B99: '',  # 𢮙
    0x22B9A: 'zè',  # 𢮚
    0x22B9B: 'shuàn,tuán',  # 𢮛
    # 0x22B9C: '',  # 𢮜
    # 0x22B9D: '',  # 𢮝
    0x22B9E: 'sào',  # 𢮞
    # 0x22B9F: '',  # 𢮟
    # 0x22BA0: '',  # 𢮠
    # 0x22BA1: '',  # 𢮡
    # 0x22BA2: '',  # 𢮢
    # 0x22BA3: '',  # 𢮣
    # 0x22BA4: '',  # 𢮤
    # 0x22BA5: '',  # 𢮥
    # 0x22BA6: '',  # 𢮦
    # 0x22BA7: '',  # 𢮧
    # 0x22BA8: '',  # 𢮨
    # 0x22BA9: '',  # 𢮩
    # 0x22BAA: '',  # 𢮪
    # 0x22BAB: '',  # 𢮫
    # 0x22BAC: '',  # 𢮬
    # 0x22BAD: '',  # 𢮭
    # 0x22BAE: '',  # 𢮮
    # 0x22BAF: '',  # 𢮯
    # 0x22BB0: '',  # 𢮰
    # 0x22BB1: '',  # 𢮱
    # 0x22BB2: '',  # 𢮲
    # 0x22BB3: '',  # 𢮳
    # 0x22BB4: '',  # 𢮴
    # 0x22BB5: '',  # 𢮵
    # 0x22BB6: '',  # 𢮶
    # 0x22BB7: '',  # 𢮷
    # 0x22BB8: '',  # 𢮸
    # 0x22BB9: '',  # 𢮹
    # 0x22BBA: '',  # 𢮺
    # 0x22BBB: '',  # 𢮻
    # 0x22BBC: '',  # 𢮼
    # 0x22BBD: '',  # 𢮽
    # 0x22BBE: '',  # 𢮾
    # 0x22BBF: '',  # 𢮿
    # 0x22BC0: '',  # 𢯀
    # 0x22BC1: '',  # 𢯁
    # 0x22BC2: '',  # 𢯂
    # 0x22BC3: '',  # 𢯃
    # 0x22BC4: '',  # 𢯄
    0x22BC5: 'lù,jué',  # 𢯅
    # 0x22BC6: '',  # 𢯆
    # 0x22BC7: '',  # 𢯇
    # 0x22BC8: '',  # 𢯈
    0x22BC9: 'xié',  # 𢯉
    # 0x22BCA: '',  # 𢯊
    0x22BCB: 'fǔ',  # 𢯋
    0x22BCC: 'zhài',  # 𢯌
    # 0x22BCD: '',  # 𢯍
    # 0x22BCE: '',  # 𢯎
    # 0x22BCF: '',  # 𢯏
    # 0x22BD0: '',  # 𢯐
    # 0x22BD1: '',  # 𢯑
    # 0x22BD2: '',  # 𢯒
    # 0x22BD3: '',  # 𢯓
    # 0x22BD4: '',  # 𢯔
    # 0x22BD5: '',  # 𢯕
    # 0x22BD6: '',  # 𢯖
    # 0x22BD7: '',  # 𢯗
    # 0x22BD8: '',  # 𢯘
    # 0x22BD9: '',  # 𢯙
    # 0x22BDA: '',  # 𢯚
    # 0x22BDB: '',  # 𢯛
    # 0x22BDC: '',  # 𢯜
    # 0x22BDD: '',  # 𢯝
    # 0x22BDE: '',  # 𢯞
    # 0x22BDF: '',  # 𢯟
    # 0x22BE0: '',  # 𢯠
    # 0x22BE1: '',  # 𢯡
    # 0x22BE2: '',  # 𢯢
    # 0x22BE3: '',  # 𢯣
    # 0x22BE4: '',  # 𢯤
    # 0x22BE5: '',  # 𢯥
    0x22BE6: 'lái',  # 𢯦
    # 0x22BE7: '',  # 𢯧
    # 0x22BE8: '',  # 𢯨
    0x22BE9: 'zè',  # 𢯩
    # 0x22BEA: '',  # 𢯪
    0x22BEB: 'duàn,wǎn',  # 𢯫
    # 0x22BEC: '',  # 𢯬
    0x22BED: 'dèng',  # 𢯭
    0x22BEE: 'yù',  # 𢯮
    # 0x22BEF: '',  # 𢯯
    0x22BF0: 'lǜ',  # 𢯰
    0x22BF1: 'sōu',  # 𢯱
    0x22BF2: 'wàn',  # 𢯲
    0x22BF3: 'xué',  # 𢯳
    0x22BF4: 'jiǎo',  # 𢯴
    0x22BF5: 'yuě',  # 𢯵
    0x22BF6: 'zhì',  # 𢯶
    0x22BF7: 'wěi,huī',  # 𢯷
    # 0x22BF8: '',  # 𢯸
    0x22BF9: 'gé',  # 𢯹
    0x22BFA: 'jǔ',  # 𢯺
    # 0x22BFB: '',  # 𢯻
    0x22BFC: 'yǎn',  # 𢯼
    0x22BFD: 'cuò',  # 𢯽
    0x22BFE: 'mào',  # 𢯾
    # 0x22BFF: '',  # 𢯿
    # 0x22C00: '',  # 𢰀
    # 0x22C01: '',  # 𢰁
    # 0x22C02: '',  # 𢰂
    # 0x22C03: '',  # 𢰃
    # 0x22C04: '',  # 𢰄
    # 0x22C05: '',  # 𢰅
    0x22C06: 'fú',  # 𢰆
    0x22C07: 'āi',  # 𢰇
    # 0x22C08: '',  # 𢰈
    # 0x22C09: '',  # 𢰉
    0x22C0A: 'xuān',  # 𢰊
    # 0x22C0B: '',  # 𢰋
    0x22C0C: 'gāng',  # 𢰌
    0x22C0D: 'ān',  # 𢰍
    # 0x22C0E: '',  # 𢰎
    # 0x22C0F: '',  # 𢰏
    # 0x22C10: '',  # 𢰐
    # 0x22C11: '',  # 𢰑
    0x22C12: 'jí',  # 𢰒
    # 0x22C13: '',  # 𢰓
    # 0x22C14: '',  # 𢰔
    # 0x22C15: '',  # 𢰕
    # 0x22C16: '',  # 𢰖
    # 0x22C17: '',  # 𢰗
    0x22C18: 'pí',  # 𢰘
    0x22C19: 'zhǐ',  # 𢰙
    # 0x22C1A: '',  # 𢰚
    # 0x22C1B: '',  # 𢰛
    0x22C1C: 'nuó',  # 𢰜
    # 0x22C1D: '',  # 𢰝
    # 0x22C1E: '',  # 𢰞
    # 0x22C1F: '',  # 𢰟
    # 0x22C20: '',  # 𢰠
    # 0x22C21: '',  # 𢰡
    # 0x22C22: '',  # 𢰢
    # 0x22C23: '',  # 𢰣
    # 0x22C24: '',  # 𢰤
    # 0x22C25: '',  # 𢰥
    # 0x22C26: '',  # 𢰦
    # 0x22C27: '',  # 𢰧
    # 0x22C28: '',  # 𢰨
    # 0x22C29: '',  # 𢰩
    # 0x22C2A: '',  # 𢰪
    # 0x22C2B: '',  # 𢰫
    # 0x22C2C: '',  # 𢰬
    # 0x22C2D: '',  # 𢰭
    # 0x22C2E: '',  # 𢰮
    # 0x22C2F: '',  # 𢰯
    # 0x22C30: '',  # 𢰰
    # 0x22C31: '',  # 𢰱
    # 0x22C32: '',  # 𢰲
    # 0x22C33: '',  # 𢰳
    # 0x22C34: '',  # 𢰴
    # 0x22C35: '',  # 𢰵
    # 0x22C36: '',  # 𢰶
    # 0x22C37: '',  # 𢰷
    # 0x22C38: '',  # 𢰸
    # 0x22C39: '',  # 𢰹
    # 0x22C3A: '',  # 𢰺
    # 0x22C3B: '',  # 𢰻
    # 0x22C3C: '',  # 𢰼
    # 0x22C3D: '',  # 𢰽
    # 0x22C3E: '',  # 𢰾
    0x22C3F: 'pàn',  # 𢰿
    # 0x22C40: '',  # 𢱀
    0x22C41: 'yí',  # 𢱁
    # 0x22C42: '',  # 𢱂
    # 0x22C43: '',  # 𢱃
    0x22C44: 'jié',  # 𢱄
    # 0x22C45: '',  # 𢱅
    0x22C46: 'zī',  # 𢱆
    # 0x22C47: '',  # 𢱇
    0x22C48: 'jià',  # 𢱈
    0x22C49: 'wǎi',  # 𢱉
    0x22C4A: 'lüè',  # 𢱊
    # 0x22C4B: '',  # 𢱋
    0x22C4C: 'jià',  # 𢱌
    # 0x22C4D: '',  # 𢱍
    # 0x22C4E: '',  # 𢱎
    # 0x22C4F: '',  # 𢱏
    # 0x22C50: '',  # 𢱐
    # 0x22C51: '',  # 𢱑
    # 0x22C52: '',  # 𢱒
    # 0x22C53: '',  # 𢱓
    # 0x22C54: '',  # 𢱔
    # 0x22C55: '',  # 𢱕
    # 0x22C56: '',  # 𢱖
    # 0x22C57: '',  # 𢱗
    # 0x22C58: '',  # 𢱘
    # 0x22C59: '',  # 𢱙
    # 0x22C5A: '',  # 𢱚
    # 0x22C5B: '',  # 𢱛
    # 0x22C5C: '',  # 𢱜
    # 0x22C5D: '',  # 𢱝
    # 0x22C5E: '',  # 𢱞
    0x22C5F: 'chǎn,chī',  # 𢱟
    # 0x22C60: '',  # 𢱠
    0x22C61: 'suǒ',  # 𢱡
    0x22C62: 'suǒ,sè',  # 𢱢
    0x22C63: 'jí',  # 𢱣
    0x22C64: 'sǒng',  # 𢱤
    # 0x22C65: '',  # 𢱥
    0x22C66: 'tī',  # 𢱦
    0x22C67: 'pī',  # 𢱧
    0x22C68: 'pó',  # 𢱨
    # 0x22C69: '',  # 𢱩
    # 0x22C6A: '',  # 𢱪
    # 0x22C6B: '',  # 𢱫
    # 0x22C6C: '',  # 𢱬
    # 0x22C6D: '',  # 𢱭
    0x22C6E: 'mì',  # 𢱮
    # 0x22C6F: '',  # 𢱯
    # 0x22C70: '',  # 𢱰
    # 0x22C71: '',  # 𢱱
    # 0x22C72: '',  # 𢱲
    # 0x22C73: '',  # 𢱳
    0x22C74: 'yè',  # 𢱴
    # 0x22C75: '',  # 𢱵
    0x22C76: 'qìn',  # 𢱶
    0x22C77: 'jìn',  # 𢱷
    # 0x22C78: '',  # 𢱸
    # 0x22C79: '',  # 𢱹
    0x22C7A: 'juē',  # 𢱺
    # 0x22C7B: '',  # 𢱻
    # 0x22C7C: '',  # 𢱼
    0x22C7D: 'yuān',  # 𢱽
    0x22C7E: 'ruán',  # 𢱾
    # 0x22C7F: '',  # 𢱿
    # 0x22C80: '',  # 𢲀
    # 0x22C81: '',  # 𢲁
    # 0x22C82: '',  # 𢲂
    # 0x22C83: '',  # 𢲃
    # 0x22C84: '',  # 𢲄
    # 0x22C85: '',  # 𢲅
    # 0x22C86: '',  # 𢲆
    # 0x22C87: '',  # 𢲇
    # 0x22C88: '',  # 𢲈
    # 0x22C89: '',  # 𢲉
    # 0x22C8A: '',  # 𢲊
    # 0x22C8B: '',  # 𢲋
    # 0x22C8C: '',  # 𢲌
    # 0x22C8D: '',  # 𢲍
    # 0x22C8E: '',  # 𢲎
    # 0x22C8F: '',  # 𢲏
    # 0x22C90: '',  # 𢲐
    # 0x22C91: '',  # 𢲑
    # 0x22C92: '',  # 𢲒
    # 0x22C93: '',  # 𢲓
    0x22C94: 'bàn,bān,pān',  # 𢲔
    # 0x22C95: '',  # 𢲕
    # 0x22C96: '',  # 𢲖
    # 0x22C97: '',  # 𢲗
    # 0x22C98: '',  # 𢲘
    # 0x22C99: '',  # 𢲙
    # 0x22C9A: '',  # 𢲚
    # 0x22C9B: '',  # 𢲛
    # 0x22C9C: '',  # 𢲜
    # 0x22C9D: '',  # 𢲝
    # 0x22C9E: '',  # 𢲞
    # 0x22C9F: '',  # 𢲟
    # 0x22CA0: '',  # 𢲠
    # 0x22CA1: '',  # 𢲡
    # 0x22CA2: '',  # 𢲢
    # 0x22CA3: '',  # 𢲣
    # 0x22CA4: '',  # 𢲤
    # 0x22CA5: '',  # 𢲥
    # 0x22CA6: '',  # 𢲦
    # 0x22CA7: '',  # 𢲧
    # 0x22CA8: '',  # 𢲨
    # 0x22CA9: '',  # 𢲩
    # 0x22CAA: '',  # 𢲪
    0x22CAB: 'mā',  # 𢲫
    # 0x22CAC: '',  # 𢲬
    # 0x22CAD: '',  # 𢲭
    # 0x22CAE: '',  # 𢲮
    # 0x22CAF: '',  # 𢲯
    0x22CB0: 'bīn',  # 𢲰
    # 0x22CB1: '',  # 𢲱
    # 0x22CB2: '',  # 𢲲
    # 0x22CB3: '',  # 𢲳
    0x22CB4: 'wèi',  # 𢲴
    0x22CB5: 'zào',  # 𢲵
    0x22CB6: 'qiè',  # 𢲶
    0x22CB7: 'ǎo',  # 𢲷
    0x22CB8: 'lǔ',  # 𢲸
    # 0x22CB9: '',  # 𢲹
    # 0x22CBA: '',  # 𢲺
    # 0x22CBB: '',  # 𢲻
    0x22CBC: 'dié',  # 𢲼
    0x22CBD: 'chuāi',  # 𢲽
    0x22CBE: 'bì',  # 𢲾
    0x22CBF: 'zhú',  # 𢲿
    0x22CC0: 'mó,mā',  # 𢳀
    0x22CC1: 'fèi',  # 𢳁
    0x22CC2: 'piē',  # 𢳂
    0x22CC3: 'yìn',  # 𢳃
    0x22CC4: 'xuàn,xuán',  # 𢳄
    # 0x22CC5: '',  # 𢳅
    0x22CC6: 'ào,áo',  # 𢳆
    0x22CC7: 'zhuó,zú',  # 𢳇
    0x22CC8: 'zú',  # 𢳈
    # 0x22CC9: '',  # 𢳉
    # 0x22CCA: '',  # 𢳊
    0x22CCB: 'bǐ',  # 𢳋
    # 0x22CCC: '',  # 𢳌
    # 0x22CCD: '',  # 𢳍
    0x22CCE: 'bài',  # 𢳎
    # 0x22CCF: '',  # 𢳏
    # 0x22CD0: '',  # 𢳐
    0x22CD1: 'làng',  # 𢳑
    # 0x22CD2: '',  # 𢳒
    0x22CD3: 'tì',  # 𢳓
    # 0x22CD4: '',  # 𢳔
    # 0x22CD5: '',  # 𢳕
    # 0x22CD6: '',  # 𢳖
    # 0x22CD7: '',  # 𢳗
    # 0x22CD8: '',  # 𢳘
    0x22CD9: 'tiǎo',  # 𢳙
    0x22CDA: 'jiān',  # 𢳚
    0x22CDB: 'zhā',  # 𢳛
    # 0x22CDC: '',  # 𢳜
    # 0x22CDD: '',  # 𢳝
    # 0x22CDE: '',  # 𢳞
    0x22CDF: 'tǒng',  # 𢳟
    # 0x22CE0: '',  # 𢳠
    # 0x22CE1: '',  # 𢳡
    # 0x22CE2: '',  # 𢳢
    # 0x22CE3: '',  # 𢳣
    # 0x22CE4: '',  # 𢳤
    0x22CE5: 'cāo',  # 𢳥
    # 0x22CE6: '',  # 𢳦
    # 0x22CE7: '',  # 𢳧
    # 0x22CE8: '',  # 𢳨
    # 0x22CE9: '',  # 𢳩
    # 0x22CEA: '',  # 𢳪
    # 0x22CEB: '',  # 𢳫
    # 0x22CEC: '',  # 𢳬
    # 0x22CED: '',  # 𢳭
    # 0x22CEE: '',  # 𢳮
    # 0x22CEF: '',  # 𢳯
    # 0x22CF0: '',  # 𢳰
    # 0x22CF1: '',  # 𢳱
    # 0x22CF2: '',  # 𢳲
    # 0x22CF3: '',  # 𢳳
    # 0x22CF4: '',  # 𢳴
    # 0x22CF5: '',  # 𢳵
    # 0x22CF6: '',  # 𢳶
    # 0x22CF7: '',  # 𢳷
    # 0x22CF8: '',  # 𢳸
    # 0x22CF9: '',  # 𢳹
    # 0x22CFA: '',  # 𢳺
    # 0x22CFB: '',  # 𢳻
    # 0x22CFC: '',  # 𢳼
    0x22CFD: 'duō',  # 𢳽
    0x22CFE: 'dòng',  # 𢳾
    # 0x22CFF: '',  # 𢳿
    # 0x22D00: '',  # 𢴀
    # 0x22D01: '',  # 𢴁
    0x22D02: 'biǎn',  # 𢴂
    # 0x22D03: '',  # 𢴃
    # 0x22D04: '',  # 𢴄
    # 0x22D05: '',  # 𢴅
    # 0x22D06: '',  # 𢴆
    # 0x22D07: '',  # 𢴇
    0x22D08: 'dá',  # 𢴈
    # 0x22D09: '',  # 𢴉
    # 0x22D0A: '',  # 𢴊
    # 0x22D0B: '',  # 𢴋
    # 0x22D0C: '',  # 𢴌
    # 0x22D0D: '',  # 𢴍
    # 0x22D0E: '',  # 𢴎
    # 0x22D0F: '',  # 𢴏
    # 0x22D10: '',  # 𢴐
    # 0x22D11: '',  # 𢴑
    0x22D12: 'pēng',  # 𢴒
    # 0x22D13: '',  # 𢴓
    # 0x22D14: '',  # 𢴔
    # 0x22D15: '',  # 𢴕
    # 0x22D16: '',  # 𢴖
    # 0x22D17: '',  # 𢴗
    # 0x22D18: '',  # 𢴘
    # 0x22D19: '',  # 𢴙
    0x22D1A: 'nì',  # 𢴚
    # 0x22D1B: '',  # 𢴛
    # 0x22D1C: '',  # 𢴜
    # 0x22D1D: '',  # 𢴝
    # 0x22D1E: '',  # 𢴞
    # 0x22D1F: '',  # 𢴟
    0x22D20: 'zhì',  # 𢴠
    # 0x22D21: '',  # 𢴡
    0x22D22: 'fén',  # 𢴢
    # 0x22D23: '',  # 𢴣
    # 0x22D24: '',  # 𢴤
    # 0x22D25: '',  # 𢴥
    0x22D26: 'káng',  # 𢴦
    0x22D27: 'zhì',  # 𢴧
    0x22D28: 'zhāi,zhì,chì',  # 𢴨
    0x22D29: 'bì',  # 𢴩
    0x22D2A: 'kuǎn',  # 𢴪
    # 0x22D2B: '',  # 𢴫
    0x22D2C: 'bàn',  # 𢴬
    0x22D2D: 'juē',  # 𢴭
    0x22D2E: 'qū',  # 𢴮
    # 0x22D2F: '',  # 𢴯
    0x22D30: 'qī',  # 𢴰
    0x22D31: 'léi',  # 𢴱
    0x22D32: 'xié,jié',  # 𢴲
    0x22D33: 'tāng',  # 𢴳
    # 0x22D34: '',  # 𢴴
    # 0x22D35: '',  # 𢴵
    # 0x22D36: '',  # 𢴶
    # 0x22D37: '',  # 𢴷
    # 0x22D38: '',  # 𢴸
    # 0x22D39: '',  # 𢴹
    # 0x22D3A: '',  # 𢴺
    # 0x22D3B: '',  # 𢴻
    0x22D3C: 'sōu',  # 𢴼
    # 0x22D3D: '',  # 𢴽
    0x22D3E: 'bèi',  # 𢴾
    # 0x22D3F: '',  # 𢴿
    # 0x22D40: '',  # 𢵀
    # 0x22D41: '',  # 𢵁
    # 0x22D42: '',  # 𢵂
    # 0x22D43: '',  # 𢵃
    # 0x22D44: '',  # 𢵄
    # 0x22D45: '',  # 𢵅
    # 0x22D46: '',  # 𢵆
    0x22D47: 'yàng',  # 𢵇
    0x22D48: 'jiǎn,zhǎn',  # 𢵈
    # 0x22D49: '',  # 𢵉
    # 0x22D4A: '',  # 𢵊
    # 0x22D4B: '',  # 𢵋
    # 0x22D4C: '',  # 𢵌
    # 0x22D4D: '',  # 𢵍
    # 0x22D4E: '',  # 𢵎
    # 0x22D4F: '',  # 𢵏
    # 0x22D50: '',  # 𢵐
    # 0x22D51: '',  # 𢵑
    # 0x22D52: '',  # 𢵒
    # 0x22D53: '',  # 𢵓
    # 0x22D54: '',  # 𢵔
    # 0x22D55: '',  # 𢵕
    # 0x22D56: '',  # 𢵖
    # 0x22D57: '',  # 𢵗
    # 0x22D58: '',  # 𢵘
    # 0x22D59: '',  # 𢵙
    # 0x22D5A: '',  # 𢵚
    # 0x22D5B: '',  # 𢵛
    # 0x22D5C: '',  # 𢵜
    # 0x22D5D: '',  # 𢵝
    # 0x22D5E: '',  # 𢵞
    # 0x22D5F: '',  # 𢵟
    # 0x22D60: '',  # 𢵠
    # 0x22D61: '',  # 𢵡
    # 0x22D62: '',  # 𢵢
    0x22D63: 'yā',  # 𢵣
    # 0x22D64: '',  # 𢵤
    0x22D65: 'zào',  # 𢵥
    # 0x22D66: '',  # 𢵦
    # 0x22D67: '',  # 𢵧
    # 0x22D68: '',  # 𢵨
    # 0x22D69: '',  # 𢵩
    # 0x22D6A: '',  # 𢵪
    # 0x22D6B: '',  # 𢵫
    # 0x22D6C: '',  # 𢵬
    # 0x22D6D: '',  # 𢵭
    0x22D6E: 'lū',  # 𢵮
    # 0x22D6F: '',  # 𢵯
    # 0x22D70: '',  # 𢵰
    # 0x22D71: '',  # 𢵱
    # 0x22D72: '',  # 𢵲
    # 0x22D73: '',  # 𢵳
    # 0x22D74: '',  # 𢵴
    # 0x22D75: '',  # 𢵵
    # 0x22D76: '',  # 𢵶
    # 0x22D77: '',  # 𢵷
    # 0x22D78: '',  # 𢵸
    # 0x22D79: '',  # 𢵹
    # 0x22D7A: '',  # 𢵺
    # 0x22D7B: '',  # 𢵻
    # 0x22D7C: '',  # 𢵼
    # 0x22D7D: '',  # 𢵽
    # 0x22D7E: '',  # 𢵾
    # 0x22D7F: '',  # 𢵿
    0x22D80: 'chuái,zhuài',  # 𢶀
    # 0x22D81: '',  # 𢶁
    # 0x22D82: '',  # 𢶂
    0x22D83: 'fán',  # 𢶃
    # 0x22D84: '',  # 𢶄
    0x22D85: 'shé',  # 𢶅
    # 0x22D86: '',  # 𢶆
    0x22D87: 'qióng',  # 𢶇
    # 0x22D88: '',  # 𢶈
    0x22D89: 'pò',  # 𢶉
    # 0x22D8A: '',  # 𢶊
    0x22D8B: 'tiě',  # 𢶋
    0x22D8C: 'shā',  # 𢶌
    0x22D8D: 'zá,sà',  # 𢶍
    # 0x22D8E: '',  # 𢶎
    # 0x22D8F: '',  # 𢶏
    # 0x22D90: '',  # 𢶐
    0x22D91: 'niǎo',  # 𢶑
    0x22D92: 'guài',  # 𢶒
    0x22D93: 'cuǐ',  # 𢶓
    # 0x22D94: '',  # 𢶔
    # 0x22D95: '',  # 𢶕
    # 0x22D96: '',  # 𢶖
    # 0x22D97: '',  # 𢶗
    # 0x22D98: '',  # 𢶘
    # 0x22D99: '',  # 𢶙
    # 0x22D9A: '',  # 𢶚
    # 0x22D9B: '',  # 𢶛
    # 0x22D9C: '',  # 𢶜
    # 0x22D9D: '',  # 𢶝
    # 0x22D9E: '',  # 𢶞
    # 0x22D9F: '',  # 𢶟
    # 0x22DA0: '',  # 𢶠
    0x22DA1: 'qiào,jiǎo',  # 𢶡
    # 0x22DA2: '',  # 𢶢
    0x22DA3: 'dié',  # 𢶣
    # 0x22DA4: '',  # 𢶤
    # 0x22DA5: '',  # 𢶥
    # 0x22DA6: '',  # 𢶦
    # 0x22DA7: '',  # 𢶧
    # 0x22DA8: '',  # 𢶨
    # 0x22DA9: '',  # 𢶩
    # 0x22DAA: '',  # 𢶪
    # 0x22DAB: '',  # 𢶫
    # 0x22DAC: '',  # 𢶬
    # 0x22DAD: '',  # 𢶭
    # 0x22DAE: '',  # 𢶮
    # 0x22DAF: '',  # 𢶯
    # 0x22DB0: '',  # 𢶰
    # 0x22DB1: '',  # 𢶱
    # 0x22DB2: '',  # 𢶲
    0x22DB3: 'pīn',  # 𢶳
    0x22DB4: 'cí',  # 𢶴
    # 0x22DB5: '',  # 𢶵
    0x22DB6: 'bàng',  # 𢶶
    # 0x22DB7: '',  # 𢶷
    # 0x22DB8: '',  # 𢶸
    # 0x22DB9: '',  # 𢶹
    # 0x22DBA: '',  # 𢶺
    # 0x22DBB: '',  # 𢶻
    # 0x22DBC: '',  # 𢶼
    # 0x22DBD: '',  # 𢶽
    # 0x22DBE: '',  # 𢶾
    # 0x22DBF: '',  # 𢶿
    # 0x22DC0: '',  # 𢷀
    # 0x22DC1: '',  # 𢷁
    # 0x22DC2: '',  # 𢷂
    0x22DC3: 'nào',  # 𢷃
    # 0x22DC4: '',  # 𢷄
    0x22DC5: 'lù',  # 𢷅
    # 0x22DC6: '',  # 𢷆
    # 0x22DC7: '',  # 𢷇
    # 0x22DC8: '',  # 𢷈
    # 0x22DC9: '',  # 𢷉
    # 0x22DCA: '',  # 𢷊
    # 0x22DCB: '',  # 𢷋
    # 0x22DCC: '',  # 𢷌
    0x22DCD: 'yìn',  # 𢷍
    # 0x22DCE: '',  # 𢷎
    # 0x22DCF: '',  # 𢷏
    # 0x22DD0: '',  # 𢷐
    0x22DD1: 'xiǎn',  # 𢷑
    # 0x22DD2: '',  # 𢷒
    # 0x22DD3: '',  # 𢷓
    0x22DD4: 'yǐ',  # 𢷔
    0x22DD5: 'miǎo',  # 𢷕
    0x22DD6: 'duǎn',  # 𢷖
    0x22DD7: 'zhòu',  # 𢷗
    # 0x22DD8: '',  # 𢷘
    0x22DD9: 'kōng',  # 𢷙
    # 0x22DDA: '',  # 𢷚
    # 0x22DDB: '',  # 𢷛
    # 0x22DDC: '',  # 𢷜
    # 0x22DDD: '',  # 𢷝
    # 0x22DDE: '',  # 𢷞
    # 0x22DDF: '',  # 𢷟
    # 0x22DE0: '',  # 𢷠
    # 0x22DE1: '',  # 𢷡
    0x22DE2: 'zhāng',  # 𢷢
    # 0x22DE3: '',  # 𢷣
    # 0x22DE4: '',  # 𢷤
    # 0x22DE5: '',  # 𢷥
    # 0x22DE6: '',  # 𢷦
    # 0x22DE7: '',  # 𢷧
    # 0x22DE8: '',  # 𢷨
    # 0x22DE9: '',  # 𢷩
    # 0x22DEA: '',  # 𢷪
    # 0x22DEB: '',  # 𢷫
    # 0x22DEC: '',  # 𢷬
    # 0x22DED: '',  # 𢷭
    # 0x22DEE: '',  # 𢷮
    # 0x22DEF: '',  # 𢷯
    # 0x22DF0: '',  # 𢷰
    # 0x22DF1: '',  # 𢷱
    # 0x22DF2: '',  # 𢷲
    # 0x22DF3: '',  # 𢷳
    # 0x22DF4: '',  # 𢷴
    # 0x22DF5: '',  # 𢷵
    0x22DF6: 'liú',  # 𢷶
    # 0x22DF7: '',  # 𢷷
    0x22DF8: 'zhǐ',  # 𢷸
    0x22DF9: 'chǎn',  # 𢷹
    0x22DFA: 'dú',  # 𢷺
    0x22DFB: 'yuán',  # 𢷻
    # 0x22DFC: '',  # 𢷼
    # 0x22DFD: '',  # 𢷽
    0x22DFE: 'suò,cè',  # 𢷾
    0x22DFF: 'jié',  # 𢷿
    0x22E00: 'lì',  # 𢸀
    0x22E01: 'gǒng',  # 𢸁
    # 0x22E02: '',  # 𢸂
    # 0x22E03: '',  # 𢸃
    # 0x22E04: '',  # 𢸄
    # 0x22E05: '',  # 𢸅
    # 0x22E06: '',  # 𢸆
    # 0x22E07: '',  # 𢸇
    # 0x22E08: '',  # 𢸈
    # 0x22E09: '',  # 𢸉
    # 0x22E0A: '',  # 𢸊
    # 0x22E0B: '',  # 𢸋
    0x22E0C: 'bāng',  # 𢸌
    # 0x22E0D: '',  # 𢸍
    # 0x22E0E: '',  # 𢸎
    # 0x22E0F: '',  # 𢸏
    # 0x22E10: '',  # 𢸐
    # 0x22E11: '',  # 𢸑
    # 0x22E12: '',  # 𢸒
    # 0x22E13: '',  # 𢸓
    # 0x22E14: '',  # 𢸔
    # 0x22E15: '',  # 𢸕
    # 0x22E16: '',  # 𢸖
    0x22E17: 'guó',  # 𢸗
    0x22E18: 'liáo',  # 𢸘
    0x22E19: 'shěn',  # 𢸙
    # 0x22E1A: '',  # 𢸚
    # 0x22E1B: '',  # 𢸛
    # 0x22E1C: '',  # 𢸜
    # 0x22E1D: '',  # 𢸝
    # 0x22E1E: '',  # 𢸞
    # 0x22E1F: '',  # 𢸟
    # 0x22E20: '',  # 𢸠
    # 0x22E21: '',  # 𢸡
    # 0x22E22: '',  # 𢸢
    0x22E23: 'niǎo',  # 𢸣
    # 0x22E24: '',  # 𢸤
    0x22E25: 'cuàn',  # 𢸥
    0x22E26: 'wěi',  # 𢸦
    # 0x22E27: '',  # 𢸧
    0x22E28: 'tuō',  # 𢸨
    # 0x22E29: '',  # 𢸩
    # 0x22E2A: '',  # 𢸪
    0x22E2B: 'sū',  # 𢸫
    # 0x22E2C: '',  # 𢸬
    0x22E2D: 'lóng',  # 𢸭
    # 0x22E2E: '',  # 𢸮
    # 0x22E2F: '',  # 𢸯
    # 0x22E30: '',  # 𢸰
    # 0x22E31: '',  # 𢸱
    # 0x22E32: '',  # 𢸲
    # 0x22E33: '',  # 𢸳
    0x22E34: 'yǎn,yán',  # 𢸴
    # 0x22E35: '',  # 𢸵
    # 0x22E36: '',  # 𢸶
    # 0x22E37: '',  # 𢸷
    # 0x22E38: '',  # 𢸸
    # 0x22E39: '',  # 𢸹
    # 0x22E3A: '',  # 𢸺
    # 0x22E3B: '',  # 𢸻
    # 0x22E3C: '',  # 𢸼
    # 0x22E3D: '',  # 𢸽
    # 0x22E3E: '',  # 𢸾
    # 0x22E3F: '',  # 𢸿
    # 0x22E40: '',  # 𢹀
    # 0x22E41: '',  # 𢹁
    # 0x22E42: '',  # 𢹂
    0x22E43: 'qǐng',  # 𢹃
    # 0x22E44: '',  # 𢹄
    # 0x22E45: '',  # 𢹅
    # 0x22E46: '',  # 𢹆
    # 0x22E47: '',  # 𢹇
    # 0x22E48: '',  # 𢹈
    # 0x22E49: '',  # 𢹉
    # 0x22E4A: '',  # 𢹊
    # 0x22E4B: '',  # 𢹋
    # 0x22E4C: '',  # 𢹌
    0x22E4D: 'xī',  # 𢹍
    0x22E4E: 'rǎo',  # 𢹎
    0x22E4F: 'yú',  # 𢹏
    # 0x22E50: '',  # 𢹐
    0x22E51: 'zhèng,zhēng',  # 𢹑
    0x22E52: 'xiè',  # 𢹒
    0x22E53: 'chāi',  # 𢹓
    0x22E54: 'fèn',  # 𢹔
    # 0x22E55: '',  # 𢹕
    0x22E56: 'guó',  # 𢹖
    # 0x22E57: '',  # 𢹗
    0x22E58: 'jǐng',  # 𢹘
    0x22E59: 'làn',  # 𢹙
    0x22E5A: 'xiān',  # 𢹚
    # 0x22E5B: '',  # 𢹛
    # 0x22E5C: '',  # 𢹜
    0x22E5D: 'líng',  # 𢹝
    # 0x22E5E: '',  # 𢹞
    # 0x22E5F: '',  # 𢹟
    # 0x22E60: '',  # 𢹠
    # 0x22E61: '',  # 𢹡
    # 0x22E62: '',  # 𢹢
    # 0x22E63: '',  # 𢹣
    # 0x22E64: '',  # 𢹤
    0x22E65: 'yā',  # 𢹥
    # 0x22E66: '',  # 𢹦
    # 0x22E67: '',  # 𢹧
    # 0x22E68: '',  # 𢹨
    # 0x22E69: '',  # 𢹩
    # 0x22E6A: '',  # 𢹪
    # 0x22E6B: '',  # 𢹫
    0x22E6C: 'yǒng',  # 𢹬
    # 0x22E6D: '',  # 𢹭
    0x22E6E: 'lěi',  # 𢹮
    # 0x22E6F: '',  # 𢹯
    # 0x22E70: '',  # 𢹰
    # 0x22E71: '',  # 𢹱
    # 0x22E72: '',  # 𢹲
    0x22E73: 'xiào',  # 𢹳
    # 0x22E74: '',  # 𢹴
    # 0x22E75: '',  # 𢹵
    # 0x22E76: '',  # 𢹶
    # 0x22E77: '',  # 𢹷
    # 0x22E78: '',  # 𢹸
    # 0x22E79: '',  # 𢹹
    # 0x22E7A: '',  # 𢹺
    # 0x22E7B: '',  # 𢹻
    0x22E7C: 'zá',  # 𢹼
    # 0x22E7D: '',  # 𢹽
    # 0x22E7E: '',  # 𢹾
    # 0x22E7F: '',  # 𢹿
    # 0x22E80: '',  # 𢺀
    # 0x22E81: '',  # 𢺁
    # 0x22E82: '',  # 𢺂
    # 0x22E83: '',  # 𢺃
    0x22E84: 'guān',  # 𢺄
    0x22E85: 'qiè',  # 𢺅
    0x22E86: 'luò',  # 𢺆
    0x22E87: 'yào',  # 𢺇
    0x22E88: 'luán',  # 𢺈
    0x22E89: 'tà',  # 𢺉
    # 0x22E8A: '',  # 𢺊
    # 0x22E8B: '',  # 𢺋
    # 0x22E8C: '',  # 𢺌
    # 0x22E8D: '',  # 𢺍
    # 0x22E8E: '',  # 𢺎
    # 0x22E8F: '',  # 𢺏
    # 0x22E90: '',  # 𢺐
    0x22E91: 'luò',  # 𢺑
    # 0x22E92: '',  # 𢺒
    # 0x22E93: '',  # 𢺓
    # 0x22E94: '',  # 𢺔
    # 0x22E95: '',  # 𢺕
    # 0x22E96: '',  # 𢺖
    # 0x22E97: '',  # 𢺗
    # 0x22E98: '',  # 𢺘
    # 0x22E99: '',  # 𢺙
    # 0x22E9A: '',  # 𢺚
    # 0x22E9B: '',  # 𢺛
    # 0x22E9C: '',  # 𢺜
    # 0x22E9D: '',  # 𢺝
    0x22E9E: 'bǎ',  # 𢺞
    0x22E9F: 'chàn',  # 𢺟
    # 0x22EA0: '',  # 𢺠
    0x22EA1: 'zhuó',  # 𢺡
    # 0x22EA2: '',  # 𢺢
    # 0x22EA3: '',  # 𢺣
    # 0x22EA4: '',  # 𢺤
    # 0x22EA5: '',  # 𢺥
    # 0x22EA6: '',  # 𢺦
    # 0x22EA7: '',  # 𢺧
    # 0x22EA8: '',  # 𢺨
    # 0x22EA9: '',  # 𢺩
    # 0x22EAA: '',  # 𢺪
    0x22EAB: 'tiǎo',  # 𢺫
    # 0x22EAC: '',  # 𢺬
    # 0x22EAD: '',  # 𢺭
    # 0x22EAE: '',  # 𢺮
    0x22EAF: 'wān',  # 𢺯
    0x22EB0: 'líng,lìng',  # 𢺰
    # 0x22EB1: '',  # 𢺱
    # 0x22EB2: '',  # 𢺲
    0x22EB3: 'mán',  # 𢺳
    0x22EB4: 'yù',  # 𢺴
    0x22EB5: 'qì,qǐ',  # 𢺵
    # 0x22EB6: '',  # 𢺶
    0x22EB7: 'qí',  # 𢺷
    # 0x22EB8: '',  # 𢺸
    # 0x22EB9: '',  # 𢺹
    # 0x22EBA: '',  # 𢺺
    # 0x22EBB: '',  # 𢺻
    0x22EBC: 'jì',  # 𢺼
    0x22EBD: 'bó,jiào',  # 𢺽
    # 0x22EBE: '',  # 𢺾
    0x22EBF: 'shī',  # 𢺿
    0x22EC0: 'fǔ',  # 𢻀
    # 0x22EC1: '',  # 𢻁
    0x22EC2: 'guī',  # 𢻂
    # 0x22EC3: '',  # 𢻃
    # 0x22EC4: '',  # 𢻄
    0x22EC5: 'diǎn',  # 𢻅
    # 0x22EC6: '',  # 𢻆
    0x22EC7: 'hāo',  # 𢻇
    # 0x22EC8: '',  # 𢻈
    0x22EC9: 'gǎi',  # 𢻉
    # 0x22ECA: '',  # 𢻊
    0x22ECB: 'qí',  # 𢻋
    # 0x22ECC: '',  # 𢻌
    # 0x22ECD: '',  # 𢻍
    # 0x22ECE: '',  # 𢻎
    # 0x22ECF: '',  # 𢻏
    # 0x22ED0: '',  # 𢻐
    # 0x22ED1: '',  # 𢻑
    # 0x22ED2: '',  # 𢻒
    0x22ED3: 'chéng',  # 𢻓
    0x22ED4: 'huì',  # 𢻔
    # 0x22ED5: '',  # 𢻕
    # 0x22ED6: '',  # 𢻖
    0x22ED7: 'xiá,guī',  # 𢻗
    0x22ED8: 'shí',  # 𢻘
    0x22ED9: 'zhì',  # 𢻙
    0x22EDA: 'qí',  # 𢻚
    # 0x22EDB: '',  # 𢻛
    0x22EDC: 'hài',  # 𢻜
    # 0x22EDD: '',  # 𢻝
    # 0x22EDE: '',  # 𢻞
    0x22EDF: 'jiǎo',  # 𢻟
    0x22EE0: 'lì',  # 𢻠
    # 0x22EE1: '',  # 𢻡
    0x22EE2: 'liǎo',  # 𢻢
    # 0x22EE3: '',  # 𢻣
    0x22EE4: 'qiāo,qiáo',  # 𢻤
    # 0x22EE5: '',  # 𢻥
    # 0x22EE6: '',  # 𢻦
    # 0x22EE7: '',  # 𢻧
    0x22EE8: 'sà',  # 𢻨
    # 0x22EE9: '',  # 𢻩
    0x22EEA: 'qī',  # 𢻪
    0x22EEB: 'shī',  # 𢻫
    # 0x22EEC: '',  # 𢻬
    # 0x22EED: '',  # 𢻭
    0x22EEE: 'jié,fú',  # 𢻮
    # 0x22EEF: '',  # 𢻯
    # 0x22EF0: '',  # 𢻰
    0x22EF1: 'shī',  # 𢻱
    0x22EF2: 'fǔ',  # 𢻲
    # 0x22EF3: '',  # 𢻳
    # 0x22EF4: '',  # 𢻴
    0x22EF5: 'bèi,lù',  # 𢻵
    0x22EF6: 'biān',  # 𢻶
    0x22EF7: 'bā',  # 𢻷
    0x22EF8: 'jūn',  # 𢻸
    0x22EF9: 'pī',  # 𢻹
    # 0x22EFA: '',  # 𢻺
    # 0x22EFB: '',  # 𢻻
    0x22EFC: 'dǎn',  # 𢻼
    # 0x22EFD: '',  # 𢻽
    # 0x22EFE: '',  # 𢻾
    0x22EFF: 'táng',  # 𢻿
    0x22F00: 'kuǐ',  # 𢼀
    0x22F01: 'kū',  # 𢼁
    # 0x22F02: '',  # 𢼂
    0x22F03: 'kǒu',  # 𢼃
    # 0x22F04: '',  # 𢼄
    # 0x22F05: '',  # 𢼅
    # 0x22F06: '',  # 𢼆
    # 0x22F07: '',  # 𢼇
    # 0x22F08: '',  # 𢼈
    0x22F09: 'shī',  # 𢼉
    0x22F0A: 'shī,tuó',  # 𢼊
    0x22F0B: 'jī',  # 𢼋
    0x22F0C: 'bào',  # 𢼌
    # 0x22F0D: '',  # 𢼍
    # 0x22F0E: '',  # 𢼎
    # 0x22F0F: '',  # 𢼏
    0x22F10: 'kě',  # 𢼐
    0x22F11: 'kuāng',  # 𢼑
    # 0x22F12: '',  # 𢼒
    # 0x22F13: '',  # 𢼓
    # 0x22F14: '',  # 𢼔
    # 0x22F15: '',  # 𢼕
    0x22F16: 'mǐn',  # 𢼖
    # 0x22F17: '',  # 𢼗
    # 0x22F18: '',  # 𢼘
    0x22F19: 'liáo',  # 𢼙
    0x22F1A: 'è',  # 𢼚
    0x22F1B: 'gé,guó,è',  # 𢼛
    # 0x22F1C: '',  # 𢼜
    # 0x22F1D: '',  # 𢼝
    # 0x22F1E: '',  # 𢼞
    0x22F1F: 'wǎng',  # 𢼟
    0x22F20: 'duó',  # 𢼠
    # 0x22F21: '',  # 𢼡
    # 0x22F22: '',  # 𢼢
    0x22F23: 'qià',  # 𢼣
    0x22F24: 'huá',  # 𢼤
    # 0x22F25: '',  # 𢼥
    0x22F26: 'hǒng',  # 𢼦
    # 0x22F27: '',  # 𢼧
    # 0x22F28: '',  # 𢼨
    0x22F29: 'pēng',  # 𢼩
    # 0x22F2A: '',  # 𢼪
    0x22F2B: 'jiào',  # 𢼫
    # 0x22F2C: '',  # 𢼬
    # 0x22F2D: '',  # 𢼭
    # 0x22F2E: '',  # 𢼮
    # 0x22F2F: '',  # 𢼯
    0x22F30: 'qū',  # 𢼰
    0x22F31: 'zì',  # 𢼱
    0x22F32: 'zhòu',  # 𢼲
    0x22F33: 'kuāng',  # 𢼳
    # 0x22F34: '',  # 𢼴
    0x22F35: 'shā',  # 𢼵
    # 0x22F36: '',  # 𢼶
    0x22F37: 'jì',  # 𢼷
    0x22F38: 'wēi,wéi',  # 𢼸
    0x22F39: 'pū,bǔ',  # 𢼹
    0x22F3A: 'xué',  # 𢼺
    # 0x22F3B: '',  # 𢼻
    0x22F3C: 'shāo',  # 𢼼
    # 0x22F3D: '',  # 𢼽
    # 0x22F3E: '',  # 𢼾
    # 0x22F3F: '',  # 𢼿
    # 0x22F40: '',  # 𢽀
    # 0x22F41: '',  # 𢽁
    0x22F42: 'láng',  # 𢽂
    0x22F43: 'zhǐ',  # 𢽃
    0x22F44: 'tǐng',  # 𢽄
    # 0x22F45: '',  # 𢽅
    # 0x22F46: '',  # 𢽆
    0x22F47: 'dà',  # 𢽇
    # 0x22F48: '',  # 𢽈
    # 0x22F49: '',  # 𢽉
    # 0x22F4A: '',  # 𢽊
    # 0x22F4B: '',  # 𢽋
    # 0x22F4C: '',  # 𢽌
    # 0x22F4D: '',  # 𢽍
    0x22F4E: 'hàn',  # 𢽎
    # 0x22F4F: '',  # 𢽏
    # 0x22F50: '',  # 𢽐
    # 0x22F51: '',  # 𢽑
    # 0x22F52: '',  # 𢽒
    # 0x22F53: '',  # 𢽓
    # 0x22F54: '',  # 𢽔
    0x22F55: 'yáng',  # 𢽕
    0x22F56: 'jìn',  # 𢽖
    0x22F57: 'zhǐ',  # 𢽗
    # 0x22F58: '',  # 𢽘
    # 0x22F59: '',  # 𢽙
    0x22F5A: 'zhuó,dū',  # 𢽚
    # 0x22F5B: '',  # 𢽛
    0x22F5C: 'zá',  # 𢽜
    0x22F5D: 'chán',  # 𢽝
    # 0x22F5E: '',  # 𢽞
    # 0x22F5F: '',  # 𢽟
    # 0x22F60: '',  # 𢽠
    # 0x22F61: '',  # 𢽡
    0x22F62: 'mào',  # 𢽢
    # 0x22F63: '',  # 𢽣
    # 0x22F64: '',  # 𢽤
    # 0x22F65: '',  # 𢽥
    0x22F66: 'kōng',  # 𢽦
    0x22F67: 'zhōu',  # 𢽧
    0x22F68: 'hū',  # 𢽨
    0x22F69: 'pēng',  # 𢽩
    # 0x22F6A: '',  # 𢽪
    # 0x22F6B: '',  # 𢽫
    # 0x22F6C: '',  # 𢽬
    0x22F6D: 'jiù',  # 𢽭
    # 0x22F6E: '',  # 𢽮
    # 0x22F6F: '',  # 𢽯
    # 0x22F70: '',  # 𢽰
    # 0x22F71: '',  # 𢽱
    # 0x22F72: '',  # 𢽲
    # 0x22F73: '',  # 𢽳
    0x22F74: 'zhuó',  # 𢽴
    # 0x22F75: '',  # 𢽵
    # 0x22F76: '',  # 𢽶
    # 0x22F77: '',  # 𢽷
    0x22F78: 'chuò',  # 𢽸
    0x22F79: 'mǐn',  # 𢽹
    # 0x22F7A: '',  # 𢽺
    # 0x22F7B: '',  # 𢽻
    # 0x22F7C: '',  # 𢽼
    # 0x22F7D: '',  # 𢽽
    # 0x22F7E: '',  # 𢽾
    # 0x22F7F: '',  # 𢽿
    0x22F80: 'dǔ',  # 𢾀
    0x22F81: 'wéi',  # 𢾁
    # 0x22F82: '',  # 𢾂
    0x22F83: 'cán',  # 𢾃
    0x22F84: 'yú',  # 𢾄
    0x22F85: 'dù',  # 𢾅
    0x22F86: 'kāi',  # 𢾆
    0x22F87: 'pì',  # 𢾇
    # 0x22F88: '',  # 𢾈
    # 0x22F89: '',  # 𢾉
    0x22F8A: 'chéng',  # 𢾊
    # 0x22F8B: '',  # 𢾋
    # 0x22F8C: '',  # 𢾌
    # 0x22F8D: '',  # 𢾍
    0x22F8E: 'chǔn',  # 𢾎
    # 0x22F8F: '',  # 𢾏
    0x22F90: 'shǎo',  # 𢾐
    0x22F91: 'yǎn',  # 𢾑
    0x22F92: 'kuài',  # 𢾒
    # 0x22F93: '',  # 𢾓
    0x22F94: 'yuē',  # 𢾔
    # 0x22F95: '',  # 𢾕
    # 0x22F96: '',  # 𢾖
    # 0x22F97: '',  # 𢾗
    # 0x22F98: '',  # 𢾘
    # 0x22F99: '',  # 𢾙
    # 0x22F9A: '',  # 𢾚
    # 0x22F9B: '',  # 𢾛
    # 0x22F9C: '',  # 𢾜
    0x22F9D: 'wéi',  # 𢾝
    # 0x22F9E: '',  # 𢾞
    # 0x22F9F: '',  # 𢾟
    # 0x22FA0: '',  # 𢾠
    # 0x22FA1: '',  # 𢾡
    # 0x22FA2: '',  # 𢾢
    # 0x22FA3: '',  # 𢾣
    # 0x22FA4: '',  # 𢾤
    # 0x22FA5: '',  # 𢾥
    0x22FA6: 'qí',  # 𢾦
    0x22FA7: 'zhēng',  # 𢾧
    # 0x22FA8: '',  # 𢾨
    0x22FA9: 'kè',  # 𢾩
    0x22FAA: 'qí',  # 𢾪
    0x22FAB: 'zhǐ',  # 𢾫
    0x22FAC: 'lù',  # 𢾬
    0x22FAD: 'fū',  # 𢾭
    # 0x22FAE: '',  # 𢾮
    # 0x22FAF: '',  # 𢾯
    # 0x22FB0: '',  # 𢾰
    0x22FB1: 'pī',  # 𢾱
    0x22FB2: 'nuò',  # 𢾲
    0x22FB3: 'pǎo',  # 𢾳
    # 0x22FB4: '',  # 𢾴
    # 0x22FB5: '',  # 𢾵
    # 0x22FB6: '',  # 𢾶
    # 0x22FB7: '',  # 𢾷
    # 0x22FB8: '',  # 𢾸
    # 0x22FB9: '',  # 𢾹
    0x22FBA: 'fěi',  # 𢾺
    # 0x22FBB: '',  # 𢾻
    # 0x22FBC: '',  # 𢾼
    # 0x22FBD: '',  # 𢾽
    # 0x22FBE: '',  # 𢾾
    0x22FBF: 'wén',  # 𢾿
    # 0x22FC0: '',  # 𢿀
    # 0x22FC1: '',  # 𢿁
    0x22FC2: 'méng',  # 𢿂
    # 0x22FC3: '',  # 𢿃
    # 0x22FC4: '',  # 𢿄
    # 0x22FC5: '',  # 𢿅
    # 0x22FC6: '',  # 𢿆
    # 0x22FC7: '',  # 𢿇
    0x22FC8: 'shǎn',  # 𢿈
    # 0x22FC9: '',  # 𢿉
    # 0x22FCA: '',  # 𢿊
    # 0x22FCB: '',  # 𢿋
    0x22FCC: 'xiòng,xuàn',  # 𢿌
    # 0x22FCD: '',  # 𢿍
    0x22FCE: 'duò',  # 𢿎
    0x22FCF: 'biào,pāo',  # 𢿏
    # 0x22FD0: '',  # 𢿐
    # 0x22FD1: '',  # 𢿑
    # 0x22FD2: '',  # 𢿒
    # 0x22FD3: '',  # 𢿓
    # 0x22FD4: '',  # 𢿔
    # 0x22FD5: '',  # 𢿕
    # 0x22FD6: '',  # 𢿖
    # 0x22FD7: '',  # 𢿗
    # 0x22FD8: '',  # 𢿘
    # 0x22FD9: '',  # 𢿙
    0x22FDA: 'yōu',  # 𢿚
    # 0x22FDB: '',  # 𢿛
    0x22FDC: 'màn',  # 𢿜
    # 0x22FDD: '',  # 𢿝
    0x22FDE: 'liǎo',  # 𢿞
    # 0x22FDF: '',  # 𢿟
    # 0x22FE0: '',  # 𢿠
    0x22FE1: 'xié',  # 𢿡
    0x22FE2: 'luàn',  # 𢿢
    0x22FE3: 'qiāo',  # 𢿣
    0x22FE4: 'dèng',  # 𢿤
    # 0x22FE5: '',  # 𢿥
    0x22FE6: 'chéng',  # 𢿦
    0x22FE7: 'chéng',  # 𢿧
    # 0x22FE8: '',  # 𢿨
    # 0x22FE9: '',  # 𢿩
    # 0x22FEA: '',  # 𢿪
    # 0x22FEB: '',  # 𢿫
    # 0x22FEC: '',  # 𢿬
    0x22FED: 'chuò',  # 𢿭
    # 0x22FEE: '',  # 𢿮
    # 0x22FEF: '',  # 𢿯
    # 0x22FF0: '',  # 𢿰
    0x22FF1: 'sàn',  # 𢿱
    0x22FF2: 'qiāo',  # 𢿲
    0x22FF3: 'luàn',  # 𢿳
    # 0x22FF4: '',  # 𢿴
    # 0x22FF5: '',  # 𢿵
    # 0x22FF6: '',  # 𢿶
    # 0x22FF7: '',  # 𢿷
    0x22FF8: 'cè',  # 𢿸
    # 0x22FF9: '',  # 𢿹
    # 0x22FFA: '',  # 𢿺
    # 0x22FFB: '',  # 𢿻
    # 0x22FFC: '',  # 𢿼
    # 0x22FFD: '',  # 𢿽
    # 0x22FFE: '',  # 𢿾
    # 0x22FFF: '',  # 𢿿
    0x23000: 'léi',  # 𣀀
    0x23001: 'zhǎn',  # 𣀁
    0x23002: 'lǐ',  # 𣀂
    0x23003: 'lián',  # 𣀃
    0x23004: 'qún',  # 𣀄
    # 0x23005: '',  # 𣀅
    0x23006: 'qún',  # 𣀆
    # 0x23007: '',  # 𣀇
    # 0x23008: '',  # 𣀈
    # 0x23009: '',  # 𣀉
    # 0x2300A: '',  # 𣀊
    # 0x2300B: '',  # 𣀋
    # 0x2300C: '',  # 𣀌
    0x2300D: 'chén',  # 𣀍
    # 0x2300E: '',  # 𣀎
    0x2300F: 'chéng',  # 𣀏
    0x23010: 'gū',  # 𣀐
    # 0x23011: '',  # 𣀑
    0x23012: 'zòng',  # 𣀒
    0x23013: 'chóu,dǎo',  # 𣀓
    0x23014: 'chuàn,chuò',  # 𣀔
    # 0x23015: '',  # 𣀕
    # 0x23016: '',  # 𣀖
    # 0x23017: '',  # 𣀗
    0x23018: 'chóu',  # 𣀘
    # 0x23019: '',  # 𣀙
    # 0x2301A: '',  # 𣀚
    # 0x2301B: '',  # 𣀛
    0x2301C: 'lèi',  # 𣀜
    0x2301D: 'shuò',  # 𣀝
    0x2301E: 'lǜ',  # 𣀞
    # 0x2301F: '',  # 𣀟
    # 0x23020: '',  # 𣀠
    # 0x23021: '',  # 𣀡
    # 0x23022: '',  # 𣀢
    0x23023: 'fú',  # 𣀣
    # 0x23024: '',  # 𣀤
    0x23025: 'lì',  # 𣀥
    # 0x23026: '',  # 𣀦
    0x23027: 'sàn',  # 𣀧
    # 0x23028: '',  # 𣀨
    # 0x23029: '',  # 𣀩
    # 0x2302A: '',  # 𣀪
    0x2302B: 'sān',  # 𣀫
    # 0x2302C: '',  # 𣀬
    # 0x2302D: '',  # 𣀭
    # 0x2302E: '',  # 𣀮
    0x2302F: 'sà',  # 𣀯
    # 0x23030: '',  # 𣀰
    # 0x23031: '',  # 𣀱
    # 0x23032: '',  # 𣀲
    0x23033: 'niè',  # 𣀳
    # 0x23034: '',  # 𣀴
    # 0x23035: '',  # 𣀵
    0x23036: 'zuān',  # 𣀶
    0x23037: 'lǐ,lí',  # 𣀷
    # 0x23038: '',  # 𣀸
    # 0x23039: '',  # 𣀹
    # 0x2303A: '',  # 𣀺
    0x2303B: 'shǔ,zhǔ',  # 𣀻
    # 0x2303C: '',  # 𣀼
    # 0x2303D: '',  # 𣀽
    0x2303E: 'fú',  # 𣀾
    # 0x2303F: '',  # 𣀿
    # 0x23040: '',  # 𣁀
    # 0x23041: '',  # 𣁁
    # 0x23042: '',  # 𣁂
    # 0x23043: '',  # 𣁃
    # 0x23044: '',  # 𣁄
    # 0x23045: '',  # 𣁅
    # 0x23046: '',  # 𣁆
    # 0x23047: '',  # 𣁇
    # 0x23048: '',  # 𣁈
    0x23049: 'bì',  # 𣁉
    # 0x2304A: '',  # 𣁊
    # 0x2304B: '',  # 𣁋
    # 0x2304C: '',  # 𣁌
    0x2304D: 'dào',  # 𣁍
    # 0x2304E: '',  # 𣁎
    # 0x2304F: '',  # 𣁏
    # 0x23050: '',  # 𣁐
    # 0x23051: '',  # 𣁑
    0x23052: 'shī',  # 𣁒
    # 0x23053: '',  # 𣁓
    # 0x23054: '',  # 𣁔
    # 0x23055: '',  # 𣁕
    0x23056: 'gàn',  # 𣁖
    0x23057: 'tàn',  # 𣁗
    # 0x23058: '',  # 𣁘
    # 0x23059: '',  # 𣁙
    # 0x2305A: '',  # 𣁚
    # 0x2305B: '',  # 𣁛
    0x2305C: 'màn',  # 𣁜
    # 0x2305D: '',  # 𣁝
    # 0x2305E: '',  # 𣁞
    0x2305F: 'lí',  # 𣁟
    # 0x23060: '',  # 𣁠
    # 0x23061: '',  # 𣁡
    0x23062: 'bì',  # 𣁢
    # 0x23063: '',  # 𣁣
    # 0x23064: '',  # 𣁤
    # 0x23065: '',  # 𣁥
    0x23066: 'pán',  # 𣁦
    # 0x23067: '',  # 𣁧
    0x23068: 'yōu',  # 𣁨
    # 0x23069: '',  # 𣁩
    # 0x2306A: '',  # 𣁪
    # 0x2306B: '',  # 𣁫
    # 0x2306C: '',  # 𣁬
    0x2306D: 'jiū',  # 𣁭
    # 0x2306E: '',  # 𣁮
    0x2306F: 'guō',  # 𣁯
    0x23070: 'liáo',  # 𣁰
    # 0x23071: '',  # 𣁱
    # 0x23072: '',  # 𣁲
    0x23073: 'wò',  # 𣁳
    0x23074: 'qià',  # 𣁴
    0x23075: 'dǒu',  # 𣁵
    # 0x23076: '',  # 𣁶
    0x23077: 'liè',  # 𣁷
    # 0x23078: '',  # 𣁸
    0x23079: 'jiǎo',  # 𣁹
    # 0x2307A: '',  # 𣁺
    0x2307B: 'liè,luō',  # 𣁻
    # 0x2307C: '',  # 𣁼
    # 0x2307D: '',  # 𣁽
    # 0x2307E: '',  # 𣁾
    # 0x2307F: '',  # 𣁿
    0x23080: 'tiāo',  # 𣂀
    0x23081: 'tiāo,qiāo',  # 𣂁
    # 0x23082: '',  # 𣂂
    # 0x23083: '',  # 𣂃
    0x23084: 'guō',  # 𣂄
    # 0x23085: '',  # 𣂅
    0x23086: 'pāng',  # 𣂆
    0x23087: 'qiāo',  # 𣂇
    # 0x23088: '',  # 𣂈
    0x23089: 'dí',  # 𣂉
    0x2308A: 'yùn',  # 𣂊
    # 0x2308B: '',  # 𣂋
    # 0x2308C: '',  # 𣂌
    # 0x2308D: '',  # 𣂍
    # 0x2308E: '',  # 𣂎
    # 0x2308F: '',  # 𣂏
    # 0x23090: '',  # 𣂐
    # 0x23091: '',  # 𣂑
    0x23092: 'lè',  # 𣂒
    # 0x23093: '',  # 𣂓
    # 0x23094: '',  # 𣂔
    # 0x23095: '',  # 𣂕
    0x23096: 'sī',  # 𣂖
    0x23097: 'xīn',  # 𣂗
    # 0x23098: '',  # 𣂘
    # 0x23099: '',  # 𣂙
    # 0x2309A: '',  # 𣂚
    # 0x2309B: '',  # 𣂛
    0x2309C: 'xīn',  # 𣂜
    0x2309D: 'xiàng',  # 𣂝
    0x2309E: 'luǒ',  # 𣂞
    # 0x2309F: '',  # 𣂟
    # 0x230A0: '',  # 𣂠
    # 0x230A1: '',  # 𣂡
    # 0x230A2: '',  # 𣂢
    # 0x230A3: '',  # 𣂣
    0x230A4: 'bēng',  # 𣂤
    0x230A5: 'tiāo,qiāo',  # 𣂥
    # 0x230A6: '',  # 𣂦
    # 0x230A7: '',  # 𣂧
    # 0x230A8: '',  # 𣂨
    # 0x230A9: '',  # 𣂩
    # 0x230AA: '',  # 𣂪
    # 0x230AB: '',  # 𣂫
    0x230AC: 'xiào',  # 𣂬
    # 0x230AD: '',  # 𣂭
    0x230AE: 'dōu,tóu',  # 𣂮
    # 0x230AF: '',  # 𣂯
    # 0x230B0: '',  # 𣂰
    # 0x230B1: '',  # 𣂱
    # 0x230B2: '',  # 𣂲
    0x230B3: 'dàng',  # 𣂳
    0x230B4: 'tíng',  # 𣂴
    0x230B5: 'zhuàn',  # 𣂵
    # 0x230B6: '',  # 𣂶
    # 0x230B7: '',  # 𣂷
    # 0x230B8: '',  # 𣂸
    # 0x230B9: '',  # 𣂹
    # 0x230BA: '',  # 𣂺
    0x230BB: 'ōu,kōu',  # 𣂻
    # 0x230BC: '',  # 𣂼
    0x230BD: 'wò',  # 𣂽
    # 0x230BE: '',  # 𣂾
    # 0x230BF: '',  # 𣂿
    # 0x230C0: '',  # 𣃀
    # 0x230C1: '',  # 𣃁
    # 0x230C2: '',  # 𣃂
    # 0x230C3: '',  # 𣃃
    0x230C4: 'xīn',  # 𣃄
    0x230C5: 'ruǎn',  # 𣃅
    # 0x230C6: '',  # 𣃆
    # 0x230C7: '',  # 𣃇
    0x230C8: 'zhuó',  # 𣃈
    0x230C9: 'dàng',  # 𣃉
    # 0x230CA: '',  # 𣃊
    # 0x230CB: '',  # 𣃋
    # 0x230CC: '',  # 𣃌
    0x230CD: 'cuì,chà',  # 𣃍
    # 0x230CE: '',  # 𣃎
    # 0x230CF: '',  # 𣃏
    # 0x230D0: '',  # 𣃐
    0x230D1: 'zhuó',  # 𣃑
    # 0x230D2: '',  # 𣃒
    # 0x230D3: '',  # 𣃓
    0x230D4: 'duàn',  # 𣃔
    # 0x230D5: '',  # 𣃕
    # 0x230D6: '',  # 𣃖
    0x230D7: 'cóng',  # 𣃗
    0x230D8: 'chǎn,chuáng',  # 𣃘
    # 0x230D9: '',  # 𣃙
    0x230DA: 'háng',  # 𣃚
    # 0x230DB: '',  # 𣃛
    # 0x230DC: '',  # 𣃜
    0x230DD: 'yǎng',  # 𣃝
    # 0x230DE: '',  # 𣃞
    # 0x230DF: '',  # 𣃟
    # 0x230E0: '',  # 𣃠
    # 0x230E1: '',  # 𣃡
    # 0x230E2: '',  # 𣃢
    # 0x230E3: '',  # 𣃣
    # 0x230E4: '',  # 𣃤
    # 0x230E5: '',  # 𣃥
    # 0x230E6: '',  # 𣃦
    0x230E7: 'yǎn',  # 𣃧
    # 0x230E8: '',  # 𣃨
    # 0x230E9: '',  # 𣃩
    # 0x230EA: '',  # 𣃪
    # 0x230EB: '',  # 𣃫
    # 0x230EC: '',  # 𣃬
    # 0x230ED: '',  # 𣃭
    # 0x230EE: '',  # 𣃮
    # 0x230EF: '',  # 𣃯
    # 0x230F0: '',  # 𣃰
    # 0x230F1: '',  # 𣃱
    # 0x230F2: '',  # 𣃲
    0x230F3: 'yǎn,yè',  # 𣃳
    # 0x230F4: '',  # 𣃴
    0x230F5: 'zhèn,shēn',  # 𣃵
    # 0x230F6: '',  # 𣃶
    # 0x230F7: '',  # 𣃷
    # 0x230F8: '',  # 𣃸
    # 0x230F9: '',  # 𣃹
    # 0x230FA: '',  # 𣃺
    # 0x230FB: '',  # 𣃻
    # 0x230FC: '',  # 𣃼
    0x230FD: 'nuǒ',  # 𣃽
    0x230FE: 'yàn',  # 𣃾
    # 0x230FF: '',  # 𣃿
    # 0x23100: '',  # 𣄀
    # 0x23101: '',  # 𣄁
    # 0x23102: '',  # 𣄂
    # 0x23103: '',  # 𣄃
    # 0x23104: '',  # 𣄄
    0x23105: 'fǎng',  # 𣄅
    # 0x23106: '',  # 𣄆
    # 0x23107: '',  # 𣄇
    # 0x23108: '',  # 𣄈
    0x23109: 'yǎn',  # 𣄉
    # 0x2310A: '',  # 𣄊
    # 0x2310B: '',  # 𣄋
    # 0x2310C: '',  # 𣄌
    0x2310D: 'tí',  # 𣄍
    0x2310E: 'fù',  # 𣄎
    0x2310F: 'běn',  # 𣄏
    # 0x23110: '',  # 𣄐
    0x23111: 'yǎn',  # 𣄑
    # 0x23112: '',  # 𣄒
    0x23113: 'huī',  # 𣄓
    # 0x23114: '',  # 𣄔
    # 0x23115: '',  # 𣄕
    # 0x23116: '',  # 𣄖
    # 0x23117: '',  # 𣄗
    # 0x23118: '',  # 𣄘
    0x23119: 'huǎng',  # 𣄙
    # 0x2311A: '',  # 𣄚
    # 0x2311B: '',  # 𣄛
    0x2311C: 'guì',  # 𣄜
    0x2311D: 'yàn',  # 𣄝
    # 0x2311E: '',  # 𣄞
    0x2311F: 'hú',  # 𣄟
    0x23120: 'biāo',  # 𣄠
    # 0x23121: '',  # 𣄡
    # 0x23122: '',  # 𣄢
    # 0x23123: '',  # 𣄣
    # 0x23124: '',  # 𣄤
    # 0x23125: '',  # 𣄥
    # 0x23126: '',  # 𣄦
    0x23127: 'suì,wéi',  # 𣄧
    # 0x23128: '',  # 𣄨
    # 0x23129: '',  # 𣄩
    # 0x2312A: '',  # 𣄪
    # 0x2312B: '',  # 𣄫
    # 0x2312C: '',  # 𣄬
    # 0x2312D: '',  # 𣄭
    0x2312E: 'zì',  # 𣄮
    0x2312F: 'jì',  # 𣄯
    0x23130: 'ě',  # 𣄰
    0x23131: 'jì',  # 𣄱
    0x23132: 'kuǐ',  # 𣄲
    # 0x23133: '',  # 𣄳
    0x23134: 'liàng',  # 𣄴
    # 0x23135: '',  # 𣄵
    # 0x23136: '',  # 𣄶
    # 0x23137: '',  # 𣄷
    0x23138: 'huò',  # 𣄸
    # 0x23139: '',  # 𣄹
    0x2313A: 'wéi',  # 𣄺
    0x2313B: 'zhuō',  # 𣄻
    # 0x2313C: '',  # 𣄼
    # 0x2313D: '',  # 𣄽
    # 0x2313E: '',  # 𣄾
    0x2313F: 'tǐng',  # 𣄿
    # 0x23140: '',  # 𣅀
    # 0x23141: '',  # 𣅁
    # 0x23142: '',  # 𣅂
    0x23143: 'zǎi',  # 𣅃
    0x23144: 'yòu',  # 𣅄
    # 0x23145: '',  # 𣅅
    # 0x23146: '',  # 𣅆
    # 0x23147: '',  # 𣅇
    # 0x23148: '',  # 𣅈
    0x23149: 'rèn',  # 𣅉
    # 0x2314A: '',  # 𣅊
    # 0x2314B: '',  # 𣅋
    # 0x2314C: '',  # 𣅌
    0x2314D: 'miàn,bīng',  # 𣅍
    # 0x2314E: '',  # 𣅎
    # 0x2314F: '',  # 𣅏
    # 0x23150: '',  # 𣅐
    # 0x23151: '',  # 𣅑
    # 0x23152: '',  # 𣅒
    # 0x23153: '',  # 𣅓
    # 0x23154: '',  # 𣅔
    # 0x23155: '',  # 𣅕
    # 0x23156: '',  # 𣅖
    # 0x23157: '',  # 𣅗
    # 0x23158: '',  # 𣅘
    # 0x23159: '',  # 𣅙
    0x2315A: 'nà,niǔ',  # 𣅚
    # 0x2315B: '',  # 𣅛
    0x2315C: 'jiē',  # 𣅜
    0x2315D: 'tū',  # 𣅝
    0x2315E: 'jué',  # 𣅞
    0x2315F: 'dān',  # 𣅟
    # 0x23160: '',  # 𣅠
    0x23161: 'jué',  # 𣅡
    # 0x23162: '',  # 𣅢
    # 0x23163: '',  # 𣅣
    0x23164: 'xū',  # 𣅤
    0x23165: 'dī',  # 𣅥
    # 0x23166: '',  # 𣅦
    # 0x23167: '',  # 𣅧
    # 0x23168: '',  # 𣅨
    # 0x23169: '',  # 𣅩
    # 0x2316A: '',  # 𣅪
    # 0x2316B: '',  # 𣅫
    # 0x2316C: '',  # 𣅬
    # 0x2316D: '',  # 𣅭
    # 0x2316E: '',  # 𣅮
    0x2316F: 'zhòu',  # 𣅯
    0x23170: 'xiàng',  # 𣅰
    # 0x23171: '',  # 𣅱
    0x23172: 'jué',  # 𣅲
    # 0x23173: '',  # 𣅳
    # 0x23174: '',  # 𣅴
    # 0x23175: '',  # 𣅵
    # 0x23176: '',  # 𣅶
    0x23177: 'xiòng',  # 𣅷
    # 0x23178: '',  # 𣅸
    # 0x23179: '',  # 𣅹
    0x2317A: 'yǒu',  # 𣅺
    0x2317B: 'guǎ,jiōng',  # 𣅻
    # 0x2317C: '',  # 𣅼
    # 0x2317D: '',  # 𣅽
    0x2317E: 'xī',  # 𣅾
    # 0x2317F: '',  # 𣅿
    # 0x23180: '',  # 𣆀
    # 0x23181: '',  # 𣆁
    # 0x23182: '',  # 𣆂
    # 0x23183: '',  # 𣆃
    # 0x23184: '',  # 𣆄
    # 0x23185: '',  # 𣆅
    # 0x23186: '',  # 𣆆
    # 0x23187: '',  # 𣆇
    0x23188: 'hè',  # 𣆈
    # 0x23189: '',  # 𣆉
    # 0x2318A: '',  # 𣆊
    # 0x2318B: '',  # 𣆋
    # 0x2318C: '',  # 𣆌
    0x2318D: 'dǐng',  # 𣆍
    # 0x2318E: '',  # 𣆎
    # 0x2318F: '',  # 𣆏
    # 0x23190: '',  # 𣆐
    0x23191: 'cè',  # 𣆑
    0x23192: 'xú',  # 𣆒
    # 0x23193: '',  # 𣆓
    0x23194: 'zhòu',  # 𣆔
    0x23195: 'xiàn',  # 𣆕
    0x23196: 'huāng',  # 𣆖
    0x23197: 'chā',  # 𣆗
    0x23198: 'shǐ',  # 𣆘
    0x23199: 'gàn',  # 𣆙
    0x2319A: 'nuǒ,chǐ',  # 𣆚
    0x2319B: 'àn,wǎn',  # 𣆛
    # 0x2319C: '',  # 𣆜
    # 0x2319D: '',  # 𣆝
    # 0x2319E: '',  # 𣆞
    0x2319F: 'xiē,jiē',  # 𣆟
    # 0x231A0: '',  # 𣆠
    # 0x231A1: '',  # 𣆡
    # 0x231A2: '',  # 𣆢
    # 0x231A3: '',  # 𣆣
    # 0x231A4: '',  # 𣆤
    # 0x231A5: '',  # 𣆥
    # 0x231A6: '',  # 𣆦
    0x231A7: 'hào',  # 𣆧
    # 0x231A8: '',  # 𣆨
    # 0x231A9: '',  # 𣆩
    # 0x231AA: '',  # 𣆪
    # 0x231AB: '',  # 𣆫
    # 0x231AC: '',  # 𣆬
    # 0x231AD: '',  # 𣆭
    # 0x231AE: '',  # 𣆮
    # 0x231AF: '',  # 𣆯
    # 0x231B0: '',  # 𣆰
    # 0x231B1: '',  # 𣆱
    0x231B2: 'qīn',  # 𣆲
    0x231B3: 'gěng',  # 𣆳
    0x231B4: 'shān',  # 𣆴
    0x231B5: 'fú',  # 𣆵
    # 0x231B6: '',  # 𣆶
    # 0x231B7: '',  # 𣆷
    # 0x231B8: '',  # 𣆸
    # 0x231B9: '',  # 𣆹
    # 0x231BA: '',  # 𣆺
    # 0x231BB: '',  # 𣆻
    # 0x231BC: '',  # 𣆼
    0x231BD: 'zè',  # 𣆽
    # 0x231BE: '',  # 𣆾
    # 0x231BF: '',  # 𣆿
    # 0x231C0: '',  # 𣇀
    # 0x231C1: '',  # 𣇁
    # 0x231C2: '',  # 𣇂
    # 0x231C3: '',  # 𣇃
    # 0x231C4: '',  # 𣇄
    # 0x231C5: '',  # 𣇅
    # 0x231C6: '',  # 𣇆
    # 0x231C7: '',  # 𣇇
    # 0x231C8: '',  # 𣇈
    # 0x231C9: '',  # 𣇉
    # 0x231CA: '',  # 𣇊
    # 0x231CB: '',  # 𣇋
    # 0x231CC: '',  # 𣇌
    # 0x231CD: '',  # 𣇍
    # 0x231CE: '',  # 𣇎
    # 0x231CF: '',  # 𣇏
    # 0x231D0: '',  # 𣇐
    # 0x231D1: '',  # 𣇑
    # 0x231D2: '',  # 𣇒
    # 0x231D3: '',  # 𣇓
    # 0x231D4: '',  # 𣇔
    # 0x231D5: '',  # 𣇕
    0x231D6: 'diǎn',  # 𣇖
    0x231D7: 'shēn',  # 𣇗
    # 0x231D8: '',  # 𣇘
    0x231D9: 'zǔ',  # 𣇙
    # 0x231DA: '',  # 𣇚
    # 0x231DB: '',  # 𣇛
    # 0x231DC: '',  # 𣇜
    # 0x231DD: '',  # 𣇝
    # 0x231DE: '',  # 𣇞
    # 0x231DF: '',  # 𣇟
    # 0x231E0: '',  # 𣇠
    # 0x231E1: '',  # 𣇡
    0x231E2: 'biē',  # 𣇢
    # 0x231E3: '',  # 𣇣
    # 0x231E4: '',  # 𣇤
    # 0x231E5: '',  # 𣇥
    0x231E6: 'chuí',  # 𣇦
    0x231E7: 'zhè',  # 𣇧
    0x231E8: 'dài',  # 𣇨
    # 0x231E9: '',  # 𣇩
    # 0x231EA: '',  # 𣇪
    0x231EB: 'wǒ',  # 𣇫
    0x231EC: 'qióng',  # 𣇬
    # 0x231ED: '',  # 𣇭
    # 0x231EE: '',  # 𣇮
    # 0x231EF: '',  # 𣇯
    0x231F0: 'lín',  # 𣇰
    # 0x231F1: '',  # 𣇱
    0x231F2: 'hūn',  # 𣇲
    0x231F3: 'jī',  # 𣇳
    # 0x231F4: '',  # 𣇴
    0x231F5: 'jīng',  # 𣇵
    0x231F6: 'mò',  # 𣇶
    # 0x231F7: '',  # 𣇷
    # 0x231F8: '',  # 𣇸
    # 0x231F9: '',  # 𣇹
    # 0x231FA: '',  # 𣇺
    # 0x231FB: '',  # 𣇻
    # 0x231FC: '',  # 𣇼
    # 0x231FD: '',  # 𣇽
    # 0x231FE: '',  # 𣇾
    # 0x231FF: '',  # 𣇿
    # 0x23200: '',  # 𣈀
    # 0x23201: '',  # 𣈁
    # 0x23202: '',  # 𣈂
    # 0x23203: '',  # 𣈃
    # 0x23204: '',  # 𣈄
    0x23205: 'cáo',  # 𣈅
    # 0x23206: '',  # 𣈆
    # 0x23207: '',  # 𣈇
    # 0x23208: '',  # 𣈈
    # 0x23209: '',  # 𣈉
    0x2320A: 'mù',  # 𣈊
    # 0x2320B: '',  # 𣈋
    0x2320C: 'dū',  # 𣈌
    0x2320D: 'dié',  # 𣈍
    0x2320E: 'wèi',  # 𣈎
    # 0x2320F: '',  # 𣈏
    # 0x23210: '',  # 𣈐
    # 0x23211: '',  # 𣈑
    # 0x23212: '',  # 𣈒
    # 0x23213: '',  # 𣈓
    # 0x23214: '',  # 𣈔
    # 0x23215: '',  # 𣈕
    # 0x23216: '',  # 𣈖
    # 0x23217: '',  # 𣈗
    # 0x23218: '',  # 𣈘
    # 0x23219: '',  # 𣈙
    # 0x2321A: '',  # 𣈚
    # 0x2321B: '',  # 𣈛
    # 0x2321C: '',  # 𣈜
    # 0x2321D: '',  # 𣈝
    # 0x2321E: '',  # 𣈞
    # 0x2321F: '',  # 𣈟
    0x23220: 'biàn',  # 𣈠
    0x23221: 'tǐ',  # 𣈡
    # 0x23222: '',  # 𣈢
    # 0x23223: '',  # 𣈣
    # 0x23224: '',  # 𣈤
    0x23225: 'tú',  # 𣈥
    # 0x23226: '',  # 𣈦
    # 0x23227: '',  # 𣈧
    # 0x23228: '',  # 𣈨
    # 0x23229: '',  # 𣈩
    # 0x2322A: '',  # 𣈪
    # 0x2322B: '',  # 𣈫
    # 0x2322C: '',  # 𣈬
    # 0x2322D: '',  # 𣈭
    # 0x2322E: '',  # 𣈮
    # 0x2322F: '',  # 𣈯
    # 0x23230: '',  # 𣈰
    # 0x23231: '',  # 𣈱
    # 0x23232: '',  # 𣈲
    # 0x23233: '',  # 𣈳
    # 0x23234: '',  # 𣈴
    # 0x23235: '',  # 𣈵
    # 0x23236: '',  # 𣈶
    # 0x23237: '',  # 𣈷
    # 0x23238: '',  # 𣈸
    # 0x23239: '',  # 𣈹
    # 0x2323A: '',  # 𣈺
    # 0x2323B: '',  # 𣈻
    # 0x2323C: '',  # 𣈼
    # 0x2323D: '',  # 𣈽
    # 0x2323E: '',  # 𣈾
    # 0x2323F: '',  # 𣈿
    # 0x23240: '',  # 𣉀
    # 0x23241: '',  # 𣉁
    # 0x23242: '',  # 𣉂
    # 0x23243: '',  # 𣉃
    0x23244: 'chí',  # 𣉄
    0x23245: 'còu',  # 𣉅
    0x23246: 'tǐ',  # 𣉆
    # 0x23247: '',  # 𣉇
    # 0x23248: '',  # 𣉈
    # 0x23249: '',  # 𣉉
    # 0x2324A: '',  # 𣉊
    # 0x2324B: '',  # 𣉋
    # 0x2324C: '',  # 𣉌
    # 0x2324D: '',  # 𣉍
    # 0x2324E: '',  # 𣉎
    # 0x2324F: '',  # 𣉏
    # 0x23250: '',  # 𣉐
    # 0x23251: '',  # 𣉑
    0x23252: 'huò',  # 𣉒
    0x23253: 'qī',  # 𣉓
    0x23254: 'sāo',  # 𣉔
    0x23255: 'sàng',  # 𣉕
    0x23256: 'xuǎn',  # 𣉖
    0x23257: 'àng',  # 𣉗
    0x23258: 'nài',  # 𣉘
    # 0x23259: '',  # 𣉙
    0x2325A: 'yáng',  # 𣉚
    0x2325B: 'shū',  # 𣉛
    0x2325C: 'shā',  # 𣉜
    # 0x2325D: '',  # 𣉝
    # 0x2325E: '',  # 𣉞
    # 0x2325F: '',  # 𣉟
    # 0x23260: '',  # 𣉠
    0x23261: 'tǐng',  # 𣉡
    # 0x23262: '',  # 𣉢
    # 0x23263: '',  # 𣉣
    # 0x23264: '',  # 𣉤
    # 0x23265: '',  # 𣉥
    # 0x23266: '',  # 𣉦
    # 0x23267: '',  # 𣉧
    # 0x23268: '',  # 𣉨
    0x23269: 'yà',  # 𣉩
    0x2326A: 'huǎng',  # 𣉪
    # 0x2326B: '',  # 𣉫
    # 0x2326C: '',  # 𣉬
    # 0x2326D: '',  # 𣉭
    0x2326E: 'bīn',  # 𣉮
    # 0x2326F: '',  # 𣉯
    # 0x23270: '',  # 𣉰
    # 0x23271: '',  # 𣉱
    # 0x23272: '',  # 𣉲
    # 0x23273: '',  # 𣉳
    # 0x23274: '',  # 𣉴
    # 0x23275: '',  # 𣉵
    # 0x23276: '',  # 𣉶
    # 0x23277: '',  # 𣉷
    # 0x23278: '',  # 𣉸
    # 0x23279: '',  # 𣉹
    # 0x2327A: '',  # 𣉺
    # 0x2327B: '',  # 𣉻
    # 0x2327C: '',  # 𣉼
    # 0x2327D: '',  # 𣉽
    0x2327E: 'òu',  # 𣉾
    0x2327F: 'cáo',  # 𣉿
    # 0x23280: '',  # 𣊀
    0x23281: 'áo',  # 𣊁
    # 0x23282: '',  # 𣊂
    0x23283: 'mào',  # 𣊃
    # 0x23284: '',  # 𣊄
    # 0x23285: '',  # 𣊅
    # 0x23286: '',  # 𣊆
    # 0x23287: '',  # 𣊇
    # 0x23288: '',  # 𣊈
    # 0x23289: '',  # 𣊉
    # 0x2328A: '',  # 𣊊
    # 0x2328B: '',  # 𣊋
    # 0x2328C: '',  # 𣊌
    # 0x2328D: '',  # 𣊍
    # 0x2328E: '',  # 𣊎
    # 0x2328F: '',  # 𣊏
    # 0x23290: '',  # 𣊐
    # 0x23291: '',  # 𣊑
    # 0x23292: '',  # 𣊒
    0x23293: 'xiè',  # 𣊓
    0x23294: 'méng',  # 𣊔
    # 0x23295: '',  # 𣊕
    0x23296: 'tiān',  # 𣊖
    # 0x23297: '',  # 𣊗
    # 0x23298: '',  # 𣊘
    # 0x23299: '',  # 𣊙
    # 0x2329A: '',  # 𣊚
    # 0x2329B: '',  # 𣊛
    # 0x2329C: '',  # 𣊜
    0x2329D: 'sàng',  # 𣊝
    0x2329E: 'xù',  # 𣊞
    0x2329F: 'kàn',  # 𣊟
    # 0x232A0: '',  # 𣊠
    # 0x232A1: '',  # 𣊡
    # 0x232A2: '',  # 𣊢
    # 0x232A3: '',  # 𣊣
    # 0x232A4: '',  # 𣊤
    # 0x232A5: '',  # 𣊥
    # 0x232A6: '',  # 𣊦
    0x232A7: 'lǎng,zhào',  # 𣊧
    # 0x232A8: '',  # 𣊨
    # 0x232A9: '',  # 𣊩
    # 0x232AA: '',  # 𣊪
    0x232AB: 'liù',  # 𣊫
    # 0x232AC: '',  # 𣊬
    # 0x232AD: '',  # 𣊭
    # 0x232AE: '',  # 𣊮
    # 0x232AF: '',  # 𣊯
    # 0x232B0: '',  # 𣊰
    # 0x232B1: '',  # 𣊱
    # 0x232B2: '',  # 𣊲
    # 0x232B3: '',  # 𣊳
    # 0x232B4: '',  # 𣊴
    # 0x232B5: '',  # 𣊵
    0x232B6: 'biē',  # 𣊶
    0x232B7: 'cóng',  # 𣊷
    # 0x232B8: '',  # 𣊸
    # 0x232B9: '',  # 𣊹
    0x232BA: 'xián',  # 𣊺
    # 0x232BB: '',  # 𣊻
    # 0x232BC: '',  # 𣊼
    # 0x232BD: '',  # 𣊽
    # 0x232BE: '',  # 𣊾
    # 0x232BF: '',  # 𣊿
    # 0x232C0: '',  # 𣋀
    # 0x232C1: '',  # 𣋁
    # 0x232C2: '',  # 𣋂
    # 0x232C3: '',  # 𣋃
    0x232C4: 'tūn',  # 𣋄
    # 0x232C5: '',  # 𣋅
    # 0x232C6: '',  # 𣋆
    # 0x232C7: '',  # 𣋇
    # 0x232C8: '',  # 𣋈
    0x232C9: 'yù',  # 𣋉
    0x232CA: 'dàn',  # 𣋊
    0x232CB: 'yìng',  # 𣋋
    0x232CC: 'yè',  # 𣋌
    0x232CD: 'zhāo',  # 𣋍
    # 0x232CE: '',  # 𣋎
    0x232CF: 'pù',  # 𣋏
    # 0x232D0: '',  # 𣋐
    # 0x232D1: '',  # 𣋑
    # 0x232D2: '',  # 𣋒
    # 0x232D3: '',  # 𣋓
    # 0x232D4: '',  # 𣋔
    # 0x232D5: '',  # 𣋕
    # 0x232D6: '',  # 𣋖
    # 0x232D7: '',  # 𣋗
    0x232D8: 'huì',  # 𣋘
    # 0x232D9: '',  # 𣋙
    # 0x232DA: '',  # 𣋚
    # 0x232DB: '',  # 𣋛
    # 0x232DC: '',  # 𣋜
    # 0x232DD: '',  # 𣋝
    0x232DE: 'ài',  # 𣋞
    0x232DF: 'mǒ',  # 𣋟
    # 0x232E0: '',  # 𣋠
    # 0x232E1: '',  # 𣋡
    0x232E2: 'jīng',  # 𣋢
    0x232E3: 'lán',  # 𣋣
    # 0x232E4: '',  # 𣋤
    # 0x232E5: '',  # 𣋥
    # 0x232E6: '',  # 𣋦
    # 0x232E7: '',  # 𣋧
    # 0x232E8: '',  # 𣋨
    # 0x232E9: '',  # 𣋩
    # 0x232EA: '',  # 𣋪
    # 0x232EB: '',  # 𣋫
    # 0x232EC: '',  # 𣋬
    # 0x232ED: '',  # 𣋭
    # 0x232EE: '',  # 𣋮
    # 0x232EF: '',  # 𣋯
    # 0x232F0: '',  # 𣋰
    # 0x232F1: '',  # 𣋱
    0x232F2: 'liè',  # 𣋲
    0x232F3: 'piǎo,bào',  # 𣋳
    # 0x232F4: '',  # 𣋴
    0x232F5: 'bó',  # 𣋵
    0x232F6: 'qióng',  # 𣋶
    # 0x232F7: '',  # 𣋷
    # 0x232F8: '',  # 𣋸
    0x232F9: 'bì',  # 𣋹
    # 0x232FA: '',  # 𣋺
    # 0x232FB: '',  # 𣋻
    # 0x232FC: '',  # 𣋼
    # 0x232FD: '',  # 𣋽
    # 0x232FE: '',  # 𣋾
    0x232FF: 'yōng',  # 𣋿
    # 0x23300: '',  # 𣌀
    # 0x23301: '',  # 𣌁
    # 0x23302: '',  # 𣌂
    # 0x23303: '',  # 𣌃
    # 0x23304: '',  # 𣌄
    0x23305: 'lì',  # 𣌅
    # 0x23306: '',  # 𣌆
    # 0x23307: '',  # 𣌇
    # 0x23308: '',  # 𣌈
    # 0x23309: '',  # 𣌉
    # 0x2330A: '',  # 𣌊
    # 0x2330B: '',  # 𣌋
    # 0x2330C: '',  # 𣌌
    0x2330D: 'niè',  # 𣌍
    # 0x2330E: '',  # 𣌎
    0x2330F: 'dé',  # 𣌏
    # 0x23310: '',  # 𣌐
    # 0x23311: '',  # 𣌑
    # 0x23312: '',  # 𣌒
    0x23313: 'huān',  # 𣌓
    # 0x23314: '',  # 𣌔
    # 0x23315: '',  # 𣌕
    # 0x23316: '',  # 𣌖
    0x23317: 'yuè',  # 𣌗
    # 0x23318: '',  # 𣌘
    # 0x23319: '',  # 𣌙
    0x2331A: 'chūn',  # 𣌚
    # 0x2331B: '',  # 𣌛
    0x2331C: 'lì',  # 𣌜
    # 0x2331D: '',  # 𣌝
    0x2331E: 'zhāng',  # 𣌞
    0x2331F: 'líng',  # 𣌟
    0x23320: 'chún',  # 𣌠
    # 0x23321: '',  # 𣌡
    # 0x23322: '',  # 𣌢
    # 0x23323: '',  # 𣌣
    # 0x23324: '',  # 𣌤
    # 0x23325: '',  # 𣌥
    # 0x23326: '',  # 𣌦
    0x23327: 'cè',  # 𣌧
    0x23328: 'xún',  # 𣌨
    # 0x23329: '',  # 𣌩
    # 0x2332A: '',  # 𣌪
    # 0x2332B: '',  # 𣌫
    0x2332C: 'jǔ',  # 𣌬
    0x2332D: 'hui,dá',  # 𣌭
    # 0x2332E: '',  # 𣌮
    # 0x2332F: '',  # 𣌯
    # 0x23330: '',  # 𣌰
    # 0x23331: '',  # 𣌱
    # 0x23332: '',  # 𣌲
    # 0x23333: '',  # 𣌳
    # 0x23334: '',  # 𣌴
    # 0x23335: '',  # 𣌵
    # 0x23336: '',  # 𣌶
    # 0x23337: '',  # 𣌷
    # 0x23338: '',  # 𣌸
    # 0x23339: '',  # 𣌹
    # 0x2333A: '',  # 𣌺
    # 0x2333B: '',  # 𣌻
    # 0x2333C: '',  # 𣌼
    # 0x2333D: '',  # 𣌽
    0x2333E: 'tōng',  # 𣌾
    # 0x2333F: '',  # 𣌿
    # 0x23340: '',  # 𣍀
    # 0x23341: '',  # 𣍁
    # 0x23342: '',  # 𣍂
    0x23343: 'yìn',  # 𣍃
    # 0x23344: '',  # 𣍄
    # 0x23345: '',  # 𣍅
    0x23346: 'níng',  # 𣍆
    0x23347: 'jù',  # 𣍇
    # 0x23348: '',  # 𣍈
    # 0x23349: '',  # 𣍉
    # 0x2334A: '',  # 𣍊
    # 0x2334B: '',  # 𣍋
    # 0x2334C: '',  # 𣍌
    # 0x2334D: '',  # 𣍍
    # 0x2334E: '',  # 𣍎
    0x2334F: 'chà',  # 𣍏
    0x23350: 'fèi',  # 𣍐
    # 0x23351: '',  # 𣍑
    # 0x23352: '',  # 𣍒
    # 0x23353: '',  # 𣍓
    # 0x23354: '',  # 𣍔
    # 0x23355: '',  # 𣍕
    0x23356: 'zāo',  # 𣍖
    # 0x23357: '',  # 𣍗
    # 0x23358: '',  # 𣍘
    # 0x23359: '',  # 𣍙
    # 0x2335A: '',  # 𣍚
    0x2335B: 'yù',  # 𣍛
    # 0x2335C: '',  # 𣍜
    # 0x2335D: '',  # 𣍝
    # 0x2335E: '',  # 𣍞
    0x2335F: 'kěn,wěi',  # 𣍟
    # 0x23360: '',  # 𣍠
    # 0x23361: '',  # 𣍡
    # 0x23362: '',  # 𣍢
    # 0x23363: '',  # 𣍣
    # 0x23364: '',  # 𣍤
    # 0x23365: '',  # 𣍥
    0x23366: 'kuàng',  # 𣍦
    0x23367: 'fěi',  # 𣍧
    # 0x23368: '',  # 𣍨
    # 0x23369: '',  # 𣍩
    # 0x2336A: '',  # 𣍪
    # 0x2336B: '',  # 𣍫
    # 0x2336C: '',  # 𣍬
    # 0x2336D: '',  # 𣍭
    # 0x2336E: '',  # 𣍮
    # 0x2336F: '',  # 𣍯
    # 0x23370: '',  # 𣍰
    # 0x23371: '',  # 𣍱
    # 0x23372: '',  # 𣍲
    # 0x23373: '',  # 𣍳
    0x23374: 'quán',  # 𣍴
    # 0x23375: '',  # 𣍵
    # 0x23376: '',  # 𣍶
    # 0x23377: '',  # 𣍷
    0x23378: 'pò',  # 𣍸
    # 0x23379: '',  # 𣍹
    0x2337A: 'pěi',  # 𣍺
    # 0x2337B: '',  # 𣍻
    # 0x2337C: '',  # 𣍼
    # 0x2337D: '',  # 𣍽
    # 0x2337E: '',  # 𣍾
    # 0x2337F: '',  # 𣍿
    # 0x23380: '',  # 𣎀
    # 0x23381: '',  # 𣎁
    # 0x23382: '',  # 𣎂
    # 0x23383: '',  # 𣎃
    0x23384: 'gèng',  # 𣎄
    0x23385: 'yì,huān',  # 𣎅
    # 0x23386: '',  # 𣎆
    # 0x23387: '',  # 𣎇
    # 0x23388: '',  # 𣎈
    # 0x23389: '',  # 𣎉
    # 0x2338A: '',  # 𣎊
    # 0x2338B: '',  # 𣎋
    # 0x2338C: '',  # 𣎌
    # 0x2338D: '',  # 𣎍
    0x2338E: 'líng',  # 𣎎
    # 0x2338F: '',  # 𣎏
    # 0x23390: '',  # 𣎐
    # 0x23391: '',  # 𣎑
    # 0x23392: '',  # 𣎒
    0x23393: 'xuǎn',  # 𣎓
    0x23394: 'niàn',  # 𣎔
    # 0x23395: '',  # 𣎕
    # 0x23396: '',  # 𣎖
    # 0x23397: '',  # 𣎗
    # 0x23398: '',  # 𣎘
    # 0x23399: '',  # 𣎙
    0x2339A: 'hú',  # 𣎚
    0x2339B: 'jú,xuè',  # 𣎛
    # 0x2339C: '',  # 𣎜
    # 0x2339D: '',  # 𣎝
    # 0x2339E: '',  # 𣎞
    0x2339F: 'xún',  # 𣎟
    # 0x233A0: '',  # 𣎠
    # 0x233A1: '',  # 𣎡
    # 0x233A2: '',  # 𣎢
    # 0x233A3: '',  # 𣎣
    # 0x233A4: '',  # 𣎤
    # 0x233A5: '',  # 𣎥
    # 0x233A6: '',  # 𣎦
    # 0x233A7: '',  # 𣎧
    # 0x233A8: '',  # 𣎨
    0x233A9: 'yè',  # 𣎩
    # 0x233AA: '',  # 𣎪
    # 0x233AB: '',  # 𣎫
    # 0x233AC: '',  # 𣎬
    # 0x233AD: '',  # 𣎭
    0x233AE: 'xī',  # 𣎮
    # 0x233AF: '',  # 𣎯
    # 0x233B0: '',  # 𣎰
    0x233B1: 'yuè',  # 𣎱
    0x233B2: 'tǎng',  # 𣎲
    0x233B3: 'pìn',  # 𣎳
    0x233B4: 'dǔn',  # 𣎴
    0x233B5: 'bèi,pō',  # 𣎵
    # 0x233B6: '',  # 𣎶
    # 0x233B7: '',  # 𣎷
    0x233B8: 'liǎo',  # 𣎸
    # 0x233B9: '',  # 𣎹
    # 0x233BA: '',  # 𣎺
    # 0x233BB: '',  # 𣎻
    # 0x233BC: '',  # 𣎼
    # 0x233BD: '',  # 𣎽
    # 0x233BE: '',  # 𣎾
    # 0x233BF: '',  # 𣎿
    0x233C0: 'yǒng',  # 𣏀
    0x233C1: 'mǒu',  # 𣏁
    # 0x233C2: '',  # 𣏂
    # 0x233C3: '',  # 𣏃
    # 0x233C4: '',  # 𣏄
    # 0x233C5: '',  # 𣏅
    # 0x233C6: '',  # 𣏆
    # 0x233C7: '',  # 𣏇
    # 0x233C8: '',  # 𣏈
    # 0x233C9: '',  # 𣏉
    # 0x233CA: '',  # 𣏊
    # 0x233CB: '',  # 𣏋
    0x233CC: 'sì',  # 𣏌
    # 0x233CD: '',  # 𣏍
    0x233CE: 'yā',  # 𣏎
    # 0x233CF: '',  # 𣏏
    # 0x233D0: '',  # 𣏐
    0x233D1: 'jiǎo',  # 𣏑
    # 0x233D2: '',  # 𣏒
    # 0x233D3: '',  # 𣏓
    0x233D4: 'kùn,kǔn',  # 𣏔
    # 0x233D5: '',  # 𣏕
    0x233D6: 'zhèn',  # 𣏖
    0x233D7: 'shù',  # 𣏗
    # 0x233D8: '',  # 𣏘
    # 0x233D9: '',  # 𣏙
    0x233DA: 'shí',  # 𣏚
    # 0x233DB: '',  # 𣏛
    # 0x233DC: '',  # 𣏜
    # 0x233DD: '',  # 𣏝
    0x233DE: 'yóu',  # 𣏞
    0x233DF: 'pài',  # 𣏟
    0x233E0: 'xiáo',  # 𣏠
    0x233E1: 'jí',  # 𣏡
    # 0x233E2: '',  # 𣏢
    # 0x233E3: '',  # 𣏣
    # 0x233E4: '',  # 𣏤
    0x233E5: 'lóu',  # 𣏥
    # 0x233E6: '',  # 𣏦
    # 0x233E7: '',  # 𣏧
    # 0x233E8: '',  # 𣏨
    # 0x233E9: '',  # 𣏩
    0x233EA: 'shuāng',  # 𣏪
    0x233EB: 'pāo',  # 𣏫
    # 0x233EC: '',  # 𣏬
    # 0x233ED: '',  # 𣏭
    # 0x233EE: '',  # 𣏮
    # 0x233EF: '',  # 𣏯
    # 0x233F0: '',  # 𣏰
    # 0x233F1: '',  # 𣏱
    # 0x233F2: '',  # 𣏲
    # 0x233F3: '',  # 𣏳
    # 0x233F4: '',  # 𣏴
    # 0x233F5: '',  # 𣏵
    0x233F6: 'qī',  # 𣏶
    0x233F7: 'hé',  # 𣏷
    # 0x233F8: '',  # 𣏸
    # 0x233F9: '',  # 𣏹
    0x233FA: 'kǒng',  # 𣏺
    # 0x233FB: '',  # 𣏻
    # 0x233FC: '',  # 𣏼
    # 0x233FD: '',  # 𣏽
    # 0x233FE: '',  # 𣏾
    # 0x233FF: '',  # 𣏿
    # 0x23400: '',  # 𣐀
    # 0x23401: '',  # 𣐁
    0x23402: 'yè',  # 𣐂
    0x23403: 'chì',  # 𣐃
    # 0x23404: '',  # 𣐄
    # 0x23405: '',  # 𣐅
    # 0x23406: '',  # 𣐆
    # 0x23407: '',  # 𣐇
    # 0x23408: '',  # 𣐈
    # 0x23409: '',  # 𣐉
    0x2340A: 'kǎo,jú',  # 𣐊
    0x2340B: 'yuè',  # 𣐋
    # 0x2340C: '',  # 𣐌
    # 0x2340D: '',  # 𣐍
    0x2340E: 'wǎ',  # 𣐎
    0x2340F: 'niǎn',  # 𣐏
    # 0x23410: '',  # 𣐐
    0x23411: 'cí',  # 𣐑
    # 0x23412: '',  # 𣐒
    0x23413: 'yí',  # 𣐓
    # 0x23414: '',  # 𣐔
    # 0x23415: '',  # 𣐕
    # 0x23416: '',  # 𣐖
    # 0x23417: '',  # 𣐗
    # 0x23418: '',  # 𣐘
    # 0x23419: '',  # 𣐙
    # 0x2341A: '',  # 𣐚
    # 0x2341B: '',  # 𣐛
    # 0x2341C: '',  # 𣐜
    # 0x2341D: '',  # 𣐝
    # 0x2341E: '',  # 𣐞
    # 0x2341F: '',  # 𣐟
    # 0x23420: '',  # 𣐠
    # 0x23421: '',  # 𣐡
    # 0x23422: '',  # 𣐢
    # 0x23423: '',  # 𣐣
    # 0x23424: '',  # 𣐤
    # 0x23425: '',  # 𣐥
    # 0x23426: '',  # 𣐦
    # 0x23427: '',  # 𣐧
    # 0x23428: '',  # 𣐨
    0x23429: 'shēn',  # 𣐩
    # 0x2342A: '',  # 𣐪
    0x2342B: 'yāng',  # 𣐫
    0x2342C: 'lí',  # 𣐬
    # 0x2342D: '',  # 𣐭
    0x2342E: 'dāi',  # 𣐮
    0x2342F: 'chóng',  # 𣐯
    # 0x23430: '',  # 𣐰
    # 0x23431: '',  # 𣐱
    # 0x23432: '',  # 𣐲
    # 0x23433: '',  # 𣐳
    # 0x23434: '',  # 𣐴
    0x23435: 'yí',  # 𣐵
    # 0x23436: '',  # 𣐶
    # 0x23437: '',  # 𣐷
    # 0x23438: '',  # 𣐸
    # 0x23439: '',  # 𣐹
    0x2343A: 'hàn',  # 𣐺
    # 0x2343B: '',  # 𣐻
    # 0x2343C: '',  # 𣐼
    # 0x2343D: '',  # 𣐽
    # 0x2343E: '',  # 𣐾
    0x2343F: 'yī',  # 𣐿
    # 0x23440: '',  # 𣑀
    0x23441: 'chòng',  # 𣑁
    0x23442: 'hù',  # 𣑂
    0x23443: 'zhuǎ',  # 𣑃
    # 0x23444: '',  # 𣑄
    # 0x23445: '',  # 𣑅
    # 0x23446: '',  # 𣑆
    # 0x23447: '',  # 𣑇
    # 0x23448: '',  # 𣑈
    # 0x23449: '',  # 𣑉
    # 0x2344A: '',  # 𣑊
    # 0x2344B: '',  # 𣑋
    # 0x2344C: '',  # 𣑌
    0x2344D: 'guǎi',  # 𣑍
    # 0x2344E: '',  # 𣑎
    # 0x2344F: '',  # 𣑏
    # 0x23450: '',  # 𣑐
    # 0x23451: '',  # 𣑑
    # 0x23452: '',  # 𣑒
    # 0x23453: '',  # 𣑓
    # 0x23454: '',  # 𣑔
    # 0x23455: '',  # 𣑕
    # 0x23456: '',  # 𣑖
    # 0x23457: '',  # 𣑗
    # 0x23458: '',  # 𣑘
    # 0x23459: '',  # 𣑙
    # 0x2345A: '',  # 𣑚
    # 0x2345B: '',  # 𣑛
    # 0x2345C: '',  # 𣑜
    # 0x2345D: '',  # 𣑝
    # 0x2345E: '',  # 𣑞
    # 0x2345F: '',  # 𣑟
    # 0x23460: '',  # 𣑠
    # 0x23461: '',  # 𣑡
    # 0x23462: '',  # 𣑢
    # 0x23463: '',  # 𣑣
    # 0x23464: '',  # 𣑤
    # 0x23465: '',  # 𣑥
    0x23466: 'qióng',  # 𣑦
    0x23467: 'duò',  # 𣑧
    # 0x23468: '',  # 𣑨
    # 0x23469: '',  # 𣑩
    # 0x2346A: '',  # 𣑪
    # 0x2346B: '',  # 𣑫
    # 0x2346C: '',  # 𣑬
    # 0x2346D: '',  # 𣑭
    0x2346E: 'nán',  # 𣑮
    0x2346F: 'táo',  # 𣑯
    # 0x23470: '',  # 𣑰
    # 0x23471: '',  # 𣑱
    # 0x23472: '',  # 𣑲
    # 0x23473: '',  # 𣑳
    # 0x23474: '',  # 𣑴
    # 0x23475: '',  # 𣑵
    # 0x23476: '',  # 𣑶
    # 0x23477: '',  # 𣑷
    0x23478: 'tóng',  # 𣑸
    0x23479: 'xiān',  # 𣑹
    # 0x2347A: '',  # 𣑺
    # 0x2347B: '',  # 𣑻
    # 0x2347C: '',  # 𣑼
    # 0x2347D: '',  # 𣑽
    # 0x2347E: '',  # 𣑾
    0x2347F: 'fú',  # 𣑿
    # 0x23480: '',  # 𣒀
    # 0x23481: '',  # 𣒁
    0x23482: 'diàn',  # 𣒂
    0x23483: 'xí',  # 𣒃
    0x23484: 'xiē',  # 𣒄
    0x23485: 'zhèn',  # 𣒅
    0x23486: 'qiào',  # 𣒆
    0x23487: 'tū',  # 𣒇
    # 0x23488: '',  # 𣒈
    # 0x23489: '',  # 𣒉
    # 0x2348A: '',  # 𣒊
    # 0x2348B: '',  # 𣒋
    # 0x2348C: '',  # 𣒌
    0x2348D: 'hé',  # 𣒍
    # 0x2348E: '',  # 𣒎
    # 0x2348F: '',  # 𣒏
    # 0x23490: '',  # 𣒐
    # 0x23491: '',  # 𣒑
    # 0x23492: '',  # 𣒒
    # 0x23493: '',  # 𣒓
    # 0x23494: '',  # 𣒔
    # 0x23495: '',  # 𣒕
    # 0x23496: '',  # 𣒖
    # 0x23497: '',  # 𣒗
    # 0x23498: '',  # 𣒘
    # 0x23499: '',  # 𣒙
    # 0x2349A: '',  # 𣒚
    # 0x2349B: '',  # 𣒛
    # 0x2349C: '',  # 𣒜
    # 0x2349D: '',  # 𣒝
    # 0x2349E: '',  # 𣒞
    # 0x2349F: '',  # 𣒟
    # 0x234A0: '',  # 𣒠
    # 0x234A1: '',  # 𣒡
    # 0x234A2: '',  # 𣒢
    # 0x234A3: '',  # 𣒣
    # 0x234A4: '',  # 𣒤
    # 0x234A5: '',  # 𣒥
    # 0x234A6: '',  # 𣒦
    # 0x234A7: '',  # 𣒧
    # 0x234A8: '',  # 𣒨
    # 0x234A9: '',  # 𣒩
    # 0x234AA: '',  # 𣒪
    # 0x234AB: '',  # 𣒫
    # 0x234AC: '',  # 𣒬
    # 0x234AD: '',  # 𣒭
    # 0x234AE: '',  # 𣒮
    # 0x234AF: '',  # 𣒯
    # 0x234B0: '',  # 𣒰
    # 0x234B1: '',  # 𣒱
    # 0x234B2: '',  # 𣒲
    # 0x234B3: '',  # 𣒳
    # 0x234B4: '',  # 𣒴
    # 0x234B5: '',  # 𣒵
    # 0x234B6: '',  # 𣒶
    0x234B7: 'hàn',  # 𣒷
    0x234B8: 'kuàng',  # 𣒸
    0x234B9: 'suō',  # 𣒹
    # 0x234BA: '',  # 𣒺
    0x234BB: 'shòu',  # 𣒻
    0x234BC: 'tiáo',  # 𣒼
    # 0x234BD: '',  # 𣒽
    # 0x234BE: '',  # 𣒾
    # 0x234BF: '',  # 𣒿
    0x234C0: 'zhēn,zhěn',  # 𣓀
    0x234C1: 'kān',  # 𣓁
    # 0x234C2: '',  # 𣓂
    0x234C3: 'nèi',  # 𣓃
    # 0x234C4: '',  # 𣓄
    0x234C5: 'qiǎn',  # 𣓅
    0x234C6: 'yín',  # 𣓆
    # 0x234C7: '',  # 𣓇
    0x234C8: 'liǎng',  # 𣓈
    0x234C9: 'shà,jié',  # 𣓉
    0x234CA: 'zì',  # 𣓊
    0x234CB: 'pí',  # 𣓋
    0x234CC: 'gāo,jú',  # 𣓌
    # 0x234CD: '',  # 𣓍
    # 0x234CE: '',  # 𣓎
    0x234CF: 'jìn',  # 𣓏
    0x234D0: 'yóu',  # 𣓐
    # 0x234D1: '',  # 𣓑
    0x234D2: 'shàn',  # 𣓒
    # 0x234D3: '',  # 𣓓
    0x234D4: 'mì',  # 𣓔
    0x234D5: 'òu',  # 𣓕
    # 0x234D6: '',  # 𣓖
    0x234D7: 'hū',  # 𣓗
    # 0x234D8: '',  # 𣓘
    # 0x234D9: '',  # 𣓙
    # 0x234DA: '',  # 𣓚
    0x234DB: 'yòu',  # 𣓛
    # 0x234DC: '',  # 𣓜
    0x234DD: 'měng',  # 𣓝
    # 0x234DE: '',  # 𣓞
    # 0x234DF: '',  # 𣓟
    # 0x234E0: '',  # 𣓠
    # 0x234E1: '',  # 𣓡
    # 0x234E2: '',  # 𣓢
    # 0x234E3: '',  # 𣓣
    # 0x234E4: '',  # 𣓤
    # 0x234E5: '',  # 𣓥
    # 0x234E6: '',  # 𣓦
    # 0x234E7: '',  # 𣓧
    # 0x234E8: '',  # 𣓨
    # 0x234E9: '',  # 𣓩
    # 0x234EA: '',  # 𣓪
    # 0x234EB: '',  # 𣓫
    # 0x234EC: '',  # 𣓬
    # 0x234ED: '',  # 𣓭
    # 0x234EE: '',  # 𣓮
    # 0x234EF: '',  # 𣓯
    # 0x234F0: '',  # 𣓰
    # 0x234F1: '',  # 𣓱
    # 0x234F2: '',  # 𣓲
    # 0x234F3: '',  # 𣓳
    # 0x234F4: '',  # 𣓴
    # 0x234F5: '',  # 𣓵
    # 0x234F6: '',  # 𣓶
    # 0x234F7: '',  # 𣓷
    # 0x234F8: '',  # 𣓸
    # 0x234F9: '',  # 𣓹
    # 0x234FA: '',  # 𣓺
    # 0x234FB: '',  # 𣓻
    # 0x234FC: '',  # 𣓼
    # 0x234FD: '',  # 𣓽
    # 0x234FE: '',  # 𣓾
    # 0x234FF: '',  # 𣓿
    # 0x23500: '',  # 𣔀
    # 0x23501: '',  # 𣔁
    # 0x23502: '',  # 𣔂
    # 0x23503: '',  # 𣔃
    # 0x23504: '',  # 𣔄
    # 0x23505: '',  # 𣔅
    # 0x23506: '',  # 𣔆
    # 0x23507: '',  # 𣔇
    # 0x23508: '',  # 𣔈
    # 0x23509: '',  # 𣔉
    # 0x2350A: '',  # 𣔊
    # 0x2350B: '',  # 𣔋
    # 0x2350C: '',  # 𣔌
    # 0x2350D: '',  # 𣔍
    # 0x2350E: '',  # 𣔎
    # 0x2350F: '',  # 𣔏
    0x23510: 'zhǐ',  # 𣔐
    # 0x23511: '',  # 𣔑
    # 0x23512: '',  # 𣔒
    0x23513: 'bǐ',  # 𣔓
    # 0x23514: '',  # 𣔔
    # 0x23515: '',  # 𣔕
    # 0x23516: '',  # 𣔖
    0x23517: 'shēn',  # 𣔗
    0x23518: 'qì',  # 𣔘
    0x23519: 'xiān',  # 𣔙
    0x2351A: 'pán',  # 𣔚
    0x2351B: 'kǎng',  # 𣔛
    # 0x2351C: '',  # 𣔜
    # 0x2351D: '',  # 𣔝
    # 0x2351E: '',  # 𣔞
    # 0x2351F: '',  # 𣔟
    # 0x23520: '',  # 𣔠
    # 0x23521: '',  # 𣔡
    # 0x23522: '',  # 𣔢
    # 0x23523: '',  # 𣔣
    # 0x23524: '',  # 𣔤
    # 0x23525: '',  # 𣔥
    # 0x23526: '',  # 𣔦
    # 0x23527: '',  # 𣔧
    # 0x23528: '',  # 𣔨
    # 0x23529: '',  # 𣔩
    # 0x2352A: '',  # 𣔪
    0x2352B: 'shuān',  # 𣔫
    0x2352C: 'pí',  # 𣔬
    # 0x2352D: '',  # 𣔭
    0x2352E: 'zāi',  # 𣔮
    0x2352F: 'zhǔ',  # 𣔯
    # 0x23530: '',  # 𣔰
    0x23531: 'sōu,sāo',  # 𣔱
    0x23532: 'jiǒng',  # 𣔲
    # 0x23533: '',  # 𣔳
    # 0x23534: '',  # 𣔴
    0x23535: 'chán',  # 𣔵
    0x23536: 'fán,fàn',  # 𣔶
    0x23537: 'xiáo',  # 𣔷
    0x23538: 'yǐn',  # 𣔸
    0x23539: 'hóu',  # 𣔹
    0x2353A: 'mào',  # 𣔺
    0x2353B: 'tú,chán',  # 𣔻
    # 0x2353C: '',  # 𣔼
    0x2353D: 'jì',  # 𣔽
    0x2353E: 'suì',  # 𣔾
    # 0x2353F: '',  # 𣔿
    # 0x23540: '',  # 𣕀
    0x23541: 'yí',  # 𣕁
    # 0x23542: '',  # 𣕂
    0x23543: 'yù',  # 𣕃
    0x23544: 'jiōng',  # 𣕄
    0x23545: 'pào',  # 𣕅
    # 0x23546: '',  # 𣕆
    0x23547: 'xiāo',  # 𣕇
    # 0x23548: '',  # 𣕈
    0x23549: 'gǒu',  # 𣕉
    # 0x2354A: '',  # 𣕊
    0x2354B: 'xiè',  # 𣕋
    0x2354C: 'gōu',  # 𣕌
    0x2354D: 'sǔn',  # 𣕍
    0x2354E: 'xiǎn',  # 𣕎
    0x2354F: 'zhuǎn',  # 𣕏
    # 0x23550: '',  # 𣕐
    # 0x23551: '',  # 𣕑
    # 0x23552: '',  # 𣕒
    # 0x23553: '',  # 𣕓
    # 0x23554: '',  # 𣕔
    # 0x23555: '',  # 𣕕
    # 0x23556: '',  # 𣕖
    # 0x23557: '',  # 𣕗
    # 0x23558: '',  # 𣕘
    # 0x23559: '',  # 𣕙
    # 0x2355A: '',  # 𣕚
    # 0x2355B: '',  # 𣕛
    # 0x2355C: '',  # 𣕜
    # 0x2355D: '',  # 𣕝
    # 0x2355E: '',  # 𣕞
    # 0x2355F: '',  # 𣕟
    # 0x23560: '',  # 𣕠
    # 0x23561: '',  # 𣕡
    # 0x23562: '',  # 𣕢
    # 0x23563: '',  # 𣕣
    0x23564: 'zǎo',  # 𣕤
    # 0x23565: '',  # 𣕥
    # 0x23566: '',  # 𣕦
    # 0x23567: '',  # 𣕧
    # 0x23568: '',  # 𣕨
    # 0x23569: '',  # 𣕩
    # 0x2356A: '',  # 𣕪
    # 0x2356B: '',  # 𣕫
    # 0x2356C: '',  # 𣕬
    # 0x2356D: '',  # 𣕭
    # 0x2356E: '',  # 𣕮
    # 0x2356F: '',  # 𣕯
    # 0x23570: '',  # 𣕰
    # 0x23571: '',  # 𣕱
    # 0x23572: '',  # 𣕲
    # 0x23573: '',  # 𣕳
    # 0x23574: '',  # 𣕴
    # 0x23575: '',  # 𣕵
    # 0x23576: '',  # 𣕶
    # 0x23577: '',  # 𣕷
    # 0x23578: '',  # 𣕸
    # 0x23579: '',  # 𣕹
    # 0x2357A: '',  # 𣕺
    # 0x2357B: '',  # 𣕻
    # 0x2357C: '',  # 𣕼
    # 0x2357D: '',  # 𣕽
    0x2357E: 'chóu,bì',  # 𣕾
    # 0x2357F: '',  # 𣕿
    # 0x23580: '',  # 𣖀
    # 0x23581: '',  # 𣖁
    # 0x23582: '',  # 𣖂
    # 0x23583: '',  # 𣖃
    0x23584: 'qiāo',  # 𣖄
    0x23585: 'tí',  # 𣖅
    0x23586: 'yún',  # 𣖆
    # 0x23587: '',  # 𣖇
    # 0x23588: '',  # 𣖈
    0x23589: 'shān',  # 𣖉
    0x2358A: 'liè,lì',  # 𣖊
    # 0x2358B: '',  # 𣖋
    0x2358C: 'zhǐ',  # 𣖌
    # 0x2358D: '',  # 𣖍
    # 0x2358E: '',  # 𣖎
    # 0x2358F: '',  # 𣖏
    0x23590: 'pāi',  # 𣖐
    # 0x23591: '',  # 𣖑
    # 0x23592: '',  # 𣖒
    # 0x23593: '',  # 𣖓
    # 0x23594: '',  # 𣖔
    # 0x23595: '',  # 𣖕
    # 0x23596: '',  # 𣖖
    # 0x23597: '',  # 𣖗
    # 0x23598: '',  # 𣖘
    # 0x23599: '',  # 𣖙
    # 0x2359A: '',  # 𣖚
    # 0x2359B: '',  # 𣖛
    # 0x2359C: '',  # 𣖜
    # 0x2359D: '',  # 𣖝
    # 0x2359E: '',  # 𣖞
    # 0x2359F: '',  # 𣖟
    # 0x235A0: '',  # 𣖠
    # 0x235A1: '',  # 𣖡
    # 0x235A2: '',  # 𣖢
    0x235A3: 'jú',  # 𣖣
    0x235A4: 'lái',  # 𣖤
    # 0x235A5: '',  # 𣖥
    # 0x235A6: '',  # 𣖦
    # 0x235A7: '',  # 𣖧
    0x235A8: 'zǐ',  # 𣖨
    # 0x235A9: '',  # 𣖩
    0x235AA: 'qú',  # 𣖪
    0x235AB: 'gǔ,què',  # 𣖫
    0x235AC: 'jué',  # 𣖬
    0x235AD: 'zhí',  # 𣖭
    0x235AE: 'àng',  # 𣖮
    0x235AF: 'qìn',  # 𣖯
    0x235B0: 'pí',  # 𣖰
    0x235B1: 'zuī',  # 𣖱
    # 0x235B2: '',  # 𣖲
    0x235B3: 'qián',  # 𣖳
    # 0x235B4: '',  # 𣖴
    0x235B5: 'cuó',  # 𣖵
    # 0x235B6: '',  # 𣖶
    0x235B7: 'jí',  # 𣖷
    0x235B8: 'tí',  # 𣖸
    0x235B9: 'rú',  # 𣖹
    # 0x235BA: '',  # 𣖺
    0x235BB: 'hǎi',  # 𣖻
    0x235BC: 'xún',  # 𣖼
    # 0x235BD: '',  # 𣖽
    0x235BE: 'bèi',  # 𣖾
    0x235BF: 'zhí',  # 𣖿
    # 0x235C0: '',  # 𣗀
    0x235C1: 'dùn,zā',  # 𣗁
    # 0x235C2: '',  # 𣗂
    # 0x235C3: '',  # 𣗃
    # 0x235C4: '',  # 𣗄
    # 0x235C5: '',  # 𣗅
    # 0x235C6: '',  # 𣗆
    # 0x235C7: '',  # 𣗇
    # 0x235C8: '',  # 𣗈
    # 0x235C9: '',  # 𣗉
    # 0x235CA: '',  # 𣗊
    # 0x235CB: '',  # 𣗋
    # 0x235CC: '',  # 𣗌
    # 0x235CD: '',  # 𣗍
    # 0x235CE: '',  # 𣗎
    # 0x235CF: '',  # 𣗏
    0x235D0: 'réng',  # 𣗐
    # 0x235D1: '',  # 𣗑
    # 0x235D2: '',  # 𣗒
    # 0x235D3: '',  # 𣗓
    # 0x235D4: '',  # 𣗔
    # 0x235D5: '',  # 𣗕
    # 0x235D6: '',  # 𣗖
    # 0x235D7: '',  # 𣗗
    # 0x235D8: '',  # 𣗘
    # 0x235D9: '',  # 𣗙
    # 0x235DA: '',  # 𣗚
    # 0x235DB: '',  # 𣗛
    # 0x235DC: '',  # 𣗜
    # 0x235DD: '',  # 𣗝
    # 0x235DE: '',  # 𣗞
    # 0x235DF: '',  # 𣗟
    # 0x235E0: '',  # 𣗠
    # 0x235E1: '',  # 𣗡
    # 0x235E2: '',  # 𣗢
    # 0x235E3: '',  # 𣗣
    # 0x235E4: '',  # 𣗤
    # 0x235E5: '',  # 𣗥
    # 0x235E6: '',  # 𣗦
    # 0x235E7: '',  # 𣗧
    # 0x235E8: '',  # 𣗨
    # 0x235E9: '',  # 𣗩
    # 0x235EA: '',  # 𣗪
    # 0x235EB: '',  # 𣗫
    0x235EC: 'chòu',  # 𣗬
    # 0x235ED: '',  # 𣗭
    # 0x235EE: '',  # 𣗮
    # 0x235EF: '',  # 𣗯
    # 0x235F0: '',  # 𣗰
    # 0x235F1: '',  # 𣗱
    0x235F2: 'gān',  # 𣗲
    0x235F3: 'shù',  # 𣗳
    # 0x235F4: '',  # 𣗴
    0x235F5: 'gàng,gāng',  # 𣗵
    0x235F6: 'tà',  # 𣗶
    # 0x235F7: '',  # 𣗷
    0x235F8: 'tuò',  # 𣗸
    0x235F9: 'yàng',  # 𣗹
    0x235FA: 'kū',  # 𣗺
    0x235FB: 'zhì',  # 𣗻
    # 0x235FC: '',  # 𣗼
    # 0x235FD: '',  # 𣗽
    # 0x235FE: '',  # 𣗾
    # 0x235FF: '',  # 𣗿
    # 0x23600: '',  # 𣘀
    # 0x23601: '',  # 𣘁
    # 0x23602: '',  # 𣘂
    # 0x23603: '',  # 𣘃
    # 0x23604: '',  # 𣘄
    # 0x23605: '',  # 𣘅
    # 0x23606: '',  # 𣘆
    # 0x23607: '',  # 𣘇
    # 0x23608: '',  # 𣘈
    # 0x23609: '',  # 𣘉
    # 0x2360A: '',  # 𣘊
    # 0x2360B: '',  # 𣘋
    # 0x2360C: '',  # 𣘌
    # 0x2360D: '',  # 𣘍
    # 0x2360E: '',  # 𣘎
    # 0x2360F: '',  # 𣘏
    # 0x23610: '',  # 𣘐
    # 0x23611: '',  # 𣘑
    # 0x23612: '',  # 𣘒
    # 0x23613: '',  # 𣘓
    # 0x23614: '',  # 𣘔
    # 0x23615: '',  # 𣘕
    0x23616: 'jiān',  # 𣘖
    0x23617: 'nì',  # 𣘗
    0x23618: 'shēn,zhēn',  # 𣘘
    0x23619: 'bàng',  # 𣘙
    0x2361A: 'shuài',  # 𣘚
    0x2361B: 'dōu',  # 𣘛
    # 0x2361C: '',  # 𣘜
    0x2361D: 'qiān',  # 𣘝
    0x2361E: 'hán',  # 𣘞
    0x2361F: 'qiā',  # 𣘟
    0x23620: 'gǎn',  # 𣘠
    # 0x23621: '',  # 𣘡
    # 0x23622: '',  # 𣘢
    0x23623: 'chún',  # 𣘣
    0x23624: 'chá,sà',  # 𣘤
    0x23625: 'bì',  # 𣘥
    0x23626: 'yī',  # 𣘦
    0x23627: 'fū',  # 𣘧
    0x23628: 'ě,ē',  # 𣘨
    # 0x23629: '',  # 𣘩
    0x2362A: 'láo',  # 𣘪
    0x2362B: 'háo',  # 𣘫
    0x2362C: 'lí',  # 𣘬
    # 0x2362D: '',  # 𣘭
    # 0x2362E: '',  # 𣘮
    # 0x2362F: '',  # 𣘯
    # 0x23630: '',  # 𣘰
    0x23631: 'tè',  # 𣘱
    0x23632: 'shēn',  # 𣘲
    # 0x23633: '',  # 𣘳
    # 0x23634: '',  # 𣘴
    # 0x23635: '',  # 𣘵
    # 0x23636: '',  # 𣘶
    # 0x23637: '',  # 𣘷
    # 0x23638: '',  # 𣘸
    # 0x23639: '',  # 𣘹
    # 0x2363A: '',  # 𣘺
    0x2363B: 'chá,tú',  # 𣘻
    # 0x2363C: '',  # 𣘼
    # 0x2363D: '',  # 𣘽
    # 0x2363E: '',  # 𣘾
    # 0x2363F: '',  # 𣘿
    # 0x23640: '',  # 𣙀
    # 0x23641: '',  # 𣙁
    # 0x23642: '',  # 𣙂
    # 0x23643: '',  # 𣙃
    # 0x23644: '',  # 𣙄
    # 0x23645: '',  # 𣙅
    # 0x23646: '',  # 𣙆
    # 0x23647: '',  # 𣙇
    # 0x23648: '',  # 𣙈
    # 0x23649: '',  # 𣙉
    # 0x2364A: '',  # 𣙊
    # 0x2364B: '',  # 𣙋
    # 0x2364C: '',  # 𣙌
    # 0x2364D: '',  # 𣙍
    # 0x2364E: '',  # 𣙎
    # 0x2364F: '',  # 𣙏
    # 0x23650: '',  # 𣙐
    # 0x23651: '',  # 𣙑
    # 0x23652: '',  # 𣙒
    # 0x23653: '',  # 𣙓
    # 0x23654: '',  # 𣙔
    # 0x23655: '',  # 𣙕
    # 0x23656: '',  # 𣙖
    0x23657: 'niè',  # 𣙗
    0x23658: 'còu',  # 𣙘
    # 0x23659: '',  # 𣙙
    # 0x2365A: '',  # 𣙚
    0x2365B: 'yí',  # 𣙛
    # 0x2365C: '',  # 𣙜
    # 0x2365D: '',  # 𣙝
    # 0x2365E: '',  # 𣙞
    0x2365F: 'táng',  # 𣙟
    # 0x23660: '',  # 𣙠
    # 0x23661: '',  # 𣙡
    0x23662: 'juàn',  # 𣙢
    # 0x23663: '',  # 𣙣
    # 0x23664: '',  # 𣙤
    # 0x23665: '',  # 𣙥
    # 0x23666: '',  # 𣙦
    # 0x23667: '',  # 𣙧
    # 0x23668: '',  # 𣙨
    # 0x23669: '',  # 𣙩
    # 0x2366A: '',  # 𣙪
    # 0x2366B: '',  # 𣙫
    # 0x2366C: '',  # 𣙬
    # 0x2366D: '',  # 𣙭
    # 0x2366E: '',  # 𣙮
    # 0x2366F: '',  # 𣙯
    0x23670: 'chì',  # 𣙰
    0x23671: 'gǒu',  # 𣙱
    # 0x23672: '',  # 𣙲
    # 0x23673: '',  # 𣙳
    0x23674: 'jié',  # 𣙴
    0x23675: 'zhé',  # 𣙵
    0x23676: 'hú',  # 𣙶
    0x23677: 'máng',  # 𣙷
    # 0x23678: '',  # 𣙸
    # 0x23679: '',  # 𣙹
    # 0x2367A: '',  # 𣙺
    0x2367B: 'zōu',  # 𣙻
    0x2367C: 'sì,cí',  # 𣙼
    # 0x2367D: '',  # 𣙽
    # 0x2367E: '',  # 𣙾
    0x2367F: 'fèi',  # 𣙿
    0x23680: 'zī',  # 𣚀
    0x23681: 'zī',  # 𣚁
    # 0x23682: '',  # 𣚂
    0x23683: 'jié',  # 𣚃
    0x23684: 'sī',  # 𣚄
    # 0x23685: '',  # 𣚅
    0x23686: 'chūn',  # 𣚆
    0x23687: 'pào',  # 𣚇
    # 0x23688: '',  # 𣚈
    # 0x23689: '',  # 𣚉
    # 0x2368A: '',  # 𣚊
    0x2368B: 'yé',  # 𣚋
    0x2368C: 'dī,shì',  # 𣚌
    0x2368D: 'yì',  # 𣚍
    0x2368E: 'léi',  # 𣚎
    0x2368F: 'xū',  # 𣚏
    0x23690: 'rú',  # 𣚐
    # 0x23691: '',  # 𣚑
    0x23692: 'pá',  # 𣚒
    0x23693: 'juàn',  # 𣚓
    0x23694: 'xì',  # 𣚔
    0x23695: 'yè,yǎn',  # 𣚕
    0x23696: 'ān',  # 𣚖
    # 0x23697: '',  # 𣚗
    0x23698: 'yì',  # 𣚘
    0x23699: 'jiān,jiàn',  # 𣚙
    # 0x2369A: '',  # 𣚚
    # 0x2369B: '',  # 𣚛
    0x2369C: 'sōng',  # 𣚜
    0x2369D: 'wǒ',  # 𣚝
    # 0x2369E: '',  # 𣚞
    0x2369F: 'sè',  # 𣚟
    0x236A0: 'zhǐ',  # 𣚠
    0x236A1: 'bī',  # 𣚡
    0x236A2: 'zhuàn',  # 𣚢
    # 0x236A3: '',  # 𣚣
    # 0x236A4: '',  # 𣚤
    # 0x236A5: '',  # 𣚥
    0x236A6: 'jiàng',  # 𣚦
    0x236A7: 'hào',  # 𣚧
    # 0x236A8: '',  # 𣚨
    0x236A9: 'chì',  # 𣚩
    0x236AA: 'dùn',  # 𣚪
    # 0x236AB: '',  # 𣚫
    # 0x236AC: '',  # 𣚬
    # 0x236AD: '',  # 𣚭
    # 0x236AE: '',  # 𣚮
    # 0x236AF: '',  # 𣚯
    # 0x236B0: '',  # 𣚰
    # 0x236B1: '',  # 𣚱
    # 0x236B2: '',  # 𣚲
    # 0x236B3: '',  # 𣚳
    # 0x236B4: '',  # 𣚴
    # 0x236B5: '',  # 𣚵
    # 0x236B6: '',  # 𣚶
    # 0x236B7: '',  # 𣚷
    # 0x236B8: '',  # 𣚸
    # 0x236B9: '',  # 𣚹
    # 0x236BA: '',  # 𣚺
    # 0x236BB: '',  # 𣚻
    # 0x236BC: '',  # 𣚼
    # 0x236BD: '',  # 𣚽
    # 0x236BE: '',  # 𣚾
    # 0x236BF: '',  # 𣚿
    # 0x236C0: '',  # 𣛀
    # 0x236C1: '',  # 𣛁
    # 0x236C2: '',  # 𣛂
    # 0x236C3: '',  # 𣛃
    # 0x236C4: '',  # 𣛄
    # 0x236C5: '',  # 𣛅
    # 0x236C6: '',  # 𣛆
    # 0x236C7: '',  # 𣛇
    # 0x236C8: '',  # 𣛈
    # 0x236C9: '',  # 𣛉
    # 0x236CA: '',  # 𣛊
    # 0x236CB: '',  # 𣛋
    # 0x236CC: '',  # 𣛌
    # 0x236CD: '',  # 𣛍
    # 0x236CE: '',  # 𣛎
    # 0x236CF: '',  # 𣛏
    # 0x236D0: '',  # 𣛐
    # 0x236D1: '',  # 𣛑
    # 0x236D2: '',  # 𣛒
    0x236D3: 'bó',  # 𣛓
    0x236D4: 'jí',  # 𣛔
    0x236D5: 'chuǎ',  # 𣛕
    # 0x236D6: '',  # 𣛖
    0x236D7: 'luò',  # 𣛗
    # 0x236D8: '',  # 𣛘
    # 0x236D9: '',  # 𣛙
    0x236DA: 'ruǐ',  # 𣛚
    # 0x236DB: '',  # 𣛛
    # 0x236DC: '',  # 𣛜
    # 0x236DD: '',  # 𣛝
    # 0x236DE: '',  # 𣛞
    # 0x236DF: '',  # 𣛟
    # 0x236E0: '',  # 𣛠
    # 0x236E1: '',  # 𣛡
    # 0x236E2: '',  # 𣛢
    # 0x236E3: '',  # 𣛣
    # 0x236E4: '',  # 𣛤
    # 0x236E5: '',  # 𣛥
    # 0x236E6: '',  # 𣛦
    # 0x236E7: '',  # 𣛧
    # 0x236E8: '',  # 𣛨
    # 0x236E9: '',  # 𣛩
    # 0x236EA: '',  # 𣛪
    0x236EB: 'hú',  # 𣛫
    # 0x236EC: '',  # 𣛬
    # 0x236ED: '',  # 𣛭
    0x236EE: 'shēng',  # 𣛮
    # 0x236EF: '',  # 𣛯
    # 0x236F0: '',  # 𣛰
    0x236F1: 'dàn,lǎn',  # 𣛱
    # 0x236F2: '',  # 𣛲
    # 0x236F3: '',  # 𣛳
    0x236F4: 'hǎn',  # 𣛴
    0x236F5: 'què',  # 𣛵
    0x236F6: 'shā',  # 𣛶
    0x236F7: 'zhǎn',  # 𣛷
    0x236F8: 'zé',  # 𣛸
    0x236F9: 'chuán,chuǎi',  # 𣛹
    0x236FA: 'qī',  # 𣛺
    0x236FB: 'dié',  # 𣛻
    # 0x236FC: '',  # 𣛼
    0x236FD: 'zhà',  # 𣛽
    0x236FE: 'tòu',  # 𣛾
    # 0x236FF: '',  # 𣛿
    # 0x23700: '',  # 𣜀
    0x23701: 'cī',  # 𣜁
    0x23702: 'sà',  # 𣜂
    # 0x23703: '',  # 𣜃
    0x23704: 'luó',  # 𣜄
    # 0x23705: '',  # 𣜅
    # 0x23706: '',  # 𣜆
    0x23707: 'jí',  # 𣜇
    # 0x23708: '',  # 𣜈
    # 0x23709: '',  # 𣜉
    # 0x2370A: '',  # 𣜊
    # 0x2370B: '',  # 𣜋
    # 0x2370C: '',  # 𣜌
    # 0x2370D: '',  # 𣜍
    # 0x2370E: '',  # 𣜎
    # 0x2370F: '',  # 𣜏
    # 0x23710: '',  # 𣜐
    # 0x23711: '',  # 𣜑
    # 0x23712: '',  # 𣜒
    # 0x23713: '',  # 𣜓
    # 0x23714: '',  # 𣜔
    # 0x23715: '',  # 𣜕
    # 0x23716: '',  # 𣜖
    # 0x23717: '',  # 𣜗
    # 0x23718: '',  # 𣜘
    # 0x23719: '',  # 𣜙
    # 0x2371A: '',  # 𣜚
    # 0x2371B: '',  # 𣜛
    # 0x2371C: '',  # 𣜜
    # 0x2371D: '',  # 𣜝
    # 0x2371E: '',  # 𣜞
    # 0x2371F: '',  # 𣜟
    # 0x23720: '',  # 𣜠
    # 0x23721: '',  # 𣜡
    0x23722: 'luǒ',  # 𣜢
    0x23723: 'qín',  # 𣜣
    # 0x23724: '',  # 𣜤
    # 0x23725: '',  # 𣜥
    0x23726: 'dào',  # 𣜦
    0x23727: 'qióng',  # 𣜧
    0x23728: 'juàn',  # 𣜨
    # 0x23729: '',  # 𣜩
    # 0x2372A: '',  # 𣜪
    # 0x2372B: '',  # 𣜫
    0x2372C: 'ài',  # 𣜬
    0x2372D: 'jiǎn',  # 𣜭
    # 0x2372E: '',  # 𣜮
    # 0x2372F: '',  # 𣜯
    # 0x23730: '',  # 𣜰
    # 0x23731: '',  # 𣜱
    # 0x23732: '',  # 𣜲
    # 0x23733: '',  # 𣜳
    # 0x23734: '',  # 𣜴
    # 0x23735: '',  # 𣜵
    # 0x23736: '',  # 𣜶
    # 0x23737: '',  # 𣜷
    # 0x23738: '',  # 𣜸
    0x23739: 'tì',  # 𣜹
    0x2373A: 'wén',  # 𣜺
    # 0x2373B: '',  # 𣜻
    # 0x2373C: '',  # 𣜼
    0x2373D: 'qiāo',  # 𣜽
    # 0x2373E: '',  # 𣜾
    # 0x2373F: '',  # 𣜿
    # 0x23740: '',  # 𣝀
    0x23741: 'pái,bēi',  # 𣝁
    0x23742: 'hún',  # 𣝂
    # 0x23743: '',  # 𣝃
    # 0x23744: '',  # 𣝄
    0x23745: 'ài',  # 𣝅
    # 0x23746: '',  # 𣝆
    0x23747: 'shuò',  # 𣝇
    0x23748: 'lián',  # 𣝈
    0x23749: 'duì',  # 𣝉
    # 0x2374A: '',  # 𣝊
    0x2374B: 'tà',  # 𣝋
    0x2374C: 'jǐn',  # 𣝌
    0x2374D: 'bì',  # 𣝍
    0x2374E: 'yǎn',  # 𣝎
    0x2374F: 'gào',  # 𣝏
    0x23750: 'piáo',  # 𣝐
    0x23751: 'yù,yú',  # 𣝑
    0x23752: 'shè',  # 𣝒
    # 0x23753: '',  # 𣝓
    # 0x23754: '',  # 𣝔
    0x23755: 'jiān',  # 𣝕
    # 0x23756: '',  # 𣝖
    0x23757: 'hú',  # 𣝗
    # 0x23758: '',  # 𣝘
    # 0x23759: '',  # 𣝙
    0x2375A: 'liè',  # 𣝚
    # 0x2375B: '',  # 𣝛
    0x2375C: 'biàn',  # 𣝜
    0x2375D: 'sù',  # 𣝝
    0x2375E: 'jiāo',  # 𣝞
    # 0x2375F: '',  # 𣝟
    # 0x23760: '',  # 𣝠
    # 0x23761: '',  # 𣝡
    # 0x23762: '',  # 𣝢
    # 0x23763: '',  # 𣝣
    # 0x23764: '',  # 𣝤
    # 0x23765: '',  # 𣝥
    # 0x23766: '',  # 𣝦
    # 0x23767: '',  # 𣝧
    # 0x23768: '',  # 𣝨
    # 0x23769: '',  # 𣝩
    # 0x2376A: '',  # 𣝪
    # 0x2376B: '',  # 𣝫
    # 0x2376C: '',  # 𣝬
    # 0x2376D: '',  # 𣝭
    # 0x2376E: '',  # 𣝮
    # 0x2376F: '',  # 𣝯
    # 0x23770: '',  # 𣝰
    # 0x23771: '',  # 𣝱
    # 0x23772: '',  # 𣝲
    # 0x23773: '',  # 𣝳
    # 0x23774: '',  # 𣝴
    # 0x23775: '',  # 𣝵
    # 0x23776: '',  # 𣝶
    # 0x23777: '',  # 𣝷
    0x23778: 'zhuì',  # 𣝸
    # 0x23779: '',  # 𣝹
    # 0x2377A: '',  # 𣝺
    # 0x2377B: '',  # 𣝻
    0x2377C: 'mián',  # 𣝼
    0x2377D: 'hān',  # 𣝽
    # 0x2377E: '',  # 𣝾
    # 0x2377F: '',  # 𣝿
    # 0x23780: '',  # 𣞀
    # 0x23781: '',  # 𣞁
    # 0x23782: '',  # 𣞂
    # 0x23783: '',  # 𣞃
    # 0x23784: '',  # 𣞄
    # 0x23785: '',  # 𣞅
    # 0x23786: '',  # 𣞆
    0x23787: 'dùn',  # 𣞇
    # 0x23788: '',  # 𣞈
    # 0x23789: '',  # 𣞉
    # 0x2378A: '',  # 𣞊
    # 0x2378B: '',  # 𣞋
    # 0x2378C: '',  # 𣞌
    # 0x2378D: '',  # 𣞍
    # 0x2378E: '',  # 𣞎
    # 0x2378F: '',  # 𣞏
    0x23790: 'xiě',  # 𣞐
    0x23791: 'méng',  # 𣞑
    0x23792: 'fū',  # 𣞒
    0x23793: 'lù',  # 𣞓
    0x23794: 'tàn',  # 𣞔
    0x23795: 'yì',  # 𣞕
    # 0x23796: '',  # 𣞖
    0x23797: 'liú',  # 𣞗
    0x23798: 'xiān',  # 𣞘
    0x23799: 'sǎng',  # 𣞙
    # 0x2379A: '',  # 𣞚
    # 0x2379B: '',  # 𣞛
    0x2379C: 'còu',  # 𣞜
    0x2379D: 'zhuāng',  # 𣞝
    # 0x2379E: '',  # 𣞞
    0x2379F: 'chēn',  # 𣞟
    # 0x237A0: '',  # 𣞠
    # 0x237A1: '',  # 𣞡
    # 0x237A2: '',  # 𣞢
    # 0x237A3: '',  # 𣞣
    0x237A4: 'wú',  # 𣞤
    # 0x237A5: '',  # 𣞥
    # 0x237A6: '',  # 𣞦
    # 0x237A7: '',  # 𣞧
    # 0x237A8: '',  # 𣞨
    # 0x237A9: '',  # 𣞩
    # 0x237AA: '',  # 𣞪
    # 0x237AB: '',  # 𣞫
    # 0x237AC: '',  # 𣞬
    # 0x237AD: '',  # 𣞭
    # 0x237AE: '',  # 𣞮
    # 0x237AF: '',  # 𣞯
    0x237B0: 'liàn',  # 𣞰
    # 0x237B1: '',  # 𣞱
    # 0x237B2: '',  # 𣞲
    # 0x237B3: '',  # 𣞳
    0x237B4: 'lí',  # 𣞴
    # 0x237B5: '',  # 𣞵
    # 0x237B6: '',  # 𣞶
    # 0x237B7: '',  # 𣞷
    # 0x237B8: '',  # 𣞸
    # 0x237B9: '',  # 𣞹
    # 0x237BA: '',  # 𣞺
    # 0x237BB: '',  # 𣞻
    # 0x237BC: '',  # 𣞼
    # 0x237BD: '',  # 𣞽
    # 0x237BE: '',  # 𣞾
    # 0x237BF: '',  # 𣞿
    0x237C0: 'pèng',  # 𣟀
    0x237C1: 'tuǒ',  # 𣟁
    # 0x237C2: '',  # 𣟂
    # 0x237C3: '',  # 𣟃
    0x237C4: 'tuò',  # 𣟄
    # 0x237C5: '',  # 𣟅
    0x237C6: 'liáo',  # 𣟆
    0x237C7: 'xiào',  # 𣟇
    0x237C8: 'chuì',  # 𣟈
    0x237C9: 'huài',  # 𣟉
    0x237CA: 'niǎo',  # 𣟊
    0x237CB: 'qiān',  # 𣟋
    0x237CC: 'lì',  # 𣟌
    # 0x237CD: '',  # 𣟍
    # 0x237CE: '',  # 𣟎
    0x237CF: 'pāo',  # 𣟏
    0x237D0: 'tiáo',  # 𣟐
    0x237D1: 'liú',  # 𣟑
    0x237D2: 'wú',  # 𣟒
    # 0x237D3: '',  # 𣟓
    # 0x237D4: '',  # 𣟔
    # 0x237D5: '',  # 𣟕
    # 0x237D6: '',  # 𣟖
    # 0x237D7: '',  # 𣟗
    # 0x237D8: '',  # 𣟘
    # 0x237D9: '',  # 𣟙
    # 0x237DA: '',  # 𣟚
    # 0x237DB: '',  # 𣟛
    # 0x237DC: '',  # 𣟜
    # 0x237DD: '',  # 𣟝
    # 0x237DE: '',  # 𣟞
    # 0x237DF: '',  # 𣟟
    # 0x237E0: '',  # 𣟠
    # 0x237E1: '',  # 𣟡
    # 0x237E2: '',  # 𣟢
    # 0x237E3: '',  # 𣟣
    0x237E4: 'yǐng',  # 𣟤
    # 0x237E5: '',  # 𣟥
    0x237E6: 'zhá',  # 𣟦
    # 0x237E7: '',  # 𣟧
    # 0x237E8: '',  # 𣟨
    # 0x237E9: '',  # 𣟩
    # 0x237EA: '',  # 𣟪
    # 0x237EB: '',  # 𣟫
    # 0x237EC: '',  # 𣟬
    # 0x237ED: '',  # 𣟭
    # 0x237EE: '',  # 𣟮
    # 0x237EF: '',  # 𣟯
    0x237F0: 'yú',  # 𣟰
    # 0x237F1: '',  # 𣟱
    0x237F2: 'xiǎn',  # 𣟲
    0x237F3: 'xuán',  # 𣟳
    # 0x237F4: '',  # 𣟴
    0x237F5: 'xī',  # 𣟵
    # 0x237F6: '',  # 𣟶
    # 0x237F7: '',  # 𣟷
    0x237F8: 'méi',  # 𣟸
    0x237F9: 'sēn',  # 𣟹
    0x237FA: 'liàn',  # 𣟺
    # 0x237FB: '',  # 𣟻
    0x237FC: 'jiū,qiāo',  # 𣟼
    0x237FD: 'lào',  # 𣟽
    # 0x237FE: '',  # 𣟾
    # 0x237FF: '',  # 𣟿
    # 0x23800: '',  # 𣠀
    # 0x23801: '',  # 𣠁
    # 0x23802: '',  # 𣠂
    # 0x23803: '',  # 𣠃
    # 0x23804: '',  # 𣠄
    # 0x23805: '',  # 𣠅
    # 0x23806: '',  # 𣠆
    # 0x23807: '',  # 𣠇
    # 0x23808: '',  # 𣠈
    # 0x23809: '',  # 𣠉
    # 0x2380A: '',  # 𣠊
    # 0x2380B: '',  # 𣠋
    # 0x2380C: '',  # 𣠌
    # 0x2380D: '',  # 𣠍
    0x2380E: 'xiāo',  # 𣠎
    0x2380F: 'zōu',  # 𣠏
    # 0x23810: '',  # 𣠐
    # 0x23811: '',  # 𣠑
    # 0x23812: '',  # 𣠒
    # 0x23813: '',  # 𣠓
    # 0x23814: '',  # 𣠔
    # 0x23815: '',  # 𣠕
    # 0x23816: '',  # 𣠖
    # 0x23817: '',  # 𣠗
    # 0x23818: '',  # 𣠘
    # 0x23819: '',  # 𣠙
    0x2381A: 'liú',  # 𣠚
    # 0x2381B: '',  # 𣠛
    0x2381C: 'zhào',  # 𣠜
    # 0x2381D: '',  # 𣠝
    0x2381E: 'zhé,shè',  # 𣠞
    # 0x2381F: '',  # 𣠟
    0x23820: 'lěi',  # 𣠠
    # 0x23821: '',  # 𣠡
    # 0x23822: '',  # 𣠢
    # 0x23823: '',  # 𣠣
    # 0x23824: '',  # 𣠤
    # 0x23825: '',  # 𣠥
    # 0x23826: '',  # 𣠦
    # 0x23827: '',  # 𣠧
    # 0x23828: '',  # 𣠨
    # 0x23829: '',  # 𣠩
    # 0x2382A: '',  # 𣠪
    # 0x2382B: '',  # 𣠫
    # 0x2382C: '',  # 𣠬
    0x2382D: 'duǎn',  # 𣠭
    # 0x2382E: '',  # 𣠮
    # 0x2382F: '',  # 𣠯
    # 0x23830: '',  # 𣠰
    # 0x23831: '',  # 𣠱
    # 0x23832: '',  # 𣠲
    # 0x23833: '',  # 𣠳
    # 0x23834: '',  # 𣠴
    # 0x23835: '',  # 𣠵
    # 0x23836: '',  # 𣠶
    0x23837: 'jiǎn',  # 𣠷
    0x23838: 'shuān',  # 𣠸
    0x23839: 'zuó',  # 𣠹
    0x2383A: 'qiè',  # 𣠺
    # 0x2383B: '',  # 𣠻
    0x2383C: 'lǎo',  # 𣠼
    # 0x2383D: '',  # 𣠽
    # 0x2383E: '',  # 𣠾
    # 0x2383F: '',  # 𣠿
    # 0x23840: '',  # 𣡀
    # 0x23841: '',  # 𣡁
    # 0x23842: '',  # 𣡂
    # 0x23843: '',  # 𣡃
    # 0x23844: '',  # 𣡄
    # 0x23845: '',  # 𣡅
    # 0x23846: '',  # 𣡆
    # 0x23847: '',  # 𣡇
    # 0x23848: '',  # 𣡈
    0x23849: 'yù',  # 𣡉
    0x2384A: 'yì',  # 𣡊
    0x2384B: 'nǐ',  # 𣡋
    0x2384C: 'niè',  # 𣡌
    # 0x2384D: '',  # 𣡍
    0x2384E: 'cén',  # 𣡎
    # 0x2384F: '',  # 𣡏
    # 0x23850: '',  # 𣡐
    # 0x23851: '',  # 𣡑
    # 0x23852: '',  # 𣡒
    # 0x23853: '',  # 𣡓
    # 0x23854: '',  # 𣡔
    0x23855: 'yàn',  # 𣡕
    # 0x23856: '',  # 𣡖
    0x23857: 'ruǎn',  # 𣡗
    # 0x23858: '',  # 𣡘
    # 0x23859: '',  # 𣡙
    # 0x2385A: '',  # 𣡚
    # 0x2385B: '',  # 𣡛
    # 0x2385C: '',  # 𣡜
    # 0x2385D: '',  # 𣡝
    0x2385E: 'yán',  # 𣡞
    0x2385F: 'dié',  # 𣡟
    0x23860: 'mián',  # 𣡠
    # 0x23861: '',  # 𣡡
    # 0x23862: '',  # 𣡢
    # 0x23863: '',  # 𣡣
    # 0x23864: '',  # 𣡤
    # 0x23865: '',  # 𣡥
    # 0x23866: '',  # 𣡦
    0x23867: 'léi',  # 𣡧
    # 0x23868: '',  # 𣡨
    0x23869: 'wān',  # 𣡩
    # 0x2386A: '',  # 𣡪
    # 0x2386B: '',  # 𣡫
    # 0x2386C: '',  # 𣡬
    # 0x2386D: '',  # 𣡭
    # 0x2386E: '',  # 𣡮
    # 0x2386F: '',  # 𣡯
    0x23870: 'nǎ',  # 𣡰
    # 0x23871: '',  # 𣡱
    # 0x23872: '',  # 𣡲
    # 0x23873: '',  # 𣡳
    # 0x23874: '',  # 𣡴
    # 0x23875: '',  # 𣡵
    0x23876: 'yán',  # 𣡶
    # 0x23877: '',  # 𣡷
    # 0x23878: '',  # 𣡸
    # 0x23879: '',  # 𣡹
    0x2387A: 'lěi',  # 𣡺
    # 0x2387B: '',  # 𣡻
    # 0x2387C: '',  # 𣡼
    0x2387D: 'shā',  # 𣡽
    0x2387E: 'hū',  # 𣡾
    # 0x2387F: '',  # 𣡿
    # 0x23880: '',  # 𣢀
    0x23881: 'xī',  # 𣢁
    0x23882: 'xī',  # 𣢂
    # 0x23883: '',  # 𣢃
    0x23884: 'yǒu,yōu',  # 𣢄
    0x23885: 'hān',  # 𣢅
    0x23886: 'jì',  # 𣢆
    0x23887: 'hāi,xī',  # 𣢇
    # 0x23888: '',  # 𣢈
    0x23889: 'wā',  # 𣢉
    0x2388A: 'xù',  # 𣢊
    0x2388B: 'pī',  # 𣢋
    0x2388C: 'tān',  # 𣢌
    0x2388D: 'xī',  # 𣢍
    0x2388E: 'xī',  # 𣢎
    0x2388F: 'bīn',  # 𣢏
    0x23890: 'qīn,kēng',  # 𣢐
    0x23891: 'xī',  # 𣢑
    0x23892: 'yú',  # 𣢒
    0x23893: 'xì',  # 𣢓
    # 0x23894: '',  # 𣢔
    0x23895: 'cì',  # 𣢕
    0x23896: 'qiàn',  # 𣢖
    0x23897: 'xiā',  # 𣢗
    # 0x23898: '',  # 𣢘
    # 0x23899: '',  # 𣢙
    0x2389A: 'wá',  # 𣢚
    0x2389B: 'è',  # 𣢛
    0x2389C: 'yǒu,yōu',  # 𣢜
    0x2389D: 'xìng',  # 𣢝
    0x2389E: 'ní',  # 𣢞
    0x2389F: 'hán,xián',  # 𣢟
    0x238A0: 'bì',  # 𣢠
    0x238A1: 'shēng',  # 𣢡
    # 0x238A2: '',  # 𣢢
    # 0x238A3: '',  # 𣢣
    0x238A4: 'zhān',  # 𣢤
    0x238A5: 'diàn',  # 𣢥
    0x238A6: 'yǔ',  # 𣢦
    # 0x238A7: '',  # 𣢧
    0x238A8: 'ǒu',  # 𣢨
    # 0x238A9: '',  # 𣢩
    0x238AA: 'guǐ',  # 𣢪
    0x238AB: 'wǎng,wāng',  # 𣢫
    0x238AC: 'qiān',  # 𣢬
    0x238AD: 'yí',  # 𣢭
    # 0x238AE: '',  # 𣢮
    # 0x238AF: '',  # 𣢯
    0x238B0: 'zú',  # 𣢰
    # 0x238B1: '',  # 𣢱
    0x238B2: 'qiān',  # 𣢲
    0x238B3: 'dìng',  # 𣢳
    0x238B4: 'kēng',  # 𣢴
    # 0x238B5: '',  # 𣢵
    0x238B6: 'chù',  # 𣢶
    0x238B7: 'yī',  # 𣢷
    # 0x238B8: '',  # 𣢸
    # 0x238B9: '',  # 𣢹
    0x238BA: 'hān',  # 𣢺
    0x238BB: 'kuǎn',  # 𣢻
    # 0x238BC: '',  # 𣢼
    # 0x238BD: '',  # 𣢽
    # 0x238BE: '',  # 𣢾
    # 0x238BF: '',  # 𣢿
    # 0x238C0: '',  # 𣣀
    # 0x238C1: '',  # 𣣁
    # 0x238C2: '',  # 𣣂
    # 0x238C3: '',  # 𣣃
    # 0x238C4: '',  # 𣣄
    # 0x238C5: '',  # 𣣅
    # 0x238C6: '',  # 𣣆
    # 0x238C7: '',  # 𣣇
    0x238C8: 'diàn',  # 𣣈
    0x238C9: 'xì',  # 𣣉
    0x238CA: 'zī',  # 𣣊
    0x238CB: 'líng',  # 𣣋
    0x238CC: 'zì,sì',  # 𣣌
    # 0x238CD: '',  # 𣣍
    0x238CE: 'yù',  # 𣣎
    0x238CF: 'hūn',  # 𣣏
    # 0x238D0: '',  # 𣣐
    0x238D1: 'sǐ',  # 𣣑
    0x238D2: 'kǎn',  # 𣣒
    # 0x238D3: '',  # 𣣓
    # 0x238D4: '',  # 𣣔
    # 0x238D5: '',  # 𣣕
    # 0x238D6: '',  # 𣣖
    # 0x238D7: '',  # 𣣗
    # 0x238D8: '',  # 𣣘
    # 0x238D9: '',  # 𣣙
    0x238DA: 'àn',  # 𣣚
    # 0x238DB: '',  # 𣣛
    0x238DC: 'yǒu',  # 𣣜
    0x238DD: 'jí',  # 𣣝
    0x238DE: 'hùn',  # 𣣞
    0x238DF: 'qiā',  # 𣣟
    0x238E0: 'hóu',  # 𣣠
    0x238E1: 'hóu',  # 𣣡
    # 0x238E2: '',  # 𣣢
    0x238E3: 'diàn',  # 𣣣
    # 0x238E4: '',  # 𣣤
    # 0x238E5: '',  # 𣣥
    # 0x238E6: '',  # 𣣦
    # 0x238E7: '',  # 𣣧
    # 0x238E8: '',  # 𣣨
    0x238E9: 'xiē',  # 𣣩
    # 0x238EA: '',  # 𣣪
    # 0x238EB: '',  # 𣣫
    # 0x238EC: '',  # 𣣬
    0x238ED: 'shè',  # 𣣭
    0x238EE: 'shà',  # 𣣮
    # 0x238EF: '',  # 𣣯
    # 0x238F0: '',  # 𣣰
    # 0x238F1: '',  # 𣣱
    0x238F2: 'xié',  # 𣣲
    0x238F3: 'yáo,yǎo',  # 𣣳
    0x238F4: 'dà',  # 𣣴
    0x238F5: 'yáo',  # 𣣵
    0x238F6: 'xiè',  # 𣣶
    0x238F7: 'chī',  # 𣣷
    0x238F8: 'yǒu',  # 𣣸
    0x238F9: 'hē',  # 𣣹
    0x238FA: 'shà',  # 𣣺
    # 0x238FB: '',  # 𣣻
    # 0x238FC: '',  # 𣣼
    # 0x238FD: '',  # 𣣽
    # 0x238FE: '',  # 𣣾
    0x238FF: 'tái',  # 𣣿
    # 0x23900: '',  # 𣤀
    0x23901: 'zhú',  # 𣤁
    # 0x23902: '',  # 𣤂
    0x23903: 'ǎi',  # 𣤃
    # 0x23904: '',  # 𣤄
    # 0x23905: '',  # 𣤅
    # 0x23906: '',  # 𣤆
    0x23907: 'què',  # 𣤇
    0x23908: 'zé',  # 𣤈
    # 0x23909: '',  # 𣤉
    0x2390A: 'lā',  # 𣤊
    0x2390B: 'lòu',  # 𣤋
    0x2390C: 'chuài,chǐ,chuò',  # 𣤌
    # 0x2390D: '',  # 𣤍
    0x2390E: 'yǒu',  # 𣤎
    # 0x2390F: '',  # 𣤏
    # 0x23910: '',  # 𣤐
    # 0x23911: '',  # 𣤑
    # 0x23912: '',  # 𣤒
    # 0x23913: '',  # 𣤓
    # 0x23914: '',  # 𣤔
    # 0x23915: '',  # 𣤕
    0x23916: 'tì',  # 𣤖
    # 0x23917: '',  # 𣤗
    0x23918: 'shī',  # 𣤘
    # 0x23919: '',  # 𣤙
    # 0x2391A: '',  # 𣤚
    # 0x2391B: '',  # 𣤛
    # 0x2391C: '',  # 𣤜
    # 0x2391D: '',  # 𣤝
    # 0x2391E: '',  # 𣤞
    # 0x2391F: '',  # 𣤟
    # 0x23920: '',  # 𣤠
    0x23921: 'xiào,yǒu',  # 𣤡
    0x23922: 'xì',  # 𣤢
    # 0x23923: '',  # 𣤣
    # 0x23924: '',  # 𣤤
    # 0x23925: '',  # 𣤥
    # 0x23926: '',  # 𣤦
    # 0x23927: '',  # 𣤧
    0x23928: 'huò',  # 𣤨
    0x23929: 'chì',  # 𣤩
    0x2392A: 'yì',  # 𣤪
    # 0x2392B: '',  # 𣤫
    # 0x2392C: '',  # 𣤬
    0x2392D: 'jiān',  # 𣤭
    # 0x2392E: '',  # 𣤮
    0x2392F: 'shú',  # 𣤯
    0x23930: 'yuè',  # 𣤰
    0x23931: 'chán',  # 𣤱
    0x23932: 'è',  # 𣤲
    0x23933: 'xī',  # 𣤳
    0x23934: 'xī',  # 𣤴
    0x23935: 'yǐng',  # 𣤵
    0x23936: 'zú,zā,zǎn',  # 𣤶
    0x23937: 'zā',  # 𣤷
    # 0x23938: '',  # 𣤸
    0x23939: 'jiào',  # 𣤹
    0x2393A: 'zā',  # 𣤺
    # 0x2393B: '',  # 𣤻
    # 0x2393C: '',  # 𣤼
    # 0x2393D: '',  # 𣤽
    # 0x2393E: '',  # 𣤾
    0x2393F: 'kūn',  # 𣤿
    # 0x23940: '',  # 𣥀
    # 0x23941: '',  # 𣥁
    0x23942: 'tà',  # 𣥂
    0x23943: 'wàn',  # 𣥃
    # 0x23944: '',  # 𣥄
    # 0x23945: '',  # 𣥅
    # 0x23946: '',  # 𣥆
    0x23947: 'xìn',  # 𣥇
    # 0x23948: '',  # 𣥈
    # 0x23949: '',  # 𣥉
    0x2394A: 'wàng',  # 𣥊
    0x2394B: 'fǔ',  # 𣥋
    # 0x2394C: '',  # 𣥌
    # 0x2394D: '',  # 𣥍
    # 0x2394E: '',  # 𣥎
    # 0x2394F: '',  # 𣥏
    0x23950: 'lǔ,lǚ',  # 𣥐
    # 0x23951: '',  # 𣥑
    # 0x23952: '',  # 𣥒
    # 0x23953: '',  # 𣥓
    # 0x23954: '',  # 𣥔
    # 0x23955: '',  # 𣥕
    # 0x23956: '',  # 𣥖
    # 0x23957: '',  # 𣥗
    # 0x23958: '',  # 𣥘
    # 0x23959: '',  # 𣥙
    # 0x2395A: '',  # 𣥚
    # 0x2395B: '',  # 𣥛
    # 0x2395C: '',  # 𣥜
    # 0x2395D: '',  # 𣥝
    0x2395E: 'jiǎn',  # 𣥞
    # 0x2395F: '',  # 𣥟
    0x23960: 'tī',  # 𣥠
    0x23961: 'yán',  # 𣥡
    # 0x23962: '',  # 𣥢
    0x23963: 'bì',  # 𣥣
    0x23964: 'kěn',  # 𣥤
    0x23965: 'guàn',  # 𣥥
    # 0x23966: '',  # 𣥦
    # 0x23967: '',  # 𣥧
    0x23968: 'zī',  # 𣥨
    # 0x23969: '',  # 𣥩
    # 0x2396A: '',  # 𣥪
    # 0x2396B: '',  # 𣥫
    # 0x2396C: '',  # 𣥬
    # 0x2396D: '',  # 𣥭
    0x2396E: 'kuǐ',  # 𣥮
    0x2396F: 'zhǒu',  # 𣥯
    0x23970: 'zhì',  # 𣥰
    # 0x23971: '',  # 𣥱
    # 0x23972: '',  # 𣥲
    0x23973: 'tú',  # 𣥳
    # 0x23974: '',  # 𣥴
    # 0x23975: '',  # 𣥵
    0x23976: 'bù',  # 𣥶
    0x23977: 'tà',  # 𣥷
    # 0x23978: '',  # 𣥸
    0x23979: 'chù',  # 𣥹
    0x2397A: 'chēng',  # 𣥺
    0x2397B: 'chěng',  # 𣥻
    0x2397C: 'zhù',  # 𣥼
    # 0x2397D: '',  # 𣥽
    0x2397E: 'dà',  # 𣥾
    # 0x2397F: '',  # 𣥿
    # 0x23980: '',  # 𣦀
    # 0x23981: '',  # 𣦁
    # 0x23982: '',  # 𣦂
    # 0x23983: '',  # 𣦃
    # 0x23984: '',  # 𣦄
    # 0x23985: '',  # 𣦅
    # 0x23986: '',  # 𣦆
    0x23987: 'bì',  # 𣦇
    # 0x23988: '',  # 𣦈
    0x23989: 'jiǎ',  # 𣦉
    # 0x2398A: '',  # 𣦊
    # 0x2398B: '',  # 𣦋
    0x2398C: 'yì',  # 𣦌
    # 0x2398D: '',  # 𣦍
    # 0x2398E: '',  # 𣦎
    0x2398F: 'yuè',  # 𣦏
    0x23990: 'gāng',  # 𣦐
    # 0x23991: '',  # 𣦑
    # 0x23992: '',  # 𣦒
    # 0x23993: '',  # 𣦓
    # 0x23994: '',  # 𣦔
    # 0x23995: '',  # 𣦕
    0x23996: 'gān',  # 𣦖
    # 0x23997: '',  # 𣦗
    # 0x23998: '',  # 𣦘
    # 0x23999: '',  # 𣦙
    # 0x2399A: '',  # 𣦚
    # 0x2399B: '',  # 𣦛
    0x2399C: 'qiāo',  # 𣦜
    # 0x2399D: '',  # 𣦝
    # 0x2399E: '',  # 𣦞
    # 0x2399F: '',  # 𣦟
    0x239A0: 'chú',  # 𣦠
    0x239A1: 'chú',  # 𣦡
    0x239A2: 'bì',  # 𣦢
    # 0x239A3: '',  # 𣦣
    # 0x239A4: '',  # 𣦤
    # 0x239A5: '',  # 𣦥
    0x239A6: 'guì',  # 𣦦
    # 0x239A7: '',  # 𣦧
    # 0x239A8: '',  # 𣦨
    0x239A9: 'gǔ',  # 𣦩
    0x239AA: 'bǐng',  # 𣦪
    0x239AB: 'yìn',  # 𣦫
    0x239AC: 'zhuì',  # 𣦬
    0x239AD: 'gǔ',  # 𣦭
    # 0x239AE: '',  # 𣦮
    0x239AF: 'lì',  # 𣦯
    # 0x239B0: '',  # 𣦰
    # 0x239B1: '',  # 𣦱
    # 0x239B2: '',  # 𣦲
    # 0x239B3: '',  # 𣦳
    # 0x239B4: '',  # 𣦴
    0x239B5: 'è,zhēn',  # 𣦵
    0x239B6: 'dǎi',  # 𣦶
    # 0x239B7: '',  # 𣦷
    # 0x239B8: '',  # 𣦸
    # 0x239B9: '',  # 𣦹
    # 0x239BA: '',  # 𣦺
    # 0x239BB: '',  # 𣦻
    0x239BC: 'cán',  # 𣦼
    # 0x239BD: '',  # 𣦽
    # 0x239BE: '',  # 𣦾
    # 0x239BF: '',  # 𣦿
    # 0x239C0: '',  # 𣧀
    # 0x239C1: '',  # 𣧁
    0x239C2: 'tì',  # 𣧂
    0x239C3: 'dù',  # 𣧃
    0x239C4: 'yì',  # 𣧄
    # 0x239C5: '',  # 𣧅
    # 0x239C6: '',  # 𣧆
    # 0x239C7: '',  # 𣧇
    0x239C8: 'dié',  # 𣧈
    # 0x239C9: '',  # 𣧉
    0x239CA: 'niǔ',  # 𣧊
    # 0x239CB: '',  # 𣧋
    0x239CC: 'xuè',  # 𣧌
    0x239CD: 'nè',  # 𣧍
    0x239CE: 'guì',  # 𣧎
    0x239CF: 'kǎo',  # 𣧏
    # 0x239D0: '',  # 𣧐
    # 0x239D1: '',  # 𣧑
    0x239D2: 'chuǎn,mò',  # 𣧒
    # 0x239D3: '',  # 𣧓
    # 0x239D4: '',  # 𣧔
    # 0x239D5: '',  # 𣧕
    0x239D6: 'zhá',  # 𣧖
    0x239D7: 'yóu',  # 𣧗
    0x239D8: 'chuǎn',  # 𣧘
    0x239D9: 'bài',  # 𣧙
    0x239DA: 'shí',  # 𣧚
    0x239DB: 'diàn',  # 𣧛
    0x239DC: 'pā',  # 𣧜
    0x239DD: 'qiú',  # 𣧝
    # 0x239DE: '',  # 𣧞
    # 0x239DF: '',  # 𣧟
    # 0x239E0: '',  # 𣧠
    0x239E1: 'xuè',  # 𣧡
    # 0x239E2: '',  # 𣧢
    0x239E3: 'mò',  # 𣧣
    0x239E4: 'kē',  # 𣧤
    0x239E5: 'yǒu',  # 𣧥
    0x239E6: 'jiǎo',  # 𣧦
    0x239E7: 'bó',  # 𣧧
    # 0x239E8: '',  # 𣧨
    # 0x239E9: '',  # 𣧩
    # 0x239EA: '',  # 𣧪
    # 0x239EB: '',  # 𣧫
    0x239EC: 'xiǔ',  # 𣧬
    # 0x239ED: '',  # 𣧭
    # 0x239EE: '',  # 𣧮
    # 0x239EF: '',  # 𣧯
    # 0x239F0: '',  # 𣧰
    # 0x239F1: '',  # 𣧱
    0x239F2: 'mǐ',  # 𣧲
    0x239F3: 'luò',  # 𣧳
    # 0x239F4: '',  # 𣧴
    0x239F5: 'xuè,xù',  # 𣧵
    # 0x239F6: '',  # 𣧶
    0x239F7: 'duò',  # 𣧷
    # 0x239F8: '',  # 𣧸
    0x239F9: 'èr',  # 𣧹
    0x239FA: 'shān',  # 𣧺
    0x239FB: 'cán',  # 𣧻
    0x239FC: 'kuì',  # 𣧼
    0x239FD: 'nào',  # 𣧽
    0x239FE: 'miǎn',  # 𣧾
    0x239FF: 'lì',  # 𣧿
    0x23A00: 'luàn',  # 𣨀
    # 0x23A01: '',  # 𣨁
    0x23A02: 'dié',  # 𣨂
    # 0x23A03: '',  # 𣨃
    0x23A04: 'qià',  # 𣨄
    0x23A05: 'lèi',  # 𣨅
    # 0x23A06: '',  # 𣨆
    0x23A07: 'mào',  # 𣨇
    # 0x23A08: '',  # 𣨈
    0x23A09: 'hēng',  # 𣨉
    0x23A0A: 'chè',  # 𣨊
    0x23A0B: 'zhì',  # 𣨋
    # 0x23A0C: '',  # 𣨌
    0x23A0D: 'gǔ',  # 𣨍
    0x23A0E: 'cuō',  # 𣨎
    # 0x23A0F: '',  # 𣨏
    # 0x23A10: '',  # 𣨐
    # 0x23A11: '',  # 𣨑
    # 0x23A12: '',  # 𣨒
    0x23A13: 'wù',  # 𣨓
    0x23A14: 'tào',  # 𣨔
    # 0x23A15: '',  # 𣨕
    # 0x23A16: '',  # 𣨖
    0x23A17: 'xī',  # 𣨗
    0x23A18: 'yāo',  # 𣨘
    0x23A19: 'wěi,wèi',  # 𣨙
    # 0x23A1A: '',  # 𣨚
    0x23A1B: 'zú',  # 𣨛
    0x23A1C: 'mà',  # 𣨜
    0x23A1D: 'yǔ',  # 𣨝
    0x23A1E: 'pěng',  # 𣨞
    0x23A1F: 'yì',  # 𣨟
    0x23A20: 'qìn,qīn',  # 𣨠
    0x23A21: 'yuè',  # 𣨡
    0x23A22: 'juè',  # 𣨢
    0x23A23: 'jiàng',  # 𣨣
    0x23A24: 'xù',  # 𣨤
    0x23A25: 'bēng',  # 𣨥
    # 0x23A26: '',  # 𣨦
    # 0x23A27: '',  # 𣨧
    # 0x23A28: '',  # 𣨨
    # 0x23A29: '',  # 𣨩
    0x23A2A: 'luǒ',  # 𣨪
    0x23A2B: 'zhuī',  # 𣨫
    # 0x23A2C: '',  # 𣨬
    # 0x23A2D: '',  # 𣨭
    # 0x23A2E: '',  # 𣨮
    # 0x23A2F: '',  # 𣨯
    # 0x23A30: '',  # 𣨰
    # 0x23A31: '',  # 𣨱
    0x23A32: 'dù',  # 𣨲
    0x23A33: 'xiàng',  # 𣨳
    # 0x23A34: '',  # 𣨴
    # 0x23A35: '',  # 𣨵
    0x23A36: 'huì',  # 𣨶
    # 0x23A37: '',  # 𣨷
    # 0x23A38: '',  # 𣨸
    # 0x23A39: '',  # 𣨹
    0x23A3A: 'gǔ',  # 𣨺
    0x23A3B: 'kǎo',  # 𣨻
    # 0x23A3C: '',  # 𣨼
    # 0x23A3D: '',  # 𣨽
    0x23A3E: 'xīng',  # 𣨾
    0x23A3F: 'hún',  # 𣨿
    0x23A40: 'biān',  # 𣩀
    # 0x23A41: '',  # 𣩁
    # 0x23A42: '',  # 𣩂
    # 0x23A43: '',  # 𣩃
    0x23A44: 'kè,ài',  # 𣩄
    0x23A45: 'kǎo',  # 𣩅
    # 0x23A46: '',  # 𣩆
    # 0x23A47: '',  # 𣩇
    0x23A48: 'cuó,zuō',  # 𣩈
    # 0x23A49: '',  # 𣩉
    # 0x23A4A: '',  # 𣩊
    # 0x23A4B: '',  # 𣩋
    # 0x23A4C: '',  # 𣩌
    # 0x23A4D: '',  # 𣩍
    # 0x23A4E: '',  # 𣩎
    0x23A4F: 'lù',  # 𣩏
    # 0x23A50: '',  # 𣩐
    0x23A51: 'zuì',  # 𣩑
    0x23A52: 'zāo',  # 𣩒
    0x23A53: 'jiǎo',  # 𣩓
    0x23A54: 'guàn',  # 𣩔
    # 0x23A55: '',  # 𣩕
    # 0x23A56: '',  # 𣩖
    # 0x23A57: '',  # 𣩗
    # 0x23A58: '',  # 𣩘
    0x23A59: 'yān',  # 𣩙
    0x23A5A: 'ér',  # 𣩚
    # 0x23A5B: '',  # 𣩛
    0x23A5C: 'qíng',  # 𣩜
    # 0x23A5D: '',  # 𣩝
    # 0x23A5E: '',  # 𣩞
    0x23A5F: 'dèng',  # 𣩟
    0x23A60: 'sì',  # 𣩠
    0x23A61: 'suì',  # 𣩡
    0x23A62: 'liào',  # 𣩢
    # 0x23A63: '',  # 𣩣
    # 0x23A64: '',  # 𣩤
    # 0x23A65: '',  # 𣩥
    # 0x23A66: '',  # 𣩦
    0x23A67: 'shàn',  # 𣩧
    # 0x23A68: '',  # 𣩨
    0x23A69: 'bì',  # 𣩩
    0x23A6A: 'wèi',  # 𣩪
    0x23A6B: 'yè',  # 𣩫
    # 0x23A6C: '',  # 𣩬
    0x23A6D: 'zhài',  # 𣩭
    # 0x23A6E: '',  # 𣩮
    0x23A6F: 'yé',  # 𣩯
    0x23A70: 'diào',  # 𣩰
    0x23A71: 'ài,kē',  # 𣩱
    # 0x23A72: '',  # 𣩲
    # 0x23A73: '',  # 𣩳
    0x23A74: 'jiàng',  # 𣩴
    # 0x23A75: '',  # 𣩵
    # 0x23A76: '',  # 𣩶
    0x23A77: 'sū',  # 𣩷
    # 0x23A78: '',  # 𣩸
    0x23A79: 'huài',  # 𣩹
    0x23A7A: 'yù',  # 𣩺
    # 0x23A7B: '',  # 𣩻
    # 0x23A7C: '',  # 𣩼
    0x23A7D: 'rǎng',  # 𣩽
    # 0x23A7E: '',  # 𣩾
    # 0x23A7F: '',  # 𣩿
    0x23A80: 'diān',  # 𣪀
    0x23A81: 'zuān',  # 𣪁
    0x23A82: 'bān',  # 𣪂
    # 0x23A83: '',  # 𣪃
    0x23A84: 'qín',  # 𣪄
    # 0x23A85: '',  # 𣪅
    # 0x23A86: '',  # 𣪆
    0x23A87: 'jiā',  # 𣪇
    # 0x23A88: '',  # 𣪈
    0x23A89: 'pí',  # 𣪉
    # 0x23A8A: '',  # 𣪊
    # 0x23A8B: '',  # 𣪋
    0x23A8C: 'tóu,duì',  # 𣪌
    # 0x23A8D: '',  # 𣪍
    # 0x23A8E: '',  # 𣪎
    # 0x23A8F: '',  # 𣪏
    0x23A90: 'chóu',  # 𣪐
    # 0x23A91: '',  # 𣪑
    # 0x23A92: '',  # 𣪒
    # 0x23A93: '',  # 𣪓
    # 0x23A94: '',  # 𣪔
    0x23A95: 'guǐ',  # 𣪕
    # 0x23A96: '',  # 𣪖
    # 0x23A97: '',  # 𣪗
    0x23A98: 'guǐ',  # 𣪘
    # 0x23A99: '',  # 𣪙
    # 0x23A9A: '',  # 𣪚
    # 0x23A9B: '',  # 𣪛
    # 0x23A9C: '',  # 𣪜
    # 0x23A9D: '',  # 𣪝
    # 0x23A9E: '',  # 𣪞
    # 0x23A9F: '',  # 𣪟
    0x23AA0: 'jī,jì,qì',  # 𣪠
    # 0x23AA1: '',  # 𣪡
    # 0x23AA2: '',  # 𣪢
    # 0x23AA3: '',  # 𣪣
    # 0x23AA4: '',  # 𣪤
    # 0x23AA5: '',  # 𣪥
    # 0x23AA6: '',  # 𣪦
    # 0x23AA7: '',  # 𣪧
    0x23AA8: 'xuè',  # 𣪨
    # 0x23AA9: '',  # 𣪩
    0x23AAA: 'diàn',  # 𣪪
    0x23AAB: 'diàn',  # 𣪫
    # 0x23AAC: '',  # 𣪬
    0x23AAD: 'biàn',  # 𣪭
    0x23AAE: 'zǎi',  # 𣪮
    0x23AAF: 'tóng',  # 𣪯
    # 0x23AB0: '',  # 𣪰
    # 0x23AB1: '',  # 𣪱
    # 0x23AB2: '',  # 𣪲
    # 0x23AB3: '',  # 𣪳
    # 0x23AB4: '',  # 𣪴
    # 0x23AB5: '',  # 𣪵
    0x23AB6: 'shǎn',  # 𣪶
    # 0x23AB7: '',  # 𣪷
    0x23AB8: 'gù',  # 𣪸
    0x23AB9: 'què',  # 𣪹
    0x23ABA: 'hú ',  # 𣪺
    # 0x23ABB: '',  # 𣪻
    # 0x23ABC: '',  # 𣪼
    # 0x23ABD: '',  # 𣪽
    # 0x23ABE: '',  # 𣪾
    # 0x23ABF: '',  # 𣪿
    0x23AC0: 'gǔ',  # 𣫀
    # 0x23AC1: '',  # 𣫁
    # 0x23AC2: '',  # 𣫂
    # 0x23AC3: '',  # 𣫃
    # 0x23AC4: '',  # 𣫄
    0x23AC5: 'hú',  # 𣫅
    0x23AC6: 'shēng',  # 𣫆
    # 0x23AC7: '',  # 𣫇
    0x23AC8: 'hú',  # 𣫈
    0x23AC9: 'kuǎi',  # 𣫉
    # 0x23ACA: '',  # 𣫊
    # 0x23ACB: '',  # 𣫋
    0x23ACC: 'gòu',  # 𣫌
    # 0x23ACD: '',  # 𣫍
    0x23ACE: 'sù',  # 𣫎
    # 0x23ACF: '',  # 𣫏
    0x23AD0: 'chóu',  # 𣫐
    # 0x23AD1: '',  # 𣫑
    0x23AD2: 'kēng',  # 𣫒
    # 0x23AD3: '',  # 𣫓
    0x23AD4: 'dū',  # 𣫔
    # 0x23AD5: '',  # 𣫕
    # 0x23AD6: '',  # 𣫖
    # 0x23AD7: '',  # 𣫗
    # 0x23AD8: '',  # 𣫘
    0x23AD9: 'yì',  # 𣫙
    # 0x23ADA: '',  # 𣫚
    # 0x23ADB: '',  # 𣫛
    0x23ADC: 'dào',  # 𣫜
    0x23ADD: 'qiāng',  # 𣫝
    # 0x23ADE: '',  # 𣫞
    # 0x23ADF: '',  # 𣫟
    # 0x23AE0: '',  # 𣫠
    # 0x23AE1: '',  # 𣫡
    # 0x23AE2: '',  # 𣫢
    0x23AE3: 'lóng',  # 𣫣
    # 0x23AE4: '',  # 𣫤
    0x23AE5: 'lí',  # 𣫥
    # 0x23AE6: '',  # 𣫦
    0x23AE7: 'lì',  # 𣫧
    0x23AE8: 'qīng',  # 𣫨
    # 0x23AE9: '',  # 𣫩
    0x23AEA: 'wēi',  # 𣫪
    # 0x23AEB: '',  # 𣫫
    0x23AEC: 'móu',  # 𣫬
    # 0x23AED: '',  # 𣫭
    # 0x23AEE: '',  # 𣫮
    # 0x23AEF: '',  # 𣫯
    # 0x23AF0: '',  # 𣫰
    0x23AF1: 'qì',  # 𣫱
    # 0x23AF2: '',  # 𣫲
    0x23AF3: 'jiǎng',  # 𣫳
    0x23AF4: 'xié',  # 𣫴
    # 0x23AF5: '',  # 𣫵
    # 0x23AF6: '',  # 𣫶
    # 0x23AF7: '',  # 𣫷
    # 0x23AF8: '',  # 𣫸
    0x23AF9: 'dài',  # 𣫹
    # 0x23AFA: '',  # 𣫺
    0x23AFB: 'lóu',  # 𣫻
    # 0x23AFC: '',  # 𣫼
    # 0x23AFD: '',  # 𣫽
    # 0x23AFE: '',  # 𣫾
    # 0x23AFF: '',  # 𣫿
    # 0x23B00: '',  # 𣬀
    # 0x23B01: '',  # 𣬁
    0x23B02: 'guàn',  # 𣬂
    # 0x23B03: '',  # 𣬃
    # 0x23B04: '',  # 𣬄
    # 0x23B05: '',  # 𣬅
    0x23B06: 'péi',  # 𣬆
    # 0x23B07: '',  # 𣬇
    0x23B08: 'pí',  # 𣬈
    0x23B09: 'pí',  # 𣬉
    # 0x23B0A: '',  # 𣬊
    0x23B0B: 'juàn,chuò',  # 𣬋
    # 0x23B0C: '',  # 𣬌
    0x23B0D: 'bēi',  # 𣬍
    0x23B0E: 'jué',  # 𣬎
    0x23B0F: 'juàn',  # 𣬏
    0x23B10: 'shì',  # 𣬐
    # 0x23B11: '',  # 𣬑
    # 0x23B12: '',  # 𣬒
    # 0x23B13: '',  # 𣬓
    # 0x23B14: '',  # 𣬔
    0x23B15: 'xiě',  # 𣬕
    # 0x23B16: '',  # 𣬖
    # 0x23B17: '',  # 𣬗
    0x23B18: 'ruí',  # 𣬘
    0x23B19: 'jìng',  # 𣬙
    0x23B1A: 'pò',  # 𣬚
    0x23B1B: 'sān,shān',  # 𣬛
    # 0x23B1C: '',  # 𣬜
    0x23B1D: 'liáo',  # 𣬝
    # 0x23B1E: '',  # 𣬞
    # 0x23B1F: '',  # 𣬟
    0x23B20: 'jī',  # 𣬠
    # 0x23B21: '',  # 𣬡
    # 0x23B22: '',  # 𣬢
    # 0x23B23: '',  # 𣬣
    # 0x23B24: '',  # 𣬤
    # 0x23B25: '',  # 𣬥
    # 0x23B26: '',  # 𣬦
    # 0x23B27: '',  # 𣬧
    # 0x23B28: '',  # 𣬨
    0x23B29: 'fēn',  # 𣬩
    0x23B2A: 'bèi',  # 𣬪
    0x23B2B: 'jiè,gà',  # 𣬫
    0x23B2C: 'sā',  # 𣬬
    # 0x23B2D: '',  # 𣬭
    0x23B2E: 'pī',  # 𣬮
    # 0x23B2F: '',  # 𣬯
    # 0x23B30: '',  # 𣬰
    # 0x23B31: '',  # 𣬱
    # 0x23B32: '',  # 𣬲
    # 0x23B33: '',  # 𣬳
    0x23B34: 'dì',  # 𣬴
    0x23B35: 'máo,mào',  # 𣬵
    0x23B36: 'ba',  # 𣬶
    0x23B37: 'ba',  # 𣬷
    0x23B38: 'tiáo',  # 𣬸
    0x23B39: 'líng',  # 𣬹
    0x23B3A: 'shēng',  # 𣬺
    0x23B3B: 'zhěn',  # 𣬻
    0x23B3C: 'pī',  # 𣬼
    0x23B3D: 'wù',  # 𣬽
    # 0x23B3E: '',  # 𣬾
    0x23B3F: 'zè',  # 𣬿
    0x23B40: 'bào',  # 𣭀
    # 0x23B41: '',  # 𣭁
    # 0x23B42: '',  # 𣭂
    # 0x23B43: '',  # 𣭃
    # 0x23B44: '',  # 𣭄
    # 0x23B45: '',  # 𣭅
    # 0x23B46: '',  # 𣭆
    0x23B47: 'lǚ',  # 𣭇
    # 0x23B48: '',  # 𣭈
    # 0x23B49: '',  # 𣭉
    # 0x23B4A: '',  # 𣭊
    # 0x23B4B: '',  # 𣭋
    # 0x23B4C: '',  # 𣭌
    # 0x23B4D: '',  # 𣭍
    # 0x23B4E: '',  # 𣭎
    # 0x23B4F: '',  # 𣭏
    # 0x23B50: '',  # 𣭐
    # 0x23B51: '',  # 𣭑
    # 0x23B52: '',  # 𣭒
    # 0x23B53: '',  # 𣭓
    # 0x23B54: '',  # 𣭔
    # 0x23B55: '',  # 𣭕
    0x23B56: 'hāo',  # 𣭖
    0x23B57: 'dǒu',  # 𣭗
    0x23B58: 'fú',  # 𣭘
    0x23B59: 'ní',  # 𣭙
    # 0x23B5A: '',  # 𣭚
    # 0x23B5B: '',  # 𣭛
    # 0x23B5C: '',  # 𣭜
    0x23B5D: 'gé',  # 𣭝
    # 0x23B5E: '',  # 𣭞
    # 0x23B5F: '',  # 𣭟
    0x23B60: 'rú',  # 𣭠
    # 0x23B61: '',  # 𣭡
    # 0x23B62: '',  # 𣭢
    # 0x23B63: '',  # 𣭣
    # 0x23B64: '',  # 𣭤
    # 0x23B65: '',  # 𣭥
    # 0x23B66: '',  # 𣭦
    # 0x23B67: '',  # 𣭧
    # 0x23B68: '',  # 𣭨
    # 0x23B69: '',  # 𣭩
    # 0x23B6A: '',  # 𣭪
    # 0x23B6B: '',  # 𣭫
    # 0x23B6C: '',  # 𣭬
    # 0x23B6D: '',  # 𣭭
    0x23B6E: 'máo',  # 𣭮
    # 0x23B6F: '',  # 𣭯
    # 0x23B70: '',  # 𣭰
    # 0x23B71: '',  # 𣭱
    # 0x23B72: '',  # 𣭲
    0x23B73: 'qiú,qú',  # 𣭳
    # 0x23B74: '',  # 𣭴
    # 0x23B75: '',  # 𣭵
    # 0x23B76: '',  # 𣭶
    0x23B77: 'bó',  # 𣭷
    # 0x23B78: '',  # 𣭸
    0x23B79: 'hāo',  # 𣭹
    0x23B7A: 'nǎo',  # 𣭺
    0x23B7B: 'yán',  # 𣭻
    # 0x23B7C: '',  # 𣭼
    # 0x23B7D: '',  # 𣭽
    # 0x23B7E: '',  # 𣭾
    # 0x23B7F: '',  # 𣭿
    # 0x23B80: '',  # 𣮀
    # 0x23B81: '',  # 𣮁
    # 0x23B82: '',  # 𣮂
    0x23B83: 'páo',  # 𣮃
    0x23B84: 'suī',  # 𣮄
    # 0x23B85: '',  # 𣮅
    0x23B86: 'tuò',  # 𣮆
    # 0x23B87: '',  # 𣮇
    0x23B88: 'qū',  # 𣮈
    0x23B89: 'lí',  # 𣮉
    0x23B8A: 'dé',  # 𣮊
    # 0x23B8B: '',  # 𣮋
    0x23B8C: 'jié',  # 𣮌
    0x23B8D: 'jié',  # 𣮍
    0x23B8E: 'gǔn',  # 𣮎
    0x23B8F: 'jiān',  # 𣮏
    0x23B90: 'bì',  # 𣮐
    # 0x23B91: '',  # 𣮑
    # 0x23B92: '',  # 𣮒
    # 0x23B93: '',  # 𣮓
    # 0x23B94: '',  # 𣮔
    # 0x23B95: '',  # 𣮕
    # 0x23B96: '',  # 𣮖
    # 0x23B97: '',  # 𣮗
    # 0x23B98: '',  # 𣮘
    # 0x23B99: '',  # 𣮙
    # 0x23B9A: '',  # 𣮚
    # 0x23B9B: '',  # 𣮛
    # 0x23B9C: '',  # 𣮜
    # 0x23B9D: '',  # 𣮝
    # 0x23B9E: '',  # 𣮞
    # 0x23B9F: '',  # 𣮟
    0x23BA0: 'sàn',  # 𣮠
    0x23BA1: 'bāng',  # 𣮡
    0x23BA2: 'chún',  # 𣮢
    # 0x23BA3: '',  # 𣮣
    # 0x23BA4: '',  # 𣮤
    # 0x23BA5: '',  # 𣮥
    0x23BA6: 'nài',  # 𣮦
    0x23BA7: 'bǎng',  # 𣮧
    # 0x23BA8: '',  # 𣮨
    # 0x23BA9: '',  # 𣮩
    0x23BAA: 'róng',  # 𣮪
    0x23BAB: 'jiā',  # 𣮫
    0x23BAC: 'sōu',  # 𣮬
    # 0x23BAD: '',  # 𣮭
    # 0x23BAE: '',  # 𣮮
    # 0x23BAF: '',  # 𣮯
    0x23BB0: 'dé',  # 𣮰
    # 0x23BB1: '',  # 𣮱
    # 0x23BB2: '',  # 𣮲
    # 0x23BB3: '',  # 𣮳
    # 0x23BB4: '',  # 𣮴
    # 0x23BB5: '',  # 𣮵
    # 0x23BB6: '',  # 𣮶
    # 0x23BB7: '',  # 𣮷
    # 0x23BB8: '',  # 𣮸
    # 0x23BB9: '',  # 𣮹
    # 0x23BBA: '',  # 𣮺
    # 0x23BBB: '',  # 𣮻
    # 0x23BBC: '',  # 𣮼
    # 0x23BBD: '',  # 𣮽
    0x23BBE: 'xiān',  # 𣮾
    0x23BBF: 'zhān',  # 𣮿
    0x23BC0: 'mào',  # 𣯀
    # 0x23BC1: '',  # 𣯁
    # 0x23BC2: '',  # 𣯂
    0x23BC3: 'zī',  # 𣯃
    # 0x23BC4: '',  # 𣯄
    0x23BC5: 'jì',  # 𣯅
    0x23BC6: 'qí',  # 𣯆
    # 0x23BC7: '',  # 𣯇
    # 0x23BC8: '',  # 𣯈
    # 0x23BC9: '',  # 𣯉
    # 0x23BCA: '',  # 𣯊
    0x23BCB: 'rù',  # 𣯋
    0x23BCC: 'suō',  # 𣯌
    0x23BCD: 'rǒng',  # 𣯍
    0x23BCE: 'wù',  # 𣯎
    0x23BCF: 'róng,rǒng',  # 𣯏
    0x23BD0: 'róng',  # 𣯐
    # 0x23BD1: '',  # 𣯑
    # 0x23BD2: '',  # 𣯒
    # 0x23BD3: '',  # 𣯓
    # 0x23BD4: '',  # 𣯔
    # 0x23BD5: '',  # 𣯕
    # 0x23BD6: '',  # 𣯖
    # 0x23BD7: '',  # 𣯗
    # 0x23BD8: '',  # 𣯘
    # 0x23BD9: '',  # 𣯙
    0x23BDA: 'tà',  # 𣯚
    # 0x23BDB: '',  # 𣯛
    0x23BDC: 'sōu',  # 𣯜
    # 0x23BDD: '',  # 𣯝
    # 0x23BDE: '',  # 𣯞
    # 0x23BDF: '',  # 𣯟
    # 0x23BE0: '',  # 𣯠
    # 0x23BE1: '',  # 𣯡
    # 0x23BE2: '',  # 𣯢
    # 0x23BE3: '',  # 𣯣
    0x23BE4: 'lí',  # 𣯤
    # 0x23BE5: '',  # 𣯥
    # 0x23BE6: '',  # 𣯦
    0x23BE7: 'cuǐ,suī',  # 𣯧
    0x23BE8: 'zōng',  # 𣯨
    0x23BE9: 'mén',  # 𣯩
    0x23BEA: 'xǐ',  # 𣯪
    # 0x23BEB: '',  # 𣯫
    0x23BEC: 'mǎng',  # 𣯬
    0x23BED: 'niè',  # 𣯭
    # 0x23BEE: '',  # 𣯮
    0x23BEF: 'suī',  # 𣯯
    # 0x23BF0: '',  # 𣯰
    0x23BF1: 'péi',  # 𣯱
    # 0x23BF2: '',  # 𣯲
    # 0x23BF3: '',  # 𣯳
    0x23BF4: 'bì',  # 𣯴
    0x23BF5: 'dì',  # 𣯵
    # 0x23BF6: '',  # 𣯶
    # 0x23BF7: '',  # 𣯷
    0x23BF8: 'qú',  # 𣯸
    0x23BF9: 'qiáo',  # 𣯹
    # 0x23BFA: '',  # 𣯺
    0x23BFB: 'fēn',  # 𣯻
    0x23BFC: 'sù',  # 𣯼
    # 0x23BFD: '',  # 𣯽
    # 0x23BFE: '',  # 𣯾
    # 0x23BFF: '',  # 𣯿
    # 0x23C00: '',  # 𣰀
    # 0x23C01: '',  # 𣰁
    # 0x23C02: '',  # 𣰂
    0x23C03: 'xū',  # 𣰃
    # 0x23C04: '',  # 𣰄
    # 0x23C05: '',  # 𣰅
    # 0x23C06: '',  # 𣰆
    # 0x23C07: '',  # 𣰇
    0x23C08: 'jī',  # 𣰈
    # 0x23C09: '',  # 𣰉
    # 0x23C0A: '',  # 𣰊
    0x23C0B: 'qú',  # 𣰋
    0x23C0C: 'liè,hé',  # 𣰌
    # 0x23C0D: '',  # 𣰍
    # 0x23C0E: '',  # 𣰎
    # 0x23C0F: '',  # 𣰏
    # 0x23C10: '',  # 𣰐
    # 0x23C11: '',  # 𣰑
    # 0x23C12: '',  # 𣰒
    # 0x23C13: '',  # 𣰓
    # 0x23C14: '',  # 𣰔
    0x23C15: 'sào',  # 𣰕
    # 0x23C16: '',  # 𣰖
    # 0x23C17: '',  # 𣰗
    0x23C18: 'kùn',  # 𣰘
    # 0x23C19: '',  # 𣰙
    0x23C1A: 'cuì',  # 𣰚
    0x23C1B: 'yè',  # 𣰛
    0x23C1C: 'bìng',  # 𣰜
    # 0x23C1D: '',  # 𣰝
    0x23C1E: 'jié',  # 𣰞
    # 0x23C1F: '',  # 𣰟
    0x23C20: 'qú',  # 𣰠
    0x23C21: 'qú',  # 𣰡
    # 0x23C22: '',  # 𣰢
    # 0x23C23: '',  # 𣰣
    # 0x23C24: '',  # 𣰤
    0x23C25: 'méng',  # 𣰥
    0x23C26: 'rán,gān',  # 𣰦
    # 0x23C27: '',  # 𣰧
    0x23C28: 'bīn',  # 𣰨
    0x23C29: 'cháo',  # 𣰩
    # 0x23C2A: '',  # 𣰪
    # 0x23C2B: '',  # 𣰫
    0x23C2C: 'dú',  # 𣰬
    # 0x23C2D: '',  # 𣰭
    # 0x23C2E: '',  # 𣰮
    # 0x23C2F: '',  # 𣰯
    # 0x23C30: '',  # 𣰰
    # 0x23C31: '',  # 𣰱
    # 0x23C32: '',  # 𣰲
    # 0x23C33: '',  # 𣰳
    # 0x23C34: '',  # 𣰴
    # 0x23C35: '',  # 𣰵
    0x23C36: 'ráng,nǎng',  # 𣰶
    0x23C37: 'xiān',  # 𣰷
    # 0x23C38: '',  # 𣰸
    # 0x23C39: '',  # 𣰹
    0x23C3A: 'táo',  # 𣰺
    0x23C3B: 'qú',  # 𣰻
    0x23C3C: 'niè',  # 𣰼
    # 0x23C3D: '',  # 𣰽
    # 0x23C3E: '',  # 𣰾
    0x23C3F: 'shū',  # 𣰿
    0x23C40: 'lǔ',  # 𣱀
    # 0x23C41: '',  # 𣱁
    0x23C42: 'kùn',  # 𣱂
    # 0x23C43: '',  # 𣱃
    # 0x23C44: '',  # 𣱄
    # 0x23C45: '',  # 𣱅
    # 0x23C46: '',  # 𣱆
    # 0x23C47: '',  # 𣱇
    0x23C48: 'mín',  # 𣱈
    0x23C49: 'mǐn',  # 𣱉
    # 0x23C4A: '',  # 𣱊
    # 0x23C4B: '',  # 𣱋
    # 0x23C4C: '',  # 𣱌
    0x23C4D: 'dàn',  # 𣱍
    # 0x23C4E: '',  # 𣱎
    # 0x23C4F: '',  # 𣱏
    0x23C50: 'yìn,zhì',  # 𣱐
    # 0x23C51: '',  # 𣱑
    # 0x23C52: '',  # 𣱒
    0x23C53: 'xiào,hào',  # 𣱓
    # 0x23C54: '',  # 𣱔
    # 0x23C55: '',  # 𣱕
    # 0x23C56: '',  # 𣱖
    0x23C57: 'jì',  # 𣱗
    # 0x23C58: '',  # 𣱘
    # 0x23C59: '',  # 𣱙
    # 0x23C5A: '',  # 𣱚
    # 0x23C5B: '',  # 𣱛
    0x23C5C: 'yīn',  # 𣱜
    # 0x23C5D: '',  # 𣱝
    # 0x23C5E: '',  # 𣱞
    # 0x23C5F: '',  # 𣱟
    # 0x23C60: '',  # 𣱠
    # 0x23C61: '',  # 𣱡
    # 0x23C62: '',  # 𣱢
    # 0x23C63: '',  # 𣱣
    # 0x23C64: '',  # 𣱤
    # 0x23C65: '',  # 𣱥
    0x23C66: 'fēn',  # 𣱦
    0x23C67: 'zhòng',  # 𣱧
    # 0x23C68: '',  # 𣱨
    # 0x23C69: '',  # 𣱩
    # 0x23C6A: '',  # 𣱪
    0x23C6B: 'gǔ',  # 𣱫
    # 0x23C6C: '',  # 𣱬
    # 0x23C6D: '',  # 𣱭
    # 0x23C6E: '',  # 𣱮
    # 0x23C6F: '',  # 𣱯
    # 0x23C70: '',  # 𣱰
    0x23C71: 'chá',  # 𣱱
    # 0x23C72: '',  # 𣱲
    0x23C73: 'liú',  # 𣱳
    # 0x23C74: '',  # 𣱴
    # 0x23C75: '',  # 𣱵
    0x23C76: 'bǔ',  # 𣱶
    # 0x23C77: '',  # 𣱷
    # 0x23C78: '',  # 𣱸
    # 0x23C79: '',  # 𣱹
    0x23C7A: 'pā',  # 𣱺
    0x23C7B: 'sì',  # 𣱻
    0x23C7C: 'dāo',  # 𣱼
    0x23C7D: 'zhěn',  # 𣱽
    # 0x23C7E: '',  # 𣱾
    # 0x23C7F: '',  # 𣱿
    0x23C80: 'shān',  # 𣲀
    # 0x23C81: '',  # 𣲁
    0x23C82: 'chuǎi',  # 𣲂
    # 0x23C83: '',  # 𣲃
    0x23C84: 'jiǔ',  # 𣲄
    # 0x23C85: '',  # 𣲅
    # 0x23C86: '',  # 𣲆
    # 0x23C87: '',  # 𣲇
    # 0x23C88: '',  # 𣲈
    # 0x23C89: '',  # 𣲉
    0x23C8A: 'kè',  # 𣲊
    0x23C8B: 'chí',  # 𣲋
    # 0x23C8C: '',  # 𣲌
    # 0x23C8D: '',  # 𣲍
    # 0x23C8E: '',  # 𣲎
    # 0x23C8F: '',  # 𣲏
    # 0x23C90: '',  # 𣲐
    0x23C91: 'hù,chí,hé,hú',  # 𣲑
    0x23C92: 'lì,lè',  # 𣲒
    0x23C93: 'shā',  # 𣲓
    # 0x23C94: '',  # 𣲔
    # 0x23C95: '',  # 𣲕
    0x23C96: 'pài,liú,gū',  # 𣲖
    0x23C97: 'wéi',  # 𣲗
    0x23C98: 'wǔ',  # 𣲘
    # 0x23C99: '',  # 𣲙
    # 0x23C9A: '',  # 𣲚
    # 0x23C9B: '',  # 𣲛
    0x23C9C: 'yíng',  # 𣲜
    0x23C9D: 'bīng',  # 𣲝
    # 0x23C9E: '',  # 𣲞
    # 0x23C9F: '',  # 𣲟
    # 0x23CA0: '',  # 𣲠
    0x23CA1: 'shā,jí,jié',  # 𣲡
    0x23CA2: 'dī',  # 𣲢
    # 0x23CA3: '',  # 𣲣
    # 0x23CA4: '',  # 𣲤
    0x23CA5: 'dān',  # 𣲥
    # 0x23CA6: '',  # 𣲦
    # 0x23CA7: '',  # 𣲧
    # 0x23CA8: '',  # 𣲨
    0x23CA9: 'pá',  # 𣲩
    # 0x23CAA: '',  # 𣲪
    # 0x23CAB: '',  # 𣲫
    # 0x23CAC: '',  # 𣲬
    # 0x23CAD: '',  # 𣲭
    # 0x23CAE: '',  # 𣲮
    # 0x23CAF: '',  # 𣲯
    # 0x23CB0: '',  # 𣲰
    0x23CB1: 'tū',  # 𣲱
    0x23CB2: 'hé',  # 𣲲
    0x23CB3: 'pǒ',  # 𣲳
    # 0x23CB4: '',  # 𣲴
    0x23CB5: 'zhǐ',  # 𣲵
    0x23CB6: 'niǔ',  # 𣲶
    0x23CB7: 'nì',  # 𣲷
    # 0x23CB8: '',  # 𣲸
    # 0x23CB9: '',  # 𣲹
    # 0x23CBA: '',  # 𣲺
    # 0x23CBB: '',  # 𣲻
    # 0x23CBC: '',  # 𣲼
    0x23CBD: 'rǒng',  # 𣲽
    0x23CBE: 'guài',  # 𣲾
    # 0x23CBF: '',  # 𣲿
    0x23CC0: 'zhí',  # 𣳀
    # 0x23CC1: '',  # 𣳁
    # 0x23CC2: '',  # 𣳂
    0x23CC3: 'jí',  # 𣳃
    # 0x23CC4: '',  # 𣳄
    # 0x23CC5: '',  # 𣳅
    # 0x23CC6: '',  # 𣳆
    # 0x23CC7: '',  # 𣳇
    # 0x23CC8: '',  # 𣳈
    # 0x23CC9: '',  # 𣳉
    # 0x23CCA: '',  # 𣳊
    # 0x23CCB: '',  # 𣳋
    # 0x23CCC: '',  # 𣳌
    # 0x23CCD: '',  # 𣳍
    # 0x23CCE: '',  # 𣳎
    # 0x23CCF: '',  # 𣳏
    # 0x23CD0: '',  # 𣳐
    # 0x23CD1: '',  # 𣳑
    # 0x23CD2: '',  # 𣳒
    # 0x23CD3: '',  # 𣳓
    # 0x23CD4: '',  # 𣳔
    # 0x23CD5: '',  # 𣳕
    # 0x23CD6: '',  # 𣳖
    0x23CD7: 'hǎi',  # 𣳗
    # 0x23CD8: '',  # 𣳘
    # 0x23CD9: '',  # 𣳙
    # 0x23CDA: '',  # 𣳚
    # 0x23CDB: '',  # 𣳛
    0x23CDC: 'fàn',  # 𣳜
    # 0x23CDD: '',  # 𣳝
    # 0x23CDE: '',  # 𣳞
    0x23CDF: 'jié',  # 𣳟
    0x23CE0: 'hǎi,mǔ',  # 𣳠
    # 0x23CE1: '',  # 𣳡
    # 0x23CE2: '',  # 𣳢
    # 0x23CE3: '',  # 𣳣
    0x23CE4: 'zhàn',  # 𣳤
    # 0x23CE5: '',  # 𣳥
    0x23CE6: 'xì,náo',  # 𣳦
    # 0x23CE7: '',  # 𣳧
    # 0x23CE8: '',  # 𣳨
    0x23CE9: 'zī',  # 𣳩
    # 0x23CEA: '',  # 𣳪
    # 0x23CEB: '',  # 𣳫
    0x23CEC: 'xí',  # 𣳬
    0x23CED: 'piào',  # 𣳭
    # 0x23CEE: '',  # 𣳮
    # 0x23CEF: '',  # 𣳯
    0x23CF0: 'bēn',  # 𣳰
    # 0x23CF1: '',  # 𣳱
    0x23CF2: 'jiǎn',  # 𣳲
    # 0x23CF3: '',  # 𣳳
    # 0x23CF4: '',  # 𣳴
    # 0x23CF5: '',  # 𣳵
    # 0x23CF6: '',  # 𣳶
    # 0x23CF7: '',  # 𣳷
    # 0x23CF8: '',  # 𣳸
    # 0x23CF9: '',  # 𣳹
    # 0x23CFA: '',  # 𣳺
    # 0x23CFB: '',  # 𣳻
    # 0x23CFC: '',  # 𣳼
    # 0x23CFD: '',  # 𣳽
    # 0x23CFE: '',  # 𣳾
    # 0x23CFF: '',  # 𣳿
    # 0x23D00: '',  # 𣴀
    0x23D01: 'xī',  # 𣴁
    # 0x23D02: '',  # 𣴂
    # 0x23D03: '',  # 𣴃
    # 0x23D04: '',  # 𣴄
    # 0x23D05: '',  # 𣴅
    # 0x23D06: '',  # 𣴆
    # 0x23D07: '',  # 𣴇
    # 0x23D08: '',  # 𣴈
    # 0x23D09: '',  # 𣴉
    # 0x23D0A: '',  # 𣴊
    # 0x23D0B: '',  # 𣴋
    # 0x23D0C: '',  # 𣴌
    # 0x23D0D: '',  # 𣴍
    # 0x23D0E: '',  # 𣴎
    # 0x23D0F: '',  # 𣴏
    # 0x23D10: '',  # 𣴐
    # 0x23D11: '',  # 𣴑
    # 0x23D12: '',  # 𣴒
    0x23D13: 'jiàn',  # 𣴓
    # 0x23D14: '',  # 𣴔
    # 0x23D15: '',  # 𣴕
    0x23D16: 'zá',  # 𣴖
    # 0x23D17: '',  # 𣴗
    # 0x23D18: '',  # 𣴘
    # 0x23D19: '',  # 𣴙
    # 0x23D1A: '',  # 𣴚
    # 0x23D1B: '',  # 𣴛
    # 0x23D1C: '',  # 𣴜
    # 0x23D1D: '',  # 𣴝
    0x23D1E: 'bèn',  # 𣴞
    0x23D1F: 'mào,huǎn',  # 𣴟
    # 0x23D20: '',  # 𣴠
    # 0x23D21: '',  # 𣴡
    0x23D22: 'zào',  # 𣴢
    0x23D23: 'zhuàng',  # 𣴣
    # 0x23D24: '',  # 𣴤
    0x23D25: 'kuáng',  # 𣴥
    # 0x23D26: '',  # 𣴦
    # 0x23D27: '',  # 𣴧
    0x23D28: 'bí',  # 𣴨
    # 0x23D29: '',  # 𣴩
    0x23D2A: 'pài,pì',  # 𣴪
    # 0x23D2B: '',  # 𣴫
    # 0x23D2C: '',  # 𣴬
    # 0x23D2D: '',  # 𣴭
    # 0x23D2E: '',  # 𣴮
    # 0x23D2F: '',  # 𣴯
    # 0x23D30: '',  # 𣴰
    # 0x23D31: '',  # 𣴱
    # 0x23D32: '',  # 𣴲
    # 0x23D33: '',  # 𣴳
    # 0x23D34: '',  # 𣴴
    # 0x23D35: '',  # 𣴵
    # 0x23D36: '',  # 𣴶
    0x23D37: 'shā',  # 𣴷
    # 0x23D38: '',  # 𣴸
    # 0x23D39: '',  # 𣴹
    # 0x23D3A: '',  # 𣴺
    # 0x23D3B: '',  # 𣴻
    0x23D3C: 'mào',  # 𣴼
    0x23D3D: 'tàn',  # 𣴽
    # 0x23D3E: '',  # 𣴾
    # 0x23D3F: '',  # 𣴿
    # 0x23D40: '',  # 𣵀
    # 0x23D41: '',  # 𣵁
    # 0x23D42: '',  # 𣵂
    # 0x23D43: '',  # 𣵃
    # 0x23D44: '',  # 𣵄
    # 0x23D45: '',  # 𣵅
    # 0x23D46: '',  # 𣵆
    # 0x23D47: '',  # 𣵇
    # 0x23D48: '',  # 𣵈
    # 0x23D49: '',  # 𣵉
    # 0x23D4A: '',  # 𣵊
    # 0x23D4B: '',  # 𣵋
    # 0x23D4C: '',  # 𣵌
    # 0x23D4D: '',  # 𣵍
    # 0x23D4E: '',  # 𣵎
    # 0x23D4F: '',  # 𣵏
    # 0x23D50: '',  # 𣵐
    # 0x23D51: '',  # 𣵑
    # 0x23D52: '',  # 𣵒
    # 0x23D53: '',  # 𣵓
    # 0x23D54: '',  # 𣵔
    # 0x23D55: '',  # 𣵕
    # 0x23D56: '',  # 𣵖
    # 0x23D57: '',  # 𣵗
    # 0x23D58: '',  # 𣵘
    # 0x23D59: '',  # 𣵙
    # 0x23D5A: '',  # 𣵚
    # 0x23D5B: '',  # 𣵛
    # 0x23D5C: '',  # 𣵜
    # 0x23D5D: '',  # 𣵝
    0x23D5E: 'tǔn',  # 𣵞
    0x23D5F: 'luǒ',  # 𣵟
    # 0x23D60: '',  # 𣵠
    # 0x23D61: '',  # 𣵡
    0x23D62: 'tān',  # 𣵢
    # 0x23D63: '',  # 𣵣
    # 0x23D64: '',  # 𣵤
    # 0x23D65: '',  # 𣵥
    # 0x23D66: '',  # 𣵦
    # 0x23D67: '',  # 𣵧
    # 0x23D68: '',  # 𣵨
    # 0x23D69: '',  # 𣵩
    # 0x23D6A: '',  # 𣵪
    # 0x23D6B: '',  # 𣵫
    # 0x23D6C: '',  # 𣵬
    # 0x23D6D: '',  # 𣵭
    # 0x23D6E: '',  # 𣵮
    # 0x23D6F: '',  # 𣵯
    # 0x23D70: '',  # 𣵰
    0x23D71: 'án',  # 𣵱
    # 0x23D72: '',  # 𣵲
    # 0x23D73: '',  # 𣵳
    # 0x23D74: '',  # 𣵴
    # 0x23D75: '',  # 𣵵
    # 0x23D76: '',  # 𣵶
    0x23D77: 'hán,gàn',  # 𣵷
    0x23D78: 'zhú',  # 𣵸
    # 0x23D79: '',  # 𣵹
    0x23D7A: 'duò,tuó',  # 𣵺
    0x23D7B: 'duò,tuó',  # 𣵻
    0x23D7C: 'gàn',  # 𣵼
    0x23D7D: 'wò',  # 𣵽
    # 0x23D7E: '',  # 𣵾
    # 0x23D7F: '',  # 𣵿
    # 0x23D80: '',  # 𣶀
    # 0x23D81: '',  # 𣶁
    # 0x23D82: '',  # 𣶂
    0x23D83: 'cháo',  # 𣶃
    # 0x23D84: '',  # 𣶄
    # 0x23D85: '',  # 𣶅
    0x23D86: 'qiòng',  # 𣶆
    # 0x23D87: '',  # 𣶇
    0x23D88: 'wǎng,mǎng',  # 𣶈
    # 0x23D89: '',  # 𣶉
    0x23D8A: 'mò',  # 𣶊
    0x23D8B: 'zhè',  # 𣶋
    0x23D8C: 'wěn',  # 𣶌
    0x23D8D: 'zhuàng',  # 𣶍
    # 0x23D8E: '',  # 𣶎
    0x23D8F: 'jiē,diē',  # 𣶏
    0x23D90: 'pào',  # 𣶐
    # 0x23D91: '',  # 𣶑
    0x23D92: 'yuān',  # 𣶒
    # 0x23D93: '',  # 𣶓
    # 0x23D94: '',  # 𣶔
    # 0x23D95: '',  # 𣶕
    # 0x23D96: '',  # 𣶖
    # 0x23D97: '',  # 𣶗
    0x23D98: 'sù',  # 𣶘
    # 0x23D99: '',  # 𣶙
    # 0x23D9A: '',  # 𣶚
    # 0x23D9B: '',  # 𣶛
    # 0x23D9C: '',  # 𣶜
    0x23D9D: 'jù',  # 𣶝
    # 0x23D9E: '',  # 𣶞
    # 0x23D9F: '',  # 𣶟
    0x23DA0: 'qī',  # 𣶠
    0x23DA1: 'càn',  # 𣶡
    # 0x23DA2: '',  # 𣶢
    0x23DA3: 'tuán',  # 𣶣
    0x23DA4: 'shā',  # 𣶤
    # 0x23DA5: '',  # 𣶥
    0x23DA6: 'tuó',  # 𣶦
    # 0x23DA7: '',  # 𣶧
    # 0x23DA8: '',  # 𣶨
    # 0x23DA9: '',  # 𣶩
    # 0x23DAA: '',  # 𣶪
    # 0x23DAB: '',  # 𣶫
    # 0x23DAC: '',  # 𣶬
    # 0x23DAD: '',  # 𣶭
    # 0x23DAE: '',  # 𣶮
    # 0x23DAF: '',  # 𣶯
    # 0x23DB0: '',  # 𣶰
    # 0x23DB1: '',  # 𣶱
    # 0x23DB2: '',  # 𣶲
    # 0x23DB3: '',  # 𣶳
    # 0x23DB4: '',  # 𣶴
    # 0x23DB5: '',  # 𣶵
    # 0x23DB6: '',  # 𣶶
    # 0x23DB7: '',  # 𣶷
    # 0x23DB8: '',  # 𣶸
    # 0x23DB9: '',  # 𣶹
    # 0x23DBA: '',  # 𣶺
    # 0x23DBB: '',  # 𣶻
    # 0x23DBC: '',  # 𣶼
    # 0x23DBD: '',  # 𣶽
    # 0x23DBE: '',  # 𣶾
    # 0x23DBF: '',  # 𣶿
    # 0x23DC0: '',  # 𣷀
    # 0x23DC1: '',  # 𣷁
    # 0x23DC2: '',  # 𣷂
    # 0x23DC3: '',  # 𣷃
    # 0x23DC4: '',  # 𣷄
    # 0x23DC5: '',  # 𣷅
    # 0x23DC6: '',  # 𣷆
    # 0x23DC7: '',  # 𣷇
    # 0x23DC8: '',  # 𣷈
    # 0x23DC9: '',  # 𣷉
    # 0x23DCA: '',  # 𣷊
    # 0x23DCB: '',  # 𣷋
    # 0x23DCC: '',  # 𣷌
    # 0x23DCD: '',  # 𣷍
    # 0x23DCE: '',  # 𣷎
    # 0x23DCF: '',  # 𣷏
    # 0x23DD0: '',  # 𣷐
    # 0x23DD1: '',  # 𣷑
    # 0x23DD2: '',  # 𣷒
    # 0x23DD3: '',  # 𣷓
    # 0x23DD4: '',  # 𣷔
    # 0x23DD5: '',  # 𣷕
    # 0x23DD6: '',  # 𣷖
    # 0x23DD7: '',  # 𣷗
    # 0x23DD8: '',  # 𣷘
    # 0x23DD9: '',  # 𣷙
    # 0x23DDA: '',  # 𣷚
    # 0x23DDB: '',  # 𣷛
    # 0x23DDC: '',  # 𣷜
    # 0x23DDD: '',  # 𣷝
    0x23DDE: 'xiè',  # 𣷞
    # 0x23DDF: '',  # 𣷟
    0x23DE0: 'míng',  # 𣷠
    0x23DE1: 'zhōng',  # 𣷡
    # 0x23DE2: '',  # 𣷢
    # 0x23DE3: '',  # 𣷣
    # 0x23DE4: '',  # 𣷤
    0x23DE5: 'shuò',  # 𣷥
    # 0x23DE6: '',  # 𣷦
    # 0x23DE7: '',  # 𣷧
    # 0x23DE8: '',  # 𣷨
    0x23DE9: 'yì',  # 𣷩
    0x23DEA: 'wǎng',  # 𣷪
    0x23DEB: 'áo',  # 𣷫
    # 0x23DEC: '',  # 𣷬
    # 0x23DED: '',  # 𣷭
    # 0x23DEE: '',  # 𣷮
    # 0x23DEF: '',  # 𣷯
    # 0x23DF0: '',  # 𣷰
    # 0x23DF1: '',  # 𣷱
    # 0x23DF2: '',  # 𣷲
    # 0x23DF3: '',  # 𣷳
    # 0x23DF4: '',  # 𣷴
    # 0x23DF5: '',  # 𣷵
    0x23DF6: 'sǔ',  # 𣷶
    # 0x23DF7: '',  # 𣷷
    # 0x23DF8: '',  # 𣷸
    # 0x23DF9: '',  # 𣷹
    # 0x23DFA: '',  # 𣷺
    # 0x23DFB: '',  # 𣷻
    # 0x23DFC: '',  # 𣷼
    # 0x23DFD: '',  # 𣷽
    0x23DFE: 'guǐ',  # 𣷾
    0x23DFF: 'tuǒ',  # 𣷿
    0x23E00: 'huǐ',  # 𣸀
    # 0x23E01: '',  # 𣸁
    # 0x23E02: '',  # 𣸂
    0x23E03: 'xù',  # 𣸃
    0x23E04: 'zǎn',  # 𣸄
    # 0x23E05: '',  # 𣸅
    0x23E06: 'zǐ',  # 𣸆
    0x23E07: 'biàn',  # 𣸇
    0x23E08: 'sǒu',  # 𣸈
    0x23E09: 'dá',  # 𣸉
    0x23E0A: 'yīn',  # 𣸊
    0x23E0B: 'quǎn',  # 𣸋
    # 0x23E0C: '',  # 𣸌
    # 0x23E0D: '',  # 𣸍
    0x23E0E: 'huài',  # 𣸎
    0x23E0F: 'ná',  # 𣸏
    0x23E10: 'zá',  # 𣸐
    # 0x23E11: '',  # 𣸑
    0x23E12: 'tí',  # 𣸒
    # 0x23E13: '',  # 𣸓
    # 0x23E14: '',  # 𣸔
    # 0x23E15: '',  # 𣸕
    # 0x23E16: '',  # 𣸖
    # 0x23E17: '',  # 𣸗
    0x23E18: 'yí',  # 𣸘
    0x23E19: 'tān',  # 𣸙
    0x23E1A: 'shé',  # 𣸚
    0x23E1B: 'shuò',  # 𣸛
    # 0x23E1C: '',  # 𣸜
    0x23E1D: 'xíng',  # 𣸝
    # 0x23E1E: '',  # 𣸞
    # 0x23E1F: '',  # 𣸟
    0x23E20: 'yǒu',  # 𣸠
    # 0x23E21: '',  # 𣸡
    # 0x23E22: '',  # 𣸢
    0x23E23: 'fén',  # 𣸣
    # 0x23E24: '',  # 𣸤
    # 0x23E25: '',  # 𣸥
    # 0x23E26: '',  # 𣸦
    # 0x23E27: '',  # 𣸧
    # 0x23E28: '',  # 𣸨
    # 0x23E29: '',  # 𣸩
    # 0x23E2A: '',  # 𣸪
    # 0x23E2B: '',  # 𣸫
    # 0x23E2C: '',  # 𣸬
    # 0x23E2D: '',  # 𣸭
    # 0x23E2E: '',  # 𣸮
    # 0x23E2F: '',  # 𣸯
    # 0x23E30: '',  # 𣸰
    # 0x23E31: '',  # 𣸱
    # 0x23E32: '',  # 𣸲
    # 0x23E33: '',  # 𣸳
    # 0x23E34: '',  # 𣸴
    # 0x23E35: '',  # 𣸵
    # 0x23E36: '',  # 𣸶
    # 0x23E37: '',  # 𣸷
    0x23E38: 'tiān',  # 𣸸
    # 0x23E39: '',  # 𣸹
    # 0x23E3A: '',  # 𣸺
    # 0x23E3B: '',  # 𣸻
    0x23E3C: 'yuán',  # 𣸼
    # 0x23E3D: '',  # 𣸽
    # 0x23E3E: '',  # 𣸾
    # 0x23E3F: '',  # 𣸿
    # 0x23E40: '',  # 𣹀
    # 0x23E41: '',  # 𣹁
    # 0x23E42: '',  # 𣹂
    # 0x23E43: '',  # 𣹃
    # 0x23E44: '',  # 𣹄
    # 0x23E45: '',  # 𣹅
    # 0x23E46: '',  # 𣹆
    0x23E47: 'kè',  # 𣹇
    # 0x23E48: '',  # 𣹈
    # 0x23E49: '',  # 𣹉
    # 0x23E4A: '',  # 𣹊
    0x23E4B: 'fú',  # 𣹋
    # 0x23E4C: '',  # 𣹌
    # 0x23E4D: '',  # 𣹍
    # 0x23E4E: '',  # 𣹎
    # 0x23E4F: '',  # 𣹏
    # 0x23E50: '',  # 𣹐
    # 0x23E51: '',  # 𣹑
    0x23E52: 'mǐn',  # 𣹒
    # 0x23E53: '',  # 𣹓
    # 0x23E54: '',  # 𣹔
    0x23E55: 'lǜ',  # 𣹕
    # 0x23E56: '',  # 𣹖
    # 0x23E57: '',  # 𣹗
    # 0x23E58: '',  # 𣹘
    # 0x23E59: '',  # 𣹙
    0x23E5A: 'pì',  # 𣹚
    # 0x23E5B: '',  # 𣹛
    0x23E5C: 'jí',  # 𣹜
    0x23E5D: 'qiào,xiào',  # 𣹝
    0x23E5E: 'zhǒng',  # 𣹞
    0x23E5F: 'gàn',  # 𣹟
    0x23E60: 'yuān',  # 𣹠
    0x23E61: 'chí',  # 𣹡
    0x23E62: 'hán',  # 𣹢
    # 0x23E63: '',  # 𣹣
    0x23E64: 'rù',  # 𣹤
    0x23E65: 'qiàn',  # 𣹥
    # 0x23E66: '',  # 𣹦
    0x23E67: 'zuó,zhà',  # 𣹧
    # 0x23E68: '',  # 𣹨
    0x23E69: 'xié',  # 𣹩
    0x23E6A: 'máo',  # 𣹪
    # 0x23E6B: '',  # 𣹫
    0x23E6C: 'hú',  # 𣹬
    0x23E6D: 'liú',  # 𣹭
    0x23E6E: 'pì',  # 𣹮
    0x23E6F: 'xùn',  # 𣹯
    # 0x23E70: '',  # 𣹰
    0x23E71: 'xiá',  # 𣹱
    0x23E72: 'tí',  # 𣹲
    # 0x23E73: '',  # 𣹳
    # 0x23E74: '',  # 𣹴
    0x23E75: 'nà',  # 𣹵
    0x23E76: 'chuǎ',  # 𣹶
    # 0x23E77: '',  # 𣹷
    # 0x23E78: '',  # 𣹸
    # 0x23E79: '',  # 𣹹
    # 0x23E7A: '',  # 𣹺
    # 0x23E7B: '',  # 𣹻
    # 0x23E7C: '',  # 𣹼
    # 0x23E7D: '',  # 𣹽
    # 0x23E7E: '',  # 𣹾
    # 0x23E7F: '',  # 𣹿
    0x23E80: 'wǔ',  # 𣺀
    # 0x23E81: '',  # 𣺁
    # 0x23E82: '',  # 𣺂
    # 0x23E83: '',  # 𣺃
    # 0x23E84: '',  # 𣺄
    # 0x23E85: '',  # 𣺅
    # 0x23E86: '',  # 𣺆
    # 0x23E87: '',  # 𣺇
    # 0x23E88: '',  # 𣺈
    # 0x23E89: '',  # 𣺉
    # 0x23E8A: '',  # 𣺊
    # 0x23E8B: '',  # 𣺋
    0x23E8C: 'miǎo',  # 𣺌
    # 0x23E8D: '',  # 𣺍
    # 0x23E8E: '',  # 𣺎
    # 0x23E8F: '',  # 𣺏
    # 0x23E90: '',  # 𣺐
    # 0x23E91: '',  # 𣺑
    # 0x23E92: '',  # 𣺒
    # 0x23E93: '',  # 𣺓
    # 0x23E94: '',  # 𣺔
    # 0x23E95: '',  # 𣺕
    # 0x23E96: '',  # 𣺖
    # 0x23E97: '',  # 𣺗
    # 0x23E98: '',  # 𣺘
    # 0x23E99: '',  # 𣺙
    # 0x23E9A: '',  # 𣺚
    # 0x23E9B: '',  # 𣺛
    # 0x23E9C: '',  # 𣺜
    # 0x23E9D: '',  # 𣺝
    # 0x23E9E: '',  # 𣺞
    # 0x23E9F: '',  # 𣺟
    # 0x23EA0: '',  # 𣺠
    # 0x23EA1: '',  # 𣺡
    # 0x23EA2: '',  # 𣺢
    # 0x23EA3: '',  # 𣺣
    # 0x23EA4: '',  # 𣺤
    # 0x23EA5: '',  # 𣺥
    # 0x23EA6: '',  # 𣺦
    # 0x23EA7: '',  # 𣺧
    # 0x23EA8: '',  # 𣺨
    # 0x23EA9: '',  # 𣺩
    # 0x23EAA: '',  # 𣺪
    # 0x23EAB: '',  # 𣺫
    0x23EAC: 'huāng',  # 𣺬
    0x23EAD: 'xuè',  # 𣺭
    0x23EAE: 'tào',  # 𣺮
    # 0x23EAF: '',  # 𣺯
    0x23EB0: 'qiào',  # 𣺰
    # 0x23EB1: '',  # 𣺱
    # 0x23EB2: '',  # 𣺲
    0x23EB3: 'jiāo',  # 𣺳
    # 0x23EB4: '',  # 𣺴
    # 0x23EB5: '',  # 𣺵
    # 0x23EB6: '',  # 𣺶
    # 0x23EB7: '',  # 𣺷
    # 0x23EB8: '',  # 𣺸
    0x23EB9: 'zhān',  # 𣺹
    # 0x23EBA: '',  # 𣺺
    # 0x23EBB: '',  # 𣺻
    # 0x23EBC: '',  # 𣺼
    # 0x23EBD: '',  # 𣺽
    # 0x23EBE: '',  # 𣺾
    # 0x23EBF: '',  # 𣺿
    # 0x23EC0: '',  # 𣻀
    # 0x23EC1: '',  # 𣻁
    # 0x23EC2: '',  # 𣻂
    # 0x23EC3: '',  # 𣻃
    # 0x23EC4: '',  # 𣻄
    # 0x23EC5: '',  # 𣻅
    # 0x23EC6: '',  # 𣻆
    # 0x23EC7: '',  # 𣻇
    # 0x23EC8: '',  # 𣻈
    # 0x23EC9: '',  # 𣻉
    # 0x23ECA: '',  # 𣻊
    # 0x23ECB: '',  # 𣻋
    # 0x23ECC: '',  # 𣻌
    0x23ECD: 'dàng,xiàng',  # 𣻍
    0x23ECE: 'kòu',  # 𣻎
    # 0x23ECF: '',  # 𣻏
    0x23ED0: 'jū',  # 𣻐
    0x23ED1: 'shā,shài',  # 𣻑
    0x23ED2: 'jīng',  # 𣻒
    # 0x23ED3: '',  # 𣻓
    # 0x23ED4: '',  # 𣻔
    0x23ED5: 'mó',  # 𣻕
    0x23ED6: 'nóu',  # 𣻖
    # 0x23ED7: '',  # 𣻗
    0x23ED8: 'shuò',  # 𣻘
    # 0x23ED9: '',  # 𣻙
    0x23EDA: 'shù',  # 𣻚
    0x23EDB: 'zhuāng',  # 𣻛
    0x23EDC: 'fú',  # 𣻜
    # 0x23EDD: '',  # 𣻝
    0x23EDE: 'zhǐ',  # 𣻞
    0x23EDF: 'zāng',  # 𣻟
    0x23EE0: 'xié',  # 𣻠
    0x23EE1: 'làng',  # 𣻡
    0x23EE2: 'tōng',  # 𣻢
    0x23EE3: 'shè',  # 𣻣
    # 0x23EE4: '',  # 𣻤
    # 0x23EE5: '',  # 𣻥
    # 0x23EE6: '',  # 𣻦
    # 0x23EE7: '',  # 𣻧
    # 0x23EE8: '',  # 𣻨
    0x23EE9: 'zhé',  # 𣻩
    # 0x23EEA: '',  # 𣻪
    # 0x23EEB: '',  # 𣻫
    0x23EEC: 'càn',  # 𣻬
    # 0x23EED: '',  # 𣻭
    0x23EEE: 'yuè',  # 𣻮
    # 0x23EEF: '',  # 𣻯
    # 0x23EF0: '',  # 𣻰
    0x23EF1: 'zhòu',  # 𣻱
    # 0x23EF2: '',  # 𣻲
    # 0x23EF3: '',  # 𣻳
    # 0x23EF4: '',  # 𣻴
    # 0x23EF5: '',  # 𣻵
    # 0x23EF6: '',  # 𣻶
    # 0x23EF7: '',  # 𣻷
    # 0x23EF8: '',  # 𣻸
    # 0x23EF9: '',  # 𣻹
    # 0x23EFA: '',  # 𣻺
    # 0x23EFB: '',  # 𣻻
    # 0x23EFC: '',  # 𣻼
    # 0x23EFD: '',  # 𣻽
    # 0x23EFE: '',  # 𣻾
    # 0x23EFF: '',  # 𣻿
    # 0x23F00: '',  # 𣼀
    # 0x23F01: '',  # 𣼁
    # 0x23F02: '',  # 𣼂
    # 0x23F03: '',  # 𣼃
    # 0x23F04: '',  # 𣼄
    # 0x23F05: '',  # 𣼅
    # 0x23F06: '',  # 𣼆
    # 0x23F07: '',  # 𣼇
    # 0x23F08: '',  # 𣼈
    # 0x23F09: '',  # 𣼉
    # 0x23F0A: '',  # 𣼊
    # 0x23F0B: '',  # 𣼋
    # 0x23F0C: '',  # 𣼌
    # 0x23F0D: '',  # 𣼍
    # 0x23F0E: '',  # 𣼎
    # 0x23F0F: '',  # 𣼏
    # 0x23F10: '',  # 𣼐
    # 0x23F11: '',  # 𣼑
    # 0x23F12: '',  # 𣼒
    # 0x23F13: '',  # 𣼓
    # 0x23F14: '',  # 𣼔
    # 0x23F15: '',  # 𣼕
    # 0x23F16: '',  # 𣼖
    # 0x23F17: '',  # 𣼗
    # 0x23F18: '',  # 𣼘
    # 0x23F19: '',  # 𣼙
    0x23F1A: 'tān',  # 𣼚
    # 0x23F1B: '',  # 𣼛
    # 0x23F1C: '',  # 𣼜
    # 0x23F1D: '',  # 𣼝
    0x23F1E: 'yán',  # 𣼞
    0x23F1F: 'lù',  # 𣼟
    0x23F20: 'yǎn',  # 𣼠
    # 0x23F21: '',  # 𣼡
    # 0x23F22: '',  # 𣼢
    # 0x23F23: '',  # 𣼣
    # 0x23F24: '',  # 𣼤
    # 0x23F25: '',  # 𣼥
    0x23F26: 'zé',  # 𣼦
    0x23F27: 'shuài',  # 𣼧
    # 0x23F28: '',  # 𣼨
    # 0x23F29: '',  # 𣼩
    # 0x23F2A: '',  # 𣼪
    # 0x23F2B: '',  # 𣼫
    # 0x23F2C: '',  # 𣼬
    # 0x23F2D: '',  # 𣼭
    # 0x23F2E: '',  # 𣼮
    # 0x23F2F: '',  # 𣼯
    # 0x23F30: '',  # 𣼰
    # 0x23F31: '',  # 𣼱
    # 0x23F32: '',  # 𣼲
    # 0x23F33: '',  # 𣼳
    # 0x23F34: '',  # 𣼴
    # 0x23F35: '',  # 𣼵
    # 0x23F36: '',  # 𣼶
    # 0x23F37: '',  # 𣼷
    # 0x23F38: '',  # 𣼸
    # 0x23F39: '',  # 𣼹
    # 0x23F3A: '',  # 𣼺
    # 0x23F3B: '',  # 𣼻
    # 0x23F3C: '',  # 𣼼
    0x23F3D: 'lǎng',  # 𣼽
    # 0x23F3E: '',  # 𣼾
    # 0x23F3F: '',  # 𣼿
    # 0x23F40: '',  # 𣽀
    # 0x23F41: '',  # 𣽁
    # 0x23F42: '',  # 𣽂
    # 0x23F43: '',  # 𣽃
    # 0x23F44: '',  # 𣽄
    0x23F45: 'guō',  # 𣽅
    0x23F46: 'zhú',  # 𣽆
    # 0x23F47: '',  # 𣽇
    0x23F48: 'rú,ruán',  # 𣽈
    0x23F49: 'rú',  # 𣽉
    # 0x23F4A: '',  # 𣽊
    # 0x23F4B: '',  # 𣽋
    0x23F4C: 'kǎn',  # 𣽌
    0x23F4D: 'jì',  # 𣽍
    0x23F4E: 'gāo,zé,háo',  # 𣽎
    0x23F4F: 'wū',  # 𣽏
    # 0x23F50: '',  # 𣽐
    # 0x23F51: '',  # 𣽑
    0x23F52: 'xiè',  # 𣽒
    # 0x23F53: '',  # 𣽓
    # 0x23F54: '',  # 𣽔
    0x23F55: 'òu',  # 𣽕
    0x23F56: 'jiān',  # 𣽖
    # 0x23F57: '',  # 𣽗
    # 0x23F58: '',  # 𣽘
    # 0x23F59: '',  # 𣽙
    0x23F5A: 'zhí',  # 𣽚
    0x23F5B: 'zhá',  # 𣽛
    # 0x23F5C: '',  # 𣽜
    0x23F5D: 'hǒng',  # 𣽝
    # 0x23F5E: '',  # 𣽞
    0x23F5F: 'kuǎn',  # 𣽟
    # 0x23F60: '',  # 𣽠
    0x23F61: 'bó',  # 𣽡
    # 0x23F62: '',  # 𣽢
    # 0x23F63: '',  # 𣽣
    0x23F64: 'sè',  # 𣽤
    0x23F65: 'àn',  # 𣽥
    0x23F66: 'jiàn',  # 𣽦
    # 0x23F67: '',  # 𣽧
    0x23F68: 'téng',  # 𣽨
    # 0x23F69: '',  # 𣽩
    # 0x23F6A: '',  # 𣽪
    0x23F6B: 'sōng',  # 𣽫
    # 0x23F6C: '',  # 𣽬
    0x23F6D: 'mèng',  # 𣽭
    0x23F6E: 'yín',  # 𣽮
    0x23F6F: 'tān',  # 𣽯
    0x23F70: 'guō',  # 𣽰
    # 0x23F71: '',  # 𣽱
    # 0x23F72: '',  # 𣽲
    0x23F73: 'ruán',  # 𣽳
    0x23F74: 'wèi',  # 𣽴
    # 0x23F75: '',  # 𣽵
    # 0x23F76: '',  # 𣽶
    # 0x23F77: '',  # 𣽷
    # 0x23F78: '',  # 𣽸
    # 0x23F79: '',  # 𣽹
    # 0x23F7A: '',  # 𣽺
    # 0x23F7B: '',  # 𣽻
    # 0x23F7C: '',  # 𣽼
    # 0x23F7D: '',  # 𣽽
    # 0x23F7E: '',  # 𣽾
    # 0x23F7F: '',  # 𣽿
    # 0x23F80: '',  # 𣾀
    # 0x23F81: '',  # 𣾁
    # 0x23F82: '',  # 𣾂
    # 0x23F83: '',  # 𣾃
    # 0x23F84: '',  # 𣾄
    # 0x23F85: '',  # 𣾅
    # 0x23F86: '',  # 𣾆
    # 0x23F87: '',  # 𣾇
    # 0x23F88: '',  # 𣾈
    # 0x23F89: '',  # 𣾉
    # 0x23F8A: '',  # 𣾊
    # 0x23F8B: '',  # 𣾋
    # 0x23F8C: '',  # 𣾌
    # 0x23F8D: '',  # 𣾍
    # 0x23F8E: '',  # 𣾎
    # 0x23F8F: '',  # 𣾏
    # 0x23F90: '',  # 𣾐
    # 0x23F91: '',  # 𣾑
    # 0x23F92: '',  # 𣾒
    # 0x23F93: '',  # 𣾓
    # 0x23F94: '',  # 𣾔
    # 0x23F95: '',  # 𣾕
    # 0x23F96: '',  # 𣾖
    # 0x23F97: '',  # 𣾗
    # 0x23F98: '',  # 𣾘
    # 0x23F99: '',  # 𣾙
    # 0x23F9A: '',  # 𣾚
    # 0x23F9B: '',  # 𣾛
    # 0x23F9C: '',  # 𣾜
    # 0x23F9D: '',  # 𣾝
    # 0x23F9E: '',  # 𣾞
    # 0x23F9F: '',  # 𣾟
    # 0x23FA0: '',  # 𣾠
    # 0x23FA1: '',  # 𣾡
    # 0x23FA2: '',  # 𣾢
    # 0x23FA3: '',  # 𣾣
    0x23FA4: 'qì',  # 𣾤
    # 0x23FA5: '',  # 𣾥
    0x23FA6: 'zhǎng',  # 𣾦
    # 0x23FA7: '',  # 𣾧
    # 0x23FA8: '',  # 𣾨
    # 0x23FA9: '',  # 𣾩
    # 0x23FAA: '',  # 𣾪
    # 0x23FAB: '',  # 𣾫
    # 0x23FAC: '',  # 𣾬
    # 0x23FAD: '',  # 𣾭
    # 0x23FAE: '',  # 𣾮
    # 0x23FAF: '',  # 𣾯
    # 0x23FB0: '',  # 𣾰
    # 0x23FB1: '',  # 𣾱
    # 0x23FB2: '',  # 𣾲
    # 0x23FB3: '',  # 𣾳
    # 0x23FB4: '',  # 𣾴
    # 0x23FB5: '',  # 𣾵
    # 0x23FB6: '',  # 𣾶
    # 0x23FB7: '',  # 𣾷
    # 0x23FB8: '',  # 𣾸
    # 0x23FB9: '',  # 𣾹
    # 0x23FBA: '',  # 𣾺
    # 0x23FBB: '',  # 𣾻
    # 0x23FBC: '',  # 𣾼
    # 0x23FBD: '',  # 𣾽
    # 0x23FBE: '',  # 𣾾
    # 0x23FBF: '',  # 𣾿
    # 0x23FC0: '',  # 𣿀
    # 0x23FC1: '',  # 𣿁
    # 0x23FC2: '',  # 𣿂
    # 0x23FC3: '',  # 𣿃
    # 0x23FC4: '',  # 𣿄
    0x23FC5: 'dǒng',  # 𣿅
    0x23FC6: 'fú',  # 𣿆
    0x23FC7: 'shěn',  # 𣿇
    0x23FC8: 'sù',  # 𣿈
    0x23FC9: 'yì',  # 𣿉
    0x23FCA: 'liàn',  # 𣿊
    # 0x23FCB: '',  # 𣿋
    0x23FCC: 'hé',  # 𣿌
    # 0x23FCD: '',  # 𣿍
    0x23FCE: 'zhēn',  # 𣿎
    # 0x23FCF: '',  # 𣿏
    0x23FD0: 'zé',  # 𣿐
    # 0x23FD1: '',  # 𣿑
    0x23FD2: 'cuǐ',  # 𣿒
    0x23FD3: 'cuǐ',  # 𣿓
    # 0x23FD4: '',  # 𣿔
    # 0x23FD5: '',  # 𣿕
    # 0x23FD6: '',  # 𣿖
    # 0x23FD7: '',  # 𣿗
    # 0x23FD8: '',  # 𣿘
    # 0x23FD9: '',  # 𣿙
    # 0x23FDA: '',  # 𣿚
    # 0x23FDB: '',  # 𣿛
    # 0x23FDC: '',  # 𣿜
    0x23FDD: 'fèng',  # 𣿝
    0x23FDE: 'lǐ',  # 𣿞
    0x23FDF: 'kòu',  # 𣿟
    # 0x23FE0: '',  # 𣿠
    # 0x23FE1: '',  # 𣿡
    # 0x23FE2: '',  # 𣿢
    0x23FE3: 'xiào',  # 𣿣
    0x23FE4: 'yǒu',  # 𣿤
    # 0x23FE5: '',  # 𣿥
    # 0x23FE6: '',  # 𣿦
    # 0x23FE7: '',  # 𣿧
    0x23FE8: 'xiè',  # 𣿨
    # 0x23FE9: '',  # 𣿩
    # 0x23FEA: '',  # 𣿪
    # 0x23FEB: '',  # 𣿫
    # 0x23FEC: '',  # 𣿬
    # 0x23FED: '',  # 𣿭
    # 0x23FEE: '',  # 𣿮
    # 0x23FEF: '',  # 𣿯
    # 0x23FF0: '',  # 𣿰
    # 0x23FF1: '',  # 𣿱
    # 0x23FF2: '',  # 𣿲
    # 0x23FF3: '',  # 𣿳
    0x23FF4: 'dàng',  # 𣿴
    # 0x23FF5: '',  # 𣿵
    # 0x23FF6: '',  # 𣿶
    # 0x23FF7: '',  # 𣿷
    # 0x23FF8: '',  # 𣿸
    # 0x23FF9: '',  # 𣿹
    # 0x23FFA: '',  # 𣿺
    # 0x23FFB: '',  # 𣿻
    # 0x23FFC: '',  # 𣿼
    # 0x23FFD: '',  # 𣿽
    # 0x23FFE: '',  # 𣿾
    # 0x23FFF: '',  # 𣿿
    # 0x24000: '',  # 𤀀
    # 0x24001: '',  # 𤀁
    # 0x24002: '',  # 𤀂
    0x24003: 'háo',  # 𤀃
    # 0x24004: '',  # 𤀄
    # 0x24005: '',  # 𤀅
    # 0x24006: '',  # 𤀆
    # 0x24007: '',  # 𤀇
    # 0x24008: '',  # 𤀈
    0x24009: 'hàn',  # 𤀉
    0x2400A: 'kěn',  # 𤀊
    # 0x2400B: '',  # 𤀋
    # 0x2400C: '',  # 𤀌
    # 0x2400D: '',  # 𤀍
    # 0x2400E: '',  # 𤀎
    # 0x2400F: '',  # 𤀏
    # 0x24010: '',  # 𤀐
    # 0x24011: '',  # 𤀑
    # 0x24012: '',  # 𤀒
    # 0x24013: '',  # 𤀓
    # 0x24014: '',  # 𤀔
    # 0x24015: '',  # 𤀕
    # 0x24016: '',  # 𤀖
    # 0x24017: '',  # 𤀗
    # 0x24018: '',  # 𤀘
    # 0x24019: '',  # 𤀙
    # 0x2401A: '',  # 𤀚
    # 0x2401B: '',  # 𤀛
    # 0x2401C: '',  # 𤀜
    0x2401D: 'yù',  # 𤀝
    # 0x2401E: '',  # 𤀞
    # 0x2401F: '',  # 𤀟
    0x24020: 'xī',  # 𤀠
    # 0x24021: '',  # 𤀡
    # 0x24022: '',  # 𤀢
    0x24023: 'huǎn',  # 𤀣
    0x24024: 'suō,shàn,shuài',  # 𤀤
    # 0x24025: '',  # 𤀥
    0x24026: 'là',  # 𤀦
    # 0x24027: '',  # 𤀧
    0x24028: 'dòu',  # 𤀨
    0x24029: 'jiàn',  # 𤀩
    0x2402A: 'pō',  # 𤀪
    0x2402B: 'biǎn',  # 𤀫
    # 0x2402C: '',  # 𤀬
    # 0x2402D: '',  # 𤀭
    # 0x2402E: '',  # 𤀮
    # 0x2402F: '',  # 𤀯
    0x24030: 'xuè',  # 𤀰
    # 0x24031: '',  # 𤀱
    0x24032: 'biàn',  # 𤀲
    # 0x24033: '',  # 𤀳
    # 0x24034: '',  # 𤀴
    # 0x24035: '',  # 𤀵
    # 0x24036: '',  # 𤀶
    0x24037: 'wèi',  # 𤀷
    # 0x24038: '',  # 𤀸
    # 0x24039: '',  # 𤀹
    # 0x2403A: '',  # 𤀺
    # 0x2403B: '',  # 𤀻
    # 0x2403C: '',  # 𤀼
    # 0x2403D: '',  # 𤀽
    # 0x2403E: '',  # 𤀾
    # 0x2403F: '',  # 𤀿
    # 0x24040: '',  # 𤁀
    # 0x24041: '',  # 𤁁
    # 0x24042: '',  # 𤁂
    # 0x24043: '',  # 𤁃
    # 0x24044: '',  # 𤁄
    # 0x24045: '',  # 𤁅
    # 0x24046: '',  # 𤁆
    # 0x24047: '',  # 𤁇
    # 0x24048: '',  # 𤁈
    # 0x24049: '',  # 𤁉
    # 0x2404A: '',  # 𤁊
    # 0x2404B: '',  # 𤁋
    # 0x2404C: '',  # 𤁌
    # 0x2404D: '',  # 𤁍
    # 0x2404E: '',  # 𤁎
    # 0x2404F: '',  # 𤁏
    # 0x24050: '',  # 𤁐
    # 0x24051: '',  # 𤁑
    # 0x24052: '',  # 𤁒
    # 0x24053: '',  # 𤁓
    # 0x24054: '',  # 𤁔
    # 0x24055: '',  # 𤁕
    # 0x24056: '',  # 𤁖
    # 0x24057: '',  # 𤁗
    # 0x24058: '',  # 𤁘
    # 0x24059: '',  # 𤁙
    # 0x2405A: '',  # 𤁚
    # 0x2405B: '',  # 𤁛
    # 0x2405C: '',  # 𤁜
    # 0x2405D: '',  # 𤁝
    # 0x2405E: '',  # 𤁞
    # 0x2405F: '',  # 𤁟
    # 0x24060: '',  # 𤁠
    0x24061: 'dàn',  # 𤁡
    0x24062: 'jié',  # 𤁢
    0x24063: 'bài',  # 𤁣
    # 0x24064: '',  # 𤁤
    0x24065: 'niǎn',  # 𤁥
    0x24066: 'xiàn',  # 𤁦
    0x24067: 'sè',  # 𤁧
    # 0x24068: '',  # 𤁨
    # 0x24069: '',  # 𤁩
    0x2406A: 'huá',  # 𤁪
    0x2406B: 'chuā',  # 𤁫
    # 0x2406C: '',  # 𤁬
    # 0x2406D: '',  # 𤁭
    0x2406E: 'òu',  # 𤁮
    0x2406F: 'liè',  # 𤁯
    0x24070: 'dí',  # 𤁰
    0x24071: 'cài',  # 𤁱
    # 0x24072: '',  # 𤁲
    0x24073: 'zhá',  # 𤁳
    # 0x24074: '',  # 𤁴
    0x24075: 'lǘ',  # 𤁵
    # 0x24076: '',  # 𤁶
    # 0x24077: '',  # 𤁷
    # 0x24078: '',  # 𤁸
    0x24079: 'huò',  # 𤁹
    # 0x2407A: '',  # 𤁺
    # 0x2407B: '',  # 𤁻
    0x2407C: 'lì',  # 𤁼
    0x2407D: 'yǐng',  # 𤁽
    # 0x2407E: '',  # 𤁾
    0x2407F: 'wěi',  # 𤁿
    0x24080: 'bì',  # 𤂀
    0x24081: 'guó',  # 𤂁
    # 0x24082: '',  # 𤂂
    0x24083: 'pì',  # 𤂃
    # 0x24084: '',  # 𤂄
    # 0x24085: '',  # 𤂅
    0x24086: 'biāo',  # 𤂆
    # 0x24087: '',  # 𤂇
    # 0x24088: '',  # 𤂈
    # 0x24089: '',  # 𤂉
    # 0x2408A: '',  # 𤂊
    # 0x2408B: '',  # 𤂋
    # 0x2408C: '',  # 𤂌
    # 0x2408D: '',  # 𤂍
    # 0x2408E: '',  # 𤂎
    # 0x2408F: '',  # 𤂏
    # 0x24090: '',  # 𤂐
    0x24091: 'nóng',  # 𤂑
    # 0x24092: '',  # 𤂒
    # 0x24093: '',  # 𤂓
    # 0x24094: '',  # 𤂔
    # 0x24095: '',  # 𤂕
    # 0x24096: '',  # 𤂖
    # 0x24097: '',  # 𤂗
    # 0x24098: '',  # 𤂘
    # 0x24099: '',  # 𤂙
    # 0x2409A: '',  # 𤂚
    # 0x2409B: '',  # 𤂛
    # 0x2409C: '',  # 𤂜
    # 0x2409D: '',  # 𤂝
    # 0x2409E: '',  # 𤂞
    # 0x2409F: '',  # 𤂟
    0x240A0: 'yǎn',  # 𤂠
    # 0x240A1: '',  # 𤂡
    # 0x240A2: '',  # 𤂢
    # 0x240A3: '',  # 𤂣
    0x240A4: 'zhuàn',  # 𤂤
    # 0x240A5: '',  # 𤂥
    # 0x240A6: '',  # 𤂦
    # 0x240A7: '',  # 𤂧
    # 0x240A8: '',  # 𤂨
    # 0x240A9: '',  # 𤂩
    # 0x240AA: '',  # 𤂪
    # 0x240AB: '',  # 𤂫
    # 0x240AC: '',  # 𤂬
    # 0x240AD: '',  # 𤂭
    # 0x240AE: '',  # 𤂮
    # 0x240AF: '',  # 𤂯
    # 0x240B0: '',  # 𤂰
    # 0x240B1: '',  # 𤂱
    0x240B2: 'hóng',  # 𤂲
    # 0x240B3: '',  # 𤂳
    # 0x240B4: '',  # 𤂴
    # 0x240B5: '',  # 𤂵
    0x240B6: 'lìn',  # 𤂶
    0x240B7: 'è',  # 𤂷
    # 0x240B8: '',  # 𤂸
    0x240B9: 'yǐn',  # 𤂹
    0x240BA: 'làn',  # 𤂺
    # 0x240BB: '',  # 𤂻
    0x240BC: 'yào',  # 𤂼
    # 0x240BD: '',  # 𤂽
    # 0x240BE: '',  # 𤂾
    0x240BF: 'xuàn',  # 𤂿
    0x240C0: 'lì',  # 𤃀
    # 0x240C1: '',  # 𤃁
    # 0x240C2: '',  # 𤃂
    # 0x240C3: '',  # 𤃃
    # 0x240C4: '',  # 𤃄
    # 0x240C5: '',  # 𤃅
    # 0x240C6: '',  # 𤃆
    # 0x240C7: '',  # 𤃇
    # 0x240C8: '',  # 𤃈
    # 0x240C9: '',  # 𤃉
    # 0x240CA: '',  # 𤃊
    # 0x240CB: '',  # 𤃋
    # 0x240CC: '',  # 𤃌
    # 0x240CD: '',  # 𤃍
    # 0x240CE: '',  # 𤃎
    # 0x240CF: '',  # 𤃏
    # 0x240D0: '',  # 𤃐
    # 0x240D1: '',  # 𤃑
    # 0x240D2: '',  # 𤃒
    # 0x240D3: '',  # 𤃓
    # 0x240D4: '',  # 𤃔
    # 0x240D5: '',  # 𤃕
    # 0x240D6: '',  # 𤃖
    # 0x240D7: '',  # 𤃗
    # 0x240D8: '',  # 𤃘
    # 0x240D9: '',  # 𤃙
    # 0x240DA: '',  # 𤃚
    # 0x240DB: '',  # 𤃛
    # 0x240DC: '',  # 𤃜
    # 0x240DD: '',  # 𤃝
    # 0x240DE: '',  # 𤃞
    # 0x240DF: '',  # 𤃟
    # 0x240E0: '',  # 𤃠
    # 0x240E1: '',  # 𤃡
    # 0x240E2: '',  # 𤃢
    # 0x240E3: '',  # 𤃣
    # 0x240E4: '',  # 𤃤
    # 0x240E5: '',  # 𤃥
    # 0x240E6: '',  # 𤃦
    # 0x240E7: '',  # 𤃧
    0x240E8: 'làn',  # 𤃨
    0x240E9: 'líng',  # 𤃩
    0x240EA: 'xī',  # 𤃪
    0x240EB: 'hōng',  # 𤃫
    0x240EC: 'huàn',  # 𤃬
    0x240ED: 'jiǎo',  # 𤃭
    0x240EE: 'zhuó',  # 𤃮
    # 0x240EF: '',  # 𤃯
    # 0x240F0: '',  # 𤃰
    # 0x240F1: '',  # 𤃱
    0x240F2: 'zhí',  # 𤃲
    # 0x240F3: '',  # 𤃳
    0x240F4: 'huò',  # 𤃴
    0x240F5: 'bó',  # 𤃵
    0x240F6: 'tēng',  # 𤃶
    0x240F7: 'ǎn',  # 𤃷
    # 0x240F8: '',  # 𤃸
    # 0x240F9: '',  # 𤃹
    0x240FA: 'xún',  # 𤃺
    0x240FB: 'lěi',  # 𤃻
    0x240FC: 'zāng',  # 𤃼
    0x240FD: 'huǐ',  # 𤃽
    # 0x240FE: '',  # 𤃾
    # 0x240FF: '',  # 𤃿
    # 0x24100: '',  # 𤄀
    # 0x24101: '',  # 𤄁
    # 0x24102: '',  # 𤄂
    # 0x24103: '',  # 𤄃
    # 0x24104: '',  # 𤄄
    # 0x24105: '',  # 𤄅
    # 0x24106: '',  # 𤄆
    # 0x24107: '',  # 𤄇
    # 0x24108: '',  # 𤄈
    # 0x24109: '',  # 𤄉
    # 0x2410A: '',  # 𤄊
    # 0x2410B: '',  # 𤄋
    # 0x2410C: '',  # 𤄌
    # 0x2410D: '',  # 𤄍
    0x2410E: 'xì',  # 𤄎
    0x2410F: 'hóng',  # 𤄏
    # 0x24110: '',  # 𤄐
    0x24111: 'fàn',  # 𤄑
    0x24112: 'jiǎn',  # 𤄒
    0x24113: 'cóng',  # 𤄓
    0x24114: 'zá',  # 𤄔
    # 0x24115: '',  # 𤄕
    0x24116: 'cā,zá',  # 𤄖
    # 0x24117: '',  # 𤄗
    0x24118: 'yōu',  # 𤄘
    # 0x24119: '',  # 𤄙
    # 0x2411A: '',  # 𤄚
    0x2411B: 'duì',  # 𤄛
    0x2411C: 'pān',  # 𤄜
    # 0x2411D: '',  # 𤄝
    # 0x2411E: '',  # 𤄞
    # 0x2411F: '',  # 𤄟
    # 0x24120: '',  # 𤄠
    # 0x24121: '',  # 𤄡
    # 0x24122: '',  # 𤄢
    # 0x24123: '',  # 𤄣
    # 0x24124: '',  # 𤄤
    0x24125: 'tà',  # 𤄥
    # 0x24126: '',  # 𤄦
    0x24127: 'pàn',  # 𤄧
    # 0x24128: '',  # 𤄨
    # 0x24129: '',  # 𤄩
    # 0x2412A: '',  # 𤄪
    0x2412B: 'fān',  # 𤄫
    0x2412C: 'xī',  # 𤄬
    # 0x2412D: '',  # 𤄭
    # 0x2412E: '',  # 𤄮
    # 0x2412F: '',  # 𤄯
    # 0x24130: '',  # 𤄰
    # 0x24131: '',  # 𤄱
    # 0x24132: '',  # 𤄲
    # 0x24133: '',  # 𤄳
    # 0x24134: '',  # 𤄴
    # 0x24135: '',  # 𤄵
    0x24136: 'yào,shuò',  # 𤄶
    0x24137: 'luó',  # 𤄷
    # 0x24138: '',  # 𤄸
    # 0x24139: '',  # 𤄹
    0x2413A: 'biān',  # 𤄺
    # 0x2413B: '',  # 𤄻
    0x2413C: 'jìn',  # 𤄼
    0x2413D: 'lì',  # 𤄽
    # 0x2413E: '',  # 𤄾
    # 0x2413F: '',  # 𤄿
    # 0x24140: '',  # 𤅀
    # 0x24141: '',  # 𤅁
    # 0x24142: '',  # 𤅂
    # 0x24143: '',  # 𤅃
    # 0x24144: '',  # 𤅄
    # 0x24145: '',  # 𤅅
    # 0x24146: '',  # 𤅆
    # 0x24147: '',  # 𤅇
    # 0x24148: '',  # 𤅈
    # 0x24149: '',  # 𤅉
    0x2414A: 'yàn',  # 𤅊
    0x2414B: 'dòu',  # 𤅋
    # 0x2414C: '',  # 𤅌
    # 0x2414D: '',  # 𤅍
    0x2414E: 'màn',  # 𤅎
    # 0x2414F: '',  # 𤅏
    0x24150: 'gōng',  # 𤅐
    0x24151: 'rǎng',  # 𤅑
    0x24152: 'càn',  # 𤅒
    # 0x24153: '',  # 𤅓
    # 0x24154: '',  # 𤅔
    # 0x24155: '',  # 𤅕
    # 0x24156: '',  # 𤅖
    # 0x24157: '',  # 𤅗
    # 0x24158: '',  # 𤅘
    # 0x24159: '',  # 𤅙
    # 0x2415A: '',  # 𤅚
    # 0x2415B: '',  # 𤅛
    # 0x2415C: '',  # 𤅜
    # 0x2415D: '',  # 𤅝
    # 0x2415E: '',  # 𤅞
    # 0x2415F: '',  # 𤅟
    # 0x24160: '',  # 𤅠
    # 0x24161: '',  # 𤅡
    # 0x24162: '',  # 𤅢
    0x24163: 'mén',  # 𤅣
    0x24164: 'mí',  # 𤅤
    # 0x24165: '',  # 𤅥
    0x24166: 'tán',  # 𤅦
    # 0x24167: '',  # 𤅧
    # 0x24168: '',  # 𤅨
    0x24169: 'tān',  # 𤅩
    # 0x2416A: '',  # 𤅪
    # 0x2416B: '',  # 𤅫
    # 0x2416C: '',  # 𤅬
    # 0x2416D: '',  # 𤅭
    # 0x2416E: '',  # 𤅮
    # 0x2416F: '',  # 𤅯
    # 0x24170: '',  # 𤅰
    0x24171: 'gǔ',  # 𤅱
    0x24172: 'shuàn',  # 𤅲
    # 0x24173: '',  # 𤅳
    # 0x24174: '',  # 𤅴
    # 0x24175: '',  # 𤅵
    # 0x24176: '',  # 𤅶
    # 0x24177: '',  # 𤅷
    0x24178: 'yán,yàn',  # 𤅸
    0x24179: 'bì',  # 𤅹
    # 0x2417A: '',  # 𤅺
    # 0x2417B: '',  # 𤅻
    # 0x2417C: '',  # 𤅼
    # 0x2417D: '',  # 𤅽
    # 0x2417E: '',  # 𤅾
    # 0x2417F: '',  # 𤅿
    0x24180: 'biāo',  # 𤆀
    0x24181: 'chéng',  # 𤆁
    0x24182: 'kuì',  # 𤆂
    # 0x24183: '',  # 𤆃
    0x24184: 'huǒ,zāi',  # 𤆄
    # 0x24185: '',  # 𤆅
    # 0x24186: '',  # 𤆆
    # 0x24187: '',  # 𤆇
    # 0x24188: '',  # 𤆈
    # 0x24189: '',  # 𤆉
    # 0x2418A: '',  # 𤆊
    # 0x2418B: '',  # 𤆋
    0x2418C: 'yán',  # 𤆌
    0x2418D: 'chì',  # 𤆍
    # 0x2418E: '',  # 𤆎
    0x2418F: 'wò',  # 𤆏
    # 0x24190: '',  # 𤆐
    0x24191: 'còu',  # 𤆑
    0x24192: 'zhì',  # 𤆒
    # 0x24193: '',  # 𤆓
    # 0x24194: '',  # 𤆔
    0x24195: 'rěn',  # 𤆕
    # 0x24196: '',  # 𤆖
    # 0x24197: '',  # 𤆗
    # 0x24198: '',  # 𤆘
    0x24199: 'shuǐ',  # 𤆙
    # 0x2419A: '',  # 𤆚
    # 0x2419B: '',  # 𤆛
    0x2419C: 'guà',  # 𤆜
    0x2419D: 'pū',  # 𤆝
    0x2419E: 'xù',  # 𤆞
    0x2419F: 'sī',  # 𤆟
    # 0x241A0: '',  # 𤆠
    0x241A1: 'wǔ',  # 𤆡
    # 0x241A2: '',  # 𤆢
    # 0x241A3: '',  # 𤆣
    0x241A4: 'zhèn',  # 𤆤
    # 0x241A5: '',  # 𤆥
    # 0x241A6: '',  # 𤆦
    # 0x241A7: '',  # 𤆧
    # 0x241A8: '',  # 𤆨
    # 0x241A9: '',  # 𤆩
    # 0x241AA: '',  # 𤆪
    # 0x241AB: '',  # 𤆫
    0x241AC: 'qǔ',  # 𤆬
    # 0x241AD: '',  # 𤆭
    0x241AE: 'fū',  # 𤆮
    # 0x241AF: '',  # 𤆯
    0x241B0: 'shì',  # 𤆰
    # 0x241B1: '',  # 𤆱
    # 0x241B2: '',  # 𤆲
    0x241B3: 'huì',  # 𤆳
    0x241B4: 'huāng',  # 𤆴
    0x241B5: 'pā',  # 𤆵
    0x241B6: 'fén',  # 𤆶
    # 0x241B7: '',  # 𤆷
    # 0x241B8: '',  # 𤆸
    # 0x241B9: '',  # 𤆹
    0x241BA: 'kǒng',  # 𤆺
    # 0x241BB: '',  # 𤆻
    0x241BC: 'zhǔ',  # 𤆼
    # 0x241BD: '',  # 𤆽
    0x241BE: 'yí',  # 𤆾
    # 0x241BF: '',  # 𤆿
    # 0x241C0: '',  # 𤇀
    # 0x241C1: '',  # 𤇁
    # 0x241C2: '',  # 𤇂
    # 0x241C3: '',  # 𤇃
    # 0x241C4: '',  # 𤇄
    # 0x241C5: '',  # 𤇅
    # 0x241C6: '',  # 𤇆
    # 0x241C7: '',  # 𤇇
    # 0x241C8: '',  # 𤇈
    # 0x241C9: '',  # 𤇉
    # 0x241CA: '',  # 𤇊
    # 0x241CB: '',  # 𤇋
    # 0x241CC: '',  # 𤇌
    # 0x241CD: '',  # 𤇍
    # 0x241CE: '',  # 𤇎
    0x241CF: 'zhēng',  # 𤇏
    # 0x241D0: '',  # 𤇐
    # 0x241D1: '',  # 𤇑
    # 0x241D2: '',  # 𤇒
    # 0x241D3: '',  # 𤇓
    # 0x241D4: '',  # 𤇔
    # 0x241D5: '',  # 𤇕
    # 0x241D6: '',  # 𤇖
    # 0x241D7: '',  # 𤇗
    # 0x241D8: '',  # 𤇘
    # 0x241D9: '',  # 𤇙
    # 0x241DA: '',  # 𤇚
    # 0x241DB: '',  # 𤇛
    0x241DC: 'mín',  # 𤇜
    # 0x241DD: '',  # 𤇝
    0x241DE: 'gē',  # 𤇞
    # 0x241DF: '',  # 𤇟
    0x241E0: 'hū',  # 𤇠
    # 0x241E1: '',  # 𤇡
    # 0x241E2: '',  # 𤇢
    # 0x241E3: '',  # 𤇣
    # 0x241E4: '',  # 𤇤
    # 0x241E5: '',  # 𤇥
    # 0x241E6: '',  # 𤇦
    # 0x241E7: '',  # 𤇧
    # 0x241E8: '',  # 𤇨
    # 0x241E9: '',  # 𤇩
    # 0x241EA: '',  # 𤇪
    # 0x241EB: '',  # 𤇫
    # 0x241EC: '',  # 𤇬
    # 0x241ED: '',  # 𤇭
    0x241EE: 'fá',  # 𤇮
    0x241EF: 'ēn,āo',  # 𤇯
    0x241F0: 'fá',  # 𤇰
    # 0x241F1: '',  # 𤇱
    # 0x241F2: '',  # 𤇲
    0x241F3: 'xù,xuè',  # 𤇳
    0x241F4: 'yí,xī',  # 𤇴
    # 0x241F5: '',  # 𤇵
    0x241F6: 'zhēng',  # 𤇶
    # 0x241F7: '',  # 𤇷
    # 0x241F8: '',  # 𤇸
    # 0x241F9: '',  # 𤇹
    # 0x241FA: '',  # 𤇺
    # 0x241FB: '',  # 𤇻
    # 0x241FC: '',  # 𤇼
    # 0x241FD: '',  # 𤇽
    0x241FE: 'yìng',  # 𤇾
    # 0x241FF: '',  # 𤇿
    # 0x24200: '',  # 𤈀
    # 0x24201: '',  # 𤈁
    # 0x24202: '',  # 𤈂
    # 0x24203: '',  # 𤈃
    0x24204: 'jí',  # 𤈄
    # 0x24205: '',  # 𤈅
    # 0x24206: '',  # 𤈆
    # 0x24207: '',  # 𤈇
    # 0x24208: '',  # 𤈈
    # 0x24209: '',  # 𤈉
    # 0x2420A: '',  # 𤈊
    # 0x2420B: '',  # 𤈋
    # 0x2420C: '',  # 𤈌
    # 0x2420D: '',  # 𤈍
    # 0x2420E: '',  # 𤈎
    # 0x2420F: '',  # 𤈏
    # 0x24210: '',  # 𤈐
    # 0x24211: '',  # 𤈑
    # 0x24212: '',  # 𤈒
    # 0x24213: '',  # 𤈓
    0x24214: 'chí',  # 𤈔
    # 0x24215: '',  # 𤈕
    # 0x24216: '',  # 𤈖
    # 0x24217: '',  # 𤈗
    # 0x24218: '',  # 𤈘
    0x24219: 'yí',  # 𤈙
    # 0x2421A: '',  # 𤈚
    # 0x2421B: '',  # 𤈛
    # 0x2421C: '',  # 𤈜
    # 0x2421D: '',  # 𤈝
    # 0x2421E: '',  # 𤈞
    # 0x2421F: '',  # 𤈟
    # 0x24220: '',  # 𤈠
    # 0x24221: '',  # 𤈡
    # 0x24222: '',  # 𤈢
    # 0x24223: '',  # 𤈣
    # 0x24224: '',  # 𤈤
    0x24225: 'dí',  # 𤈥
    0x24226: 'huǐ,méi',  # 𤈦
    0x24227: 'hé',  # 𤈧
    # 0x24228: '',  # 𤈨
    0x24229: 'zhǎ',  # 𤈩
    # 0x2422A: '',  # 𤈪
    0x2422B: 'wèi',  # 𤈫
    # 0x2422C: '',  # 𤈬
    # 0x2422D: '',  # 𤈭
    # 0x2422E: '',  # 𤈮
    # 0x2422F: '',  # 𤈯
    # 0x24230: '',  # 𤈰
    # 0x24231: '',  # 𤈱
    # 0x24232: '',  # 𤈲
    # 0x24233: '',  # 𤈳
    # 0x24234: '',  # 𤈴
    # 0x24235: '',  # 𤈵
    # 0x24236: '',  # 𤈶
    # 0x24237: '',  # 𤈷
    # 0x24238: '',  # 𤈸
    # 0x24239: '',  # 𤈹
    # 0x2423A: '',  # 𤈺
    # 0x2423B: '',  # 𤈻
    # 0x2423C: '',  # 𤈼
    # 0x2423D: '',  # 𤈽
    # 0x2423E: '',  # 𤈾
    # 0x2423F: '',  # 𤈿
    # 0x24240: '',  # 𤉀
    # 0x24241: '',  # 𤉁
    # 0x24242: '',  # 𤉂
    # 0x24243: '',  # 𤉃
    # 0x24244: '',  # 𤉄
    # 0x24245: '',  # 𤉅
    # 0x24246: '',  # 𤉆
    # 0x24247: '',  # 𤉇
    # 0x24248: '',  # 𤉈
    # 0x24249: '',  # 𤉉
    # 0x2424A: '',  # 𤉊
    # 0x2424B: '',  # 𤉋
    0x2424C: 'xián',  # 𤉌
    0x2424D: 'lào',  # 𤉍
    0x2424E: 'shào',  # 𤉎
    0x2424F: 'shì',  # 𤉏
    0x24250: 'zhuó',  # 𤉐
    # 0x24251: '',  # 𤉑
    # 0x24252: '',  # 𤉒
    # 0x24253: '',  # 𤉓
    # 0x24254: '',  # 𤉔
    # 0x24255: '',  # 𤉕
    # 0x24256: '',  # 𤉖
    # 0x24257: '',  # 𤉗
    # 0x24258: '',  # 𤉘
    0x24259: 'jūn',  # 𤉙
    # 0x2425A: '',  # 𤉚
    # 0x2425B: '',  # 𤉛
    # 0x2425C: '',  # 𤉜
    # 0x2425D: '',  # 𤉝
    # 0x2425E: '',  # 𤉞
    # 0x2425F: '',  # 𤉟
    # 0x24260: '',  # 𤉠
    0x24261: 'sì',  # 𤉡
    # 0x24262: '',  # 𤉢
    # 0x24263: '',  # 𤉣
    0x24264: 'biē',  # 𤉤
    0x24265: 'jiǔ',  # 𤉥
    0x24266: 'wō',  # 𤉦
    0x24267: 'jiǎo',  # 𤉧
    0x24268: 'fú',  # 𤉨
    # 0x24269: '',  # 𤉩
    0x2426A: 'xiāng',  # 𤉪
    0x2426B: 'kài',  # 𤉫
    # 0x2426C: '',  # 𤉬
    # 0x2426D: '',  # 𤉭
    # 0x2426E: '',  # 𤉮
    # 0x2426F: '',  # 𤉯
    # 0x24270: '',  # 𤉰
    # 0x24271: '',  # 𤉱
    # 0x24272: '',  # 𤉲
    # 0x24273: '',  # 𤉳
    # 0x24274: '',  # 𤉴
    # 0x24275: '',  # 𤉵
    # 0x24276: '',  # 𤉶
    # 0x24277: '',  # 𤉷
    # 0x24278: '',  # 𤉸
    # 0x24279: '',  # 𤉹
    # 0x2427A: '',  # 𤉺
    # 0x2427B: '',  # 𤉻
    # 0x2427C: '',  # 𤉼
    # 0x2427D: '',  # 𤉽
    # 0x2427E: '',  # 𤉾
    # 0x2427F: '',  # 𤉿
    # 0x24280: '',  # 𤊀
    # 0x24281: '',  # 𤊁
    # 0x24282: '',  # 𤊂
    # 0x24283: '',  # 𤊃
    # 0x24284: '',  # 𤊄
    # 0x24285: '',  # 𤊅
    # 0x24286: '',  # 𤊆
    # 0x24287: '',  # 𤊇
    # 0x24288: '',  # 𤊈
    # 0x24289: '',  # 𤊉
    # 0x2428A: '',  # 𤊊
    # 0x2428B: '',  # 𤊋
    # 0x2428C: '',  # 𤊌
    # 0x2428D: '',  # 𤊍
    # 0x2428E: '',  # 𤊎
    # 0x2428F: '',  # 𤊏
    # 0x24290: '',  # 𤊐
    # 0x24291: '',  # 𤊑
    # 0x24292: '',  # 𤊒
    # 0x24293: '',  # 𤊓
    # 0x24294: '',  # 𤊔
    # 0x24295: '',  # 𤊕
    # 0x24296: '',  # 𤊖
    # 0x24297: '',  # 𤊗
    # 0x24298: '',  # 𤊘
    # 0x24299: '',  # 𤊙
    # 0x2429A: '',  # 𤊚
    # 0x2429B: '',  # 𤊛
    # 0x2429C: '',  # 𤊜
    # 0x2429D: '',  # 𤊝
    # 0x2429E: '',  # 𤊞
    # 0x2429F: '',  # 𤊟
    # 0x242A0: '',  # 𤊠
    # 0x242A1: '',  # 𤊡
    # 0x242A2: '',  # 𤊢
    # 0x242A3: '',  # 𤊣
    # 0x242A4: '',  # 𤊤
    # 0x242A5: '',  # 𤊥
    # 0x242A6: '',  # 𤊦
    # 0x242A7: '',  # 𤊧
    # 0x242A8: '',  # 𤊨
    # 0x242A9: '',  # 𤊩
    # 0x242AA: '',  # 𤊪
    # 0x242AB: '',  # 𤊫
    # 0x242AC: '',  # 𤊬
    # 0x242AD: '',  # 𤊭
    # 0x242AE: '',  # 𤊮
    # 0x242AF: '',  # 𤊯
    # 0x242B0: '',  # 𤊰
    # 0x242B1: '',  # 𤊱
    0x242B2: 'nǎo',  # 𤊲
    # 0x242B3: '',  # 𤊳
    0x242B4: 'huò',  # 𤊴
    0x242B5: 'jí',  # 𤊵
    0x242B6: 'là',  # 𤊶
    # 0x242B7: '',  # 𤊷
    # 0x242B8: '',  # 𤊸
    # 0x242B9: '',  # 𤊹
    # 0x242BA: '',  # 𤊺
    0x242BB: 'fōu',  # 𤊻
    0x242BC: 'shǎn',  # 𤊼
    0x242BD: 'liào,liǎo',  # 𤊽
    0x242BE: 'miè',  # 𤊾
    0x242BF: 'chè',  # 𤊿
    # 0x242C0: '',  # 𤋀
    # 0x242C1: '',  # 𤋁
    0x242C2: 'mó',  # 𤋂
    # 0x242C3: '',  # 𤋃
    # 0x242C4: '',  # 𤋄
    # 0x242C5: '',  # 𤋅
    # 0x242C6: '',  # 𤋆
    # 0x242C7: '',  # 𤋇
    # 0x242C8: '',  # 𤋈
    # 0x242C9: '',  # 𤋉
    # 0x242CA: '',  # 𤋊
    # 0x242CB: '',  # 𤋋
    # 0x242CC: '',  # 𤋌
    # 0x242CD: '',  # 𤋍
    # 0x242CE: '',  # 𤋎
    # 0x242CF: '',  # 𤋏
    # 0x242D0: '',  # 𤋐
    # 0x242D1: '',  # 𤋑
    # 0x242D2: '',  # 𤋒
    # 0x242D3: '',  # 𤋓
    # 0x242D4: '',  # 𤋔
    # 0x242D5: '',  # 𤋕
    # 0x242D6: '',  # 𤋖
    # 0x242D7: '',  # 𤋗
    # 0x242D8: '',  # 𤋘
    # 0x242D9: '',  # 𤋙
    # 0x242DA: '',  # 𤋚
    # 0x242DB: '',  # 𤋛
    # 0x242DC: '',  # 𤋜
    # 0x242DD: '',  # 𤋝
    # 0x242DE: '',  # 𤋞
    # 0x242DF: '',  # 𤋟
    0x242E0: 'yàn',  # 𤋠
    # 0x242E1: '',  # 𤋡
    # 0x242E2: '',  # 𤋢
    # 0x242E3: '',  # 𤋣
    # 0x242E4: '',  # 𤋤
    # 0x242E5: '',  # 𤋥
    # 0x242E6: '',  # 𤋦
    # 0x242E7: '',  # 𤋧
    0x242E8: 'duò',  # 𤋨
    # 0x242E9: '',  # 𤋩
    # 0x242EA: '',  # 𤋪
    0x242EB: 'nǎo',  # 𤋫
    # 0x242EC: '',  # 𤋬
    0x242ED: 'jī',  # 𤋭
    0x242EE: 'xī',  # 𤋮
    # 0x242EF: '',  # 𤋯
    0x242F0: 'zhù',  # 𤋰
    # 0x242F1: '',  # 𤋱
    # 0x242F2: '',  # 𤋲
    # 0x242F3: '',  # 𤋳
    # 0x242F4: '',  # 𤋴
    # 0x242F5: '',  # 𤋵
    # 0x242F6: '',  # 𤋶
    # 0x242F7: '',  # 𤋷
    # 0x242F8: '',  # 𤋸
    # 0x242F9: '',  # 𤋹
    # 0x242FA: '',  # 𤋺
    # 0x242FB: '',  # 𤋻
    # 0x242FC: '',  # 𤋼
    # 0x242FD: '',  # 𤋽
    # 0x242FE: '',  # 𤋾
    # 0x242FF: '',  # 𤋿
    # 0x24300: '',  # 𤌀
    # 0x24301: '',  # 𤌁
    0x24302: 'sù',  # 𤌂
    0x24303: 'duò',  # 𤌃
    # 0x24304: '',  # 𤌄
    # 0x24305: '',  # 𤌅
    # 0x24306: '',  # 𤌆
    0x24307: 'jiǒng',  # 𤌇
    # 0x24308: '',  # 𤌈
    # 0x24309: '',  # 𤌉
    0x2430A: 'zǎi',  # 𤌊
    0x2430B: 'huǐ',  # 𤌋
    0x2430C: 'yǐng',  # 𤌌
    0x2430D: 'hú',  # 𤌍
    0x2430E: 'lìn,lǐn',  # 𤌎
    0x2430F: 'wěng',  # 𤌏
    0x24310: 'hàn',  # 𤌐
    # 0x24311: '',  # 𤌑
    # 0x24312: '',  # 𤌒
    # 0x24313: '',  # 𤌓
    0x24314: 'nán',  # 𤌔
    # 0x24315: '',  # 𤌕
    # 0x24316: '',  # 𤌖
    # 0x24317: '',  # 𤌗
    # 0x24318: '',  # 𤌘
    # 0x24319: '',  # 𤌙
    # 0x2431A: '',  # 𤌚
    # 0x2431B: '',  # 𤌛
    # 0x2431C: '',  # 𤌜
    # 0x2431D: '',  # 𤌝
    # 0x2431E: '',  # 𤌞
    # 0x2431F: '',  # 𤌟
    # 0x24320: '',  # 𤌠
    # 0x24321: '',  # 𤌡
    # 0x24322: '',  # 𤌢
    # 0x24323: '',  # 𤌣
    # 0x24324: '',  # 𤌤
    # 0x24325: '',  # 𤌥
    # 0x24326: '',  # 𤌦
    # 0x24327: '',  # 𤌧
    # 0x24328: '',  # 𤌨
    # 0x24329: '',  # 𤌩
    # 0x2432A: '',  # 𤌪
    # 0x2432B: '',  # 𤌫
    # 0x2432C: '',  # 𤌬
    # 0x2432D: '',  # 𤌭
    # 0x2432E: '',  # 𤌮
    # 0x2432F: '',  # 𤌯
    # 0x24330: '',  # 𤌰
    # 0x24331: '',  # 𤌱
    # 0x24332: '',  # 𤌲
    # 0x24333: '',  # 𤌳
    # 0x24334: '',  # 𤌴
    # 0x24335: '',  # 𤌵
    # 0x24336: '',  # 𤌶
    0x24337: 'xì',  # 𤌷
    # 0x24338: '',  # 𤌸
    0x24339: 'gàn',  # 𤌹
    # 0x2433A: '',  # 䌺
    # 0x2433B: '',  # 䌻
    # 0x2433C: '',  # 䌼
    # 0x2433D: '',  # 䌽
    0x2433E: 'hè',  # 䌾
    0x2433F: 'jī',  # 䌿
    0x24340: 'xiǎng',  # 𤍀
    0x24341: 'shā',  # 𤍁
    # 0x24342: '',  # 𤍂
    # 0x24343: '',  # 𤍃
    # 0x24344: '',  # 𤍄
    # 0x24345: '',  # 𤍅
    # 0x24346: '',  # 𤍆
    # 0x24347: '',  # 𤍇
    # 0x24348: '',  # 𤍈
    # 0x24349: '',  # 𤍉
    # 0x2434A: '',  # 𤍊
    # 0x2434B: '',  # 𤍋
    # 0x2434C: '',  # 𤍌
    # 0x2434D: '',  # 𤍍
    # 0x2434E: '',  # 𤍎
    # 0x2434F: '',  # 𤍏
    # 0x24350: '',  # 𤍐
    # 0x24351: '',  # 𤍑
    0x24352: 'zhāo',  # 𤍒
    0x24353: 'shù',  # 𤍓
    # 0x24354: '',  # 𤍔
    0x24355: 'yǒu',  # 𤍕
    0x24356: 'jiān',  # 𤍖
    # 0x24357: '',  # 𤍗
    # 0x24358: '',  # 𤍘
    # 0x24359: '',  # 𤍙
    # 0x2435A: '',  # 𤍚
    # 0x2435B: '',  # 𤍛
    0x2435C: 'zào',  # 𤍜
    # 0x2435D: '',  # 𤍝
    # 0x2435E: '',  # 𤍞
    # 0x2435F: '',  # 𤍟
    # 0x24360: '',  # 𤍠
    # 0x24361: '',  # 𤍡
    # 0x24362: '',  # 𤍢
    # 0x24363: '',  # 𤍣
    0x24364: 'zhāng',  # 𤍤
    # 0x24365: '',  # 𤍥
    # 0x24366: '',  # 𤍦
    # 0x24367: '',  # 𤍧
    # 0x24368: '',  # 𤍨
    # 0x24369: '',  # 𤍩
    # 0x2436A: '',  # 𤍪
    # 0x2436B: '',  # 𤍫
    # 0x2436C: '',  # 𤍬
    # 0x2436D: '',  # 𤍭
    # 0x2436E: '',  # 𤍮
    # 0x2436F: '',  # 𤍯
    # 0x24370: '',  # 𤍰
    # 0x24371: '',  # 𤍱
    # 0x24372: '',  # 𤍲
    # 0x24373: '',  # 𤍳
    # 0x24374: '',  # 𤍴
    # 0x24375: '',  # 𤍵
    # 0x24376: '',  # 𤍶
    # 0x24377: '',  # 𤍷
    # 0x24378: '',  # 𤍸
    # 0x24379: '',  # 𤍹
    # 0x2437A: '',  # 𤍺
    # 0x2437B: '',  # 𤍻
    # 0x2437C: '',  # 𤍼
    0x2437D: 'ruò',  # 𤍽
    # 0x2437E: '',  # 𤍾
    # 0x2437F: '',  # 𤍿
    # 0x24380: '',  # 𤎀
    # 0x24381: '',  # 𤎁
    # 0x24382: '',  # 𤎂
    # 0x24383: '',  # 𤎃
    0x24384: 'yān',  # 𤎄
    0x24385: 'áo',  # 𤎅
    # 0x24386: '',  # 𤎆
    # 0x24387: '',  # 𤎇
    # 0x24388: '',  # 𤎈
    0x24389: 'lián',  # 𤎉
    # 0x2438A: '',  # 𤎊
    0x2438B: 'cuì',  # 𤎋
    # 0x2438C: '',  # 𤎌
    # 0x2438D: '',  # 𤎍
    # 0x2438E: '',  # 𤎎
    # 0x2438F: '',  # 𤎏
    # 0x24390: '',  # 𤎐
    # 0x24391: '',  # 𤎑
    # 0x24392: '',  # 𤎒
    # 0x24393: '',  # 𤎓
    # 0x24394: '',  # 𤎔
    # 0x24395: '',  # 𤎕
    # 0x24396: '',  # 𤎖
    0x24397: 'jí',  # 𤎗
    0x24398: 'shāng',  # 𤎘
    # 0x24399: '',  # 𤎙
    # 0x2439A: '',  # 𤎚
    # 0x2439B: '',  # 𤎛
    # 0x2439C: '',  # 𤎜
    # 0x2439D: '',  # 𤎝
    # 0x2439E: '',  # 𤎞
    # 0x2439F: '',  # 𤎟
    # 0x243A0: '',  # 𤎠
    # 0x243A1: '',  # 𤎡
    # 0x243A2: '',  # 𤎢
    0x243A3: 'è',  # 𤎣
    0x243A4: 'láo',  # 𤎤
    0x243A5: 'tǎn,chān',  # 𤎥
    # 0x243A6: '',  # 𤎦
    0x243A7: 'zhù',  # 𤎧
    # 0x243A8: '',  # 𤎨
    # 0x243A9: '',  # 𤎩
    # 0x243AA: '',  # 𤎪
    # 0x243AB: '',  # 𤎫
    # 0x243AC: '',  # 𤎬
    0x243AD: 'lǐn,yǐn',  # 𤎭
    # 0x243AE: '',  # 𤎮
    0x243AF: 'zēng',  # 𤎯
    # 0x243B0: '',  # 𤎰
    0x243B1: 'juǎn',  # 𤎱
    0x243B2: 'hū',  # 𤎲
    # 0x243B3: '',  # 𤎳
    # 0x243B4: '',  # 𤎴
    # 0x243B5: '',  # 𤎵
    # 0x243B6: '',  # 𤎶
    # 0x243B7: '',  # 𤎷
    # 0x243B8: '',  # 𤎸
    # 0x243B9: '',  # 𤎹
    # 0x243BA: '',  # 𤎺
    # 0x243BB: '',  # 𤎻
    # 0x243BC: '',  # 𤎼
    # 0x243BD: '',  # 𤎽
    # 0x243BE: '',  # 𤎾
    # 0x243BF: '',  # 𤎿
    # 0x243C0: '',  # 𤏀
    # 0x243C1: '',  # 𤏁
    # 0x243C2: '',  # 𤏂
    # 0x243C3: '',  # 𤏃
    # 0x243C4: '',  # 𤏄
    # 0x243C5: '',  # 𤏅
    # 0x243C6: '',  # 𤏆
    # 0x243C7: '',  # 𤏇
    # 0x243C8: '',  # 𤏈
    # 0x243C9: '',  # 𤏉
    # 0x243CA: '',  # 𤏊
    # 0x243CB: '',  # 𤏋
    # 0x243CC: '',  # 𤏌
    # 0x243CD: '',  # 𤏍
    # 0x243CE: '',  # 𤏎
    # 0x243CF: '',  # 𤏏
    # 0x243D0: '',  # 𤏐
    # 0x243D1: '',  # 𤏑
    # 0x243D2: '',  # 𤏒
    # 0x243D3: '',  # 𤏓
    # 0x243D4: '',  # 𤏔
    # 0x243D5: '',  # 𤏕
    # 0x243D6: '',  # 𤏖
    0x243D7: 'shěn',  # 𤏗
    0x243D8: 'huò',  # 𤏘
    # 0x243D9: '',  # 𤏙
    # 0x243DA: '',  # 𤏚
    # 0x243DB: '',  # 𤏛
    0x243DC: 'kuì',  # 𤏜
    # 0x243DD: '',  # 𤏝
    # 0x243DE: '',  # 𤏞
    # 0x243DF: '',  # 𤏟
    # 0x243E0: '',  # 𤏠
    # 0x243E1: '',  # 𤏡
    # 0x243E2: '',  # 𤏢
    # 0x243E3: '',  # 𤏣
    # 0x243E4: '',  # 𤏤
    # 0x243E5: '',  # 𤏥
    # 0x243E6: '',  # 𤏦
    # 0x243E7: '',  # 𤏧
    # 0x243E8: '',  # 𤏨
    # 0x243E9: '',  # 𤏩
    # 0x243EA: '',  # 𤏪
    # 0x243EB: '',  # 𤏫
    # 0x243EC: '',  # 𤏬
    # 0x243ED: '',  # 𤏭
    # 0x243EE: '',  # 𤏮
    # 0x243EF: '',  # 𤏯
    0x243F0: 'piē',  # 𤏰
    0x243F1: 'chù',  # 𤏱
    0x243F2: 'zhòu',  # 𤏲
    # 0x243F3: '',  # 𤏳
    # 0x243F4: '',  # 𤏴
    # 0x243F5: '',  # 𤏵
    0x243F6: 'āo',  # 𤏶
    # 0x243F7: '',  # 𤏷
    0x243F8: 'zhuó',  # 𤏸
    # 0x243F9: '',  # 𤏹
    # 0x243FA: '',  # 𤏺
    0x243FB: 'xiè',  # 𤏻
    # 0x243FC: '',  # 𤏼
    0x243FD: 'xīng',  # 𤏽
    # 0x243FE: '',  # 𤏾
    0x243FF: 'miè',  # 𤏿
    0x24400: 'hū',  # 𤐀
    # 0x24401: '',  # 𤐁
    # 0x24402: '',  # 𤐂
    # 0x24403: '',  # 𤐃
    # 0x24404: '',  # 𤐄
    # 0x24405: '',  # 𤐅
    # 0x24406: '',  # 𤐆
    # 0x24407: '',  # 𤐇
    # 0x24408: '',  # 𤐈
    # 0x24409: '',  # 𤐉
    # 0x2440A: '',  # 𤐊
    # 0x2440B: '',  # 𤐋
    # 0x2440C: '',  # 𤐌
    # 0x2440D: '',  # 𤐍
    # 0x2440E: '',  # 𤐎
    # 0x2440F: '',  # 𤐏
    # 0x24410: '',  # 𤐐
    # 0x24411: '',  # 𤐑
    # 0x24412: '',  # 𤐒
    # 0x24413: '',  # 𤐓
    0x24414: 'tán',  # 𤐔
    # 0x24415: '',  # 𤐕
    # 0x24416: '',  # 𤐖
    # 0x24417: '',  # 𤐗
    # 0x24418: '',  # 𤐘
    0x24419: 'bì',  # 𤐙
    # 0x2441A: '',  # 𤐚
    # 0x2441B: '',  # 𤐛
    # 0x2441C: '',  # 𤐜
    # 0x2441D: '',  # 𤐝
    # 0x2441E: '',  # 𤐞
    # 0x2441F: '',  # 𤐟
    # 0x24420: '',  # 𤐠
    # 0x24421: '',  # 𤐡
    # 0x24422: '',  # 𤐢
    0x24423: 'dǐng',  # 𤐣
    # 0x24424: '',  # 𤐤
    # 0x24425: '',  # 𤐥
    # 0x24426: '',  # 𤐦
    # 0x24427: '',  # 𤐧
    # 0x24428: '',  # 𤐨
    0x24429: 'kài',  # 𤐩
    # 0x2442A: '',  # 𤐪
    0x2442B: 'biāo',  # 𤐫
    # 0x2442C: '',  # 𤐬
    # 0x2442D: '',  # 𤐭
    # 0x2442E: '',  # 𤐮
    # 0x2442F: '',  # 𤐯
    0x24430: 'huò',  # 𤐰
    0x24431: 'liè',  # 𤐱
    0x24432: 'cuàn',  # 𤐲
    # 0x24433: '',  # 𤐳
    # 0x24434: '',  # 𤐴
    # 0x24435: '',  # 𤐵
    # 0x24436: '',  # 𤐶
    # 0x24437: '',  # 𤐷
    0x24438: 'bì',  # 𤐸
    # 0x24439: '',  # 𤐹
    # 0x2443A: '',  # 𤐺
    # 0x2443B: '',  # 𤐻
    # 0x2443C: '',  # 𤐼
    # 0x2443D: '',  # 𤐽
    # 0x2443E: '',  # 𤐾
    # 0x2443F: '',  # 𤐿
    # 0x24440: '',  # 𤑀
    # 0x24441: '',  # 𤑁
    # 0x24442: '',  # 𤑂
    0x24443: 'xiàn',  # 𤑃
    0x24444: 'rè',  # 𤑄
    # 0x24445: '',  # 𤑅
    # 0x24446: '',  # 𤑆
    # 0x24447: '',  # 𤑇
    # 0x24448: '',  # 𤑈
    # 0x24449: '',  # 𤑉
    # 0x2444A: '',  # 𤑊
    # 0x2444B: '',  # 𤑋
    # 0x2444C: '',  # 𤑌
    # 0x2444D: '',  # 𤑍
    # 0x2444E: '',  # 𤑎
    # 0x2444F: '',  # 𤑏
    # 0x24450: '',  # 𤑐
    # 0x24451: '',  # 𤑑
    # 0x24452: '',  # 𤑒
    0x24453: 'yuè',  # 𤑓
    # 0x24454: '',  # 𤑔
    0x24455: 'xūn,xùn',  # 𤑕
    # 0x24456: '',  # 𤑖
    0x24457: 'liǎo,zhāo',  # 𤑗
    # 0x24458: '',  # 𤑘
    # 0x24459: '',  # 𤑙
    # 0x2445A: '',  # 𤑚
    # 0x2445B: '',  # 𤑛
    # 0x2445C: '',  # 𤑜
    # 0x2445D: '',  # 𤑝
    # 0x2445E: '',  # 𤑞
    # 0x2445F: '',  # 𤑟
    # 0x24460: '',  # 𤑠
    # 0x24461: '',  # 𤑡
    # 0x24462: '',  # 𤑢
    0x24463: 'shā',  # 𤑣
    # 0x24464: '',  # 𤑤
    # 0x24465: '',  # 𤑥
    0x24466: 'shì',  # 𤑦
    # 0x24467: '',  # 𤑧
    # 0x24468: '',  # 𤑨
    # 0x24469: '',  # 𤑩
    0x2446A: 'xiè',  # 𤑪
    # 0x2446B: '',  # 𤑫
    # 0x2446C: '',  # 𤑬
    # 0x2446D: '',  # 𤑭
    # 0x2446E: '',  # 𤑮
    # 0x2446F: '',  # 𤑯
    # 0x24470: '',  # 𤑰
    # 0x24471: '',  # 𤑱
    # 0x24472: '',  # 𤑲
    0x24473: 'xiāo',  # 𤑳
    # 0x24474: '',  # 𤑴
    # 0x24475: '',  # 𤑵
    # 0x24476: '',  # 𤑶
    0x24477: 'yé',  # 𤑷
    0x24478: 'lǎn',  # 𤑸
    0x24479: 'yì',  # 𤑹
    # 0x2447A: '',  # 𤑺
    # 0x2447B: '',  # 𤑻
    # 0x2447C: '',  # 𤑼
    # 0x2447D: '',  # 𤑽
    # 0x2447E: '',  # 𤑾
    0x2447F: 'liǎn',  # 𤑿
    # 0x24480: '',  # 𤒀
    # 0x24481: '',  # 𤒁
    # 0x24482: '',  # 𤒂
    # 0x24483: '',  # 𤒃
    # 0x24484: '',  # 𤒄
    0x24485: 'jiāo',  # 𤒅
    # 0x24486: '',  # 𤒆
    # 0x24487: '',  # 𤒇
    # 0x24488: '',  # 𤒈
    # 0x24489: '',  # 𤒉
    # 0x2448A: '',  # 𤒊
    # 0x2448B: '',  # 𤒋
    # 0x2448C: '',  # 𤒌
    # 0x2448D: '',  # 𤒍
    # 0x2448E: '',  # 𤒎
    # 0x2448F: '',  # 𤒏
    # 0x24490: '',  # 𤒐
    # 0x24491: '',  # 𤒑
    # 0x24492: '',  # 𤒒
    0x24493: 'fú',  # 𤒓
    0x24494: 'bó',  # 𤒔
    0x24495: 'cāo',  # 𤒕
    # 0x24496: '',  # 𤒖
    # 0x24497: '',  # 𤒗
    0x24498: 'dǔ',  # 𤒘
    # 0x24499: '',  # 𤒙
    # 0x2449A: '',  # 𤒚
    # 0x2449B: '',  # 𤒛
    # 0x2449C: '',  # 𤒜
    0x2449D: 'yào',  # 𤒝
    # 0x2449E: '',  # 𤒞
    # 0x2449F: '',  # 𤒟
    # 0x244A0: '',  # 𤒠
    # 0x244A1: '',  # 𤒡
    # 0x244A2: '',  # 𤒢
    # 0x244A3: '',  # 𤒣
    # 0x244A4: '',  # 𤒤
    # 0x244A5: '',  # 𤒥
    0x244A6: 'liàn,yàn',  # 𤒦
    # 0x244A7: '',  # 𤒧
    # 0x244A8: '',  # 𤒨
    # 0x244A9: '',  # 𤒩
    # 0x244AA: '',  # 𤒪
    # 0x244AB: '',  # 𤒫
    # 0x244AC: '',  # 𤒬
    # 0x244AD: '',  # 𤒭
    # 0x244AE: '',  # 𤒮
    # 0x244AF: '',  # 𤒯
    # 0x244B0: '',  # 𤒰
    # 0x244B1: '',  # 𤒱
    # 0x244B2: '',  # 𤒲
    # 0x244B3: '',  # 𤒳
    # 0x244B4: '',  # 𤒴
    # 0x244B5: '',  # 𤒵
    # 0x244B6: '',  # 𤒶
    # 0x244B7: '',  # 𤒷
    # 0x244B8: '',  # 𤒸
    # 0x244B9: '',  # 𤒹
    # 0x244BA: '',  # 𤒺
    0x244BB: 'tà',  # 𤒻
    # 0x244BC: '',  # 𤒼
    # 0x244BD: '',  # 𤒽
    # 0x244BE: '',  # 𤒾
    # 0x244BF: '',  # 𤒿
    # 0x244C0: '',  # 𤓀
    # 0x244C1: '',  # 𤓁
    # 0x244C2: '',  # 𤓂
    # 0x244C3: '',  # 𤓃
    # 0x244C4: '',  # 𤓄
    # 0x244C5: '',  # 𤓅
    # 0x244C6: '',  # 𤓆
    # 0x244C7: '',  # 𤓇
    # 0x244C8: '',  # 𤓈
    # 0x244C9: '',  # 𤓉
    # 0x244CA: '',  # 𤓊
    # 0x244CB: '',  # 𤓋
    0x244CC: 'rán',  # 𤓌
    # 0x244CD: '',  # 𤓍
    # 0x244CE: '',  # 𤓎
    # 0x244CF: '',  # 𤓏
    # 0x244D0: '',  # 𤓐
    0x244D1: 'jì',  # 𤓑
    0x244D2: 'mí',  # 𤓒
    0x244D3: 'luó',  # 𤓓
    0x244D4: 'xī',  # 𤓔
    0x244D5: 'zhì',  # 𤓕
    # 0x244D6: '',  # 𤓖
    # 0x244D7: '',  # 𤓗
    # 0x244D8: '',  # 𤓘
    # 0x244D9: '',  # 𤓙
    0x244DA: 'xī',  # 𤓚
    # 0x244DB: '',  # 𤓛
    # 0x244DC: '',  # 𤓜
    0x244DD: 'yuè',  # 𤓝
    # 0x244DE: '',  # 𤓞
    # 0x244DF: '',  # 𤓟
    # 0x244E0: '',  # 𤓠
    # 0x244E1: '',  # 𤓡
    # 0x244E2: '',  # 𤓢
    # 0x244E3: '',  # 𤓣
    0x244E4: 'xiǎn',  # 𤓤
    # 0x244E5: '',  # 𤓥
    0x244E6: 'zhuò',  # 𤓦
    # 0x244E7: '',  # 𤓧
    # 0x244E8: '',  # 𤓨
    # 0x244E9: '',  # 𤓩
    0x244EA: 'jiāo',  # 𤓪
    # 0x244EB: '',  # 𤓫
    # 0x244EC: '',  # 𤓬
    # 0x244ED: '',  # 𤓭
    # 0x244EE: '',  # 𤓮
    0x244EF: 'zhǎng,jú',  # 𤓯
    # 0x244F0: '',  # 𤓰
    # 0x244F1: '',  # 𤓱
    # 0x244F2: '',  # 𤓲
    # 0x244F3: '',  # 𤓳
    # 0x244F4: '',  # 𤓴
    0x244F5: 'zǔ',  # 𤓵
    # 0x244F6: '',  # 𤓶
    0x244F7: 'ná',  # 𤓷
    # 0x244F8: '',  # 𤓸
    # 0x244F9: '',  # 𤓹
    # 0x244FA: '',  # 𤓺
    # 0x244FB: '',  # 𤓻
    # 0x244FC: '',  # 𤓼
    # 0x244FD: '',  # 𤓽
    0x244FE: 'dào',  # 𤓾
    0x244FF: 'liè',  # 𤓿
    0x24500: 'ná',  # 𤔀
    # 0x24501: '',  # 𤔁
    # 0x24502: '',  # 𤔂
    # 0x24503: '',  # 𤔃
    # 0x24504: '',  # 𤔄
    # 0x24505: '',  # 𤔅
    # 0x24506: '',  # 𤔆
    # 0x24507: '',  # 𤔇
    # 0x24508: '',  # 𤔈
    0x24509: 'páo',  # 𤔉
    # 0x2450A: '',  # 𤔊
    0x2450B: 'jù',  # 𤔋
    0x2450C: 'yǐn',  # 𤔌
    # 0x2450D: '',  # 𤔍
    # 0x2450E: '',  # 𤔎
    # 0x2450F: '',  # 𤔏
    # 0x24510: '',  # 𤔐
    # 0x24511: '',  # 𤔑
    # 0x24512: '',  # 𤔒
    # 0x24513: '',  # 𤔓
    0x24514: 'luàn',  # 𤔔
    # 0x24515: '',  # 𤔕
    0x24516: 'luǒ',  # 𤔖
    # 0x24517: '',  # 𤔗
    # 0x24518: '',  # 𤔘
    0x24519: 'shuǎ',  # 𤔙
    0x2451A: 'shàng',  # 𤔚
    # 0x2451B: '',  # 𤔛
    # 0x2451C: '',  # 𤔜
    0x2451D: 'luǒ',  # 𤔝
    # 0x2451E: '',  # 𤔞
    0x2451F: 'fēn',  # 𤔟
    # 0x24520: '',  # 𤔠
    # 0x24521: '',  # 𤔡
    # 0x24522: '',  # 𤔢
    0x24523: 'bào',  # 𤔣
    # 0x24524: '',  # 𤔤
    # 0x24525: '',  # 𤔥
    # 0x24526: '',  # 𤔦
    # 0x24527: '',  # 𤔧
    0x24528: 'lì',  # 𤔨
    # 0x24529: '',  # 𤔩
    # 0x2452A: '',  # 𤔪
    0x2452B: 'xiòng',  # 𤔫
    # 0x2452C: '',  # 𤔬
    # 0x2452D: '',  # 𤔭
    # 0x2452E: '',  # 𤔮
    # 0x2452F: '',  # 𤔯
    # 0x24530: '',  # 𤔰
    0x24531: 'tāo',  # 𤔱
    # 0x24532: '',  # 𤔲
    # 0x24533: '',  # 𤔳
    # 0x24534: '',  # 𤔴
    # 0x24535: '',  # 𤔵
    0x24536: 'dāng',  # 𤔶
    # 0x24537: '',  # 𤔷
    # 0x24538: '',  # 𤔸
    # 0x24539: '',  # 𤔹
    # 0x2453A: '',  # 𤔺
    # 0x2453B: '',  # 𤔻
    # 0x2453C: '',  # 𤔼
    # 0x2453D: '',  # 𤔽
    # 0x2453E: '',  # 𤔾
    # 0x2453F: '',  # 𤔿
    0x24540: 'chèng',  # 𤕀
    # 0x24541: '',  # 𤕁
    # 0x24542: '',  # 𤕂
    # 0x24543: '',  # 𤕃
    0x24544: 'zhǎng',  # 𤕄
    # 0x24545: '',  # 𤕅
    # 0x24546: '',  # 𤕆
    0x24547: 'sǒu',  # 𤕇
    0x24548: 'liàn',  # 𤕈
    # 0x24549: '',  # 𤕉
    0x2454A: 'shén',  # 𤕊
    # 0x2454B: '',  # 𤕋
    # 0x2454C: '',  # 𤕌
    # 0x2454D: '',  # 𤕍
    # 0x2454E: '',  # 𤕎
    # 0x2454F: '',  # 𤕏
    # 0x24550: '',  # 𤕐
    # 0x24551: '',  # 𤕑
    0x24552: 'gě',  # 𤕒
    0x24553: 'yé',  # 𤕓
    # 0x24554: '',  # 𤕔
    # 0x24555: '',  # 𤕕
    # 0x24556: '',  # 𤕖
    # 0x24557: '',  # 𤕗
    0x24558: 'yū,wù',  # 𤕘
    # 0x24559: '',  # 𤕙
    0x2455A: 'huī',  # 𤕚
    0x2455B: 'chè',  # 𤕛
    # 0x2455C: '',  # 𤕜
    0x2455D: 'jiào,bó',  # 𤕝
    0x2455E: 'zhù',  # 𤕞
    0x2455F: 'shū',  # 𤕟
    # 0x24560: '',  # 𤕠
    # 0x24561: '',  # 𤕡
    0x24562: 'xiáo',  # 𤕢
    # 0x24563: '',  # 𤕣
    0x24564: 'shuāng,shuǎng',  # 𤕤
    # 0x24565: '',  # 𤕥
    0x24566: 'níng',  # 𤕦
    # 0x24567: '',  # 𤕧
    # 0x24568: '',  # 𤕨
    # 0x24569: '',  # 𤕩
    # 0x2456A: '',  # 𤕪
    # 0x2456B: '',  # 𤕫
    0x2456C: 'jí',  # 𤕬
    0x2456D: 'jiāng,jiàng,qiāng',  # 𤕭
    # 0x2456E: '',  # 𤕮
    0x2456F: 'jiāng,zhuàng',  # 𤕯
    # 0x24570: '',  # 𤕰
    # 0x24571: '',  # 𤕱
    # 0x24572: '',  # 𤕲
    # 0x24573: '',  # 𤕳
    # 0x24574: '',  # 𤕴
    # 0x24575: '',  # 𤕵
    # 0x24576: '',  # 𤕶
    0x24577: 'diào',  # 𤕷
    # 0x24578: '',  # 𤕸
    # 0x24579: '',  # 𤕹
    # 0x2457A: '',  # 𤕺
    # 0x2457B: '',  # 𤕻
    # 0x2457C: '',  # 𤕼
    0x2457D: 'qiáng',  # 𤕽
    0x2457E: 'qiú,fǔ',  # 𤕾
    # 0x2457F: '',  # 𤕿
    0x24580: 'fēng',  # 𤖀
    # 0x24581: '',  # 𤖁
    # 0x24582: '',  # 𤖂
    # 0x24583: '',  # 𤖃
    # 0x24584: '',  # 𤖄
    0x24585: 'jiāng',  # 𤖅
    0x24586: 'zhàn',  # 𤖆
    0x24587: 'kē',  # 𤖇
    # 0x24588: '',  # 𤖈
    # 0x24589: '',  # 𤖉
    # 0x2458A: '',  # 𤖊
    # 0x2458B: '',  # 𤖋
    # 0x2458C: '',  # 𤖌
    # 0x2458D: '',  # 𤖍
    # 0x2458E: '',  # 𤖎
    # 0x2458F: '',  # 𤖏
    # 0x24590: '',  # 𤖐
    # 0x24591: '',  # 𤖑
    0x24592: 'dié',  # 𤖒
    0x24593: 'zé',  # 𤖓
    # 0x24594: '',  # 𤖔
    # 0x24595: '',  # 𤖕
    0x24596: 'guāng',  # 𤖖
    0x24597: 'sè',  # 𤖗
    0x24598: 'fèn,fén',  # 𤖘
    # 0x24599: '',  # 𤖙
    # 0x2459A: '',  # 𤖚
    0x2459B: 'jiǎng',  # 𤖛
    # 0x2459C: '',  # 𤖜
    0x2459D: 'yán',  # 𤖝
    0x2459E: 'zhì',  # 𤖞
    0x2459F: 'bò',  # 𤖟
    # 0x245A0: '',  # 𤖠
    # 0x245A1: '',  # 𤖡
    0x245A2: 'lì',  # 𤖢
    # 0x245A3: '',  # 𤖣
    # 0x245A4: '',  # 𤖤
    # 0x245A5: '',  # 𤖥
    0x245A6: 'líng',  # 𤖦
    # 0x245A7: '',  # 𤖧
    # 0x245A8: '',  # 𤖨
    # 0x245A9: '',  # 𤖩
    0x245AA: 'yí',  # 𤖪
    # 0x245AB: '',  # 𤖫
    0x245AC: 'qǔ',  # 𤖬
    0x245AD: 'pán',  # 𤖭
    0x245AE: 'gōu',  # 𤖮
    # 0x245AF: '',  # 𤖯
    0x245B0: 'jiǎ',  # 𤖰
    0x245B1: 'hé',  # 𤖱
    # 0x245B2: '',  # 𤖲
    0x245B3: 'pèng',  # 𤖳
    # 0x245B4: '',  # 𤖴
    0x245B5: 'jù',  # 𤖵
    # 0x245B6: '',  # 𤖶
    0x245B7: 'chè',  # 𤖷
    # 0x245B8: '',  # 𤖸
    # 0x245B9: '',  # 𤖹
    0x245BA: 'liè',  # 𤖺
    0x245BB: 'shì',  # 𤖻
    0x245BC: 'pò',  # 𤖼
    0x245BD: 'xiàng',  # 𤖽
    # 0x245BE: '',  # 𤖾
    0x245BF: 'pì',  # 𤖿
    0x245C0: 'luǒ',  # 𤗀
    0x245C1: 'cù',  # 𤗁
    # 0x245C2: '',  # 𤗂
    0x245C3: 'yǔ',  # 𤗃
    # 0x245C4: '',  # 𤗄
    # 0x245C5: '',  # 𤗅
    # 0x245C6: '',  # 𤗆
    0x245C7: 'kòng',  # 𤗇
    0x245C8: 'xiè',  # 𤗈
    # 0x245C9: '',  # 𤗉
    # 0x245CA: '',  # 𤗊
    # 0x245CB: '',  # 𤗋
    # 0x245CC: '',  # 𤗌
    0x245CD: 'wǎn',  # 𤗍
    0x245CE: 'yǎn',  # 𤗎
    0x245CF: 'péi',  # 𤗏
    # 0x245D0: '',  # 𤗐
    # 0x245D1: '',  # 𤗑
    # 0x245D2: '',  # 𤗒
    0x245D3: 'chéng',  # 𤗓
    # 0x245D4: '',  # 𤗔
    # 0x245D5: '',  # 𤗕
    # 0x245D6: '',  # 𤗖
    # 0x245D7: '',  # 𤗗
    0x245D8: 'tí',  # 𤗘
    0x245D9: 'chè,tuò',  # 𤗙
    0x245DA: 'bì',  # 𤗚
    0x245DB: 'liàn',  # 𤗛
    0x245DC: 'jiǎ',  # 𤗜
    # 0x245DD: '',  # 𤗝
    0x245DE: 'tíng',  # 𤗞
    # 0x245DF: '',  # 𤗟
    # 0x245E0: '',  # 𤗠
    # 0x245E1: '',  # 𤗡
    0x245E2: 'tī',  # 𤗢
    # 0x245E3: '',  # 𤗣
    # 0x245E4: '',  # 𤗤
    # 0x245E5: '',  # 𤗥
    # 0x245E6: '',  # 𤗦
    # 0x245E7: '',  # 𤗧
    0x245E8: 'dié',  # 𤗨
    # 0x245E9: '',  # 𤗩
    0x245EA: 'shù',  # 𤗪
    0x245EB: 'lí',  # 𤗫
    0x245EC: 'lǘ',  # 𤗬
    0x245ED: 'xiā',  # 𤗭
    # 0x245EE: '',  # 𤗮
    0x245EF: 'cuī',  # 𤗯
    # 0x245F0: '',  # 𤗰
    # 0x245F1: '',  # 𤗱
    # 0x245F2: '',  # 𤗲
    0x245F3: 'bō',  # 𤗳
    0x245F4: 'tuí',  # 𤗴
    0x245F5: 'pú',  # 𤗵
    # 0x245F6: '',  # 𤗶
    0x245F7: 'lìn',  # 𤗷
    0x245F8: 'fèn,fén',  # 𤗸
    # 0x245F9: '',  # 𤗹
    0x245FA: 'bó',  # 𤗺
    0x245FB: 'chàn',  # 𤗻
    # 0x245FC: '',  # 𤗼
    # 0x245FD: '',  # 𤗽
    0x245FE: 'dāng',  # 𤗾
    0x245FF: 'tǎi',  # 𤗿
    0x24600: 'dào',  # 𤘀
    # 0x24601: '',  # 𤘁
    # 0x24602: '',  # 𤘂
    0x24603: 'lì',  # 𤘃
    # 0x24604: '',  # 𤘄
    0x24605: 'yá',  # 𤘅
    0x24606: 'yá',  # 𤘆
    0x24607: 'zhān',  # 𤘇
    # 0x24608: '',  # 𤘈
    # 0x24609: '',  # 𤘉
    0x2460A: 'yí',  # 𤘊
    # 0x2460B: '',  # 𤘋
    0x2460C: 'qī',  # 𤘌
    # 0x2460D: '',  # 𤘍
    # 0x2460E: '',  # 𤘎
    # 0x2460F: '',  # 𤘏
    0x24610: 'qǔ',  # 𤘐
    # 0x24611: '',  # 𤘑
    # 0x24612: '',  # 𤘒
    # 0x24613: '',  # 𤘓
    0x24614: 'hù',  # 𤘔
    # 0x24615: '',  # 𤘕
    0x24616: 'tīng',  # 𤘖
    # 0x24617: '',  # 𤘗
    0x24618: 'kǒu',  # 𤘘
    # 0x24619: '',  # 𤘙
    # 0x2461A: '',  # 𤘚
    0x2461B: 'chún',  # 𤘛
    0x2461C: 'yóu',  # 𤘜
    0x2461D: 'fèn',  # 𤘝
    # 0x2461E: '',  # 𤘞
    0x2461F: 'nuó',  # 𤘟
    0x24620: 'tiàn',  # 𤘠
    0x24621: 'jìn',  # 𤘡
    0x24622: 'pí',  # 𤘢
    0x24623: 'chén',  # 𤘣
    0x24624: 'pì',  # 𤘤
    # 0x24625: '',  # 𤘥
    0x24626: 'jiè',  # 𤘦
    0x24627: 'guǐ',  # 𤘧
    # 0x24628: '',  # 𤘨
    # 0x24629: '',  # 𤘩
    # 0x2462A: '',  # 𤘪
    # 0x2462B: '',  # 𤘫
    # 0x2462C: '',  # 𤘬
    # 0x2462D: '',  # 𤘭
    # 0x2462E: '',  # 𤘮
    # 0x2462F: '',  # 𤘯
    # 0x24630: '',  # 𤘰
    # 0x24631: '',  # 𤘱
    0x24632: 'zhuàng',  # 𤘲
    # 0x24633: '',  # 𤘳
    # 0x24634: '',  # 𤘴
    0x24635: 'hú',  # 𤘵
    0x24636: 'chǒu',  # 𤘶
    0x24637: 'shù',  # 𤘷
    0x24638: 'tāo',  # 𤘸
    0x24639: 'pí',  # 𤘹
    0x2463A: 'rǒng',  # 𤘺
    0x2463B: 'rǒng',  # 𤘻
    # 0x2463C: '',  # 𤘼
    0x2463D: 'hǒu',  # 𤘽
    0x2463E: 'pēng',  # 𤘾
    # 0x2463F: '',  # 𤘿
    # 0x24640: '',  # 𤙀
    # 0x24641: '',  # 𤙁
    # 0x24642: '',  # 𤙂
    # 0x24643: '',  # 𤙃
    # 0x24644: '',  # 𤙄
    0x24645: 'bài',  # 𤙅
    # 0x24646: '',  # 𤙆
    0x24647: 'xiá',  # 𤙇
    # 0x24648: '',  # 𤙈
    # 0x24649: '',  # 𤙉
    # 0x2464A: '',  # 𤙊
    0x2464B: 'qǐn',  # 𤙋
    0x2464C: 'nǐ',  # 𤙌
    # 0x2464D: '',  # 𤙍
    0x2464E: 'tāo',  # 𤙎
    0x2464F: 'qù',  # 𤙏
    # 0x24650: '',  # 𤙐
    # 0x24651: '',  # 𤙑
    0x24652: 'xié',  # 𤙒
    # 0x24653: '',  # 𤙓
    0x24654: 'zhào',  # 𤙔
    0x24655: 'huā',  # 𤙕
    0x24656: 'xīn',  # 𤙖
    # 0x24657: '',  # 𤙗
    0x24658: 'shōu',  # 𤙘
    # 0x24659: '',  # 𤙙
    # 0x2465A: '',  # 𤙚
    0x2465B: 'tú',  # 𤙛
    # 0x2465C: '',  # 𤙜
    0x2465D: 'liáng',  # 𤙝
    0x2465E: 'bì',  # 𤙞
    0x2465F: 'chū',  # 𤙟
    # 0x24660: '',  # 𤙠
    0x24661: 'xīng',  # 𤙡
    # 0x24662: '',  # 𤙢
    0x24663: 'xīn',  # 𤙣
    0x24664: 'fū',  # 𤙤
    # 0x24665: '',  # 𤙥
    # 0x24666: '',  # 𤙦
    # 0x24667: '',  # 𤙧
    # 0x24668: '',  # 𤙨
    0x24669: 'jiè',  # 𤙩
    # 0x2466A: '',  # 𤙪
    # 0x2466B: '',  # 𤙫
    # 0x2466C: '',  # 𤙬
    0x2466D: 'fǔ',  # 𤙭
    # 0x2466E: '',  # 𤙮
    0x2466F: 'láo',  # 𤙯
    0x24670: 'tè',  # 𤙰
    0x24671: 'shè',  # 𤙱
    # 0x24672: '',  # 𤙲
    # 0x24673: '',  # 𤙳
    0x24674: 'chāo',  # 𤙴
    0x24675: 'chuī',  # 𤙵
    # 0x24676: '',  # 𤙶
    # 0x24677: '',  # 𤙷
    # 0x24678: '',  # 𤙸
    # 0x24679: '',  # 𤙹
    # 0x2467A: '',  # 𤙺
    # 0x2467B: '',  # 𤙻
    0x2467C: 'rán',  # 𤙼
    0x2467D: 'hǒu',  # 𤙽
    0x2467E: 'bēng',  # 𤙾
    # 0x2467F: '',  # 𤙿
    0x24680: 'cǎi',  # 𤚀
    # 0x24681: '',  # 𤚁
    # 0x24682: '',  # 𤚂
    # 0x24683: '',  # 𤚃
    # 0x24684: '',  # 𤚄
    0x24685: 'mú',  # 𤚅
    # 0x24686: '',  # 𤚆
    # 0x24687: '',  # 𤚇
    # 0x24688: '',  # 𤚈
    0x24689: 'xū',  # 𤚉
    0x2468A: 'dié',  # 𤚊
    # 0x2468B: '',  # 𤚋
    # 0x2468C: '',  # 𤚌
    0x2468D: 'chǎn',  # 𤚍
    0x2468E: 'yú',  # 𤚎
    0x2468F: 'zhòng',  # 𤚏
    # 0x24690: '',  # 𤚐
    # 0x24691: '',  # 𤚑
    # 0x24692: '',  # 𤚒
    0x24693: 'lí',  # 𤚓
    0x24694: 'shōu',  # 𤚔
    # 0x24695: '',  # 𤚕
    # 0x24696: '',  # 𤚖
    # 0x24697: '',  # 𤚗
    # 0x24698: '',  # 𤚘
    # 0x24699: '',  # 𤚙
    0x2469A: 'dú',  # 𤚚
    # 0x2469B: '',  # 𤚛
    0x2469C: 'māo',  # 𤚜
    0x2469D: 'huáng',  # 𤚝
    # 0x2469E: '',  # 𤚞
    0x2469F: 'táo',  # 𤚟
    # 0x246A0: '',  # 𤚠
    0x246A1: 'dù',  # 𤚡
    0x246A2: 'tí',  # 𤚢
    0x246A3: 'shēng',  # 𤚣
    0x246A4: 'méi',  # 𤚤
    # 0x246A5: '',  # 𤚥
    # 0x246A6: '',  # 𤚦
    # 0x246A7: '',  # 𤚧
    0x246A8: 'zhēn',  # 𤚨
    0x246A9: 'qín',  # 𤚩
    0x246AA: 'pì',  # 𤚪
    0x246AB: 'táng',  # 𤚫
    0x246AC: 'cāng',  # 𤚬
    0x246AD: 'yáo',  # 𤚭
    # 0x246AE: '',  # 𤚮
    0x246AF: 'xiù',  # 𤚯
    0x246B0: 'bāng',  # 𤚰
    0x246B1: 'gǔ',  # 𤚱
    # 0x246B2: '',  # 𤚲
    # 0x246B3: '',  # 𤚳
    # 0x246B4: '',  # 𤚴
    0x246B5: 'bù',  # 𤚵
    # 0x246B6: '',  # 𤚶
    # 0x246B7: '',  # 𤚷
    # 0x246B8: '',  # 𤚸
    # 0x246B9: '',  # 𤚹
    # 0x246BA: '',  # 𤚺
    # 0x246BB: '',  # 𤚻
    0x246BC: 'gòu',  # 𤚼
    0x246BD: 'bó',  # 𤚽
    # 0x246BE: '',  # 𤚾
    # 0x246BF: '',  # 𤚿
    # 0x246C0: '',  # 𤛀
    0x246C1: 'wèn',  # 𤛁
    # 0x246C2: '',  # 𤛂
    # 0x246C3: '',  # 𤛃
    0x246C4: 'jì',  # 𤛄
    # 0x246C5: '',  # 𤛅
    # 0x246C6: '',  # 𤛆
    # 0x246C7: '',  # 𤛇
    # 0x246C8: '',  # 𤛈
    # 0x246C9: '',  # 𤛉
    0x246CA: 'lā',  # 𤛊
    # 0x246CB: '',  # 𤛋
    # 0x246CC: '',  # 𤛌
    0x246CD: 'cuī',  # 𤛍
    0x246CE: 'mǐn',  # 𤛎
    0x246CF: 'cǔ',  # 𤛏
    0x246D0: 'ōu',  # 𤛐
    0x246D1: 'yōng',  # 𤛑
    # 0x246D2: '',  # 𤛒
    # 0x246D3: '',  # 𤛓
    # 0x246D4: '',  # 𤛔
    # 0x246D5: '',  # 𤛕
    0x246D6: 'máo',  # 𤛖
    0x246D7: 'kè',  # 𤛗
    # 0x246D8: '',  # 𤛘
    0x246D9: 'dǐng',  # 𤛙
    0x246DA: 'huān',  # 𤛚
    0x246DB: 'duǒ',  # 𤛛
    0x246DC: 'jiāng',  # 𤛜
    0x246DD: 'sù',  # 𤛝
    # 0x246DE: '',  # 𤛞
    0x246DF: 'bèi',  # 𤛟
    # 0x246E0: '',  # 𤛠
    # 0x246E1: '',  # 𤛡
    0x246E2: 'céng',  # 𤛢
    0x246E3: 'tà',  # 𤛣
    # 0x246E4: '',  # 𤛤
    0x246E5: 'huáng',  # 𤛥
    0x246E6: 'jué',  # 𤛦
    0x246E7: 'xún',  # 𤛧
    # 0x246E8: '',  # 𤛨
    # 0x246E9: '',  # 𤛩
    0x246EA: 'xiòng',  # 𤛪
    # 0x246EB: '',  # 𤛫
    0x246EC: 'mì',  # 𤛬
    0x246ED: 'qún',  # 𤛭
    0x246EE: 'láo',  # 𤛮
    # 0x246EF: '',  # 𤛯
    # 0x246F0: '',  # 𤛰
    0x246F1: 'zhì',  # 𤛱
    0x246F2: 'wěi,wéi',  # 𤛲
    # 0x246F3: '',  # 𤛳
    # 0x246F4: '',  # 𤛴
    # 0x246F5: '',  # 𤛵
    # 0x246F6: '',  # 𤛶
    0x246F7: 'sè',  # 𤛷
    # 0x246F8: '',  # 𤛸
    # 0x246F9: '',  # 𤛹
    # 0x246FA: '',  # 𤛺
    0x246FB: 'zāng',  # 𤛻
    # 0x246FC: '',  # 𤛼
    # 0x246FD: '',  # 𤛽
    # 0x246FE: '',  # 𤛾
    0x246FF: 'lí',  # 𤛿
    # 0x24700: '',  # 𤜀
    0x24701: 'ǎn',  # 𤜁
    0x24702: 'wèi,guì',  # 𤜂
    # 0x24703: '',  # 𤜃
    0x24704: 'huài',  # 𤜄
    # 0x24705: '',  # 𤜅
    # 0x24706: '',  # 𤜆
    0x24707: 'zhàn',  # 𤜇
    # 0x24708: '',  # 𤜈
    0x24709: 'yīng',  # 𤜉
    0x2470A: 'gē',  # 𤜊
    0x2470B: 'huì',  # 𤜋
    # 0x2470C: '',  # 𤜌
    0x2470D: 'quán',  # 𤜍
    # 0x2470E: '',  # 𤜎
    # 0x2470F: '',  # 𤜏
    # 0x24710: '',  # 𤜐
    # 0x24711: '',  # 𤜑
    # 0x24712: '',  # 𤜒
    0x24713: 'liè',  # 𤜓
    0x24714: 'jú',  # 𤜔
    0x24715: 'bà',  # 𤜕
    0x24716: 'léi',  # 𤜖
    # 0x24717: '',  # 𤜗
    0x24718: 'mán',  # 𤜘
    0x24719: 'líng',  # 𤜙
    # 0x2471A: '',  # 𤜚
    # 0x2471B: '',  # 𤜛
    0x2471C: 'lì',  # 𤜜
    0x2471D: 'jǐ',  # 𤜝
    # 0x2471E: '',  # 𤜞
    # 0x2471F: '',  # 𤜟
    # 0x24720: '',  # 𤜠
    0x24721: 'huí',  # 𤜡
    0x24722: 'xìn',  # 𤜢
    0x24723: 'shì,shé',  # 𤜣
    0x24724: 'zhé',  # 𤜤
    # 0x24725: '',  # 𤜥
    # 0x24726: '',  # 𤜦
    0x24727: 'bō',  # 𤜧
    # 0x24728: '',  # 𤜨
    # 0x24729: '',  # 𤜩
    # 0x2472A: '',  # 𤜪
    0x2472B: 'chā',  # 𤜫
    # 0x2472C: '',  # 𤜬
    # 0x2472D: '',  # 𤜭
    # 0x2472E: '',  # 𤜮
    0x2472F: 'chā',  # 𤜯
    0x24730: 'jīng',  # 𤜰
    0x24731: 'bā',  # 𤜱
    0x24732: 'bèi,pèi',  # 𤜲
    # 0x24733: '',  # 𤜳
    # 0x24734: '',  # 𤜴
    0x24735: 'yàn',  # 𤜵
    # 0x24736: '',  # 𤜶
    0x24737: 'hù',  # 𤜷
    # 0x24738: '',  # 𤜸
    0x24739: 'yú',  # 𤜹
    # 0x2473A: '',  # 𤜺
    0x2473B: 'bì,pí',  # 𤜻
    0x2473C: 'chuán',  # 𤜼
    # 0x2473D: '',  # 𤜽
    0x2473E: 'jǐ',  # 𤜾
    # 0x2473F: '',  # 𤜿
    # 0x24740: '',  # 𤝀
    # 0x24741: '',  # 𤝁
    0x24742: 'mù',  # 𤝂
    # 0x24743: '',  # 𤝃
    0x24744: 'máo',  # 𤝄
    0x24745: 'zhōng',  # 𤝅
    # 0x24746: '',  # 𤝆
    0x24747: 'yè',  # 𤝇
    0x24748: 'dōu',  # 𤝈
    0x24749: 'yě',  # 𤝉
    # 0x2474A: '',  # 𤝊
    # 0x2474B: '',  # 𤝋
    # 0x2474C: '',  # 𤝌
    0x2474D: 'rì',  # 𤝍
    0x2474E: 'yīn',  # 𤝎
    # 0x2474F: '',  # 𤝏
    0x24750: 'hào',  # 𤝐
    # 0x24751: '',  # 𤝑
    0x24752: 'nà',  # 𤝒
    0x24753: 'tiè',  # 𤝓
    0x24754: 'fù,chái',  # 𤝔
    0x24755: 'mǔ',  # 𤝕
    0x24756: 'zǎi',  # 𤝖
    # 0x24757: '',  # 𤝗
    0x24758: 'hú',  # 𤝘
    # 0x24759: '',  # 𤝙
    0x2475A: 'chēn',  # 𤝚
    0x2475B: 'tuó',  # 𤝛
    # 0x2475C: '',  # 𤝜
    # 0x2475D: '',  # 𤝝
    0x2475E: 'chù',  # 𤝞
    0x2475F: 'fú,fèi',  # 𤝟
    # 0x24760: '',  # 𤝠
    # 0x24761: '',  # 𤝡
    # 0x24762: '',  # 𤝢
    # 0x24763: '',  # 𤝣
    # 0x24764: '',  # 𤝤
    # 0x24765: '',  # 𤝥
    # 0x24766: '',  # 𤝦
    0x24767: 'bào',  # 𤝧
    # 0x24768: '',  # 𤝨
    # 0x24769: '',  # 𤝩
    # 0x2476A: '',  # 𤝪
    # 0x2476B: '',  # 𤝫
    0x2476C: 'dǐ',  # 𤝬
    0x2476D: 'cǎi',  # 𤝭
    0x2476E: 'lù',  # 𤝮
    0x2476F: 'pǒ',  # 𤝯
    0x24770: 'dá',  # 𤝰
    0x24771: 'yè',  # 𤝱
    # 0x24772: '',  # 𤝲
    0x24773: 'yǐ',  # 𤝳
    # 0x24774: '',  # 𤝴
    # 0x24775: '',  # 𤝵
    # 0x24776: '',  # 𤝶
    0x24777: 'xiáng',  # 𤝷
    0x24778: 'bī',  # 𤝸
    0x24779: 'zhū',  # 𤝹
    # 0x2477A: '',  # 𤝺
    0x2477B: 'yí',  # 𤝻
    0x2477C: 'zhì',  # 𤝼
    # 0x2477D: '',  # 𤝽
    # 0x2477E: '',  # 𤝾
    0x2477F: 'kuāng',  # 𤝿
    # 0x24780: '',  # 𤞀
    # 0x24781: '',  # 𤞁
    0x24782: 'zhì',  # 𤞂
    # 0x24783: '',  # 𤞃
    # 0x24784: '',  # 𤞄
    # 0x24785: '',  # 𤞅
    # 0x24786: '',  # 𤞆
    0x24787: 'wá,kuáng',  # 𤞇
    0x24788: 'dī',  # 𤞈
    0x24789: 'shù',  # 𤞉
    0x2478A: 'liè',  # 𤞊
    0x2478B: 'zǎo',  # 𤞋
    0x2478C: 'zhì',  # 𤞌
    0x2478D: 'náo',  # 𤞍
    # 0x2478E: '',  # 𤞎
    0x2478F: 'shī',  # 𤞏
    # 0x24790: '',  # 𤞐
    # 0x24791: '',  # 𤞑
    # 0x24792: '',  # 𤞒
    # 0x24793: '',  # 𤞓
    # 0x24794: '',  # 𤞔
    # 0x24795: '',  # 𤞕
    # 0x24796: '',  # 𤞖
    0x24797: 'chái',  # 𤞗
    # 0x24798: '',  # 𤞘
    # 0x24799: '',  # 𤞙
    0x2479A: 'xiāo',  # 𤞚
    0x2479B: 'zàng',  # 𤞛
    # 0x2479C: '',  # 𤞜
    # 0x2479D: '',  # 𤞝
    0x2479E: 'yù',  # 𤞞
    0x2479F: 'dòu',  # 𤞟
    0x247A0: 'chà',  # 𤞠
    0x247A1: 'xié',  # 𤞡
    0x247A2: 'yáng',  # 𤞢
    0x247A3: 'yàn',  # 𤞣
    # 0x247A4: '',  # 𤞤
    0x247A5: 'bǎo',  # 𤞥
    # 0x247A6: '',  # 𤞦
    # 0x247A7: '',  # 𤞧
    # 0x247A8: '',  # 𤞨
    # 0x247A9: '',  # 𤞩
    # 0x247AA: '',  # 𤞪
    # 0x247AB: '',  # 𤞫
    # 0x247AC: '',  # 𤞬
    # 0x247AD: '',  # 𤞭
    0x247AE: 'zhāi',  # 𤞮
    # 0x247AF: '',  # 𤞯
    0x247B0: 'qiú',  # 𤞰
    # 0x247B1: '',  # 𤞱
    0x247B2: 'hú',  # 𤞲
    0x247B3: 'zài',  # 𤞳
    0x247B4: 'jué',  # 𤞴
    # 0x247B5: '',  # 𤞵
    0x247B6: 'hàn',  # 𤞶
    # 0x247B7: '',  # 𤞷
    # 0x247B8: '',  # 𤞸
    # 0x247B9: '',  # 𤞹
    # 0x247BA: '',  # 𤞺
    # 0x247BB: '',  # 𤞻
    # 0x247BC: '',  # 𤞼
    # 0x247BD: '',  # 𤞽
    # 0x247BE: '',  # 𤞾
    0x247BF: 'àn',  # 𤞿
    0x247C0: 'zào',  # 𤟀
    # 0x247C1: '',  # 𤟁
    # 0x247C2: '',  # 𤟂
    0x247C3: 'shà',  # 𤟃
    # 0x247C4: '',  # 𤟄
    0x247C5: 'xiàn',  # 𤟅
    0x247C6: 'chǐ',  # 𤟆
    0x247C7: 'yǎn',  # 𤟇
    # 0x247C8: '',  # 𤟈
    0x247C9: 'àn',  # 𤟉
    # 0x247CA: '',  # 𤟊
    # 0x247CB: '',  # 𤟋
    0x247CC: 'jiǎng',  # 𤟌
    0x247CD: 'zhé',  # 𤟍
    0x247CE: 'jué',  # 𤟎
    # 0x247CF: '',  # 𤟏
    # 0x247D0: '',  # 𤟐
    0x247D1: 'lì',  # 𤟑
    # 0x247D2: '',  # 𤟒
    0x247D3: 'lè',  # 𤟓
    # 0x247D4: '',  # 𤟔
    # 0x247D5: '',  # 𤟕
    0x247D6: 'cǎi',  # 𤟖
    # 0x247D7: '',  # 𤟗
    0x247D8: 'lù',  # 𤟘
    # 0x247D9: '',  # 𤟙
    0x247DA: 'jiā',  # 𤟚
    # 0x247DB: '',  # 𤟛
    # 0x247DC: '',  # 𤟜
    0x247DD: 'xià',  # 𤟝
    0x247DE: 'xiào',  # 𤟞
    0x247DF: 'yān',  # 𤟟
    0x247E0: 'xū',  # 𤟠
    # 0x247E1: '',  # 𤟡
    0x247E2: 'dùn',  # 𤟢
    0x247E3: 'yíng',  # 𤟣
    0x247E4: 'huī,xūn',  # 𤟤
    0x247E5: 'tí',  # 𤟥
    0x247E6: 'nóu',  # 𤟦
    0x247E7: 'xǐ',  # 𤟧
    # 0x247E8: '',  # 𤟨
    # 0x247E9: '',  # 𤟩
    0x247EA: 'tú',  # 𤟪
    # 0x247EB: '',  # 𤟫
    # 0x247EC: '',  # 𤟬
    # 0x247ED: '',  # 𤟭
    # 0x247EE: '',  # 𤟮
    # 0x247EF: '',  # 𤟯
    # 0x247F0: '',  # 𤟰
    # 0x247F1: '',  # 𤟱
    # 0x247F2: '',  # 𤟲
    # 0x247F3: '',  # 𤟳
    # 0x247F4: '',  # 𤟴
    # 0x247F5: '',  # 𤟵
    # 0x247F6: '',  # 𤟶
    0x247F7: 'wāi',  # 𤟷
    0x247F8: 'chēn',  # 𤟸
    0x247F9: 'yù',  # 𤟹
    # 0x247FA: '',  # 𤟺
    # 0x247FB: '',  # 𤟻
    0x247FC: 'hōng',  # 𤟼
    # 0x247FD: '',  # 𤟽
    0x247FE: 'tí',  # 𤟾
    0x247FF: 'xuān',  # 𤟿
    0x24800: 'zá',  # 𤠀
    # 0x24801: '',  # 𤠁
    # 0x24802: '',  # 𤠂
    # 0x24803: '',  # 𤠃
    # 0x24804: '',  # 𤠄
    # 0x24805: '',  # 𤠅
    # 0x24806: '',  # 𤠆
    0x24807: 'gé',  # 𤠇
    # 0x24808: '',  # 𤠈
    # 0x24809: '',  # 𤠉
    # 0x2480A: '',  # 𤠊
    # 0x2480B: '',  # 𤠋
    0x2480C: 'chái',  # 𤠌
    0x2480D: 'pán',  # 𤠍
    0x2480E: 'jí',  # 𤠎
    0x2480F: 'nǎo',  # 𤠏
    0x24810: 'tà',  # 𤠐
    # 0x24811: '',  # 𤠑
    # 0x24812: '',  # 𤠒
    0x24813: 'xī',  # 𤠓
    # 0x24814: '',  # 𤠔
    # 0x24815: '',  # 𤠕
    0x24816: 'xiāo',  # 𤠖
    # 0x24817: '',  # 𤠗
    0x24818: 'sāo',  # 𤠘
    0x24819: 'jiā',  # 𤠙
    0x2481A: 'sù',  # 𤠚
    0x2481B: 'huāng',  # 𤠛
    # 0x2481C: '',  # 𤠜
    0x2481D: 'cuō',  # 𤠝
    # 0x2481E: '',  # 𤠞
    0x2481F: 'tà',  # 𤠟
    0x24820: 'shuāi',  # 𤠠
    # 0x24821: '',  # 𤠡
    # 0x24822: '',  # 𤠢
    # 0x24823: '',  # 𤠣
    # 0x24824: '',  # 𤠤
    # 0x24825: '',  # 𤠥
    # 0x24826: '',  # 𤠦
    # 0x24827: '',  # 𤠧
    # 0x24828: '',  # 𤠨
    # 0x24829: '',  # 𤠩
    0x2482A: 'fú',  # 𤠪
    0x2482B: 'lì',  # 𤠫
    # 0x2482C: '',  # 𤠬
    0x2482D: 'shè',  # 𤠭
    # 0x2482E: '',  # 𤠮
    0x2482F: 'táng',  # 𤠯
    # 0x24830: '',  # 𤠰
    # 0x24831: '',  # 𤠱
    # 0x24832: '',  # 𤠲
    # 0x24833: '',  # 𤠳
    # 0x24834: '',  # 𤠴
    # 0x24835: '',  # 𤠵
    0x24836: 'diān',  # 𤠶
    # 0x24837: '',  # 𤠷
    # 0x24838: '',  # 𤠸
    # 0x24839: '',  # 𤠹
    0x2483A: 'bì',  # 𤠺
    # 0x2483B: '',  # 𤠻
    0x2483C: 'gòu',  # 𤠼
    0x2483D: 'cù',  # 𤠽
    # 0x2483E: '',  # 𤠾
    0x2483F: 'qiān',  # 𤠿
    # 0x24840: '',  # 𤡀
    # 0x24841: '',  # 𤡁
    0x24842: 'léi,lěi',  # 𤡂
    0x24843: 'sù',  # 𤡃
    # 0x24844: '',  # 𤡄
    # 0x24845: '',  # 𤡅
    0x24846: 'zòng,zōng',  # 𤡆
    0x24847: 'hāo',  # 𤡇
    # 0x24848: '',  # 𤡈
    # 0x24849: '',  # 𤡉
    # 0x2484A: '',  # 𤡊
    # 0x2484B: '',  # 𤡋
    # 0x2484C: '',  # 𤡌
    # 0x2484D: '',  # 𤡍
    # 0x2484E: '',  # 𤡎
    0x2484F: 'chì',  # 𤡏
    0x24850: 'cáo',  # 𤡐
    # 0x24851: '',  # 𤡑
    # 0x24852: '',  # 𤡒
    0x24853: 'wò',  # 𤡓
    0x24854: 'xiāo',  # 𤡔
    0x24855: 'liè,wěn',  # 𤡕
    0x24856: 'yān',  # 𤡖
    # 0x24857: '',  # 𤡗
    # 0x24858: '',  # 𤡘
    # 0x24859: '',  # 𤡙
    # 0x2485A: '',  # 𤡚
    # 0x2485B: '',  # 𤡛
    # 0x2485C: '',  # 𤡜
    0x2485D: 'bì',  # 𤡝
    # 0x2485E: '',  # 𤡞
    0x2485F: 'huàn',  # 𤡟
    # 0x24860: '',  # 𤡠
    0x24861: 'xī',  # 𤡡
    0x24862: 'chī',  # 𤡢
    0x24863: 'xū',  # 𤡣
    0x24864: 'náo,nà,rú',  # 𤡤
    0x24865: 'yán,xiàn',  # 𤡥
    # 0x24866: '',  # 𤡦
    0x24867: 'xiè',  # 𤡧
    0x24868: 'zhá',  # 𤡨
    # 0x24869: '',  # 𤡩
    0x2486A: 'suì,wěi',  # 𤡪
    # 0x2486B: '',  # 𤡫
    0x2486C: 'xì',  # 𤡬
    0x2486D: 'bēng,péng',  # 𤡭
    0x2486E: 'rán',  # 𤡮
    0x2486F: 'shuò,xī,què',  # 𤡯
    0x24870: 'bān',  # 𤡰
    0x24871: 'guì',  # 𤡱
    0x24872: 'kāi',  # 𤡲
    0x24873: 'chēn',  # 𤡳
    # 0x24874: '',  # 𤡴
    # 0x24875: '',  # 𤡵
    0x24876: 'xù',  # 𤡶
    # 0x24877: '',  # 𤡷
    # 0x24878: '',  # 𤡸
    # 0x24879: '',  # 𤡹
    # 0x2487A: '',  # 𤡺
    # 0x2487B: '',  # 𤡻
    # 0x2487C: '',  # 𤡼
    # 0x2487D: '',  # 𤡽
    0x2487E: 'è',  # 𤡾
    0x2487F: 'lì',  # 𤡿
    0x24880: 'xī',  # 𤢀
    0x24881: 'huàn',  # 𤢁
    0x24882: 'sù',  # 𤢂
    # 0x24883: '',  # 𤢃
    0x24884: 'chǎng',  # 𤢄
    # 0x24885: '',  # 𤢅
    # 0x24886: '',  # 𤢆
    # 0x24887: '',  # 𤢇
    # 0x24888: '',  # 𤢈
    # 0x24889: '',  # 𤢉
    0x2488A: 'lù',  # 𤢊
    0x2488B: 'yán',  # 𤢋
    # 0x2488C: '',  # 𤢌
    # 0x2488D: '',  # 𤢍
    0x2488E: 'dāng',  # 𤢎
    0x2488F: 'dǎn',  # 𤢏
    0x24890: 'yāng',  # 𤢐
    # 0x24891: '',  # 𤢑
    0x24892: 'zhǎi',  # 𤢒
    0x24893: 'jù,qú',  # 𤢓
    # 0x24894: '',  # 𤢔
    0x24895: 'duó',  # 𤢕
    0x24896: 'sāo,shān',  # 𤢖
    0x24897: 'lái',  # 𤢗
    0x24898: 'sù',  # 𤢘
    # 0x24899: '',  # 𤢙
    # 0x2489A: '',  # 𤢚
    # 0x2489B: '',  # 𤢛
    # 0x2489C: '',  # 𤢜
    # 0x2489D: '',  # 𤢝
    # 0x2489E: '',  # 𤢞
    0x2489F: 'zé',  # 𤢟
    # 0x248A0: '',  # 𤢠
    # 0x248A1: '',  # 𤢡
    # 0x248A2: '',  # 𤢢
    0x248A3: 'bì',  # 𤢣
    # 0x248A4: '',  # 𤢤
    # 0x248A5: '',  # 𤢥
    0x248A6: 'yìn',  # 𤢦
    # 0x248A7: '',  # 𤢧
    0x248A8: 'hāo',  # 𤢨
    # 0x248A9: '',  # 𤢩
    0x248AA: 'liè',  # 𤢪
    # 0x248AB: '',  # 𤢫
    # 0x248AC: '',  # 𤢬
    0x248AD: 'háo',  # 𤢭
    0x248AE: 'yáng',  # 𤢮
    # 0x248AF: '',  # 𤢯
    # 0x248B0: '',  # 𤢰
    # 0x248B1: '',  # 𤢱
    # 0x248B2: '',  # 𤢲
    # 0x248B3: '',  # 𤢳
    0x248B4: 'shuò,lì',  # 𤢴
    0x248B5: 'ài',  # 𤢵
    0x248B6: 'qióng',  # 𤢶
    # 0x248B7: '',  # 𤢷
    # 0x248B8: '',  # 𤢸
    0x248B9: 'lěi',  # 𤢹
    0x248BA: 'xié',  # 𤢺
    # 0x248BB: '',  # 𤢻
    0x248BC: 'shì',  # 𤢼
    # 0x248BD: '',  # 𤢽
    # 0x248BE: '',  # 𤢾
    # 0x248BF: '',  # 𤢿
    # 0x248C0: '',  # 𤣀
    # 0x248C1: '',  # 𤣁
    # 0x248C2: '',  # 𤣂
    0x248C3: 'lǔ',  # 𤣃
    # 0x248C4: '',  # 𤣄
    0x248C5: 'què',  # 𤣅
    0x248C6: 'lián',  # 𤣆
    # 0x248C7: '',  # 𤣇
    # 0x248C8: '',  # 𤣈
    # 0x248C9: '',  # 𤣉
    # 0x248CA: '',  # 𤣊
    # 0x248CB: '',  # 𤣋
    0x248CC: 'xiào',  # 𤣌
    # 0x248CD: '',  # 𤣍
    0x248CE: 'yīng',  # 𤣎
    # 0x248CF: '',  # 𤣏
    # 0x248D0: '',  # 𤣐
    0x248D1: 'xié',  # 𤣑
    # 0x248D2: '',  # 𤣒
    # 0x248D3: '',  # 𤣓
    0x248D4: 'xiǎn',  # 𤣔
    # 0x248D5: '',  # 𤣕
    0x248D6: 'fēng',  # 𤣖
    # 0x248D7: '',  # 𤣗
    0x248D8: 'líng',  # 𤣘
    0x248D9: 'yōu',  # 𤣙
    # 0x248DA: '',  # 𤣚
    # 0x248DB: '',  # 𤣛
    # 0x248DC: '',  # 𤣜
    # 0x248DD: '',  # 𤣝
    0x248DE: 'dǎng',  # 𤣞
    0x248DF: 'lǎn',  # 𤣟
    0x248E0: 'xiāo',  # 𤣠
    # 0x248E1: '',  # 𤣡
    # 0x248E2: '',  # 𤣢
    # 0x248E3: '',  # 𤣣
    # 0x248E4: '',  # 𤣤
    0x248E5: 'xuán',  # 𤣥
    # 0x248E6: '',  # 𤣦
    # 0x248E7: '',  # 𤣧
    0x248E8: 'yì',  # 𤣨
    # 0x248E9: '',  # 𤣩
    # 0x248EA: '',  # 𤣪
    # 0x248EB: '',  # 𤣫
    0x248EC: 'wū',  # 𤣬
    # 0x248ED: '',  # 𤣭
    0x248EE: 'yì',  # 𤣮
    0x248EF: 'tuō',  # 𤣯
    0x248F0: 'bǔ',  # 𤣰
    0x248F1: 'qǐ',  # 𤣱
    0x248F2: 'xìn',  # 𤣲
    # 0x248F3: '',  # 𤣳
    # 0x248F4: '',  # 𤣴
    0x248F5: 'sī',  # 𤣵
    0x248F6: 'jīn',  # 𤣶
    # 0x248F7: '',  # 𤣷
    0x248F8: 'bā',  # 𤣸
    0x248F9: 'fǎ',  # 𤣹
    # 0x248FA: '',  # 𤣺
    0x248FB: 'mò',  # 𤣻
    0x248FC: 'ruò',  # 𤣼
    # 0x248FD: '',  # 𤣽
    # 0x248FE: '',  # 𤣾
    # 0x248FF: '',  # 𤣿
    # 0x24900: '',  # 𤤀
    # 0x24901: '',  # 𤤁
    # 0x24902: '',  # 𤤂
    # 0x24903: '',  # 𤤃
    # 0x24904: '',  # 𤤄
    # 0x24905: '',  # 𤤅
    # 0x24906: '',  # 𤤆
    # 0x24907: '',  # 𤤇
    # 0x24908: '',  # 𤤈
    # 0x24909: '',  # 𤤉
    0x2490A: 'dà',  # 𤤊
    0x2490B: 'jì',  # 𤤋
    # 0x2490C: '',  # 𤤌
    # 0x2490D: '',  # 𤤍
    # 0x2490E: '',  # 𤤎
    # 0x2490F: '',  # 𤤏
    0x24910: 'sù',  # 𤤐
    0x24911: 'qióng',  # 𤤑
    0x24912: 'bā',  # 𤤒
    # 0x24913: '',  # 𤤓
    # 0x24914: '',  # 𤤔
    # 0x24915: '',  # 𤤕
    # 0x24916: '',  # 𤤖
    # 0x24917: '',  # 𤤗
    # 0x24918: '',  # 𤤘
    # 0x24919: '',  # 𤤙
    # 0x2491A: '',  # 𤤚
    # 0x2491B: '',  # 𤤛
    # 0x2491C: '',  # 𤤜
    # 0x2491D: '',  # 𤤝
    # 0x2491E: '',  # 𤤞
    # 0x2491F: '',  # 𤤟
    # 0x24920: '',  # 𤤠
    # 0x24921: '',  # 𤤡
    # 0x24922: '',  # 𤤢
    # 0x24923: '',  # 𤤣
    # 0x24924: '',  # 𤤤
    # 0x24925: '',  # 𤤥
    0x24926: 'tián',  # 𤤦
    0x24927: 'yóu',  # 𤤧
    # 0x24928: '',  # 𤤨
    0x24929: 'tuó',  # 𤤩
    # 0x2492A: '',  # 𤤪
    0x2492B: 'wài',  # 𤤫
    0x2492C: 'yòu',  # 𤤬
    # 0x2492D: '',  # 𤤭
    0x2492E: 'dōng',  # 𤤮
    # 0x2492F: '',  # 𤤯
    # 0x24930: '',  # 𤤰
    0x24931: 'xǐ',  # 𤤱
    0x24932: 'kǒng',  # 𤤲
    # 0x24933: '',  # 𤤳
    # 0x24934: '',  # 𤤴
    # 0x24935: '',  # 𤤵
    0x24936: 'qióng',  # 𤤶
    0x24937: 'duī',  # 𤤷
    0x24938: 'duò',  # 𤤸
    # 0x24939: '',  # 𤤹
    0x2493A: 'yì',  # 𤤺
    # 0x2493B: '',  # 𤤻
    # 0x2493C: '',  # 𤤼
    # 0x2493D: '',  # 𤤽
    # 0x2493E: '',  # 𤤾
    # 0x2493F: '',  # 𤤿
    # 0x24940: '',  # 𤥀
    # 0x24941: '',  # 𤥁
    # 0x24942: '',  # 𤥂
    # 0x24943: '',  # 𤥃
    # 0x24944: '',  # 𤥄
    # 0x24945: '',  # 𤥅
    # 0x24946: '',  # 𤥆
    # 0x24947: '',  # 𤥇
    # 0x24948: '',  # 𤥈
    # 0x24949: '',  # 𤥉
    # 0x2494A: '',  # 𤥊
    # 0x2494B: '',  # 𤥋
    # 0x2494C: '',  # 𤥌
    # 0x2494D: '',  # 𤥍
    0x2494E: 'yǎn',  # 𤥎
    # 0x2494F: '',  # 𤥏
    # 0x24950: '',  # 𤥐
    # 0x24951: '',  # 𤥑
    0x24952: 'xī',  # 𤥒
    0x24953: 'qīn',  # 𤥓
    0x24954: 'sù',  # 𤥔
    # 0x24955: '',  # 𤥕
    # 0x24956: '',  # 𤥖
    0x24957: 'liú',  # 𤥗
    # 0x24958: '',  # 𤥘
    0x24959: 'wán',  # 𤥙
    # 0x2495A: '',  # 𤥚
    # 0x2495B: '',  # 𤥛
    # 0x2495C: '',  # 𤥜
    # 0x2495D: '',  # 𤥝
    # 0x2495E: '',  # 𤥞
    # 0x2495F: '',  # 𤥟
    # 0x24960: '',  # 𤥠
    # 0x24961: '',  # 𤥡
    # 0x24962: '',  # 𤥢
    # 0x24963: '',  # 𤥣
    # 0x24964: '',  # 𤥤
    # 0x24965: '',  # 𤥥
    # 0x24966: '',  # 𤥦
    # 0x24967: '',  # 𤥧
    # 0x24968: '',  # 𤥨
    # 0x24969: '',  # 𤥩
    # 0x2496A: '',  # 𤥪
    # 0x2496B: '',  # 𤥫
    # 0x2496C: '',  # 𤥬
    0x2496D: 'chē',  # 𤥭
    0x2496E: 'zhū',  # 𤥮
    # 0x2496F: '',  # 𤥯
    0x24970: 'mào',  # 𤥰
    # 0x24971: '',  # 𤥱
    # 0x24972: '',  # 𤥲
    # 0x24973: '',  # 𤥳
    # 0x24974: '',  # 𤥴
    # 0x24975: '',  # 𤥵
    # 0x24976: '',  # 𤥶
    0x24977: 'quán',  # 𤥷
    # 0x24978: '',  # 𤥸
    # 0x24979: '',  # 𤥹
    # 0x2497A: '',  # 𤥺
    0x2497B: 'yán',  # 𤥻
    # 0x2497C: '',  # 𤥼
    0x2497D: 'yū',  # 𤥽
    # 0x2497E: '',  # 𤥾
    0x2497F: 'yì',  # 𤥿
    # 0x24980: '',  # 𤦀
    # 0x24981: '',  # 𤦁
    # 0x24982: '',  # 𤦂
    0x24983: 'lái',  # 𤦃
    0x24984: 'zhì',  # 𤦄
    # 0x24985: '',  # 𤦅
    # 0x24986: '',  # 𤦆
    # 0x24987: '',  # 𤦇
    # 0x24988: '',  # 𤦈
    # 0x24989: '',  # 𤦉
    # 0x2498A: '',  # 𤦊
    # 0x2498B: '',  # 𤦋
    # 0x2498C: '',  # 𤦌
    # 0x2498D: '',  # 𤦍
    # 0x2498E: '',  # 𤦎
    # 0x2498F: '',  # 𤦏
    # 0x24990: '',  # 𤦐
    # 0x24991: '',  # 𤦑
    # 0x24992: '',  # 𤦒
    # 0x24993: '',  # 𤦓
    # 0x24994: '',  # 𤦔
    # 0x24995: '',  # 𤦕
    # 0x24996: '',  # 𤦖
    # 0x24997: '',  # 𤦗
    # 0x24998: '',  # 𤦘
    # 0x24999: '',  # 𤦙
    # 0x2499A: '',  # 𤦚
    # 0x2499B: '',  # 𤦛
    # 0x2499C: '',  # 𤦜
    # 0x2499D: '',  # 𤦝
    # 0x2499E: '',  # 𤦞
    # 0x2499F: '',  # 𤦟
    # 0x249A0: '',  # 𤦠
    # 0x249A1: '',  # 𤦡
    # 0x249A2: '',  # 𤦢
    # 0x249A3: '',  # 𤦣
    0x249A4: 'ní',  # 𤦤
    # 0x249A5: '',  # 𤦥
    0x249A6: 'bān',  # 𤦦
    # 0x249A7: '',  # 𤦧
    # 0x249A8: '',  # 𤦨
    # 0x249A9: '',  # 𤦩
    0x249AA: 'dōng',  # 𤦪
    # 0x249AB: '',  # 𤦫
    # 0x249AC: '',  # 𤦬
    # 0x249AD: '',  # 𤦭
    0x249AE: 'zhì',  # 𤦮
    # 0x249AF: '',  # 𤦯
    # 0x249B0: '',  # 𤦰
    # 0x249B1: '',  # 𤦱
    # 0x249B2: '',  # 𤦲
    # 0x249B3: '',  # 𤦳
    # 0x249B4: '',  # 𤦴
    # 0x249B5: '',  # 𤦵
    # 0x249B6: '',  # 𤦶
    # 0x249B7: '',  # 𤦷
    # 0x249B8: '',  # 𤦸
    # 0x249B9: '',  # 𤦹
    0x249BA: 'qí',  # 𤦺
    # 0x249BB: '',  # 𤦻
    # 0x249BC: '',  # 𤦼
    # 0x249BD: '',  # 𤦽
    # 0x249BE: '',  # 𤦾
    # 0x249BF: '',  # 𤦿
    # 0x249C0: '',  # 𤧀
    # 0x249C1: '',  # 𤧁
    # 0x249C2: '',  # 𤧂
    # 0x249C3: '',  # 𤧃
    # 0x249C4: '',  # 𤧄
    # 0x249C5: '',  # 𤧅
    # 0x249C6: '',  # 𤧆
    # 0x249C7: '',  # 𤧇
    # 0x249C8: '',  # 𤧈
    # 0x249C9: '',  # 𤧉
    # 0x249CA: '',  # 𤧊
    # 0x249CB: '',  # 𤧋
    # 0x249CC: '',  # 𤧌
    # 0x249CD: '',  # 𤧍
    # 0x249CE: '',  # 𤧎
    # 0x249CF: '',  # 𤧏
    # 0x249D0: '',  # 𤧐
    # 0x249D1: '',  # 𤧑
    # 0x249D2: '',  # 𤧒
    # 0x249D3: '',  # 𤧓
    # 0x249D4: '',  # 𤧔
    0x249D5: 'yì',  # 𤧕
    # 0x249D6: '',  # 𤧖
    # 0x249D7: '',  # 𤧗
    0x249D8: 'líng',  # 𤧘
    0x249D9: 'yú',  # 𤧙
    # 0x249DA: '',  # 𤧚
    0x249DB: 'dì',  # 𤧛
    0x249DC: 'zhì',  # 𤧜
    # 0x249DD: '',  # 𤧝
    # 0x249DE: '',  # 𤧞
    # 0x249DF: '',  # 𤧟
    0x249E0: 'ruǎn',  # 𤧠
    # 0x249E1: '',  # 𤧡
    # 0x249E2: '',  # 𤧢
    0x249E3: 'jiàn',  # 𤧣
    # 0x249E4: '',  # 𤧤
    # 0x249E5: '',  # 𤧥
    # 0x249E6: '',  # 𤧦
    # 0x249E7: '',  # 𤧧
    # 0x249E8: '',  # 𤧨
    0x249E9: 'wàn',  # 𤧩
    # 0x249EA: '',  # 𤧪
    0x249EB: 'jìn,duī',  # 𤧫
    # 0x249EC: '',  # 𤧬
    0x249ED: 'páng',  # 𤧭
    # 0x249EE: '',  # 𤧮
    # 0x249EF: '',  # 𤧯
    # 0x249F0: '',  # 𤧰
    # 0x249F1: '',  # 𤧱
    # 0x249F2: '',  # 𤧲
    # 0x249F3: '',  # 𤧳
    # 0x249F4: '',  # 𤧴
    # 0x249F5: '',  # 𤧵
    # 0x249F6: '',  # 𤧶
    # 0x249F7: '',  # 𤧷
    # 0x249F8: '',  # 𤧸
    # 0x249F9: '',  # 𤧹
    # 0x249FA: '',  # 𤧺
    # 0x249FB: '',  # 𤧻
    # 0x249FC: '',  # 𤧼
    # 0x249FD: '',  # 𤧽
    # 0x249FE: '',  # 𤧾
    # 0x249FF: '',  # 𤧿
    # 0x24A00: '',  # 𤨀
    # 0x24A01: '',  # 𤨁
    # 0x24A02: '',  # 𤨂
    # 0x24A03: '',  # 𤨃
    # 0x24A04: '',  # 𤨄
    # 0x24A05: '',  # 𤨅
    # 0x24A06: '',  # 𤨆
    # 0x24A07: '',  # 𤨇
    # 0x24A08: '',  # 𤨈
    # 0x24A09: '',  # 𤨉
    # 0x24A0A: '',  # 𤨊
    # 0x24A0B: '',  # 𤨋
    # 0x24A0C: '',  # 𤨌
    0x24A0D: 'lù',  # 𤨍
    0x24A0E: 'qú',  # 𤨎
    0x24A0F: 'suǒ',  # 𤨏
    0x24A10: 'xǐ,tāo',  # 𤨐
    0x24A11: 'dá',  # 𤨑
    # 0x24A12: '',  # 𤨒
    # 0x24A13: '',  # 𤨓
    # 0x24A14: '',  # 𤨔
    # 0x24A15: '',  # 𤨕
    0x24A16: 'hù',  # 𤨖
    0x24A17: 'luǒ',  # 𤨗
    # 0x24A18: '',  # 𤨘
    0x24A19: 'lè',  # 𤨙
    # 0x24A1A: '',  # 𤨚
    # 0x24A1B: '',  # 𤨛
    # 0x24A1C: '',  # 𤨜
    # 0x24A1D: '',  # 𤨝
    # 0x24A1E: '',  # 𤨞
    # 0x24A1F: '',  # 𤨟
    # 0x24A20: '',  # 𤨠
    # 0x24A21: '',  # 𤨡
    # 0x24A22: '',  # 𤨢
    # 0x24A23: '',  # 𤨣
    # 0x24A24: '',  # 𤨤
    # 0x24A25: '',  # 𤨥
    # 0x24A26: '',  # 𤨦
    # 0x24A27: '',  # 𤨧
    # 0x24A28: '',  # 𤨨
    # 0x24A29: '',  # 𤨩
    # 0x24A2A: '',  # 𤨪
    # 0x24A2B: '',  # 𤨫
    # 0x24A2C: '',  # 𤨬
    # 0x24A2D: '',  # 𤨭
    # 0x24A2E: '',  # 𤨮
    # 0x24A2F: '',  # 𤨯
    # 0x24A30: '',  # 𤨰
    # 0x24A31: '',  # 𤨱
    # 0x24A32: '',  # 𤨲
    # 0x24A33: '',  # 𤨳
    # 0x24A34: '',  # 𤨴
    # 0x24A35: '',  # 𤨵
    0x24A36: 'gǒng',  # 𤨶
    # 0x24A37: '',  # 𤨷
    # 0x24A38: '',  # 𤨸
    # 0x24A39: '',  # 𤨹
    # 0x24A3A: '',  # 𤨺
    0x24A3B: 'lìng',  # 𤨻
    # 0x24A3C: '',  # 𤨼
    # 0x24A3D: '',  # 𤨽
    # 0x24A3E: '',  # 𤨾
    # 0x24A3F: '',  # 𤨿
    # 0x24A40: '',  # 𤩀
    # 0x24A41: '',  # 𤩁
    0x24A42: 'láo',  # 𤩂
    # 0x24A43: '',  # 𤩃
    0x24A44: 'zhuàn',  # 𤩄
    # 0x24A45: '',  # 𤩅
    # 0x24A46: '',  # 𤩆
    # 0x24A47: '',  # 𤩇
    # 0x24A48: '',  # 𤩈
    # 0x24A49: '',  # 𤩉
    # 0x24A4A: '',  # 𤩊
    # 0x24A4B: '',  # 𤩋
    # 0x24A4C: '',  # 𤩌
    # 0x24A4D: '',  # 𤩍
    # 0x24A4E: '',  # 𤩎
    # 0x24A4F: '',  # 𤩏
    # 0x24A50: '',  # 𤩐
    # 0x24A51: '',  # 𤩑
    # 0x24A52: '',  # 𤩒
    # 0x24A53: '',  # 𤩓
    # 0x24A54: '',  # 𤩔
    # 0x24A55: '',  # 𤩕
    # 0x24A56: '',  # 𤩖
    # 0x24A57: '',  # 𤩗
    # 0x24A58: '',  # 𤩘
    # 0x24A59: '',  # 𤩙
    # 0x24A5A: '',  # 𤩚
    # 0x24A5B: '',  # 𤩛
    # 0x24A5C: '',  # 𤩜
    # 0x24A5D: '',  # 𤩝
    # 0x24A5E: '',  # 𤩞
    # 0x24A5F: '',  # 𤩟
    # 0x24A60: '',  # 𤩠
    # 0x24A61: '',  # 𤩡
    # 0x24A62: '',  # 𤩢
    # 0x24A63: '',  # 𤩣
    # 0x24A64: '',  # 𤩤
    # 0x24A65: '',  # 𤩥
    # 0x24A66: '',  # 𤩦
    # 0x24A67: '',  # 𤩧
    0x24A68: 'zǎo',  # 𤩨
    0x24A69: 'hào',  # 𤩩
    0x24A6A: 'xiàng',  # 𤩪
    # 0x24A6B: '',  # 𤩫
    # 0x24A6C: '',  # 𤩬
    0x24A6D: 'hào',  # 𤩭
    0x24A6E: 'lì',  # 𤩮
    0x24A6F: 'lì',  # 𤩯
    0x24A70: 'lì',  # 𤩰
    0x24A71: 'diàn,tiàn',  # 𤩱
    0x24A72: 'gé',  # 𤩲
    # 0x24A73: '',  # 𤩳
    # 0x24A74: '',  # 𤩴
    # 0x24A75: '',  # 𤩵
    # 0x24A76: '',  # 𤩶
    # 0x24A77: '',  # 𤩷
    # 0x24A78: '',  # 𤩸
    # 0x24A79: '',  # 𤩹
    # 0x24A7A: '',  # 𤩺
    # 0x24A7B: '',  # 𤩻
    # 0x24A7C: '',  # 𤩼
    # 0x24A7D: '',  # 𤩽
    # 0x24A7E: '',  # 𤩾
    # 0x24A7F: '',  # 𤩿
    # 0x24A80: '',  # 𤪀
    # 0x24A81: '',  # 𤪁
    # 0x24A82: '',  # 𤪂
    # 0x24A83: '',  # 𤪃
    0x24A84: 'è',  # 𤪄
    # 0x24A85: '',  # 𤪅
    0x24A86: 'xiá',  # 𤪆
    # 0x24A87: '',  # 𤪇
    # 0x24A88: '',  # 𤪈
    # 0x24A89: '',  # 𤪉
    # 0x24A8A: '',  # 𤪊
    0x24A8B: 'jiān',  # 𤪋
    0x24A8C: 'qí',  # 𤪌
    0x24A8D: 'xiá',  # 𤪍
    0x24A8E: 'yǒu',  # 𤪎
    # 0x24A8F: '',  # 𤪏
    # 0x24A90: '',  # 𤪐
    # 0x24A91: '',  # 𤪑
    # 0x24A92: '',  # 𤪒
    # 0x24A93: '',  # 𤪓
    # 0x24A94: '',  # 𤪔
    # 0x24A95: '',  # 𤪕
    # 0x24A96: '',  # 𤪖
    # 0x24A97: '',  # 𤪗
    # 0x24A98: '',  # 𤪘
    # 0x24A99: '',  # 𤪙
    # 0x24A9A: '',  # 𤪚
    # 0x24A9B: '',  # 𤪛
    # 0x24A9C: '',  # 𤪜
    # 0x24A9D: '',  # 𤪝
    0x24A9E: 'qióng',  # 𤪞
    # 0x24A9F: '',  # 𤪟
    # 0x24AA0: '',  # 𤪠
    0x24AA1: 'zhēng',  # 𤪡
    # 0x24AA2: '',  # 𤪢
    # 0x24AA3: '',  # 𤪣
    # 0x24AA4: '',  # 𤪤
    # 0x24AA5: '',  # 𤪥
    # 0x24AA6: '',  # 𤪦
    # 0x24AA7: '',  # 𤪧
    # 0x24AA8: '',  # 𤪨
    # 0x24AA9: '',  # 𤪩
    0x24AAA: 'zhuàn,chūn',  # 𤪪
    # 0x24AAB: '',  # 𤪫
    # 0x24AAC: '',  # 𤪬
    # 0x24AAD: '',  # 𤪭
    0x24AAE: 'chàn',  # 𤪮
    # 0x24AAF: '',  # 𤪯
    # 0x24AB0: '',  # 𤪰
    # 0x24AB1: '',  # 𤪱
    # 0x24AB2: '',  # 𤪲
    # 0x24AB3: '',  # 𤪳
    # 0x24AB4: '',  # 𤪴
    # 0x24AB5: '',  # 𤪵
    # 0x24AB6: '',  # 𤪶
    # 0x24AB7: '',  # 𤪷
    # 0x24AB8: '',  # 𤪸
    # 0x24AB9: '',  # 𤪹
    # 0x24ABA: '',  # 𤪺
    # 0x24ABB: '',  # 𤪻
    # 0x24ABC: '',  # 𤪼
    # 0x24ABD: '',  # 𤪽
    # 0x24ABE: '',  # 𤪾
    # 0x24ABF: '',  # 𤪿
    # 0x24AC0: '',  # 𤫀
    # 0x24AC1: '',  # 𤫁
    # 0x24AC2: '',  # 𤫂
    # 0x24AC3: '',  # 𤫃
    # 0x24AC4: '',  # 𤫄
    # 0x24AC5: '',  # 𤫅
    # 0x24AC6: '',  # 𤫆
    # 0x24AC7: '',  # 𤫇
    # 0x24AC8: '',  # 𤫈
    0x24AC9: 'xiè',  # 𤫉
    0x24ACA: 'líng',  # 𤫊
    # 0x24ACB: '',  # 𤫋
    # 0x24ACC: '',  # 𤫌
    # 0x24ACD: '',  # 𤫍
    # 0x24ACE: '',  # 𤫎
    # 0x24ACF: '',  # 𤫏
    # 0x24AD0: '',  # 𤫐
    # 0x24AD1: '',  # 𤫑
    # 0x24AD2: '',  # 𤫒
    # 0x24AD3: '',  # 𤫓
    # 0x24AD4: '',  # 𤫔
    0x24AD5: 'náo',  # 𤫕
    # 0x24AD6: '',  # 𤫖
    # 0x24AD7: '',  # 𤫗
    # 0x24AD8: '',  # 𤫘
    # 0x24AD9: '',  # 𤫙
    # 0x24ADA: '',  # 𤫚
    # 0x24ADB: '',  # 𤫛
    # 0x24ADC: '',  # 𤫜
    0x24ADD: 'jì',  # 𤫝
    0x24ADE: 'tián',  # 𤫞
    # 0x24ADF: '',  # 𤫟
    # 0x24AE0: '',  # 𤫠
    # 0x24AE1: '',  # 𤫡
    # 0x24AE2: '',  # 𤫢
    0x24AE3: 'yǎn',  # 𤫣
    # 0x24AE4: '',  # 𤫤
    # 0x24AE5: '',  # 𤫥
    # 0x24AE6: '',  # 𤫦
    0x24AE7: 'hǎo',  # 𤫧
    0x24AE8: 'xín',  # 𤫨
    # 0x24AE9: '',  # 𤫩
    # 0x24AEA: '',  # 𤫪
    0x24AEB: 'bān',  # 𤫫
    0x24AEC: 'běng',  # 𤫬
    # 0x24AED: '',  # 𤫭
    # 0x24AEE: '',  # 𤫮
    # 0x24AEF: '',  # 𤫯
    # 0x24AF0: '',  # 𤫰
    0x24AF1: 'gōu',  # 𤫱
    0x24AF2: 'líng',  # 𤫲
    # 0x24AF3: '',  # 𤫳
    # 0x24AF4: '',  # 𤫴
    0x24AF5: 'kuò,guó',  # 𤫵
    0x24AF6: 'qià',  # 𤫶
    0x24AF7: 'jiào',  # 𤫷
    # 0x24AF8: '',  # 𤫸
    0x24AF9: 'ēn',  # 𤫹
    0x24AFA: 'yáo',  # 𤫺
    0x24AFB: 'dū',  # 𤫻
    # 0x24AFC: '',  # 𤫼
    # 0x24AFD: '',  # 𤫽
    # 0x24AFE: '',  # 𤫾
    # 0x24AFF: '',  # 𤫿
    # 0x24B00: '',  # 𤬀
    0x24B01: 'huǒ,guǒ,luǒ',  # 𤬁
    0x24B02: 'dǔ',  # 𤬂
    0x24B03: 'pēi',  # 𤬃
    # 0x24B04: '',  # 𤬄
    # 0x24B05: '',  # 𤬅
    # 0x24B06: '',  # 𤬆
    # 0x24B07: '',  # 𤬇
    # 0x24B08: '',  # 𤬈
    # 0x24B09: '',  # 𤬉
    # 0x24B0A: '',  # 𤬊
    # 0x24B0B: '',  # 𤬋
    0x24B0C: 'yuán',  # 𤬌
    # 0x24B0D: '',  # 𤬍
    # 0x24B0E: '',  # 𤬎
    0x24B0F: 'lóu',  # 𤬏
    0x24B10: 'xíng',  # 𤬐
    # 0x24B11: '',  # 𤬑
    # 0x24B12: '',  # 𤬒
    0x24B13: 'lián,liǎn',  # 𤬓
    0x24B14: 'yáo',  # 𤬔
    0x24B15: 'xī',  # 𤬕
    0x24B16: 'yáo',  # 𤬖
    # 0x24B17: '',  # 𤬗
    0x24B18: 'xī',  # 𤬘
    # 0x24B19: '',  # 𤬙
    # 0x24B1A: '',  # 𤬚
    0x24B1B: 'lú',  # 𤬛
    # 0x24B1C: '',  # 𤬜
    0x24B1D: 'yàn',  # 𤬝
    # 0x24B1E: '',  # 𤬞
    # 0x24B1F: '',  # 𤬟
    0x24B20: 'quán',  # 𤬠
    # 0x24B21: '',  # 𤬡
    # 0x24B22: '',  # 𤬢
    # 0x24B23: '',  # 𤬣
    # 0x24B24: '',  # 𤬤
    0x24B25: 'ráng',  # 𤬥
    0x24B26: 'wà',  # 𤬦
    0x24B27: 'zú',  # 𤬧
    0x24B28: 'fàn',  # 𤬨
    0x24B29: 'yì',  # 𤬩
    0x24B2A: 'dù,kān',  # 𤬪
    0x24B2B: 'suì',  # 𤬫
    # 0x24B2C: '',  # 𤬬
    0x24B2D: 'pī',  # 𤬭
    # 0x24B2E: '',  # 𤬮
    0x24B2F: 'hán,qiàn',  # 𤬯
    # 0x24B30: '',  # 𤬰
    0x24B31: 'xù',  # 𤬱
    # 0x24B32: '',  # 𤬲
    0x24B33: 'gǒng',  # 𤬳
    # 0x24B34: '',  # 𤬴
    0x24B35: 'dì',  # 𤬵
    # 0x24B36: '',  # 𤬶
    0x24B37: 'nà',  # 𤬷
    # 0x24B38: '',  # 𤬸
    # 0x24B39: '',  # 𤬹
    # 0x24B3A: '',  # 𤬺
    # 0x24B3B: '',  # 𤬻
    # 0x24B3C: '',  # 𤬼
    # 0x24B3D: '',  # 𤬽
    0x24B3E: 'duò,tuó',  # 𤬾
    0x24B3F: 'wā',  # 𤬿
    # 0x24B40: '',  # 𤭀
    # 0x24B41: '',  # 𤭁
    0x24B42: 'niè',  # 𤭂
    # 0x24B43: '',  # 𤭃
    # 0x24B44: '',  # 𤭄
    # 0x24B45: '',  # 𤭅
    # 0x24B46: '',  # 𤭆
    # 0x24B47: '',  # 𤭇
    0x24B48: 'diào',  # 𤭈
    0x24B49: 'huāng',  # 𤭉
    # 0x24B4A: '',  # 𤭊
    # 0x24B4B: '',  # 𤭋
    0x24B4C: 'tí',  # 𤭌
    0x24B4D: 'fàn',  # 𤭍
    # 0x24B4E: '',  # 𤭎
    # 0x24B4F: '',  # 𤭏
    # 0x24B50: '',  # 𤭐
    0x24B51: 'wú',  # 𤭑
    0x24B52: 'áng',  # 𤭒
    # 0x24B53: '',  # 𤭓
    0x24B54: 'píng',  # 𤭔
    # 0x24B55: '',  # 𤭕
    # 0x24B56: '',  # 𤭖
    # 0x24B57: '',  # 𤭗
    # 0x24B58: '',  # 𤭘
    0x24B59: 'hán,gān',  # 𤭙
    # 0x24B5A: '',  # 𤭚
    # 0x24B5B: '',  # 𤭛
    0x24B5C: 'lí',  # 𤭜
    # 0x24B5D: '',  # 𤭝
    0x24B5E: 'dūn',  # 𤭞
    0x24B5F: 'fù',  # 𤭟
    0x24B60: 'nà',  # 𤭠
    # 0x24B61: '',  # 𤭡
    0x24B62: 'suì',  # 𤭢
    # 0x24B63: '',  # 𤭣
    # 0x24B64: '',  # 𤭤
    # 0x24B65: '',  # 𤭥
    # 0x24B66: '',  # 𤭦
    0x24B67: 'jiē',  # 𤭧
    # 0x24B68: '',  # 𤭨
    0x24B69: 'qìng',  # 𤭩
    # 0x24B6A: '',  # 𤭪
    0x24B6B: 'yīng',  # 𤭫
    0x24B6C: 'xiáng',  # 𤭬
    # 0x24B6D: '',  # 𤭭
    # 0x24B6E: '',  # 𤭮
    # 0x24B6F: '',  # 𤭯
    0x24B70: 'zhòu',  # 𤭰
    0x24B71: 'hú',  # 𤭱
    # 0x24B72: '',  # 𤭲
    # 0x24B73: '',  # 𤭳
    0x24B74: 'sù',  # 𤭴
    # 0x24B75: '',  # 𤭵
    # 0x24B76: '',  # 𤭶
    # 0x24B77: '',  # 𤭷
    # 0x24B78: '',  # 𤭸
    # 0x24B79: '',  # 𤭹
    # 0x24B7A: '',  # 𤭺
    0x24B7B: 'gē',  # 𤭻
    0x24B7C: 'è',  # 𤭼
    0x24B7D: 'xù',  # 𤭽
    # 0x24B7E: '',  # 𤭾
    # 0x24B7F: '',  # 𤭿
    # 0x24B80: '',  # 𤮀
    # 0x24B81: '',  # 𤮁
    # 0x24B82: '',  # 𤮂
    # 0x24B83: '',  # 𤮃
    # 0x24B84: '',  # 𤮄
    # 0x24B85: '',  # 𤮅
    0x24B86: 'xī',  # 𤮆
    # 0x24B87: '',  # 𤮇
    # 0x24B88: '',  # 𤮈
    # 0x24B89: '',  # 𤮉
    0x24B8A: 'kāng',  # 𤮊
    0x24B8B: 'guó',  # 𤮋
    0x24B8C: 'jiē',  # 𤮌
    0x24B8D: 'chuán',  # 𤮍
    0x24B8E: 'léi',  # 𤮎
    0x24B8F: 'héng',  # 𤮏
    0x24B90: 'zūn',  # 𤮐
    # 0x24B91: '',  # 𤮑
    # 0x24B92: '',  # 𤮒
    # 0x24B93: '',  # 𤮓
    # 0x24B94: '',  # 𤮔
    0x24B95: 'piè',  # 𤮕
    # 0x24B96: '',  # 𤮖
    # 0x24B97: '',  # 𤮗
    0x24B98: 'dēng',  # 𤮘
    0x24B99: 'xī',  # 𤮙
    0x24B9A: 'léi',  # 𤮚
    # 0x24B9B: '',  # 𤮛
    0x24B9C: 'shàn',  # 𤮜
    # 0x24B9D: '',  # 𤮝
    # 0x24B9E: '',  # 𤮞
    # 0x24B9F: '',  # 𤮟
    # 0x24BA0: '',  # 𤮠
    # 0x24BA1: '',  # 𤮡
    # 0x24BA2: '',  # 𤮢
    # 0x24BA3: '',  # 𤮣
    # 0x24BA4: '',  # 𤮤
    # 0x24BA5: '',  # 𤮥
    # 0x24BA6: '',  # 𤮦
    0x24BA7: 'lú',  # 𤮧
    # 0x24BA8: '',  # 𤮨
    0x24BA9: 'duì',  # 𤮩
    0x24BAA: 'jùn',  # 𤮪
    # 0x24BAB: '',  # 𤮫
    # 0x24BAC: '',  # 𤮬
    0x24BAD: 'chàn',  # 𤮭
    # 0x24BAE: '',  # 𤮮
    0x24BAF: 'xié',  # 𤮯
    0x24BB0: 'wā',  # 𤮰
    0x24BB1: 'zhé',  # 𤮱
    # 0x24BB2: '',  # 𤮲
    0x24BB3: 'zhuān,guàn',  # 𤮳
    # 0x24BB4: '',  # 𤮴
    # 0x24BB5: '',  # 𤮵
    # 0x24BB6: '',  # 𤮶
    0x24BB7: 'liù',  # 𤮷
    0x24BB8: 'léi',  # 𤮸
    # 0x24BB9: '',  # 𤮹
    # 0x24BBA: '',  # 𤮺
    # 0x24BBB: '',  # 𤮻
    0x24BBC: 'dài',  # 𤮼
    0x24BBD: 'gān',  # 𤮽
    # 0x24BBE: '',  # 𤮾
    # 0x24BBF: '',  # 𤮿
    # 0x24BC0: '',  # 𤯀
    # 0x24BC1: '',  # 𤯁
    # 0x24BC2: '',  # 𤯂
    # 0x24BC3: '',  # 𤯃
    0x24BC4: 'shì',  # 𤯄
    # 0x24BC5: '',  # 𤯅
    # 0x24BC6: '',  # 𤯆
    0x24BC7: 'yǎn',  # 𤯇
    # 0x24BC8: '',  # 𤯈
    # 0x24BC9: '',  # 𤯉
    # 0x24BCA: '',  # 𤯊
    # 0x24BCB: '',  # 𤯋
    0x24BCC: 'gān',  # 𤯌
    # 0x24BCD: '',  # 𤯍
    # 0x24BCE: '',  # 𤯎
    # 0x24BCF: '',  # 𤯏
    0x24BD0: 'yán',  # 𤯐
    # 0x24BD1: '',  # 𤯑
    # 0x24BD2: '',  # 𤯒
    # 0x24BD3: '',  # 𤯓
    # 0x24BD4: '',  # 𤯔
    # 0x24BD5: '',  # 𤯕
    0x24BD6: 'suī',  # 𤯖
    # 0x24BD7: '',  # 𤯗
    # 0x24BD8: '',  # 𤯘
    # 0x24BD9: '',  # 𤯙
    0x24BDA: 'zhōng',  # 𤯚
    # 0x24BDB: '',  # 𤯛
    0x24BDC: 'shì',  # 𤯜
    # 0x24BDD: '',  # 𤯝
    # 0x24BDE: '',  # 𤯞
    # 0x24BDF: '',  # 𤯟
    # 0x24BE0: '',  # 𤯠
    0x24BE1: 'shèng',  # 𤯡
    # 0x24BE2: '',  # 𤯢
    # 0x24BE3: '',  # 𤯣
    # 0x24BE4: '',  # 𤯤
    0x24BE5: 'chǎn',  # 𤯥
    # 0x24BE6: '',  # 𤯦
    # 0x24BE7: '',  # 𤯧
    # 0x24BE8: '',  # 𤯨
    # 0x24BE9: '',  # 𤯩
    # 0x24BEA: '',  # 𤯪
    # 0x24BEB: '',  # 𤯫
    # 0x24BEC: '',  # 𤯬
    # 0x24BED: '',  # 𤯭
    # 0x24BEE: '',  # 𤯮
    # 0x24BEF: '',  # 𤯯
    # 0x24BF0: '',  # 𤯰
    # 0x24BF1: '',  # 𤯱
    # 0x24BF2: '',  # 𤯲
    # 0x24BF3: '',  # 𤯳
    # 0x24BF4: '',  # 𤯴
    # 0x24BF5: '',  # 𤯵
    # 0x24BF6: '',  # 𤯶
    0x24BF7: 'huáng',  # 𤯷
    0x24BF8: 'yìn',  # 𤯸
    # 0x24BF9: '',  # 𤯹
    # 0x24BFA: '',  # 𤯺
    0x24BFB: 'měng',  # 𤯻
    # 0x24BFC: '',  # 𤯼
    # 0x24BFD: '',  # 𤯽
    # 0x24BFE: '',  # 𤯾
    # 0x24BFF: '',  # 𤯿
    # 0x24C00: '',  # 𤰀
    # 0x24C01: '',  # 𤰁
    0x24C02: 'ráng',  # 𤰂
    # 0x24C03: '',  # 𤰃
    # 0x24C04: '',  # 𤰄
    0x24C05: 'xiáng',  # 𤰅
    # 0x24C06: '',  # 𤰆
    # 0x24C07: '',  # 𤰇
    0x24C08: 'bèi,fú',  # 𤰈
    # 0x24C09: '',  # 𤰉
    # 0x24C0A: '',  # 𤰊
    # 0x24C0B: '',  # 𤰋
    0x24C0C: 'chuán',  # 𤰌
    # 0x24C0D: '',  # 𤰍
    # 0x24C0E: '',  # 𤰎
    # 0x24C0F: '',  # 𤰏
    # 0x24C10: '',  # 𤰐
    0x24C11: 'pú',  # 𤰑
    # 0x24C12: '',  # 𤰒
    # 0x24C13: '',  # 𤰓
    # 0x24C14: '',  # 𤰔
    # 0x24C15: '',  # 𤰕
    # 0x24C16: '',  # 𤰖
    # 0x24C17: '',  # 𤰗
    # 0x24C18: '',  # 𤰘
    0x24C19: 'gé,kē',  # 𤰙
    0x24C1A: 'lá',  # 𤰚
    # 0x24C1B: '',  # 𤰛
    # 0x24C1C: '',  # 𤰜
    0x24C1D: 'quǎn',  # 𤰝
    # 0x24C1E: '',  # 𤰞
    0x24C1F: 'hàng',  # 𤰟
    0x24C20: 'chì',  # 𤰠
    0x24C21: 'máng',  # 𤰡
    # 0x24C22: '',  # 𤰢
    # 0x24C23: '',  # 𤰣
    # 0x24C24: '',  # 𤰤
    # 0x24C25: '',  # 𤰥
    0x24C26: 'zhà',  # 𤰦
    # 0x24C27: '',  # 𤰧
    # 0x24C28: '',  # 𤰨
    # 0x24C29: '',  # 𤰩
    0x24C2A: 'fèn',  # 𤰪
    # 0x24C2B: '',  # 𤰫
    0x24C2C: 'chào',  # 𤰬
    # 0x24C2D: '',  # 𤰭
    # 0x24C2E: '',  # 𤰮
    # 0x24C2F: '',  # 𤰯
    # 0x24C30: '',  # 𤰰
    # 0x24C31: '',  # 𤰱
    # 0x24C32: '',  # 𤰲
    0x24C33: 'jǐng',  # 𤰳
    # 0x24C34: '',  # 𤰴
    # 0x24C35: '',  # 𤰵
    # 0x24C36: '',  # 𤰶
    # 0x24C37: '',  # 𤰷
    # 0x24C38: '',  # 𤰸
    # 0x24C39: '',  # 𤰹
    # 0x24C3A: '',  # 𤰺
    # 0x24C3B: '',  # 𤰻
    # 0x24C3C: '',  # 𤰼
    # 0x24C3D: '',  # 𤰽
    # 0x24C3E: '',  # 𤰾
    # 0x24C3F: '',  # 𤰿
    # 0x24C40: '',  # 𤱀
    # 0x24C41: '',  # 𤱁
    # 0x24C42: '',  # 𤱂
    0x24C43: 'liè',  # 𤱃
    # 0x24C44: '',  # 𤱄
    0x24C45: 'nà',  # 𤱅
    0x24C46: 'nà',  # 𤱆
    0x24C47: 'tóng',  # 𤱇
    # 0x24C48: '',  # 𤱈
    # 0x24C49: '',  # 𤱉
    # 0x24C4A: '',  # 𤱊
    0x24C4B: 'rán',  # 𤱋
    0x24C4C: 'zǔ',  # 𤱌
    0x24C4D: 'pī,pǒ',  # 𤱍
    0x24C4E: 'yǒu',  # 𤱎
    # 0x24C4F: '',  # 𤱏
    0x24C50: 'shū',  # 𤱐
    # 0x24C51: '',  # 𤱑
    # 0x24C52: '',  # 𤱒
    # 0x24C53: '',  # 𤱓
    0x24C54: 'mǔ',  # 𤱔
    # 0x24C55: '',  # 𤱕
    # 0x24C56: '',  # 𤱖
    # 0x24C57: '',  # 𤱗
    # 0x24C58: '',  # 𤱘
    # 0x24C59: '',  # 𤱙
    # 0x24C5A: '',  # 𤱚
    0x24C5B: 'liè',  # 𤱛
    0x24C5C: 'shōu',  # 𤱜
    # 0x24C5D: '',  # 𤱝
    # 0x24C5E: '',  # 𤱞
    0x24C5F: 'gǎo',  # 𤱟
    0x24C60: 'sháo',  # 𤱠
    0x24C61: 'tuó',  # 𤱡
    # 0x24C62: '',  # 𤱢
    0x24C63: 'nán',  # 𤱣
    # 0x24C64: '',  # 𤱤
    # 0x24C65: '',  # 𤱥
    # 0x24C66: '',  # 𤱦
    0x24C67: 'tuǒ',  # 𤱧
    0x24C68: 'gōng',  # 𤱨
    0x24C69: 'diào',  # 𤱩
    # 0x24C6A: '',  # 𤱪
    # 0x24C6B: '',  # 𤱫
    # 0x24C6C: '',  # 𤱬
    # 0x24C6D: '',  # 𤱭
    # 0x24C6E: '',  # 𤱮
    # 0x24C6F: '',  # 𤱯
    # 0x24C70: '',  # 𤱰
    # 0x24C71: '',  # 𤱱
    # 0x24C72: '',  # 𤱲
    # 0x24C73: '',  # 𤱳
    0x24C74: 'měng',  # 𤱴
    0x24C75: 'bāng',  # 𤱵
    # 0x24C76: '',  # 𤱶
    0x24C77: 'xié',  # 𤱷
    0x24C78: 'sì',  # 𤱸
    0x24C79: 'tǐng',  # 𤱹
    0x24C7A: 'guì',  # 𤱺
    # 0x24C7B: '',  # 𤱻
    # 0x24C7C: '',  # 𤱼
    0x24C7D: 'fú',  # 𤱽
    0x24C7E: 'guì',  # 𤱾
    # 0x24C7F: '',  # 𤱿
    # 0x24C80: '',  # 𤲀
    # 0x24C81: '',  # 𤲁
    # 0x24C82: '',  # 𤲂
    # 0x24C83: '',  # 𤲃
    # 0x24C84: '',  # 𤲄
    # 0x24C85: '',  # 𤲅
    # 0x24C86: '',  # 𤲆
    # 0x24C87: '',  # 𤲇
    # 0x24C88: '',  # 𤲈
    0x24C89: 'guì',  # 𤲉
    # 0x24C8A: '',  # 𤲊
    # 0x24C8B: '',  # 𤲋
    # 0x24C8C: '',  # 𤲌
    # 0x24C8D: '',  # 𤲍
    # 0x24C8E: '',  # 𤲎
    # 0x24C8F: '',  # 𤲏
    # 0x24C90: '',  # 𤲐
    0x24C91: 'zhǔ',  # 𤲑
    # 0x24C92: '',  # 𤲒
    0x24C93: 'lái',  # 𤲓
    # 0x24C94: '',  # 𤲔
    0x24C95: 'lǔn',  # 𤲕
    0x24C96: 'tiǎn',  # 𤲖
    0x24C97: 'rǎn',  # 𤲗
    # 0x24C98: '',  # 𤲘
    0x24C99: 'běn',  # 𤲙
    0x24C9A: 'dōng',  # 𤲚
    # 0x24C9B: '',  # 𤲛
    # 0x24C9C: '',  # 𤲜
    # 0x24C9D: '',  # 𤲝
    # 0x24C9E: '',  # 𤲞
    # 0x24C9F: '',  # 𤲟
    # 0x24CA0: '',  # 𤲠
    # 0x24CA1: '',  # 𤲡
    # 0x24CA2: '',  # 𤲢
    # 0x24CA3: '',  # 𤲣
    # 0x24CA4: '',  # 𤲤
    # 0x24CA5: '',  # 𤲥
    # 0x24CA6: '',  # 𤲦
    # 0x24CA7: '',  # 𤲧
    0x24CA8: 'juàn',  # 𤲨
    0x24CA9: 'yán',  # 𤲩
    # 0x24CAA: '',  # 𤲪
    # 0x24CAB: '',  # 𤲫
    0x24CAC: 'ruán',  # 𤲬
    0x24CAD: 'dǎn',  # 𤲭
    # 0x24CAE: '',  # 𤲮
    # 0x24CAF: '',  # 𤲯
    0x24CB0: 'mào',  # 𤲰
    # 0x24CB1: '',  # 𤲱
    # 0x24CB2: '',  # 𤲲
    # 0x24CB3: '',  # 𤲳
    # 0x24CB4: '',  # 𤲴
    # 0x24CB5: '',  # 𤲵
    0x24CB6: 'luán,niǎo',  # 𤲶
    # 0x24CB7: '',  # 𤲷
    0x24CB8: 'xù,zī',  # 𤲸
    # 0x24CB9: '',  # 𤲹
    0x24CBA: 'xī',  # 𤲺
    # 0x24CBB: '',  # 𤲻
    # 0x24CBC: '',  # 𤲼
    # 0x24CBD: '',  # 𤲽
    # 0x24CBE: '',  # 𤲾
    # 0x24CBF: '',  # 𤲿
    # 0x24CC0: '',  # 𤳀
    # 0x24CC1: '',  # 𤳁
    0x24CC2: 'má',  # 𤳂
    0x24CC3: 'qī',  # 𤳃
    # 0x24CC4: '',  # 𤳄
    0x24CC5: 'chà',  # 𤳅
    # 0x24CC6: '',  # 𤳆
    # 0x24CC7: '',  # 𤳇
    # 0x24CC8: '',  # 𤳈
    0x24CC9: 'hàn',  # 𤳉
    0x24CCA: 'píng',  # 𤳊
    # 0x24CCB: '',  # 𤳋
    # 0x24CCC: '',  # 𤳌
    # 0x24CCD: '',  # 𤳍
    0x24CCE: 'jī',  # 𤳎
    # 0x24CCF: '',  # 𤳏
    # 0x24CD0: '',  # 𤳐
    # 0x24CD1: '',  # 𤳑
    # 0x24CD2: '',  # 𤳒
    0x24CD3: 'lì',  # 𤳓
    # 0x24CD4: '',  # 𤳔
    0x24CD5: 'yù',  # 𤳕
    0x24CD6: 'bān,fān',  # 𤳖
    # 0x24CD7: '',  # 𤳗
    0x24CD8: 'tēng',  # 𤳘
    # 0x24CD9: '',  # 𤳙
    # 0x24CDA: '',  # 𤳚
    # 0x24CDB: '',  # 𤳛
    # 0x24CDC: '',  # 𤳜
    0x24CDD: 'chóu',  # 𤳝
    # 0x24CDE: '',  # 𤳞
    # 0x24CDF: '',  # 𤳟
    0x24CE0: 'chóu',  # 𤳠
    # 0x24CE1: '',  # 𤳡
    # 0x24CE2: '',  # 𤳢
    # 0x24CE3: '',  # 𤳣
    0x24CE4: 'qī',  # 𤳤
    0x24CE5: 'xī',  # 𤳥
    0x24CE6: 'bèi',  # 𤳦
    # 0x24CE7: '',  # 𤳧
    # 0x24CE8: '',  # 𤳨
    # 0x24CE9: '',  # 𤳩
    0x24CEA: 'yè',  # 𤳪
    # 0x24CEB: '',  # 𤳫
    # 0x24CEC: '',  # 𤳬
    0x24CED: 'guǎng',  # 𤳭
    # 0x24CEE: '',  # 𤳮
    0x24CEF: 'zhù',  # 𤳯
    # 0x24CF0: '',  # 𤳰
    # 0x24CF1: '',  # 𤳱
    # 0x24CF2: '',  # 𤳲
    0x24CF3: 'huǐ',  # 𤳳
    0x24CF4: 'léi',  # 𤳴
    0x24CF5: 'chā',  # 𤳵
    # 0x24CF6: '',  # 𤳶
    # 0x24CF7: '',  # 𤳷
    # 0x24CF8: '',  # 𤳸
    # 0x24CF9: '',  # 𤳹
    # 0x24CFA: '',  # 𤳺
    # 0x24CFB: '',  # 𤳻
    # 0x24CFC: '',  # 𤳼
    # 0x24CFD: '',  # 𤳽
    # 0x24CFE: '',  # 𤳾
    # 0x24CFF: '',  # 𤳿
    0x24D00: 'guǎng,qiāo',  # 𤴀
    # 0x24D01: '',  # 𤴁
    # 0x24D02: '',  # 𤴂
    # 0x24D03: '',  # 𤴃
    0x24D04: 'huǐ',  # 𤴄
    # 0x24D05: '',  # 𤴅
    # 0x24D06: '',  # 𤴆
    # 0x24D07: '',  # 𤴇
    # 0x24D08: '',  # 𤴈
    # 0x24D09: '',  # 𤴉
    # 0x24D0A: '',  # 𤴊
    # 0x24D0B: '',  # 𤴋
    # 0x24D0C: '',  # 𤴌
    0x24D0D: 'dié',  # 𤴍
    # 0x24D0E: '',  # 𤴎
    # 0x24D0F: '',  # 𤴏
    # 0x24D10: '',  # 𤴐
    # 0x24D11: '',  # 𤴑
    0x24D12: 'léi',  # 𤴒
    0x24D13: 'yǎ',  # 𤴓
    # 0x24D14: '',  # 𤴔
    # 0x24D15: '',  # 𤴕
    # 0x24D16: '',  # 𤴖
    # 0x24D17: '',  # 𤴗
    0x24D18: 'niè',  # 𤴘
    0x24D19: 'shū,xū',  # 𤴙
    # 0x24D1A: '',  # 𤴚
    # 0x24D1B: '',  # 𤴛
    # 0x24D1C: '',  # 𤴜
    # 0x24D1D: '',  # 𤴝
    # 0x24D1E: '',  # 𤴞
    0x24D1F: 'zhì',  # 𤴟
    # 0x24D20: '',  # 𤴠
    # 0x24D21: '',  # 𤴡
    0x24D22: 'zhì',  # 𤴢
    0x24D23: 'pǐ',  # 𤴣
    # 0x24D24: '',  # 𤴤
    0x24D25: 'jiū',  # 𤴥
    0x24D26: 'jiū',  # 𤴦
    0x24D27: 'yì',  # 𤴧
    0x24D28: 'yòu,yǒu',  # 𤴨
    # 0x24D29: '',  # 𤴩
    0x24D2A: 'jiū',  # 𤴪
    # 0x24D2B: '',  # 𤴫
    # 0x24D2C: '',  # 𤴬
    # 0x24D2D: '',  # 𤴭
    # 0x24D2E: '',  # 𤴮
    0x24D2F: 'huàn',  # 𤴯
    # 0x24D30: '',  # 𤴰
    0x24D31: 'dù',  # 𤴱
    # 0x24D32: '',  # 𤴲
    # 0x24D33: '',  # 𤴳
    # 0x24D34: '',  # 𤴴
    # 0x24D35: '',  # 𤴵
    # 0x24D36: '',  # 𤴶
    # 0x24D37: '',  # 𤴷
    # 0x24D38: '',  # 𤴸
    # 0x24D39: '',  # 𤴹
    # 0x24D3A: '',  # 𤴺
    0x24D3B: 'táo',  # 𤴻
    0x24D3C: 'qiè,cí',  # 𤴼
    0x24D3D: 'qín',  # 𤴽
    0x24D3E: 'xìn',  # 𤴾
    0x24D3F: 'chān',  # 𤴿
    0x24D40: 'jì',  # 𤵀
    # 0x24D41: '',  # 𤵁
    0x24D42: 'qìn',  # 𤵂
    # 0x24D43: '',  # 𤵃
    # 0x24D44: '',  # 𤵄
    # 0x24D45: '',  # 𤵅
    # 0x24D46: '',  # 𤵆
    # 0x24D47: '',  # 𤵇
    # 0x24D48: '',  # 𤵈
    # 0x24D49: '',  # 𤵉
    0x24D4A: 'dù',  # 𤵊
    0x24D4B: 'zhī',  # 𤵋
    # 0x24D4C: '',  # 𤵌
    # 0x24D4D: '',  # 𤵍
    0x24D4E: 'ǒu',  # 𤵎
    # 0x24D4F: '',  # 𤵏
    0x24D50: 'wù',  # 𤵐
    # 0x24D51: '',  # 𤵑
    0x24D52: 'wén',  # 𤵒
    # 0x24D53: '',  # 𤵓
    # 0x24D54: '',  # 𤵔
    # 0x24D55: '',  # 𤵕
    # 0x24D56: '',  # 𤵖
    # 0x24D57: '',  # 𤵗
    0x24D58: 'bì',  # 𤵘
    # 0x24D59: '',  # 𤵙
    0x24D5A: 'tuó',  # 𤵚
    0x24D5B: 'bēi',  # 𤵛
    # 0x24D5C: '',  # 𤵜
    0x24D5D: 'mǔ',  # 𤵝
    0x24D5E: 'jìn',  # 𤵞
    0x24D5F: 'táo',  # 𤵟
    0x24D60: 'liáo',  # 𤵠
    0x24D61: 'hú',  # 𤵡
    # 0x24D62: '',  # 𤵢
    # 0x24D63: '',  # 𤵣
    # 0x24D64: '',  # 𤵤
    0x24D65: 'cáo,zhǒu',  # 𤵥
    0x24D66: 'zhá',  # 𤵦
    # 0x24D67: '',  # 𤵧
    # 0x24D68: '',  # 𤵨
    # 0x24D69: '',  # 𤵩
    # 0x24D6A: '',  # 𤵪
    # 0x24D6B: '',  # 𤵫
    0x24D6C: 'chǐ',  # 𤵬
    0x24D6D: 'yā',  # 𤵭
    0x24D6E: 'kuí',  # 𤵮
    0x24D6F: 'yìn',  # 𤵯
    # 0x24D70: '',  # 𤵰
    # 0x24D71: '',  # 𤵱
    # 0x24D72: '',  # 𤵲
    # 0x24D73: '',  # 𤵳
    # 0x24D74: '',  # 𤵴
    # 0x24D75: '',  # 𤵵
    # 0x24D76: '',  # 𤵶
    # 0x24D77: '',  # 𤵷
    0x24D78: 'lóng,pāng',  # 𤵸
    0x24D79: 'qià',  # 𤵹
    # 0x24D7A: '',  # 𤵺
    0x24D7B: 'hāng',  # 𤵻
    0x24D7C: 'shàng,shāng',  # 𤵼
    0x24D7D: 'hài',  # 𤵽
    0x24D7E: 'chā',  # 𤵾
    # 0x24D7F: '',  # 𤵿
    0x24D80: 'jiǎo',  # 𤶀
    0x24D81: 'lǎo',  # 𤶁
    # 0x24D82: '',  # 𤶂
    # 0x24D83: '',  # 𤶃
    # 0x24D84: '',  # 𤶄
    # 0x24D85: '',  # 𤶅
    # 0x24D86: '',  # 𤶆
    # 0x24D87: '',  # 𤶇
    0x24D88: 'xī',  # 𤶈
    # 0x24D89: '',  # 𤶉
    # 0x24D8A: '',  # 𤶊
    0x24D8B: 'bó',  # 𤶋
    # 0x24D8C: '',  # 𤶌
    # 0x24D8D: '',  # 𤶍
    # 0x24D8E: '',  # 𤶎
    # 0x24D8F: '',  # 𤶏
    # 0x24D90: '',  # 𤶐
    # 0x24D91: '',  # 𤶑
    # 0x24D92: '',  # 𤶒
    0x24D93: 'zhǐ',  # 𤶓
    # 0x24D94: '',  # 𤶔
    0x24D95: 'tùn',  # 𤶕
    0x24D96: 'fú',  # 𤶖
    # 0x24D97: '',  # 𤶗
    0x24D98: 'hū',  # 𤶘
    # 0x24D99: '',  # 𤶙
    0x24D9A: 'niè',  # 𤶚
    0x24D9B: 'yì',  # 𤶛
    0x24D9C: 'zhuàng',  # 𤶜
    # 0x24D9D: '',  # 𤶝
    # 0x24D9E: '',  # 𤶞
    # 0x24D9F: '',  # 𤶟
    0x24DA0: 'chá',  # 𤶠
    # 0x24DA1: '',  # 𤶡
    # 0x24DA2: '',  # 𤶢
    # 0x24DA3: '',  # 𤶣
    0x24DA4: 'suān',  # 𤶤
    # 0x24DA5: '',  # 𤶥
    # 0x24DA6: '',  # 𤶦
    # 0x24DA7: '',  # 𤶧
    # 0x24DA8: '',  # 𤶨
    # 0x24DA9: '',  # 𤶩
    # 0x24DAA: '',  # 𤶪
    # 0x24DAB: '',  # 𤶫
    # 0x24DAC: '',  # 𤶬
    # 0x24DAD: '',  # 𤶭
    0x24DAE: 'dù',  # 𤶮
    # 0x24DAF: '',  # 𤶯
    0x24DB0: 'xī',  # 𤶰
    0x24DB1: 'chuàn',  # 𤶱
    0x24DB2: 'xíng',  # 𤶲
    0x24DB3: 'jiǎo',  # 𤶳
    0x24DB4: 'shēn',  # 𤶴
    # 0x24DB5: '',  # 𤶵
    # 0x24DB6: '',  # 𤶶
    # 0x24DB7: '',  # 𤶷
    0x24DB8: 'nā',  # 𤶸
    # 0x24DB9: '',  # 𤶹
    # 0x24DBA: '',  # 𤶺
    # 0x24DBB: '',  # 𤶻
    # 0x24DBC: '',  # 𤶼
    # 0x24DBD: '',  # 𤶽
    # 0x24DBE: '',  # 𤶾
    # 0x24DBF: '',  # 𤶿
    0x24DC0: 'wāng',  # 𤷀
    0x24DC1: 'bēi',  # 𤷁
    0x24DC2: 'féi',  # 𤷂
    0x24DC3: 'jiàn',  # 𤷃
    0x24DC4: 'quán',  # 𤷄
    0x24DC5: 'yì,yá',  # 𤷅
    0x24DC6: 'dōng',  # 𤷆
    0x24DC7: 'xù',  # 𤷇
    0x24DC8: 'nà,niè',  # 𤷈
    0x24DC9: 'jí',  # 𤷉
    # 0x24DCA: '',  # 𤷊
    # 0x24DCB: '',  # 𤷋
    0x24DCC: 'zhěn',  # 𤷌
    0x24DCD: 'qí',  # 𤷍
    0x24DCE: 'duī',  # 𤷎
    0x24DCF: 'yín',  # 𤷏
    # 0x24DD0: '',  # 𤷐
    0x24DD1: 'jiù',  # 𤷑
    0x24DD2: 'pí,bì,bēi',  # 𤷒
    0x24DD3: 'xìn',  # 𤷓
    0x24DD4: 'lún',  # 𤷔
    0x24DD5: 'cǎi',  # 𤷕
    0x24DD6: 'lìng',  # 𤷖
    0x24DD7: 'biē',  # 𤷗
    0x24DD8: 'dào',  # 𤷘
    0x24DD9: 'dé',  # 𤷙
    # 0x24DDA: '',  # 𤷚
    # 0x24DDB: '',  # 𤷛
    # 0x24DDC: '',  # 𤷜
    # 0x24DDD: '',  # 𤷝
    # 0x24DDE: '',  # 𤷞
    0x24DDF: 'la',  # 𤷟
    # 0x24DE0: '',  # 𤷠
    0x24DE1: 'xī,nüè',  # 𤷡
    0x24DE2: 'jù',  # 𤷢
    # 0x24DE3: '',  # 𤷣
    0x24DE4: 'xiáo',  # 𤷤
    # 0x24DE5: '',  # 𤷥
    0x24DE6: 'jīng',  # 𤷦
    # 0x24DE7: '',  # 𤷧
    # 0x24DE8: '',  # 𤷨
    # 0x24DE9: '',  # 𤷩
    0x24DEA: 'měng',  # 𤷪
    # 0x24DEB: '',  # 𤷫
    # 0x24DEC: '',  # 𤷬
    # 0x24DED: '',  # 𤷭
    # 0x24DEE: '',  # 𤷮
    # 0x24DEF: '',  # 𤷯
    # 0x24DF0: '',  # 𤷰
    # 0x24DF1: '',  # 𤷱
    # 0x24DF2: '',  # 𤷲
    # 0x24DF3: '',  # 𤷳
    # 0x24DF4: '',  # 𤷴
    # 0x24DF5: '',  # 𤷵
    # 0x24DF6: '',  # 𤷶
    # 0x24DF7: '',  # 𤷷
    # 0x24DF8: '',  # 𤷸
    0x24DF9: 'wài',  # 𤷹
    # 0x24DFA: '',  # 𤷺
    0x24DFB: 'nǎo',  # 𤷻
    0x24DFC: 'xiāng',  # 𤷼
    0x24DFD: 'què',  # 𤷽
    0x24DFE: 'qiè',  # 𤷾
    0x24DFF: 'tū',  # 𤷿
    0x24E00: 'xǔ',  # 𤸀
    0x24E01: 'huì',  # 𤸁
    # 0x24E02: '',  # 𤸂
    0x24E03: 'shòu',  # 𤸃
    # 0x24E04: '',  # 𤸄
    0x24E05: 'mín',  # 𤸅
    0x24E06: 'wěi',  # 𤸆
    # 0x24E07: '',  # 𤸇
    0x24E08: 'yóu',  # 𤸈
    0x24E09: 'tuí',  # 𤸉
    0x24E0A: 'dài',  # 𤸊
    0x24E0B: 'jiè',  # 𤸋
    # 0x24E0C: '',  # 𤸌
    # 0x24E0D: '',  # 𤸍
    0x24E0E: 'kě,hài',  # 𤸎
    0x24E0F: 'nà,niè',  # 𤸏
    # 0x24E10: '',  # 𤸐
    0x24E11: 'fù',  # 𤸑
    0x24E12: 'yù',  # 𤸒
    0x24E13: 'zhǐ',  # 𤸓
    # 0x24E14: '',  # 𤸔
    0x24E15: 'hān',  # 𤸕
    0x24E16: 'āi',  # 𤸖
    0x24E17: 'fù',  # 𤸗
    # 0x24E18: '',  # 𤸘
    # 0x24E19: '',  # 𤸙
    # 0x24E1A: '',  # 𤸚
    # 0x24E1B: '',  # 𤸛
    # 0x24E1C: '',  # 𤸜
    # 0x24E1D: '',  # 𤸝
    # 0x24E1E: '',  # 𤸞
    # 0x24E1F: '',  # 𤸟
    # 0x24E20: '',  # 𤸠
    0x24E21: 'yāng',  # 𤸡
    # 0x24E22: '',  # 𤸢
    # 0x24E23: '',  # 𤸣
    0x24E24: 'shí',  # 𤸤
    # 0x24E25: '',  # 𤸥
    0x24E26: 'chán',  # 𤸦
    # 0x24E27: '',  # 𤸧
    # 0x24E28: '',  # 𤸨
    # 0x24E29: '',  # 𤸩
    0x24E2A: 'chì',  # 𤸪
    0x24E2B: 'yùn',  # 𤸫
    0x24E2C: 'shuāi',  # 𤸬
    # 0x24E2D: '',  # 𤸭
    0x24E2E: 'sù',  # 𤸮
    0x24E2F: 'sǎng',  # 𤸯
    # 0x24E30: '',  # 𤸰
    0x24E31: 'è,kè,kài,yà',  # 𤸱
    0x24E32: 'zhěng',  # 𤸲
    0x24E33: 'ái',  # 𤸳
    0x24E34: 'suǒ',  # 𤸴
    0x24E35: 'bù',  # 𤸵
    # 0x24E36: '',  # 𤸶
    0x24E37: 'qún',  # 𤸷
    0x24E38: 'yì',  # 𤸸
    0x24E39: 'yǎn',  # 𤸹
    # 0x24E3A: '',  # 𤸺
    0x24E3B: 'nà',  # 𤸻
    0x24E3C: 'wǔ',  # 𤸼
    # 0x24E3D: '',  # 𤸽
    # 0x24E3E: '',  # 𤸾
    # 0x24E3F: '',  # 𤸿
    # 0x24E40: '',  # 𤹀
    # 0x24E41: '',  # 𤹁
    # 0x24E42: '',  # 𤹂
    # 0x24E43: '',  # 𤹃
    # 0x24E44: '',  # 𤹄
    # 0x24E45: '',  # 𤹅
    # 0x24E46: '',  # 𤹆
    0x24E47: 'lì',  # 𤹇
    0x24E48: 'lì',  # 𤹈
    # 0x24E49: '',  # 𤹉
    0x24E4A: 'xī',  # 𤹊
    0x24E4B: 'jué',  # 𤹋
    0x24E4C: 'shī',  # 𤹌
    # 0x24E4D: '',  # 𤹍
    0x24E4E: 'yǎ',  # 𤹎
    # 0x24E4F: '',  # 𤹏
    0x24E50: 'liè',  # 𤹐
    # 0x24E51: '',  # 𤹑
    # 0x24E52: '',  # 𤹒
    # 0x24E53: '',  # 𤹓
    # 0x24E54: '',  # 𤹔
    # 0x24E55: '',  # 𤹕
    # 0x24E56: '',  # 𤹖
    # 0x24E57: '',  # 𤹗
    # 0x24E58: '',  # 𤹘
    # 0x24E59: '',  # 𤹙
    # 0x24E5A: '',  # 𤹚
    0x24E5B: 'chén',  # 𤹛
    0x24E5C: 'yíng',  # 𤹜
    0x24E5D: 'bì',  # 𤹝
    0x24E5E: 'chè',  # 𤹞
    # 0x24E5F: '',  # 𤹟
    # 0x24E60: '',  # 𤹠
    0x24E61: 'zhā',  # 𤹡
    0x24E62: 'tuǒ',  # 𤹢
    0x24E63: 'hù',  # 𤹣
    0x24E64: 'téng',  # 𤹤
    0x24E65: 'yìng',  # 𤹥
    0x24E66: 'bǐ',  # 𤹦
    0x24E67: 'níng',  # 𤹧
    0x24E68: 'liàn',  # 𤹨
    0x24E69: 'xìn',  # 𤹩
    0x24E6A: 'yǔ',  # 𤹪
    # 0x24E6B: '',  # 𤹫
    # 0x24E6C: '',  # 𤹬
    # 0x24E6D: '',  # 𤹭
    # 0x24E6E: '',  # 𤹮
    0x24E6F: 'tòng',  # 𤹯
    # 0x24E70: '',  # 𤹰
    # 0x24E71: '',  # 𤹱
    0x24E72: 'bèi',  # 𤹲
    # 0x24E73: '',  # 𤹳
    0x24E74: 'mó',  # 𤹴
    0x24E75: 'duī',  # 𤹵
    # 0x24E76: '',  # 𤹶
    0x24E77: 'dǎo',  # 𤹷
    0x24E78: 'qí',  # 𤹸
    # 0x24E79: '',  # 𤹹
    # 0x24E7A: '',  # 𤹺
    # 0x24E7B: '',  # 𤹻
    # 0x24E7C: '',  # 𤹼
    # 0x24E7D: '',  # 𤹽
    # 0x24E7E: '',  # 𤹾
    # 0x24E7F: '',  # 𤹿
    0x24E80: 'shuāi',  # 𤺀
    # 0x24E81: '',  # 𤺁
    # 0x24E82: '',  # 𤺂
    0x24E83: 'xiāo,jiāo,yāo',  # 𤺃
    0x24E84: 'zhǒng,tóng',  # 𤺄
    0x24E85: 'zhuì',  # 𤺅
    # 0x24E86: '',  # 𤺆
    0x24E87: 'biàn',  # 𤺇
    # 0x24E88: '',  # 𤺈
    0x24E89: 'wěi',  # 𤺉
    0x24E8A: 'xī,sī',  # 𤺊
    # 0x24E8B: '',  # 𤺋
    0x24E8C: 'dēng',  # 𤺌
    # 0x24E8D: '',  # 𤺍
    0x24E8E: 'xiē',  # 𤺎
    0x24E8F: 'pān',  # 𤺏
    0x24E90: 'niè',  # 𤺐
    # 0x24E91: '',  # 𤺑
    # 0x24E92: '',  # 𤺒
    0x24E93: 'bié',  # 𤺓
    0x24E94: 'shè',  # 𤺔
    0x24E95: 'fèi',  # 𤺕
    0x24E96: 'mǐn',  # 𤺖
    0x24E97: 'qì,jì',  # 𤺗
    0x24E98: 'yǎ',  # 𤺘
    # 0x24E99: '',  # 𤺙
    # 0x24E9A: '',  # 𤺚
    # 0x24E9B: '',  # 𤺛
    # 0x24E9C: '',  # 𤺜
    # 0x24E9D: '',  # 𤺝
    # 0x24E9E: '',  # 𤺞
    # 0x24E9F: '',  # 𤺟
    # 0x24EA0: '',  # 𤺠
    # 0x24EA1: '',  # 𤺡
    # 0x24EA2: '',  # 𤺢
    # 0x24EA3: '',  # 𤺣
    # 0x24EA4: '',  # 𤺤
    # 0x24EA5: '',  # 𤺥
    # 0x24EA6: '',  # 𤺦
    # 0x24EA7: '',  # 𤺧
    # 0x24EA8: '',  # 𤺨
    # 0x24EA9: '',  # 𤺩
    0x24EAA: 'shàn',  # 𤺪
    0x24EAB: 'suǒ',  # 𤺫
    # 0x24EAC: '',  # 𤺬
    # 0x24EAD: '',  # 𤺭
    # 0x24EAE: '',  # 𤺮
    # 0x24EAF: '',  # 𤺯
    # 0x24EB0: '',  # 𤺰
    # 0x24EB1: '',  # 𤺱
    # 0x24EB2: '',  # 𤺲
    # 0x24EB3: '',  # 𤺳
    # 0x24EB4: '',  # 𤺴
    # 0x24EB5: '',  # 𤺵
    # 0x24EB6: '',  # 𤺶
    0x24EB7: 'jí',  # 𤺷
    # 0x24EB8: '',  # 𤺸
    # 0x24EB9: '',  # 𤺹
    0x24EBA: 'dǎn,dàn,tán',  # 𤺺
    0x24EBB: 'juàn',  # 𤺻
    0x24EBC: 'lù',  # 𤺼
    # 0x24EBD: '',  # 𤺽
    0x24EBE: 'ào',  # 𤺾
    # 0x24EBF: '',  # 𤺿
    # 0x24EC0: '',  # 𤻀
    # 0x24EC1: '',  # 𤻁
    0x24EC2: 'yì',  # 𤻂
    0x24EC3: 'shǔ',  # 𤻃
    0x24EC4: 'suì',  # 𤻄
    0x24EC5: 'wèi',  # 𤻅
    0x24EC6: 'wán',  # 𤻆
    0x24EC7: 'chǔ',  # 𤻇
    # 0x24EC8: '',  # 𤻈
    # 0x24EC9: '',  # 𤻉
    # 0x24ECA: '',  # 𤻊
    # 0x24ECB: '',  # 𤻋
    0x24ECC: 'wò',  # 𤻌
    # 0x24ECD: '',  # 𤻍
    # 0x24ECE: '',  # 𤻎
    # 0x24ECF: '',  # 𤻏
    # 0x24ED0: '',  # 𤻐
    # 0x24ED1: '',  # 𤻑
    # 0x24ED2: '',  # 𤻒
    # 0x24ED3: '',  # 𤻓
    # 0x24ED4: '',  # 𤻔
    # 0x24ED5: '',  # 𤻕
    0x24ED6: 'bì',  # 𤻖
    # 0x24ED7: '',  # 𤻗
    0x24ED8: 'yǐn',  # 𤻘
    0x24ED9: 'huó',  # 𤻙
    # 0x24EDA: '',  # 𤻚
    # 0x24EDB: '',  # 𤻛
    0x24EDC: 'kài,è',  # 𤻜
    0x24EDD: 'níng',  # 𤻝
    # 0x24EDE: '',  # 𤻞
    # 0x24EDF: '',  # 𤻟
    # 0x24EE0: '',  # 𤻠
    # 0x24EE1: '',  # 𤻡
    0x24EE2: 'ài',  # 𤻢
    # 0x24EE3: '',  # 𤻣
    0x24EE4: 'lì',  # 𤻤
    # 0x24EE5: '',  # 𤻥
    0x24EE6: 'zhāi',  # 𤻦
    # 0x24EE7: '',  # 𤻧
    # 0x24EE8: '',  # 𤻨
    # 0x24EE9: '',  # 𤻩
    # 0x24EEA: '',  # 𤻪
    # 0x24EEB: '',  # 𤻫
    # 0x24EEC: '',  # 𤻬
    # 0x24EED: '',  # 𤻭
    # 0x24EEE: '',  # 𤻮
    # 0x24EEF: '',  # 𤻯
    # 0x24EF0: '',  # 𤻰
    0x24EF1: 'lù',  # 𤻱
    0x24EF2: 'liáo',  # 𤻲
    # 0x24EF3: '',  # 𤻳
    # 0x24EF4: '',  # 𤻴
    # 0x24EF5: '',  # 𤻵
    0x24EF6: 'biàn',  # 𤻶
    0x24EF7: 'pán',  # 𤻷
    # 0x24EF8: '',  # 𤻸
    # 0x24EF9: '',  # 𤻹
    # 0x24EFA: '',  # 𤻺
    # 0x24EFB: '',  # 𤻻
    # 0x24EFC: '',  # 𤻼
    # 0x24EFD: '',  # 𤻽
    # 0x24EFE: '',  # 𤻾
    0x24EFF: 'guì',  # 𤻿
    0x24F00: 'sū',  # 𤼀
    0x24F01: 'méng',  # 𤼁
    0x24F02: 'xiǎn',  # 𤼂
    0x24F03: 'lòng,lóng',  # 𤼃
    # 0x24F04: '',  # 𤼄
    0x24F05: 'qì',  # 𤼅
    # 0x24F06: '',  # 𤼆
    # 0x24F07: '',  # 𤼇
    # 0x24F08: '',  # 𤼈
    # 0x24F09: '',  # 𤼉
    # 0x24F0A: '',  # 𤼊
    0x24F0B: 'chàn',  # 𤼋
    0x24F0C: 'yì',  # 𤼌
    0x24F0D: 'háng',  # 𤼍
    # 0x24F0E: '',  # 𤼎
    0x24F0F: 'liǎn',  # 𤼏
    0x24F10: 'guàn,huàn',  # 𤼐
    # 0x24F11: '',  # 𤼑
    0x24F12: 'wěi,huà',  # 𤼒
    # 0x24F13: '',  # 𤼓
    # 0x24F14: '',  # 𤼔
    # 0x24F15: '',  # 𤼕
    # 0x24F16: '',  # 𤼖
    0x24F17: 'jué',  # 𤼗
    0x24F18: 'léi',  # 𤼘
    0x24F19: 'luán',  # 𤼙
    0x24F1A: 'lì',  # 𤼚
    # 0x24F1B: '',  # 𤼛
    0x24F1C: 'pí',  # 𤼜
    # 0x24F1D: '',  # 𤼝
    # 0x24F1E: '',  # 𤼞
    # 0x24F1F: '',  # 𤼟
    # 0x24F20: '',  # 𤼠
    # 0x24F21: '',  # 𤼡
    0x24F22: 'huǎn',  # 𤼢
    # 0x24F23: '',  # 𤼣
    0x24F24: 'pì',  # 𤼤
    # 0x24F25: '',  # 𤼥
    # 0x24F26: '',  # 𤼦
    # 0x24F27: '',  # 𤼧
    # 0x24F28: '',  # 𤼨
    # 0x24F29: '',  # 𤼩
    # 0x24F2A: '',  # 𤼪
    # 0x24F2B: '',  # 𤼫
    # 0x24F2C: '',  # 𤼬
    # 0x24F2D: '',  # 𤼭
    0x24F2E: 'guī',  # 𤼮
    # 0x24F2F: '',  # 𤼯
    # 0x24F30: '',  # 𤼰
    # 0x24F31: '',  # 𤼱
    # 0x24F32: '',  # 𤼲
    0x24F33: 'jú',  # 𤼳
    # 0x24F34: '',  # 𤼴
    0x24F35: 'fā',  # 𤼵
    0x24F36: 'dēng',  # 𤼶
    # 0x24F37: '',  # 𤼷
    # 0x24F38: '',  # 𤼸
    # 0x24F39: '',  # 𤼹
    0x24F3A: 'fèi',  # 𤼺
    # 0x24F3B: '',  # 𤼻
    # 0x24F3C: '',  # 𤼼
    # 0x24F3D: '',  # 𤼽
    # 0x24F3E: '',  # 𤼾
    # 0x24F3F: '',  # 𤼿
    # 0x24F40: '',  # 𤽀
    0x24F41: 'zhī',  # 𤽁
    # 0x24F42: '',  # 𤽂
    0x24F43: 'mèi',  # 𤽃
    # 0x24F44: '',  # 𤽄
    0x24F45: 'huàn',  # 𤽅
    # 0x24F46: '',  # 𤽆
    # 0x24F47: '',  # 𤽇
    # 0x24F48: '',  # 𤽈
    0x24F49: 'pā',  # 𤽉
    0x24F4A: 'bǐ',  # 𤽊
    # 0x24F4B: '',  # 𤽋
    0x24F4C: 'pō',  # 𤽌
    # 0x24F4D: '',  # 𤽍
    # 0x24F4E: '',  # 𤽎
    # 0x24F4F: '',  # 𤽏
    # 0x24F50: '',  # 𤽐
    # 0x24F51: '',  # 𤽑
    # 0x24F52: '',  # 𤽒
    0x24F53: 'ér',  # 𤽓
    # 0x24F54: '',  # 𤽔
    0x24F55: 'huàn',  # 𤽕
    # 0x24F56: '',  # 𤽖
    # 0x24F57: '',  # 𤽗
    # 0x24F58: '',  # 𤽘
    # 0x24F59: '',  # 𤽙
    # 0x24F5A: '',  # 𤽚
    # 0x24F5B: '',  # 𤽛
    # 0x24F5C: '',  # 𤽜
    # 0x24F5D: '',  # 𤽝
    # 0x24F5E: '',  # 𤽞
    # 0x24F5F: '',  # 𤽟
    # 0x24F60: '',  # 𤽠
    # 0x24F61: '',  # 𤽡
    # 0x24F62: '',  # 𤽢
    0x24F63: 'chàng',  # 𤽣
    # 0x24F64: '',  # 𤽤
    0x24F65: 'luò',  # 𤽥
    0x24F66: 'fǒu',  # 𤽦
    # 0x24F67: '',  # 𤽧
    # 0x24F68: '',  # 𤽨
    # 0x24F69: '',  # 𤽩
    # 0x24F6A: '',  # 𤽪
    # 0x24F6B: '',  # 𤽫
    # 0x24F6C: '',  # 𤽬
    # 0x24F6D: '',  # 𤽭
    # 0x24F6E: '',  # 𤽮
    # 0x24F6F: '',  # 𤽯
    # 0x24F70: '',  # 𤽰
    0x24F71: 'zú',  # 𤽱
    0x24F72: 'nán',  # 𤽲
    0x24F73: 'xiǎo',  # 𤽳
    # 0x24F74: '',  # 𤽴
    # 0x24F75: '',  # 𤽵
    # 0x24F76: '',  # 𤽶
    # 0x24F77: '',  # 𤽷
    # 0x24F78: '',  # 𤽸
    0x24F79: 'bài',  # 𤽹
    0x24F7A: 'lù',  # 𤽺
    # 0x24F7B: '',  # 𤽻
    0x24F7C: 'luò',  # 𤽼
    # 0x24F7D: '',  # 𤽽
    # 0x24F7E: '',  # 𤽾
    0x24F7F: 'niàn',  # 𤽿
    # 0x24F80: '',  # 𤾀
    # 0x24F81: '',  # 𤾁
    # 0x24F82: '',  # 𤾂
    # 0x24F83: '',  # 𤾃
    0x24F84: 'zhù',  # 𤾄
    0x24F85: 'hú',  # 𤾅
    # 0x24F86: '',  # 𤾆
    # 0x24F87: '',  # 𤾇
    0x24F88: 'huī',  # 𤾈
    0x24F89: 'tǎng',  # 𤾉
    0x24F8A: 'chóu',  # 𤾊
    # 0x24F8B: '',  # 𤾋
    # 0x24F8C: '',  # 𤾌
    # 0x24F8D: '',  # 𤾍
    # 0x24F8E: '',  # 𤾎
    # 0x24F8F: '',  # 𤾏
    # 0x24F90: '',  # 𤾐
    0x24F91: 'huáng',  # 𤾑
    0x24F92: 'dōu',  # 𤾒
    # 0x24F93: '',  # 𤾓
    # 0x24F94: '',  # 𤾔
    0x24F95: 'tì',  # 𤾕
    # 0x24F96: '',  # 𤾖
    # 0x24F97: '',  # 𤾗
    # 0x24F98: '',  # 𤾘
    # 0x24F99: '',  # 𤾙
    # 0x24F9A: '',  # 𤾚
    0x24F9B: 'miào',  # 𤾛
    # 0x24F9C: '',  # 𤾜
    0x24F9D: 'bó',  # 𤾝
    # 0x24F9E: '',  # 𤾞
    # 0x24F9F: '',  # 𤾟
    0x24FA0: 'dì',  # 𤾠
    # 0x24FA1: '',  # 𤾡
    0x24FA2: 'děng',  # 𤾢
    0x24FA3: 'pū',  # 𤾣
    # 0x24FA4: '',  # 𤾤
    0x24FA5: 'sōng',  # 𤾥
    0x24FA6: 'chóu',  # 𤾦
    # 0x24FA7: '',  # 𤾧
    # 0x24FA8: '',  # 𤾨
    # 0x24FA9: '',  # 𤾩
    # 0x24FAA: '',  # 𤾪
    0x24FAB: 'yào',  # 𤾫
    0x24FAC: 'měng',  # 𤾬
    0x24FAD: 'lóng',  # 𤾭
    # 0x24FAE: '',  # 𤾮
    # 0x24FAF: '',  # 𤾯
    # 0x24FB0: '',  # 𤾰
    # 0x24FB1: '',  # 𤾱
    0x24FB2: 'lián',  # 𤾲
    # 0x24FB3: '',  # 𤾳
    # 0x24FB4: '',  # 𤾴
    0x24FB5: 'bié',  # 𤾵
    # 0x24FB6: '',  # 𤾶
    # 0x24FB7: '',  # 𤾷
    # 0x24FB8: '',  # 𤾸
    # 0x24FB9: '',  # 𤾹
    0x24FBA: 'lǚ',  # 𤾺
    # 0x24FBB: '',  # 𤾻
    # 0x24FBC: '',  # 𤾼
    # 0x24FBD: '',  # 𤾽
    # 0x24FBE: '',  # 𤾾
    0x24FBF: 'sè',  # 𤾿
    0x24FC0: 'zuó',  # 𤿀
    # 0x24FC1: '',  # 𤿁
    # 0x24FC2: '',  # 𤿂
    # 0x24FC3: '',  # 𤿃
    0x24FC4: 'cún',  # 𤿄
    0x24FC5: 'líng',  # 𤿅
    0x24FC6: 'zhěng',  # 𤿆
    0x24FC7: 'pǐ',  # 𤿇
    0x24FC8: 'báo',  # 𤿈
    # 0x24FC9: '',  # 𤿉
    # 0x24FCA: '',  # 𤿊
    0x24FCB: 'què',  # 𤿋
    # 0x24FCC: '',  # 𤿌
    # 0x24FCD: '',  # 𤿍
    0x24FCE: 'pī',  # 𤿎
    0x24FCF: 'nàn',  # 𤿏
    0x24FD0: 'pī',  # 𤿐
    0x24FD1: 'bǒ',  # 𤿑
    0x24FD2: 'bèi',  # 𤿒
    0x24FD3: 'fā',  # 𤿓
    # 0x24FD4: '',  # 𤿔
    0x24FD5: 'mǐn',  # 𤿕
    0x24FD6: 'mò',  # 𤿖
    0x24FD7: 'wà',  # 𤿗
    0x24FD8: 'zhāo',  # 𤿘
    0x24FD9: 'zhì,pí',  # 𤿙
    0x24FDA: 'cū',  # 𤿚
    # 0x24FDB: '',  # 𤿛
    # 0x24FDC: '',  # 𤿜
    # 0x24FDD: '',  # 𤿝
    # 0x24FDE: '',  # 𤿞
    0x24FDF: 'xún',  # 𤿟
    0x24FE0: 'jí',  # 𤿠
    0x24FE1: 'guì,qí',  # 𤿡
    # 0x24FE2: '',  # 𤿢
    0x24FE3: 'chéng',  # 𤿣
    # 0x24FE4: '',  # 𤿤
    # 0x24FE5: '',  # 𤿥
    # 0x24FE6: '',  # 𤿦
    0x24FE7: 'hàn',  # 𤿧
    0x24FE8: 'xiào',  # 𤿨
    0x24FE9: 'què',  # 𤿩
    # 0x24FEA: '',  # 𤿪
    0x24FEB: 'chuò',  # 𤿫
    # 0x24FEC: '',  # 𤿬
    0x24FED: 'fǔ',  # 𤿭
    # 0x24FEE: '',  # 𤿮
    # 0x24FEF: '',  # 𤿯
    # 0x24FF0: '',  # 𤿰
    # 0x24FF1: '',  # 𤿱
    # 0x24FF2: '',  # 𤿲
    0x24FF3: 'qǐn',  # 𤿳
    0x24FF4: 'lù',  # 𤿴
    0x24FF5: 'què',  # 𤿵
    0x24FF6: 'diǎn',  # 𤿶
    0x24FF7: 'qiān',  # 𤿷
    # 0x24FF8: '',  # 𤿸
    # 0x24FF9: '',  # 𤿹
    # 0x24FFA: '',  # 𤿺
    # 0x24FFB: '',  # 𤿻
    0x24FFC: 'chǎng',  # 𤿼
    0x24FFD: 'tà',  # 𤿽
    0x24FFE: 'bēi',  # 𤿾
    # 0x24FFF: '',  # 𤿿
    # 0x25000: '',  # 𥀀
    0x25001: 'dù',  # 𥀁
    0x25002: 'běng,bāng',  # 𥀂
    0x25003: 'hòu',  # 𥀃
    # 0x25004: '',  # 𥀄
    # 0x25005: '',  # 𥀅
    # 0x25006: '',  # 𥀆
    # 0x25007: '',  # 𥀇
    0x25008: 'zhǎ',  # 𥀈
    0x25009: 'zhǎ',  # 𥀉
    # 0x2500A: '',  # 𥀊
    # 0x2500B: '',  # 𥀋
    # 0x2500C: '',  # 𥀌
    # 0x2500D: '',  # 𥀍
    0x2500E: 'què',  # 𥀎
    0x2500F: 'má',  # 𥀏
    0x25010: 'hán',  # 𥀐
    # 0x25011: '',  # 𥀑
    # 0x25012: '',  # 𥀒
    0x25013: 'liú',  # 𥀓
    0x25014: 'lù',  # 𥀔
    # 0x25015: '',  # 𥀕
    0x25016: 'zī',  # 𥀖
    # 0x25017: '',  # 𥀗
    0x25018: 'pǐ',  # 𥀘
    0x25019: 'zhòu',  # 𥀙
    # 0x2501A: '',  # 𥀚
    0x2501B: 'zāo',  # 𥀛
    # 0x2501C: '',  # 𥀜
    0x2501D: 'niǔ',  # 𥀝
    # 0x2501E: '',  # 𥀞
    # 0x2501F: '',  # 𥀟
    0x25020: 'huì',  # 𥀠
    # 0x25021: '',  # 𥀡
    # 0x25022: '',  # 𥀢
    0x25023: 'xué,qiào',  # 𥀣
    # 0x25024: '',  # 𥀤
    0x25025: 'là',  # 𥀥
    # 0x25026: '',  # 𥀦
    # 0x25027: '',  # 𥀧
    # 0x25028: '',  # 𥀨
    # 0x25029: '',  # 𥀩
    # 0x2502A: '',  # 𥀪
    0x2502B: 'nóu,rǎn',  # 𥀫
    0x2502C: 'yǎn,yè',  # 𥀬
    0x2502D: 'rǎn',  # 𥀭
    0x2502E: 'nǎo',  # 𥀮
    # 0x2502F: '',  # 𥀯
    0x25030: 'là',  # 𥀰
    0x25031: 'guǎng',  # 𥀱
    0x25032: 'dú',  # 𥀲
    # 0x25033: '',  # 𥀳
    # 0x25034: '',  # 𥀴
    0x25035: 'lú',  # 𥀵
    # 0x25036: '',  # 𥀶
    # 0x25037: '',  # 𥀷
    # 0x25038: '',  # 𥀸
    0x25039: 'jiǎn',  # 𥀹
    0x2503A: 'xiè',  # 𥀺
    0x2503B: 'qì',  # 𥀻
    # 0x2503C: '',  # 𥀼
    # 0x2503D: '',  # 𥀽
    0x2503E: 'xiàng',  # 𥀾
    # 0x2503F: '',  # 𥀿
    # 0x25040: '',  # 𥁀
    0x25041: 'guǒ',  # 𥁁
    0x25042: 'jié',  # 𥁂
    0x25043: 'màng',  # 𥁃
    # 0x25044: '',  # 𥁄
    # 0x25045: '',  # 𥁅
    0x25046: 'xiā',  # 𥁆
    0x25047: 'kuī',  # 𥁇
    # 0x25048: '',  # 𥁈
    # 0x25049: '',  # 𥁉
    # 0x2504A: '',  # 𥁊
    # 0x2504B: '',  # 𥁋
    # 0x2504C: '',  # 𥁌
    # 0x2504D: '',  # 𥁍
    0x2504E: 'yòng',  # 𥁎
    # 0x2504F: '',  # 𥁏
    0x25050: 'hǎi',  # 𥁐
    0x25051: 'mì',  # 𥁑
    0x25052: 'yào',  # 𥁒
    # 0x25053: '',  # 𥁓
    # 0x25054: '',  # 𥁔
    0x25055: 'wēn',  # 𥁕
    # 0x25056: '',  # 𥁖
    # 0x25057: '',  # 𥁗
    # 0x25058: '',  # 𥁘
    # 0x25059: '',  # 𥁙
    # 0x2505A: '',  # 𥁚
    # 0x2505B: '',  # 𥁛
    # 0x2505C: '',  # 𥁜
    # 0x2505D: '',  # 𥁝
    # 0x2505E: '',  # 𥁞
    0x2505F: 'lì',  # 𥁟
    0x25060: 'juàn,quán,quān',  # 𥁠
    0x25061: 'wū',  # 𥁡
    # 0x25062: '',  # 𥁢
    # 0x25063: '',  # 𥁣
    # 0x25064: '',  # 𥁤
    # 0x25065: '',  # 𥁥
    # 0x25066: '',  # 𥁦
    # 0x25067: '',  # 𥁧
    # 0x25068: '',  # 𥁨
    # 0x25069: '',  # 𥁩
    # 0x2506A: '',  # 𥁪
    # 0x2506B: '',  # 𥁫
    # 0x2506C: '',  # 𥁬
    # 0x2506D: '',  # 𥁭
    0x2506E: 'diào',  # 𥁮
    0x2506F: 'chù,chuò',  # 𥁯
    # 0x25070: '',  # 𥁰
    # 0x25071: '',  # 𥁱
    0x25072: 'suō',  # 𥁲
    # 0x25073: '',  # 𥁳
    # 0x25074: '',  # 𥁴
    0x25075: 'chōng',  # 𥁵
    # 0x25076: '',  # 𥁶
    # 0x25077: '',  # 𥁷
    0x25078: 'quān',  # 𥁸
    0x25079: 'shè',  # 𥁹
    # 0x2507A: '',  # 𥁺
    # 0x2507B: '',  # 𥁻
    # 0x2507C: '',  # 𥁼
    # 0x2507D: '',  # 𥁽
    # 0x2507E: '',  # 𥁾
    # 0x2507F: '',  # 𥁿
    # 0x25080: '',  # 𥂀
    0x25081: 'yán',  # 𥂁
    0x25082: 'měng',  # 𥂂
    0x25083: 'jù',  # 𥂃
    # 0x25084: '',  # 𥂄
    # 0x25085: '',  # 𥂅
    # 0x25086: '',  # 𥂆
    # 0x25087: '',  # 𥂇
    # 0x25088: '',  # 𥂈
    # 0x25089: '',  # 𥂉
    # 0x2508A: '',  # 𥂊
    0x2508B: 'tú',  # 𥂋
    # 0x2508C: '',  # 𥂌
    # 0x2508D: '',  # 𥂍
    # 0x2508E: '',  # 𥂎
    # 0x2508F: '',  # 𥂏
    # 0x25090: '',  # 𥂐
    # 0x25091: '',  # 𥂑
    0x25092: 'nóng',  # 𥂒
    0x25093: 'mó',  # 𥂓
    # 0x25094: '',  # 𥂔
    # 0x25095: '',  # 𥂕
    # 0x25096: '',  # 𥂖
    # 0x25097: '',  # 𥂗
    # 0x25098: '',  # 𥂘
    0x25099: 'fèn',  # 𥂙
    # 0x2509A: '',  # 𥂚
    # 0x2509B: '',  # 𥂛
    # 0x2509C: '',  # 𥂜
    # 0x2509D: '',  # 𥂝
    # 0x2509E: '',  # 𥂞
    # 0x2509F: '',  # 𥂟
    # 0x250A0: '',  # 𥂠
    # 0x250A1: '',  # 𥂡
    0x250A2: 'áo',  # 𥂢
    0x250A3: 'guō',  # 𥂣
    0x250A4: 'hú',  # 𥂤
    0x250A5: 'cán',  # 𥂥
    0x250A6: 'dūn',  # 𥂦
    0x250A7: 'hǎi',  # 𥂧
    0x250A8: 'jiǎo',  # 𥂨
    # 0x250A9: '',  # 𥂩
    # 0x250AA: '',  # 𥂪
    # 0x250AB: '',  # 𥂫
    # 0x250AC: '',  # 𥂬
    # 0x250AD: '',  # 𥂭
    # 0x250AE: '',  # 𥂮
    # 0x250AF: '',  # 𥂯
    0x250B0: 'gū',  # 𥂰
    # 0x250B1: '',  # 𥂱
    # 0x250B2: '',  # 𥂲
    # 0x250B3: '',  # 𥂳
    # 0x250B4: '',  # 𥂴
    0x250B5: 'jīn',  # 𥂵
    # 0x250B6: '',  # 𥂶
    # 0x250B7: '',  # 𥂷
    0x250B8: 'yáng',  # 𥂸
    # 0x250B9: '',  # 𥂹
    # 0x250BA: '',  # 𥂺
    # 0x250BB: '',  # 𥂻
    # 0x250BC: '',  # 𥂼
    # 0x250BD: '',  # 𥂽
    # 0x250BE: '',  # 𥂾
    # 0x250BF: '',  # 𥂿
    0x250C0: 'chà',  # 𥃀
    # 0x250C1: '',  # 𥃁
    # 0x250C2: '',  # 𥃂
    # 0x250C3: '',  # 𥃃
    # 0x250C4: '',  # 𥃄
    # 0x250C5: '',  # 𥃅
    # 0x250C6: '',  # 𥃆
    # 0x250C7: '',  # 𥃇
    # 0x250C8: '',  # 𥃈
    # 0x250C9: '',  # 𥃉
    # 0x250CA: '',  # 𥃊
    # 0x250CB: '',  # 𥃋
    0x250CC: 'huī',  # 𥃌
    # 0x250CD: '',  # 𥃍
    # 0x250CE: '',  # 𥃎
    # 0x250CF: '',  # 𥃏
    # 0x250D0: '',  # 𥃐
    # 0x250D1: '',  # 𥃑
    # 0x250D2: '',  # 𥃒
    # 0x250D3: '',  # 𥃓
    0x250D4: 'qú',  # 𥃔
    0x250D5: 'kē',  # 𥃕
    # 0x250D6: '',  # 𥃖
    # 0x250D7: '',  # 𥃗
    # 0x250D8: '',  # 𥃘
    # 0x250D9: '',  # 𥃙
    # 0x250DA: '',  # 𥃚
    # 0x250DB: '',  # 𥃛
    0x250DC: 'qú',  # 𥃜
    # 0x250DD: '',  # 𥃝
    # 0x250DE: '',  # 𥃞
    0x250DF: 'qīng',  # 𥃟
    0x250E0: 'yì',  # 𥃠
    # 0x250E1: '',  # 𥃡
    # 0x250E2: '',  # 𥃢
    0x250E3: 'kǎi',  # 𥃣
    0x250E4: 'jiǎo',  # 𥃤
    # 0x250E5: '',  # 𥃥
    # 0x250E6: '',  # 𥃦
    0x250E7: 'chōu,jiǎo,yǎo',  # 𥃧
    0x250E8: 'bǔ',  # 𥃨
    0x250E9: 'gèn,yǎn',  # 𥃩
    0x250EA: 'jiāo',  # 𥃪
    0x250EB: 'zhī',  # 𥃫
    # 0x250EC: '',  # 𥃬
    # 0x250ED: '',  # 𥃭
    0x250EE: 'wèn',  # 𥃮
    0x250EF: 'yào',  # 𥃯
    0x250F0: 'bīn',  # 𥃰
    # 0x250F1: '',  # 𥃱
    # 0x250F2: '',  # 𥃲
    # 0x250F3: '',  # 𥃳
    0x250F4: 'xiòng',  # 𥃴
    0x250F5: 'fàn',  # 𥃵
    # 0x250F6: '',  # 𥃶
    # 0x250F7: '',  # 𥃷
    0x250F8: 'yí',  # 𥃸
    0x250F9: 'chuàn',  # 𥃹
    0x250FA: 'yào',  # 𥃺
    # 0x250FB: '',  # 𥃻
    # 0x250FC: '',  # 𥃼
    0x250FD: 'yāng',  # 𥃽
    0x250FE: 'dù',  # 𥃾
    0x250FF: 'yǎn',  # 𥃿
    # 0x25100: '',  # 𥄀
    0x25101: 'méng',  # 𥄁
    # 0x25102: '',  # 𥄂
    # 0x25103: '',  # 𥄃
    # 0x25104: '',  # 𥄄
    # 0x25105: '',  # 𥄅
    # 0x25106: '',  # 𥄆
    0x25107: 'chī,hūn',  # 𥄇
    0x25108: 'mù',  # 𥄈
    0x25109: 'jiāo',  # 𥄉
    # 0x2510A: '',  # 𥄊
    0x2510B: 'nǜ',  # 𥄋
    # 0x2510C: '',  # 𥄌
    0x2510D: 'guó',  # 𥄍
    0x2510E: 'xuè',  # 𥄎
    # 0x2510F: '',  # 𥄏
    # 0x25110: '',  # 𥄐
    0x25111: 'fú',  # 𥄑
    0x25112: 'xuē',  # 𥄒
    0x25113: 'fū',  # 𥄓
    0x25114: 'pèi,pò',  # 𥄔
    0x25115: 'mò',  # 𥄕
    0x25116: 'xī',  # 𥄖
    0x25117: 'wò,nài',  # 𥄗
    0x25118: 'shǎn',  # 𥄘
    # 0x25119: '',  # 𥄙
    # 0x2511A: '',  # 𥄚
    0x2511B: 'xī',  # 𥄛
    0x2511C: 'qì',  # 𥄜
    0x2511D: 'miàn',  # 𥄝
    # 0x2511E: '',  # 𥄞
    # 0x2511F: '',  # 𥄟
    # 0x25120: '',  # 𥄠
    # 0x25121: '',  # 𥄡
    0x25122: 'xiāng',  # 𥄢
    # 0x25123: '',  # 𥄣
    # 0x25124: '',  # 𥄤
    # 0x25125: '',  # 𥄥
    0x25126: 'dǎn',  # 𥄦
    # 0x25127: '',  # 𥄧
    # 0x25128: '',  # 𥄨
    # 0x25129: '',  # 𥄩
    # 0x2512A: '',  # 𥄪
    0x2512B: 'jí',  # 𥄫
    # 0x2512C: '',  # 𥄬
    # 0x2512D: '',  # 𥄭
    # 0x2512E: '',  # 𥄮
    # 0x2512F: '',  # 𥄯
    # 0x25130: '',  # 𥄰
    0x25131: 'fèi',  # 𥄱
    0x25132: 'mié',  # 𥄲
    # 0x25133: '',  # 𥄳
    0x25134: 'xuè,jué',  # 𥄴
    0x25135: 'xù,yù',  # 𥄵
    0x25136: 'sī',  # 𥄶
    0x25137: 'jǔ',  # 𥄷
    0x25138: 'mǎo',  # 𥄸
    0x25139: 'bào',  # 𥄹
    # 0x2513A: '',  # 𥄺
    0x2513B: 'yí',  # 𥄻
    0x2513C: 'guā',  # 𥄼
    0x2513D: 'nì',  # 𥄽
    # 0x2513E: '',  # 𥄾
    0x2513F: 'yí,dì',  # 𥄿
    # 0x25140: '',  # 𥅀
    0x25141: 'zuò',  # 𥅁
    # 0x25142: '',  # 𥅂
    # 0x25143: '',  # 𥅃
    0x25144: 'nǔ',  # 𥅄
    # 0x25145: '',  # 𥅅
    # 0x25146: '',  # 𥅆
    # 0x25147: '',  # 𥅇
    # 0x25148: '',  # 𥅈
    # 0x25149: '',  # 𥅉
    # 0x2514A: '',  # 𥅊
    # 0x2514B: '',  # 𥅋
    # 0x2514C: '',  # 𥅌
    # 0x2514D: '',  # 𥅍
    # 0x2514E: '',  # 𥅎
    # 0x2514F: '',  # 𥅏
    # 0x25150: '',  # 𥅐
    0x25151: 'diàn',  # 𥅑
    0x25152: 'fàn',  # 𥅒
    0x25153: 'yì',  # 𥅓
    0x25154: 'shì',  # 𥅔
    # 0x25155: '',  # 𥅕
    # 0x25156: '',  # 𥅖
    0x25157: 'cū',  # 𥅗
    0x25158: 'zhěn,mí',  # 𥅘
    # 0x25159: '',  # 𥅙
    # 0x2515A: '',  # 𥅚
    # 0x2515B: '',  # 𥅛
    # 0x2515C: '',  # 𥅜
    # 0x2515D: '',  # 𥅝
    0x2515E: 'shì',  # 𥅞
    0x2515F: 'jiǎo',  # 𥅟
    0x25160: 'hòu',  # 𥅠
    0x25161: 'ér',  # 𥅡
    # 0x25162: '',  # 𥅢
    # 0x25163: '',  # 𥅣
    # 0x25164: '',  # 𥅤
    # 0x25165: '',  # 𥅥
    0x25166: 'lèi',  # 𥅦
    0x25167: 'xuè',  # 𥅧
    0x25168: 'gèng',  # 𥅨
    # 0x25169: '',  # 𥅩
    0x2516A: 'shōu',  # 𥅪
    # 0x2516B: '',  # 𥅫
    0x2516C: 'juān',  # 𥅬
    # 0x2516D: '',  # 𥅭
    # 0x2516E: '',  # 𥅮
    # 0x2516F: '',  # 𥅯
    # 0x25170: '',  # 𥅰
    # 0x25171: '',  # 𥅱
    # 0x25172: '',  # 𥅲
    # 0x25173: '',  # 𥅳
    # 0x25174: '',  # 𥅴
    0x25175: 'wéi',  # 𥅵
    # 0x25176: '',  # 𥅶
    0x25177: 'shǒu',  # 𥅷
    0x25178: 'jìng',  # 𥅸
    # 0x25179: '',  # 𥅹
    0x2517A: 'xú',  # 𥅺
    0x2517B: 'chòng',  # 𥅻
    # 0x2517C: '',  # 𥅼
    0x2517D: 'mì',  # 𥅽
    # 0x2517E: '',  # 𥅾
    # 0x2517F: '',  # 𥅿
    # 0x25180: '',  # 𥆀
    # 0x25181: '',  # 𥆁
    # 0x25182: '',  # 𥆂
    # 0x25183: '',  # 𥆃
    # 0x25184: '',  # 𥆄
    0x25185: 'jiāng',  # 𥆅
    0x25186: 'mòu',  # 𥆆
    # 0x25187: '',  # 𥆇
    # 0x25188: '',  # 𥆈
    0x25189: 'yù',  # 𥆉
    # 0x2518A: '',  # 𥆊
    # 0x2518B: '',  # 𥆋
    0x2518C: 'jué',  # 𥆌
    # 0x2518D: '',  # 𥆍
    # 0x2518E: '',  # 𥆎
    # 0x2518F: '',  # 𥆏
    # 0x25190: '',  # 𥆐
    0x25191: 'tìng',  # 𥆑
    # 0x25192: '',  # 𥆒
    # 0x25193: '',  # 𥆓
    0x25194: 'xiāo',  # 𥆔
    # 0x25195: '',  # 𥆕
    0x25196: 'dōu',  # 𥆖
    # 0x25197: '',  # 𥆗
    0x25198: 'guó',  # 𥆘
    0x25199: 'máng',  # 𥆙
    0x2519A: 'wāng',  # 𥆚
    0x2519B: 'xù',  # 𥆛
    0x2519C: 'wàng',  # 𥆜
    0x2519D: 'suō',  # 𥆝
    0x2519E: 'juàn',  # 𥆞
    0x2519F: 'yuè',  # 𥆟
    # 0x251A0: '',  # 𥆠
    0x251A1: 'hán',  # 𥆡
    # 0x251A2: '',  # 𥆢
    0x251A3: 'shēn',  # 𥆣
    # 0x251A4: '',  # 𥆤
    0x251A5: 'xié',  # 𥆥
    0x251A6: 'liú',  # 𥆦
    # 0x251A7: '',  # 𥆧
    # 0x251A8: '',  # 𥆨
    # 0x251A9: '',  # 𥆩
    # 0x251AA: '',  # 𥆪
    # 0x251AB: '',  # 𥆫
    # 0x251AC: '',  # 𥆬
    # 0x251AD: '',  # 𥆭
    # 0x251AE: '',  # 𥆮
    0x251AF: 'bì',  # 𥆯
    # 0x251B0: '',  # 𥆰
    # 0x251B1: '',  # 𥆱
    0x251B2: 'nào',  # 𥆲
    0x251B3: 'dū',  # 𥆳
    # 0x251B4: '',  # 𥆴
    # 0x251B5: '',  # 𥆵
    0x251B6: 'wàn',  # 𥆶
    0x251B7: 'jiù',  # 𥆷
    0x251B8: 'quē',  # 𥆸
    # 0x251B9: '',  # 𥆹
    # 0x251BA: '',  # 𥆺
    # 0x251BB: '',  # 𥆻
    # 0x251BC: '',  # 𥆼
    # 0x251BD: '',  # 𥆽
    # 0x251BE: '',  # 𥆾
    # 0x251BF: '',  # 𥆿
    # 0x251C0: '',  # 𥇀
    # 0x251C1: '',  # 𥇁
    # 0x251C2: '',  # 𥇂
    # 0x251C3: '',  # 𥇃
    0x251C4: 'nì',  # 𥇄
    # 0x251C5: '',  # 𥇅
    0x251C6: 'mí',  # 𥇆
    0x251C7: 'suō',  # 𥇇
    # 0x251C8: '',  # 𥇈
    0x251C9: 'qiǎng',  # 𥇉
    # 0x251CA: '',  # 𥇊
    # 0x251CB: '',  # 𥇋
    0x251CC: 'hàn,qià',  # 𥇌
    0x251CD: 'zhuó',  # 𥇍
    0x251CE: 'mí',  # 𥇎
    0x251CF: 'xù',  # 𥇏
    # 0x251D0: '',  # 𥇐
    0x251D1: 'lǎng',  # 𥇑
    0x251D2: 'jié',  # 𥇒
    0x251D3: 'dìng',  # 𥇓
    0x251D4: 'chàng,zhāng',  # 𥇔
    0x251D5: 'zhì',  # 𥇕
    0x251D6: 'fēi',  # 𥇖
    0x251D7: 'jiá',  # 𥇗
    0x251D8: 'jùn',  # 𥇘
    0x251D9: 'huò',  # 𥇙
    0x251DA: 'qī',  # 𥇚
    0x251DB: 'jū,jù,xì',  # 𥇛
    0x251DC: 'zhūn,guō',  # 𥇜
    # 0x251DD: '',  # 𥇝
    0x251DE: 'diàn',  # 𥇞
    0x251DF: 'jiǎo',  # 𥇟
    0x251E0: 'yā',  # 𥇠
    # 0x251E1: '',  # 𥇡
    # 0x251E2: '',  # 𥇢
    # 0x251E3: '',  # 𥇣
    # 0x251E4: '',  # 𥇤
    # 0x251E5: '',  # 𥇥
    # 0x251E6: '',  # 𥇦
    # 0x251E7: '',  # 𥇧
    # 0x251E8: '',  # 𥇨
    # 0x251E9: '',  # 𥇩
    # 0x251EA: '',  # 𥇪
    # 0x251EB: '',  # 𥇫
    # 0x251EC: '',  # 𥇬
    0x251ED: 'zhī',  # 𥇭
    # 0x251EE: '',  # 𥇮
    0x251EF: 'mài',  # 𥇯
    0x251F0: 'hū',  # 𥇰
    0x251F1: 'xiè',  # 𥇱
    0x251F2: 'shí',  # 𥇲
    0x251F3: 'guī',  # 𥇳
    # 0x251F4: '',  # 𥇴
    # 0x251F5: '',  # 𥇵
    # 0x251F6: '',  # 𥇶
    # 0x251F7: '',  # 𥇷
    # 0x251F8: '',  # 𥇸
    # 0x251F9: '',  # 𥇹
    # 0x251FA: '',  # 𥇺
    # 0x251FB: '',  # 𥇻
    # 0x251FC: '',  # 𥇼
    # 0x251FD: '',  # 𥇽
    # 0x251FE: '',  # 𥇾
    0x251FF: 'xù',  # 𥇿
    # 0x25200: '',  # 𥈀
    # 0x25201: '',  # 𥈁
    0x25202: 'jí',  # 𥈂
    # 0x25203: '',  # 𥈃
    0x25204: 'chuàng',  # 𥈄
    # 0x25205: '',  # 𥈅
    0x25206: 'mào',  # 𥈆
    0x25207: 'ruán',  # 𥈇
    0x25208: 'xū',  # 𥈈
    0x25209: 'huàn',  # 𥈉
    0x2520A: 'shà',  # 𥈊
    0x2520B: 'jǔ',  # 𥈋
    # 0x2520C: '',  # 𥈌
    # 0x2520D: '',  # 𥈍
    # 0x2520E: '',  # 𥈎
    0x2520F: 'kuàng',  # 𥈏
    # 0x25210: '',  # 𥈐
    0x25211: 'hóu',  # 𥈑
    0x25212: 'guān',  # 𥈒
    0x25213: 'guā',  # 𥈓
    # 0x25214: '',  # 𥈔
    0x25215: 'mí',  # 𥈕
    0x25216: 'dié',  # 𥈖
    0x25217: 'bì',  # 𥈗
    0x25218: 'liǎng',  # 𥈘
    0x25219: 'là',  # 𥈙
    0x2521A: 'shǎn',  # 𥈚
    0x2521B: 'lù',  # 𥈛
    0x2521C: 'xì',  # 𥈜
    # 0x2521D: '',  # 𥈝
    # 0x2521E: '',  # 𥈞
    0x2521F: 'sǒu',  # 𥈟
    # 0x25220: '',  # 𥈠
    # 0x25221: '',  # 𥈡
    # 0x25222: '',  # 𥈢
    # 0x25223: '',  # 𥈣
    # 0x25224: '',  # 𥈤
    # 0x25225: '',  # 𥈥
    # 0x25226: '',  # 𥈦
    # 0x25227: '',  # 𥈧
    # 0x25228: '',  # 𥈨
    # 0x25229: '',  # 𥈩
    # 0x2522A: '',  # 𥈪
    # 0x2522B: '',  # 𥈫
    0x2522C: 'ōu',  # 𥈬
    # 0x2522D: '',  # 𥈭
    0x2522E: 'léng',  # 𥈮
    # 0x2522F: '',  # 𥈯
    # 0x25230: '',  # 𥈰
    # 0x25231: '',  # 𥈱
    # 0x25232: '',  # 𥈲
    # 0x25233: '',  # 𥈳
    # 0x25234: '',  # 𥈴
    # 0x25235: '',  # 𥈵
    # 0x25236: '',  # 𥈶
    0x25237: 'kū',  # 𥈷
    0x25238: 'guī',  # 𥈸
    # 0x25239: '',  # 𥈹
    # 0x2523A: '',  # 𥈺
    0x2523B: 'xī',  # 𥈻
    0x2523C: 'pán,pān',  # 𥈼
    0x2523D: 'sè',  # 𥈽
    0x2523E: 'juè',  # 𥈾
    0x2523F: 'hòng',  # 𥈿
    0x25240: 'guàn',  # 𥉀
    0x25241: 'jù',  # 𥉁
    # 0x25242: '',  # 𥉂
    0x25243: 'nài',  # 𥉃
    0x25244: 'huá',  # 𥉄
    0x25245: 'gé',  # 𥉅
    0x25246: 'lì',  # 𥉆
    0x25247: 'gòu',  # 𥉇
    0x25248: 'tì',  # 𥉈
    # 0x25249: '',  # 𥉉
    0x2524A: 'mà',  # 𥉊
    0x2524B: 'téng',  # 𥉋
    0x2524C: 'dá',  # 𥉌
    # 0x2524D: '',  # 𥉍
    # 0x2524E: '',  # 𥉎
    # 0x2524F: '',  # 𥉏
    0x25250: 'qī',  # 𥉐
    0x25251: 'yù,hè',  # 𥉑
    0x25252: 'jiǎo',  # 𥉒
    0x25253: 'miè',  # 𥉓
    0x25254: 'gěng',  # 𥉔
    0x25255: 'mèng,méng',  # 𥉕
    0x25256: 'wèi',  # 𥉖
    # 0x25257: '',  # 𥉗
    0x25258: 'tí',  # 𥉘
    0x25259: 'qí',  # 𥉙
    # 0x2525A: '',  # 𥉚
    # 0x2525B: '',  # 𥉛
    0x2525C: 'chén',  # 𥉜
    0x2525D: 'dōu',  # 𥉝
    # 0x2525E: '',  # 𥉞
    0x2525F: 'pán',  # 𥉟
    # 0x25260: '',  # 𥉠
    # 0x25261: '',  # 𥉡
    # 0x25262: '',  # 𥉢
    # 0x25263: '',  # 𥉣
    # 0x25264: '',  # 𥉤
    # 0x25265: '',  # 𥉥
    # 0x25266: '',  # 𥉦
    # 0x25267: '',  # 𥉧
    # 0x25268: '',  # 𥉨
    # 0x25269: '',  # 𥉩
    # 0x2526A: '',  # 𥉪
    # 0x2526B: '',  # 𥉫
    # 0x2526C: '',  # 𥉬
    # 0x2526D: '',  # 𥉭
    # 0x2526E: '',  # 𥉮
    # 0x2526F: '',  # 𥉯
    0x25270: 'hàn,qià',  # 𥉰
    # 0x25271: '',  # 𥉱
    # 0x25272: '',  # 𥉲
    0x25273: 'liū',  # 𥉳
    0x25274: 'mì',  # 𥉴
    0x25275: 'má',  # 𥉵
    0x25276: 'lù',  # 𥉶
    0x25277: 'qī',  # 𥉷
    0x25278: 'kēng',  # 𥉸
    # 0x25279: '',  # 𥉹
    0x2527A: 'dié',  # 𥉺
    0x2527B: 'qì',  # 𥉻
    0x2527C: 'jiāo',  # 𥉼
    0x2527D: 'kāng',  # 𥉽
    0x2527E: 'qiāo',  # 𥉾
    0x2527F: 'mì',  # 𥉿
    0x25280: 'shān,sǎn',  # 𥊀
    # 0x25281: '',  # 𥊁
    # 0x25282: '',  # 𥊂
    # 0x25283: '',  # 𥊃
    # 0x25284: '',  # 𥊄
    # 0x25285: '',  # 𥊅
    # 0x25286: '',  # 𥊆
    0x25287: 'jiān',  # 𥊇
    0x25288: 'lí',  # 𥊈
    0x25289: 'kè',  # 𥊉
    0x2528A: 'xù',  # 𥊊
    # 0x2528B: '',  # 𥊋
    0x2528C: 'cháo',  # 𥊌
    # 0x2528D: '',  # 𥊍
    # 0x2528E: '',  # 𥊎
    # 0x2528F: '',  # 𥊏
    # 0x25290: '',  # 𥊐
    0x25291: 'mán,màn',  # 𥊑
    0x25292: 'fèng',  # 𥊒
    0x25293: 'chàn',  # 𥊓
    0x25294: 'huǐ',  # 𥊔
    # 0x25295: '',  # 𥊕
    # 0x25296: '',  # 𥊖
    # 0x25297: '',  # 𥊗
    # 0x25298: '',  # 𥊘
    # 0x25299: '',  # 𥊙
    # 0x2529A: '',  # 𥊚
    # 0x2529B: '',  # 𥊛
    # 0x2529C: '',  # 𥊜
    # 0x2529D: '',  # 𥊝
    # 0x2529E: '',  # 𥊞
    # 0x2529F: '',  # 𥊟
    # 0x252A0: '',  # 𥊠
    # 0x252A1: '',  # 𥊡
    # 0x252A2: '',  # 𥊢
    # 0x252A3: '',  # 𥊣
    # 0x252A4: '',  # 𥊤
    # 0x252A5: '',  # 𥊥
    # 0x252A6: '',  # 𥊦
    0x252A7: 'kòu',  # 𥊧
    # 0x252A8: '',  # 𥊨
    # 0x252A9: '',  # 𥊩
    0x252AA: 'wěi',  # 𥊪
    0x252AB: 'guàn',  # 𥊫
    0x252AC: 'jí',  # 𥊬
    0x252AD: 'zùn',  # 𥊭
    0x252AE: 'huò',  # 𥊮
    0x252AF: 'xié',  # 𥊯
    # 0x252B0: '',  # 𥊰
    # 0x252B1: '',  # 𥊱
    # 0x252B2: '',  # 𥊲
    # 0x252B3: '',  # 𥊳
    0x252B4: 'suì',  # 𥊴
    # 0x252B5: '',  # 𥊵
    0x252B6: 'ruǎn',  # 𥊶
    # 0x252B7: '',  # 𥊷
    0x252B8: 'tè',  # 𥊸
    # 0x252B9: '',  # 𥊹
    # 0x252BA: '',  # 𥊺
    # 0x252BB: '',  # 𥊻
    0x252BC: 'zhèng',  # 𥊼
    0x252BD: 'kūn',  # 𥊽
    0x252BE: 'xiǎng',  # 𥊾
    0x252BF: 'mián',  # 𥊿
    # 0x252C0: '',  # 𥋀
    0x252C1: 'xì',  # 𥋁
    # 0x252C2: '',  # 𥋂
    # 0x252C3: '',  # 𥋃
    # 0x252C4: '',  # 𥋄
    # 0x252C5: '',  # 𥋅
    # 0x252C6: '',  # 𥋆
    0x252C7: 'chèng',  # 𥋇
    # 0x252C8: '',  # 𥋈
    # 0x252C9: '',  # 𥋉
    # 0x252CA: '',  # 𥋊
    # 0x252CB: '',  # 𥋋
    0x252CC: 'sā',  # 𥋌
    # 0x252CD: '',  # 𥋍
    0x252CE: 'mèi',  # 𥋎
    # 0x252CF: '',  # 𥋏
    # 0x252D0: '',  # 𥋐
    # 0x252D1: '',  # 𥋑
    # 0x252D2: '',  # 𥋒
    # 0x252D3: '',  # 𥋓
    # 0x252D4: '',  # 𥋔
    # 0x252D5: '',  # 𥋕
    # 0x252D6: '',  # 𥋖
    # 0x252D7: '',  # 𥋗
    # 0x252D8: '',  # 𥋘
    0x252D9: 'è',  # 𥋙
    0x252DA: 'miè',  # 𥋚
    0x252DB: 'zhǔ',  # 𥋛
    0x252DC: 'zōu',  # 𥋜
    0x252DD: 'měng',  # 𥋝
    # 0x252DE: '',  # 𥋞
    0x252DF: 'xī',  # 𥋟
    # 0x252E0: '',  # 𥋠
    0x252E1: 'táng',  # 𥋡
    # 0x252E2: '',  # 𥋢
    0x252E3: 'jià',  # 𥋣
    0x252E4: 'cháng',  # 𥋤
    0x252E5: 'jí',  # 𥋥
    # 0x252E6: '',  # 𥋦
    # 0x252E7: '',  # 𥋧
    # 0x252E8: '',  # 𥋨
    # 0x252E9: '',  # 𥋩
    # 0x252EA: '',  # 𥋪
    # 0x252EB: '',  # 𥋫
    # 0x252EC: '',  # 𥋬
    # 0x252ED: '',  # 𥋭
    0x252EE: 'zhuó',  # 𥋮
    # 0x252EF: '',  # 𥋯
    # 0x252F0: '',  # 𥋰
    # 0x252F1: '',  # 𥋱
    # 0x252F2: '',  # 𥋲
    # 0x252F3: '',  # 𥋳
    # 0x252F4: '',  # 𥋴
    # 0x252F5: '',  # 𥋵
    # 0x252F6: '',  # 𥋶
    # 0x252F7: '',  # 𥋷
    # 0x252F8: '',  # 𥋸
    # 0x252F9: '',  # 𥋹
    # 0x252FA: '',  # 𥋺
    # 0x252FB: '',  # 𥋻
    # 0x252FC: '',  # 𥋼
    # 0x252FD: '',  # 𥋽
    # 0x252FE: '',  # 𥋾
    0x252FF: 'hè',  # 𥋿
    0x25300: 'chá',  # 𥌀
    0x25301: 'qì',  # 𥌁
    0x25302: 'mián',  # 𥌂
    # 0x25303: '',  # 𥌃
    0x25304: 'kū',  # 𥌄
    0x25305: 'yè',  # 𥌅
    0x25306: 'zhōu',  # 𥌆
    # 0x25307: '',  # 𥌇
    0x25308: 'jiān',  # 𥌈
    # 0x25309: '',  # 𥌉
    0x2530A: 'pàn',  # 𥌊
    # 0x2530B: '',  # 𥌋
    # 0x2530C: '',  # 𥌌
    0x2530D: 'huī',  # 𥌍
    # 0x2530E: '',  # 𥌎
    0x2530F: 'míng',  # 𥌏
    0x25310: 'liù',  # 𥌐
    # 0x25311: '',  # 𥌑
    # 0x25312: '',  # 𥌒
    # 0x25313: '',  # 𥌓
    # 0x25314: '',  # 𥌔
    # 0x25315: '',  # 𥌕
    # 0x25316: '',  # 𥌖
    # 0x25317: '',  # 𥌗
    0x25318: 'shuì',  # 𥌘
    # 0x25319: '',  # 𥌙
    0x2531A: 'mài,yá,shù',  # 𥌚
    0x2531B: 'lí',  # 𥌛
    # 0x2531C: '',  # 𥌜
    # 0x2531D: '',  # 𥌝
    0x2531E: 'shuò',  # 𥌞
    0x2531F: 'yí',  # 𥌟
    # 0x25320: '',  # 𥌠
    # 0x25321: '',  # 𥌡
    # 0x25322: '',  # 𥌢
    # 0x25323: '',  # 𥌣
    0x25324: 'lì',  # 𥌤
    # 0x25325: '',  # 𥌥
    # 0x25326: '',  # 𥌦
    # 0x25327: '',  # 𥌧
    0x25328: 'xiē,miè',  # 𥌨
    0x25329: 'tè',  # 𥌩
    0x2532A: 'xiū',  # 𥌪
    # 0x2532B: '',  # 𥌫
    # 0x2532C: '',  # 𥌬
    0x2532D: 'xuàn',  # 𥌭
    0x2532E: 'lì',  # 𥌮
    0x2532F: 'méng',  # 𥌯
    0x25330: 'wéi',  # 𥌰
    0x25331: 'méng',  # 𥌱
    # 0x25332: '',  # 𥌲
    # 0x25333: '',  # 𥌳
    # 0x25334: '',  # 𥌴
    # 0x25335: '',  # 𥌵
    # 0x25336: '',  # 𥌶
    # 0x25337: '',  # 𥌷
    # 0x25338: '',  # 𥌸
    # 0x25339: '',  # 𥌹
    0x2533A: 'yào',  # 𥌺
    0x2533B: 'lán',  # 𥌻
    0x2533C: 'líng',  # 𥌼
    0x2533D: 'yīng',  # 𥌽
    0x2533E: 'yīng',  # 𥌾
    0x2533F: 'lì',  # 𥌿
    0x25340: 'jiǎn',  # 𥍀
    0x25341: 'guī,guì',  # 𥍁
    # 0x25342: '',  # 𥍂
    # 0x25343: '',  # 𥍃
    # 0x25344: '',  # 𥍄
    0x25345: 'guān',  # 𥍅
    0x25346: 'xiè',  # 𥍆
    # 0x25347: '',  # 𥍇
    # 0x25348: '',  # 𥍈
    0x25349: 'shè',  # 𥍉
    # 0x2534A: '',  # 𥍊
    0x2534B: 'zuī,xiē,huǐ',  # 𥍋
    # 0x2534C: '',  # 𥍌
    # 0x2534D: '',  # 𥍍
    # 0x2534E: '',  # 𥍎
    # 0x2534F: '',  # 𥍏
    # 0x25350: '',  # 𥍐
    # 0x25351: '',  # 𥍑
    # 0x25352: '',  # 𥍒
    0x25353: 'kàn,yǎn',  # 𥍓
    0x25354: 'léi',  # 𥍔
    # 0x25355: '',  # 𥍕
    # 0x25356: '',  # 𥍖
    # 0x25357: '',  # 𥍗
    # 0x25358: '',  # 𥍘
    # 0x25359: '',  # 𥍙
    0x2535A: 'biàn',  # 𥍚
    # 0x2535B: '',  # 𥍛
    # 0x2535C: '',  # 𥍜
    0x2535D: 'shǔ',  # 𥍝
    0x2535E: 'nǜ',  # 𥍞
    0x2535F: 'xù,yì',  # 𥍟
    # 0x25360: '',  # 𥍠
    # 0x25361: '',  # 𥍡
    # 0x25362: '',  # 𥍢
    0x25363: 'hào',  # 𥍣
    # 0x25364: '',  # 𥍤
    # 0x25365: '',  # 𥍥
    # 0x25366: '',  # 𥍦
    # 0x25367: '',  # 𥍧
    0x25368: 'guǐ',  # 𥍨
    # 0x25369: '',  # 𥍩
    0x2536A: 'zhài',  # 𥍪
    0x2536B: 'láng',  # 𥍫
    0x2536C: 'cuān',  # 𥍬
    0x2536D: 'zhì',  # 𥍭
    0x2536E: 'féng,fēng',  # 𥍮
    0x2536F: 'qīn',  # 𥍯
    # 0x25370: '',  # 𥍰
    0x25371: 'zé',  # 𥍱
    0x25372: 'nà',  # 𥍲
    0x25373: 'niǔ',  # 𥍳
    0x25374: 'yì',  # 𥍴
    # 0x25375: '',  # 𥍵
    # 0x25376: '',  # 𥍶
    0x25377: 'cōng',  # 𥍷
    0x25378: 'shī',  # 𥍸
    0x25379: 'jiǎn',  # 𥍹
    0x2537A: 'zōng',  # 𥍺
    0x2537B: 'yǎn',  # 𥍻
    0x2537C: 'yīng',  # 𥍼
    # 0x2537D: '',  # 𥍽
    # 0x2537E: '',  # 𥍾
    # 0x2537F: '',  # 𥍿
    0x25380: 'ruǎn',  # 𥎀
    # 0x25381: '',  # 𥎁
    0x25382: 'róng',  # 𥎂
    0x25383: 'xì',  # 𥎃
    # 0x25384: '',  # 𥎄
    0x25385: 'guān',  # 𥎅
    0x25386: 'kài',  # 𥎆
    # 0x25387: '',  # 𥎇
    0x25388: 'wù',  # 𥎈
    # 0x25389: '',  # 𥎉
    0x2538A: 'qín',  # 𥎊
    0x2538B: 'cōng',  # 𥎋
    # 0x2538C: '',  # 𥎌
    0x2538D: 'zé',  # 𥎍
    0x2538E: 'xiè',  # 𥎎
    # 0x2538F: '',  # 𥎏
    0x25390: 'yù',  # 𥎐
    0x25391: 'zàn',  # 𥎑
    0x25392: 'chuāng',  # 𥎒
    0x25393: 'lǐ',  # 𥎓
    0x25394: 'lǐ',  # 𥎔
    0x25395: 'xù',  # 𥎕
    0x25396: 'mí',  # 𥎖
    0x25397: 'xù',  # 𥎗
    0x25398: 'ruǎn',  # 𥎘
    # 0x25399: '',  # 𥎙
    # 0x2539A: '',  # 𥎚
    0x2539B: 'guì',  # 𥎛
    0x2539C: 'rǒng',  # 𥎜
    # 0x2539D: '',  # 𥎝
    # 0x2539E: '',  # 𥎞
    0x2539F: 'máo',  # 𥎟
    # 0x253A0: '',  # 𥎠
    0x253A1: 'qín',  # 𥎡
    0x253A2: 'cuàn',  # 𥎢
    0x253A3: 'cuàn',  # 𥎣
    0x253A4: 'cuàn',  # 𥎤
    # 0x253A5: '',  # 𥎥
    # 0x253A6: '',  # 𥎦
    # 0x253A7: '',  # 𥎧
    # 0x253A8: '',  # 𥎨
    # 0x253A9: '',  # 𥎩
    0x253AA: 'shěn',  # 𥎪
    # 0x253AB: '',  # 𥎫
    # 0x253AC: '',  # 𥎬
    # 0x253AD: '',  # 𥎭
    0x253AE: 'wū',  # 𥎮
    # 0x253AF: '',  # 𥎯
    0x253B0: 'fǎ',  # 𥎰
    0x253B1: 'bá',  # 𥎱
    # 0x253B2: '',  # 𥎲
    # 0x253B3: '',  # 𥎳
    # 0x253B4: '',  # 𥎴
    # 0x253B5: '',  # 𥎵
    # 0x253B6: '',  # 𥎶
    # 0x253B7: '',  # 𥎷
    0x253B8: 'qià',  # 𥎸
    0x253B9: 'zhì',  # 𥎹
    0x253BA: 'tiào',  # 𥎺
    # 0x253BB: '',  # 𥎻
    # 0x253BC: '',  # 𥎼
    # 0x253BD: '',  # 𥎽
    # 0x253BE: '',  # 𥎾
    # 0x253BF: '',  # 𥎿
    # 0x253C0: '',  # 𥏀
    # 0x253C1: '',  # 𥏁
    # 0x253C2: '',  # 𥏂
    # 0x253C3: '',  # 𥏃
    0x253C4: 'zhì',  # 𥏄
    0x253C5: 'zhí',  # 𥏅
    # 0x253C6: '',  # 𥏆
    0x253C7: 'huàn',  # 𥏇
    0x253C8: 'chóu',  # 𥏈
    # 0x253C9: '',  # 𥏉
    0x253CA: 'zhì',  # 𥏊
    # 0x253CB: '',  # 𥏋
    # 0x253CC: '',  # 𥏌
    # 0x253CD: '',  # 𥏍
    0x253CE: 'yǐng',  # 𥏎
    # 0x253CF: '',  # 𥏏
    # 0x253D0: '',  # 𥏐
    # 0x253D1: '',  # 𥏑
    0x253D2: 'wù',  # 𥏒
    0x253D3: 'bēi',  # 𥏓
    # 0x253D4: '',  # 𥏔
    0x253D5: 'hóng',  # 𥏕
    0x253D6: 'shěn',  # 𥏖
    # 0x253D7: '',  # 𥏗
    0x253D8: 'jué',  # 𥏘
    0x253D9: 'kuì',  # 𥏙
    # 0x253DA: '',  # 𥏚
    # 0x253DB: '',  # 𥏛
    0x253DC: 'yǐ',  # 𥏜
    0x253DD: 'yà',  # 𥏝
    # 0x253DE: '',  # 𥏞
    # 0x253DF: '',  # 𥏟
    0x253E0: 'bī',  # 𥏠
    # 0x253E1: '',  # 𥏡
    # 0x253E2: '',  # 𥏢
    # 0x253E3: '',  # 𥏣
    0x253E4: 'kuà',  # 𥏤
    0x253E5: 'qiān',  # 𥏥
    # 0x253E6: '',  # 𥏦
    # 0x253E7: '',  # 𥏧
    0x253E8: 'zhāo',  # 𥏨
    # 0x253E9: '',  # 𥏩
    0x253EA: 'kǎi',  # 𥏪
    0x253EB: 'shāng',  # 𥏫
    # 0x253EC: '',  # 𥏬
    # 0x253ED: '',  # 𥏭
    0x253EE: 'àn',  # 𥏮
    0x253EF: 'zhé',  # 𥏯
    0x253F0: 'zhì',  # 𥏰
    # 0x253F1: '',  # 𥏱
    # 0x253F2: '',  # 𥏲
    # 0x253F3: '',  # 𥏳
    # 0x253F4: '',  # 𥏴
    # 0x253F5: '',  # 𥏵
    # 0x253F6: '',  # 𥏶
    0x253F7: 'zhì',  # 𥏷
    # 0x253F8: '',  # 𥏸
    0x253F9: 'jiǎo',  # 𥏹
    # 0x253FA: '',  # 𥏺
    # 0x253FB: '',  # 𥏻
    # 0x253FC: '',  # 𥏼
    # 0x253FD: '',  # 𥏽
    # 0x253FE: '',  # 𥏾
    # 0x253FF: '',  # 𥏿
    0x25400: 'sī',  # 𥐀
    0x25401: 'pú',  # 𥐁
    0x25402: 'ǒu',  # 𥐂
    # 0x25403: '',  # 𥐃
    # 0x25404: '',  # 𥐄
    # 0x25405: '',  # 𥐅
    # 0x25406: '',  # 𥐆
    # 0x25407: '',  # 𥐇
    # 0x25408: '',  # 𥐈
    # 0x25409: '',  # 𥐉
    0x2540A: 'zhuó',  # 𥐊
    # 0x2540B: '',  # 𥐋
    # 0x2540C: '',  # 𥐌
    # 0x2540D: '',  # 𥐍
    # 0x2540E: '',  # 𥐎
    # 0x2540F: '',  # 𥐏
    # 0x25410: '',  # 𥐐
    0x25411: 'yīng',  # 𥐑
    # 0x25412: '',  # 𥐒
    0x25413: 'huān',  # 𥐓
    # 0x25414: '',  # 𥐔
    0x25415: 'yà',  # 𥐕
    # 0x25416: '',  # 𥐖
    # 0x25417: '',  # 𥐗
    0x25418: 'shí',  # 𥐘
    0x25419: 'pā,bā',  # 𥐙
    0x2541A: 'pǔ',  # 𥐚
    # 0x2541B: '',  # 𥐛
    # 0x2541C: '',  # 𥐜
    # 0x2541D: '',  # 𥐝
    0x2541E: 'máng',  # 𥐞
    0x2541F: 'chāi',  # 𥐟
    # 0x25420: '',  # 𥐠
    # 0x25421: '',  # 𥐡
    # 0x25422: '',  # 𥐢
    # 0x25423: '',  # 𥐣
    # 0x25424: '',  # 𥐤
    # 0x25425: '',  # 𥐥
    # 0x25426: '',  # 𥐦
    # 0x25427: '',  # 𥐧
    # 0x25428: '',  # 𥐨
    0x25429: 'yún',  # 𥐩
    # 0x2542A: '',  # 𥐪
    # 0x2542B: '',  # 𥐫
    0x2542C: 'gǔ',  # 𥐬
    # 0x2542D: '',  # 𥐭
    # 0x2542E: '',  # 𥐮
    # 0x2542F: '',  # 𥐯
    0x25430: 'qū',  # 𥐰
    # 0x25431: '',  # 𥐱
    # 0x25432: '',  # 𥐲
    # 0x25433: '',  # 𥐳
    # 0x25434: '',  # 𥐴
    # 0x25435: '',  # 𥐵
    # 0x25436: '',  # 𥐶
    # 0x25437: '',  # 𥐷
    # 0x25438: '',  # 𥐸
    0x25439: 'dǎn',  # 𥐹
    # 0x2543A: '',  # 𥐺
    # 0x2543B: '',  # 𥐻
    # 0x2543C: '',  # 𥐼
    0x2543D: 'zhé',  # 𥐽
    # 0x2543E: '',  # 𥐾
    0x2543F: 'hú',  # 𥐿
    # 0x25440: '',  # 𥑀
    # 0x25441: '',  # 𥑁
    # 0x25442: '',  # 𥑂
    # 0x25443: '',  # 𥑃
    # 0x25444: '',  # 𥑄
    0x25445: 'kēng',  # 𥑅
    # 0x25446: '',  # 𥑆
    0x25447: 'dié',  # 𥑇
    0x25448: 'tīng',  # 𥑈
    # 0x25449: '',  # 𥑉
    # 0x2544A: '',  # 𥑊
    0x2544B: 'guài',  # 𥑋
    # 0x2544C: '',  # 𥑌
    # 0x2544D: '',  # 𥑍
    0x2544E: 'qiōng',  # 𥑎
    0x2544F: 'shǐ',  # 𥑏
    0x25450: 'jiǎ',  # 𥑐
    0x25451: 'ào',  # 𥑑
    0x25452: 'nǎ,kēng',  # 𥑒
    0x25453: 'pǐn',  # 𥑓
    0x25454: 'jiá',  # 𥑔
    # 0x25455: '',  # 𥑕
    # 0x25456: '',  # 𥑖
    # 0x25457: '',  # 𥑗
    # 0x25458: '',  # 𥑘
    # 0x25459: '',  # 𥑙
    # 0x2545A: '',  # 𥑚
    # 0x2545B: '',  # 𥑛
    # 0x2545C: '',  # 𥑜
    # 0x2545D: '',  # 𥑝
    # 0x2545E: '',  # 𥑞
    # 0x2545F: '',  # 𥑟
    # 0x25460: '',  # 𥑠
    0x25461: 'zhè',  # 𥑡
    0x25462: 'bù',  # 𥑢
    0x25463: 'wǒ',  # 𥑣
    # 0x25464: '',  # 𥑤
    0x25465: 'chǎ',  # 𥑥
    # 0x25466: '',  # 𥑦
    # 0x25467: '',  # 𥑧
    0x25468: 'náo',  # 𥑨
    0x25469: 'náo',  # 𥑩
    0x2546A: 'náo',  # 𥑪
    0x2546B: 'kǎn',  # 𥑫
    # 0x2546C: '',  # 𥑬
    # 0x2546D: '',  # 𥑭
    # 0x2546E: '',  # 𥑮
    0x2546F: 'dú',  # 𥑯
    0x25470: 'guài',  # 𥑰
    0x25471: 'qióng',  # 𥑱
    # 0x25472: '',  # 𥑲
    0x25473: 'róng',  # 𥑳
    0x25474: 'yǐ',  # 𥑴
    0x25475: 'duī',  # 𥑵
    0x25476: 'lěi',  # 𥑶
    # 0x25477: '',  # 𥑷
    0x25478: 'zhōu',  # 𥑸
    0x25479: 'kuā',  # 𥑹
    0x2547A: 'ē',  # 𥑺
    0x2547B: 'xiān',  # 𥑻
    0x2547C: 'diàn',  # 𥑼
    0x2547D: 'nuò',  # 𥑽
    0x2547E: 'è',  # 𥑾
    0x2547F: 'yōng',  # 𥑿
    0x25480: 'wù',  # 𥒀
    0x25481: 'kēng',  # 𥒁
    # 0x25482: '',  # 𥒂
    # 0x25483: '',  # 𥒃
    # 0x25484: '',  # 𥒄
    # 0x25485: '',  # 𥒅
    # 0x25486: '',  # 𥒆
    # 0x25487: '',  # 𥒇
    # 0x25488: '',  # 𥒈
    # 0x25489: '',  # 𥒉
    # 0x2548A: '',  # 𥒊
    # 0x2548B: '',  # 𥒋
    # 0x2548C: '',  # 𥒌
    # 0x2548D: '',  # 𥒍
    # 0x2548E: '',  # 𥒎
    # 0x2548F: '',  # 𥒏
    # 0x25490: '',  # 𥒐
    # 0x25491: '',  # 𥒑
    # 0x25492: '',  # 𥒒
    0x25493: 'zhì',  # 𥒓
    # 0x25494: '',  # 𥒔
    # 0x25495: '',  # 𥒕
    # 0x25496: '',  # 𥒖
    0x25497: 'zhǐ',  # 𥒗
    0x25498: 'xún',  # 𥒘
    # 0x25499: '',  # 𥒙
    # 0x2549A: '',  # 𥒚
    0x2549B: 'zhèng',  # 𥒛
    # 0x2549C: '',  # 𥒜
    # 0x2549D: '',  # 𥒝
    0x2549E: 'yáng',  # 𥒞
    # 0x2549F: '',  # 𥒟
    0x254A0: 'huò',  # 𥒠
    0x254A1: 'jí',  # 𥒡
    0x254A2: 'nǎo,lì',  # 𥒢
    # 0x254A3: '',  # 𥒣
    # 0x254A4: '',  # 𥒤
    0x254A5: 'jiù',  # 𥒥
    # 0x254A6: '',  # 𥒦
    0x254A7: 'yà',  # 𥒧
    0x254A8: 'lù',  # 𥒨
    # 0x254A9: '',  # 𥒩
    # 0x254AA: '',  # 𥒪
    0x254AB: 'fū',  # 𥒫
    0x254AC: 'sǎn',  # 𥒬
    0x254AD: 'chù',  # 𥒭
    0x254AE: 'wěi',  # 𥒮
    # 0x254AF: '',  # 𥒯
    0x254B0: 'fǔ',  # 𥒰
    0x254B1: 'kēng',  # 𥒱
    0x254B2: 'sì',  # 𥒲
    0x254B3: 'kàng',  # 𥒳
    # 0x254B4: '',  # 𥒴
    0x254B5: 'yì',  # 𥒵
    0x254B6: 'huà',  # 𥒶
    # 0x254B7: '',  # 𥒷
    # 0x254B8: '',  # 𥒸
    # 0x254B9: '',  # 𥒹
    # 0x254BA: '',  # 𥒺
    # 0x254BB: '',  # 𥒻
    # 0x254BC: '',  # 𥒼
    # 0x254BD: '',  # 𥒽
    0x254BE: 'yǔ',  # 𥒾
    # 0x254BF: '',  # 𥒿
    # 0x254C0: '',  # 𥓀
    # 0x254C1: '',  # 𥓁
    # 0x254C2: '',  # 𥓂
    0x254C3: 'lì',  # 𥓃
    # 0x254C4: '',  # 𥓄
    # 0x254C5: '',  # 𥓅
    0x254C6: 'lǐn',  # 𥓆
    0x254C7: 'dǔ',  # 𥓇
    0x254C8: 'è',  # 𥓈
    # 0x254C9: '',  # 𥓉
    # 0x254CA: '',  # 𥓊
    # 0x254CB: '',  # 𥓋
    0x254CC: 'qiǎng',  # 𥓌
    0x254CD: 'dú',  # 𥓍
    # 0x254CE: '',  # 𥓎
    # 0x254CF: '',  # 𥓏
    0x254D0: 'jié',  # 𥓐
    0x254D1: 'chuò',  # 𥓑
    0x254D2: 'xiàn,kàn',  # 𥓒
    0x254D3: 'bēi',  # 𥓓
    # 0x254D4: '',  # 𥓔
    # 0x254D5: '',  # 𥓕
    0x254D6: 'gǎo',  # 𥓖
    # 0x254D7: '',  # 𥓗
    # 0x254D8: '',  # 𥓘
    # 0x254D9: '',  # 𥓙
    # 0x254DA: '',  # 𥓚
    # 0x254DB: '',  # 𥓛
    # 0x254DC: '',  # 𥓜
    # 0x254DD: '',  # 𥓝
    # 0x254DE: '',  # 𥓞
    # 0x254DF: '',  # 𥓟
    # 0x254E0: '',  # 𥓠
    # 0x254E1: '',  # 𥓡
    # 0x254E2: '',  # 𥓢
    # 0x254E3: '',  # 𥓣
    # 0x254E4: '',  # 𥓤
    # 0x254E5: '',  # 𥓥
    # 0x254E6: '',  # 𥓦
    # 0x254E7: '',  # 𥓧
    # 0x254E8: '',  # 𥓨
    # 0x254E9: '',  # 𥓩
    # 0x254EA: '',  # 𥓪
    # 0x254EB: '',  # 𥓫
    0x254EC: 'dào',  # 𥓬
    0x254ED: 'suǒ',  # 𥓭
    # 0x254EE: '',  # 𥓮
    # 0x254EF: '',  # 𥓯
    0x254F0: 'hōng',  # 𥓰
    # 0x254F1: '',  # 𥓱
    # 0x254F2: '',  # 𥓲
    # 0x254F3: '',  # 𥓳
    # 0x254F4: '',  # 𥓴
    # 0x254F5: '',  # 𥓵
    # 0x254F6: '',  # 𥓶
    # 0x254F7: '',  # 𥓷
    # 0x254F8: '',  # 𥓸
    # 0x254F9: '',  # 𥓹
    # 0x254FA: '',  # 𥓺
    0x254FB: 'zōng',  # 𥓻
    # 0x254FC: '',  # 𥓼
    # 0x254FD: '',  # 𥓽
    0x254FE: 'qì',  # 𥓾
    0x254FF: 'tuó',  # 𥓿
    0x25500: 'hōng',  # 𥔀
    0x25501: 'pǐ',  # 𥔁
    0x25502: 'gèng',  # 𥔂
    # 0x25503: '',  # 𥔃
    0x25504: 'niè',  # 𥔄
    # 0x25505: '',  # 𥔅
    # 0x25506: '',  # 𥔆
    0x25507: 'kōng',  # 𥔇
    # 0x25508: '',  # 𥔈
    # 0x25509: '',  # 𥔉
    0x2550A: 'zhǐ',  # 𥔊
    # 0x2550B: '',  # 𥔋
    # 0x2550C: '',  # 𥔌
    # 0x2550D: '',  # 𥔍
    # 0x2550E: '',  # 𥔎
    # 0x2550F: '',  # 𥔏
    # 0x25510: '',  # 𥔐
    0x25511: 'xiǎo',  # 𥔑
    # 0x25512: '',  # 𥔒
    # 0x25513: '',  # 𥔓
    # 0x25514: '',  # 𥔔
    # 0x25515: '',  # 𥔕
    # 0x25516: '',  # 𥔖
    # 0x25517: '',  # 𥔗
    # 0x25518: '',  # 𥔘
    # 0x25519: '',  # 𥔙
    # 0x2551A: '',  # 𥔚
    # 0x2551B: '',  # 𥔛
    # 0x2551C: '',  # 𥔜
    # 0x2551D: '',  # 𥔝
    # 0x2551E: '',  # 𥔞
    # 0x2551F: '',  # 𥔟
    # 0x25520: '',  # 𥔠
    0x25521: 'shè',  # 𥔡
    0x25522: 'yú',  # 𥔢
    0x25523: 'jiāng',  # 𥔣
    # 0x25524: '',  # 𥔤
    # 0x25525: '',  # 𥔥
    # 0x25526: '',  # 𥔦
    # 0x25527: '',  # 𥔧
    # 0x25528: '',  # 𥔨
    0x25529: 'qǐ',  # 𥔩
    0x2552A: 'chěn',  # 𥔪
    0x2552B: 'sǎng',  # 𥔫
    # 0x2552C: '',  # 𥔬
    0x2552D: 'suǒ',  # 𥔭
    0x2552E: 'qián',  # 𥔮
    0x2552F: 'huì',  # 𥔯
    # 0x25530: '',  # 𥔰
    0x25531: 'shàn',  # 𥔱
    0x25532: 'è',  # 𥔲
    # 0x25533: '',  # 𥔳
    # 0x25534: '',  # 𥔴
    # 0x25535: '',  # 𥔵
    # 0x25536: '',  # 𥔶
    # 0x25537: '',  # 𥔷
    # 0x25538: '',  # 𥔸
    # 0x25539: '',  # 𥔹
    # 0x2553A: '',  # 𥔺
    0x2553B: 'qiū',  # 𥔻
    # 0x2553C: '',  # 𥔼
    0x2553D: 'kè',  # 𥔽
    # 0x2553E: '',  # 𥔾
    # 0x2553F: '',  # 𥔿
    0x25540: 'wēng',  # 𥕀
    0x25541: 'zī',  # 𥕁
    0x25542: 'jí',  # 𥕂
    # 0x25543: '',  # 𥕃
    # 0x25544: '',  # 𥕄
    # 0x25545: '',  # 𥕅
    # 0x25546: '',  # 𥕆
    0x25547: 'dǎ',  # 𥕇
    # 0x25548: '',  # 𥕈
    0x25549: 'cuò',  # 𥕉
    # 0x2554A: '',  # 𥕊
    # 0x2554B: '',  # 𥕋
    # 0x2554C: '',  # 𥕌
    0x2554D: 'lǒu',  # 𥕍
    0x2554E: 'kāng',  # 𥕎
    0x2554F: 'kuò',  # 𥕏
    0x25550: 'dí',  # 𥕐
    0x25551: 'qiē,jū',  # 𥕑
    # 0x25552: '',  # 𥕒
    0x25553: 'mò',  # 𥕓
    # 0x25554: '',  # 𥕔
    0x25555: 'xià',  # 𥕕
    0x25556: 'guǒ',  # 𥕖
    0x25557: 'hōng',  # 𥕗
    0x25558: 'cháo,suǒ',  # 𥕘
    0x25559: 'hēi',  # 𥕙
    # 0x2555A: '',  # 𥕚
    # 0x2555B: '',  # 𥕛
    # 0x2555C: '',  # 𥕜
    # 0x2555D: '',  # 𥕝
    # 0x2555E: '',  # 𥕞
    # 0x2555F: '',  # 𥕟
    # 0x25560: '',  # 𥕠
    # 0x25561: '',  # 𥕡
    0x25562: 'cáo',  # 𥕢
    0x25563: 'zhé',  # 𥕣
    # 0x25564: '',  # 𥕤
    0x25565: 'qū',  # 𥕥
    # 0x25566: '',  # 𥕦
    # 0x25567: '',  # 𥕧
    # 0x25568: '',  # 𥕨
    # 0x25569: '',  # 𥕩
    # 0x2556A: '',  # 𥕪
    # 0x2556B: '',  # 𥕫
    # 0x2556C: '',  # 𥕬
    # 0x2556D: '',  # 𥕭
    # 0x2556E: '',  # 𥕮
    # 0x2556F: '',  # 𥕯
    0x25570: 'xū',  # 𥕰
    0x25571: 'péng,pēng',  # 𥕱
    0x25572: 'jué',  # 𥕲
    # 0x25573: '',  # 𥕳
    # 0x25574: '',  # 𥕴
    0x25575: 'gǎn',  # 𥕵
    0x25576: 'sī',  # 𥕶
    # 0x25577: '',  # 𥕷
    0x25578: 'suì',  # 𥕸
    0x25579: 'què',  # 𥕹
    # 0x2557A: '',  # 𥕺
    0x2557B: 'wú,wǔ',  # 𥕻
    0x2557C: 'yán',  # 𥕼
    0x2557D: 'pèng',  # 𥕽
    0x2557E: 'xiǎo',  # 𥕾
    0x2557F: 'pān',  # 𥕿
    # 0x25580: '',  # 𥖀
    # 0x25581: '',  # 𥖁
    # 0x25582: '',  # 𥖂
    # 0x25583: '',  # 𥖃
    0x25584: 'xiàn',  # 𥖄
    # 0x25585: '',  # 𥖅
    # 0x25586: '',  # 𥖆
    # 0x25587: '',  # 𥖇
    # 0x25588: '',  # 𥖈
    # 0x25589: '',  # 𥖉
    # 0x2558A: '',  # 𥖊
    # 0x2558B: '',  # 𥖋
    # 0x2558C: '',  # 𥖌
    0x2558D: 'là',  # 𥖍
    # 0x2558E: '',  # 𥖎
    # 0x2558F: '',  # 𥖏
    # 0x25590: '',  # 𥖐
    # 0x25591: '',  # 𥖑
    # 0x25592: '',  # 𥖒
    # 0x25593: '',  # 𥖓
    # 0x25594: '',  # 𥖔
    # 0x25595: '',  # 𥖕
    # 0x25596: '',  # 𥖖
    0x25597: 'bèng',  # 𥖗
    0x25598: 'zhěn',  # 𥖘
    0x25599: 'jí',  # 𥖙
    # 0x2559A: '',  # 𥖚
    # 0x2559B: '',  # 𥖛
    0x2559C: 'jǐn',  # 𥖜
    0x2559D: 'lián',  # 𥖝
    0x2559E: 'kěn',  # 𥖞
    # 0x2559F: '',  # 𥖟
    0x255A0: 'zhóu,dú',  # 𥖠
    # 0x255A1: '',  # 𥖡
    # 0x255A2: '',  # 𥖢
    # 0x255A3: '',  # 𥖣
    # 0x255A4: '',  # 𥖤
    # 0x255A5: '',  # 𥖥
    # 0x255A6: '',  # 𥖦
    # 0x255A7: '',  # 𥖧
    0x255A8: 'zào',  # 𥖨
    # 0x255A9: '',  # 𥖩
    0x255AA: 'lè',  # 𥖪
    0x255AB: 'qī',  # 𥖫
    0x255AC: 'bìng',  # 𥖬
    # 0x255AD: '',  # 𥖭
    # 0x255AE: '',  # 𥖮
    # 0x255AF: '',  # 𥖯
    # 0x255B0: '',  # 𥖰
    # 0x255B1: '',  # 𥖱
    # 0x255B2: '',  # 𥖲
    # 0x255B3: '',  # 𥖳
    # 0x255B4: '',  # 𥖴
    0x255B5: 'yǐn',  # 𥖵
    0x255B6: 'pīn',  # 𥖶
    # 0x255B7: '',  # 𥖷
    # 0x255B8: '',  # 𥖸
    # 0x255B9: '',  # 𥖹
    # 0x255BA: '',  # 𥖺
    0x255BB: 'sǒu',  # 𥖻
    0x255BC: 'lǜ',  # 𥖼
    # 0x255BD: '',  # 𥖽
    0x255BE: 'dí',  # 𥖾
    0x255BF: 'dú',  # 𥖿
    0x255C0: 'liǎo',  # 𥗀
    0x255C1: 'zhuó',  # 𥗁
    # 0x255C2: '',  # 𥗂
    # 0x255C3: '',  # 𥗃
    # 0x255C4: '',  # 𥗄
    # 0x255C5: '',  # 𥗅
    # 0x255C6: '',  # 𥗆
    # 0x255C7: '',  # 𥗇
    # 0x255C8: '',  # 𥗈
    # 0x255C9: '',  # 𥗉
    0x255CA: 'chǎng',  # 𥗊
    # 0x255CB: '',  # 𥗋
    # 0x255CC: '',  # 𥗌
    # 0x255CD: '',  # 𥗍
    # 0x255CE: '',  # 𥗎
    # 0x255CF: '',  # 𥗏
    # 0x255D0: '',  # 𥗐
    # 0x255D1: '',  # 𥗑
    0x255D2: 'chèn',  # 𥗒
    0x255D3: 'tà',  # 𥗓
    # 0x255D4: '',  # 𥗔
    # 0x255D5: '',  # 𥗕
    # 0x255D6: '',  # 𥗖
    # 0x255D7: '',  # 𥗗
    # 0x255D8: '',  # 𥗘
    0x255D9: 'què',  # 𥗙
    0x255DA: 'dào',  # 𥗚
    # 0x255DB: '',  # 𥗛
    # 0x255DC: '',  # 𥗜
    0x255DD: 'rǎng',  # 𥗝
    # 0x255DE: '',  # 𥗞
    0x255DF: 'pò',  # 𥗟
    # 0x255E0: '',  # 𥗠
    # 0x255E1: '',  # 𥗡
    # 0x255E2: '',  # 𥗢
    # 0x255E3: '',  # 𥗣
    # 0x255E4: '',  # 𥗤
    # 0x255E5: '',  # 𥗥
    0x255E6: 'zhōng',  # 𥗦
    0x255E7: 'xiē',  # 𥗧
    # 0x255E8: '',  # 𥗨
    # 0x255E9: '',  # 𥗩
    0x255EA: 'jiāng',  # 𥗪
    0x255EB: 'qú',  # 𥗫
    0x255EC: 'lěi',  # 𥗬
    0x255ED: 'cà',  # 𥗭
    0x255EE: 'quē',  # 𥗮
    # 0x255EF: '',  # 𥗯
    # 0x255F0: '',  # 𥗰
    # 0x255F1: '',  # 𥗱
    # 0x255F2: '',  # 𥗲
    # 0x255F3: '',  # 𥗳
    # 0x255F4: '',  # 𥗴
    0x255F5: 'xiàng',  # 𥗵
    0x255F6: 'lèi',  # 𥗶
    # 0x255F7: '',  # 𥗷
    # 0x255F8: '',  # 𥗸
    # 0x255F9: '',  # 𥗹
    0x255FA: 'làn',  # 𥗺
    # 0x255FB: '',  # 𥗻
    # 0x255FC: '',  # 𥗼
    # 0x255FD: '',  # 𥗽
    # 0x255FE: '',  # 𥗾
    0x255FF: 'lǎ',  # 𥗿
    # 0x25600: '',  # 𥘀
    0x25601: 'lǎ',  # 𥘁
    # 0x25602: '',  # 𥘂
    # 0x25603: '',  # 𥘃
    0x25604: 'yù',  # 𥘄
    # 0x25605: '',  # 𥘅
    # 0x25606: '',  # 𥘆
    # 0x25607: '',  # 𥘇
    # 0x25608: '',  # 𥘈
    # 0x25609: '',  # 𥘉
    0x2560A: 'jiào',  # 𥘊
    0x2560B: 'qín',  # 𥘋
    0x2560C: 'jī',  # 𥘌
    # 0x2560D: '',  # 𥘍
    # 0x2560E: '',  # 𥘎
    0x2560F: 'gǎn',  # 𥘏
    # 0x25610: '',  # 𥘐
    0x25611: 'cùn',  # 𥘑
    0x25612: 'yì',  # 𥘒
    # 0x25613: '',  # 𥘓
    # 0x25614: '',  # 𥘔
    # 0x25615: '',  # 𥘕
    # 0x25616: '',  # 𥘖
    # 0x25617: '',  # 𥘗
    # 0x25618: '',  # 𥘘
    # 0x25619: '',  # 𥘙
    # 0x2561A: '',  # 𥘚
    # 0x2561B: '',  # 𥘛
    # 0x2561C: '',  # 𥘜
    # 0x2561D: '',  # 𥘝
    # 0x2561E: '',  # 𥘞
    # 0x2561F: '',  # 𥘟
    0x25620: 'yì',  # 𥘠
    0x25621: 'zhī',  # 𥘡
    # 0x25622: '',  # 𥘢
    # 0x25623: '',  # 𥘣
    0x25624: 'biǎo',  # 𥘤
    0x25625: 'shēng',  # 𥘥
    0x25626: 'jiù,shè',  # 𥘦
    # 0x25627: '',  # 𥘧
    # 0x25628: '',  # 𥘨
    # 0x25629: '',  # 𥘩
    # 0x2562A: '',  # 𥘪
    0x2562B: 'hē',  # 𥘫
    0x2562C: 'fú',  # 𥘬
    # 0x2562D: '',  # 𥘭
    0x2562E: 'jū',  # 𥘮
    # 0x2562F: '',  # 𥘯
    # 0x25630: '',  # 𥘰
    # 0x25631: '',  # 𥘱
    # 0x25632: '',  # 𥘲
    # 0x25633: '',  # 𥘳
    # 0x25634: '',  # 𥘴
    # 0x25635: '',  # 𥘵
    # 0x25636: '',  # 𥘶
    # 0x25637: '',  # 𥘷
    # 0x25638: '',  # 𥘸
    # 0x25639: '',  # 𥘹
    # 0x2563A: '',  # 𥘺
    # 0x2563B: '',  # 𥘻
    # 0x2563C: '',  # 𥘼
    # 0x2563D: '',  # 𥘽
    # 0x2563E: '',  # 𥘾
    # 0x2563F: '',  # 𥘿
    0x25640: 'zuǒ',  # 𥙀
    0x25641: 'yí',  # 𥙁
    # 0x25642: '',  # 𥙂
    # 0x25643: '',  # 𥙃
    # 0x25644: '',  # 𥙄
    # 0x25645: '',  # 𥙅
    0x25646: 'xiàn,zhī',  # 𥙆
    0x25647: 'yí',  # 𥙇
    # 0x25648: '',  # 𥙈
    0x25649: 'sì,tái',  # 𥙉
    # 0x2564A: '',  # 𥙊
    0x2564B: 'chuì',  # 𥙋
    # 0x2564C: '',  # 𥙌
    # 0x2564D: '',  # 𥙍
    0x2564E: 'mò',  # 𥙎
    # 0x2564F: '',  # 𥙏
    # 0x25650: '',  # 𥙐
    # 0x25651: '',  # 𥙑
    # 0x25652: '',  # 𥙒
    # 0x25653: '',  # 𥙓
    # 0x25654: '',  # 𥙔
    # 0x25655: '',  # 𥙕
    # 0x25656: '',  # 𥙖
    # 0x25657: '',  # 𥙗
    # 0x25658: '',  # 𥙘
    # 0x25659: '',  # 𥙙
    # 0x2565A: '',  # 𥙚
    # 0x2565B: '',  # 𥙛
    # 0x2565C: '',  # 𥙜
    # 0x2565D: '',  # 𥙝
    # 0x2565E: '',  # 𥙞
    # 0x2565F: '',  # 𥙟
    # 0x25660: '',  # 𥙠
    0x25661: 'zhān',  # 𥙡
    # 0x25662: '',  # 𥙢
    0x25663: 'xún',  # 𥙣
    # 0x25664: '',  # 𥙤
    # 0x25665: '',  # 𥙥
    0x25666: 'rú',  # 𥙦
    # 0x25667: '',  # 𥙧
    0x25668: 'huò',  # 𥙨
    # 0x25669: '',  # 𥙩
    # 0x2566A: '',  # 𥙪
    0x2566B: 'yǒu',  # 𥙫
    0x2566C: 'shāo',  # 𥙬
    # 0x2566D: '',  # 𥙭
    # 0x2566E: '',  # 𥙮
    # 0x2566F: '',  # 𥙯
    0x25670: 'shòu',  # 𥙰
    # 0x25671: '',  # 𥙱
    # 0x25672: '',  # 𥙲
    # 0x25673: '',  # 𥙳
    # 0x25674: '',  # 𥙴
    # 0x25675: '',  # 𥙵
    # 0x25676: '',  # 𥙶
    # 0x25677: '',  # 𥙷
    # 0x25678: '',  # 𥙸
    # 0x25679: '',  # 𥙹
    # 0x2567A: '',  # 𥙺
    # 0x2567B: '',  # 𥙻
    # 0x2567C: '',  # 𥙼
    # 0x2567D: '',  # 𥙽
    0x2567E: 'yòu',  # 𥙾
    0x2567F: 'yù',  # 𥙿
    # 0x25680: '',  # 𥚀
    # 0x25681: '',  # 𥚁
    0x25682: 'jùn',  # 𥚂
    # 0x25683: '',  # 𥚃
    # 0x25684: '',  # 𥚄
    # 0x25685: '',  # 𥚅
    # 0x25686: '',  # 𥚆
    # 0x25687: '',  # 𥚇
    # 0x25688: '',  # 𥚈
    0x25689: 'zī',  # 𥚉
    0x2568A: 'lù',  # 𥚊
    # 0x2568B: '',  # 𥚋
    # 0x2568C: '',  # 𥚌
    # 0x2568D: '',  # 𥚍
    # 0x2568E: '',  # 𥚎
    # 0x2568F: '',  # 𥚏
    # 0x25690: '',  # 𥚐
    # 0x25691: '',  # 𥚑
    # 0x25692: '',  # 𥚒
    # 0x25693: '',  # 𥚓
    # 0x25694: '',  # 𥚔
    # 0x25695: '',  # 𥚕
    # 0x25696: '',  # 𥚖
    # 0x25697: '',  # 𥚗
    # 0x25698: '',  # 𥚘
    # 0x25699: '',  # 𥚙
    0x2569A: 'chǐ',  # 𥚚
    0x2569B: 'kūn',  # 𥚛
    # 0x2569C: '',  # 𥚜
    # 0x2569D: '',  # 𥚝
    # 0x2569E: '',  # 𥚞
    0x2569F: 'huò',  # 𥚟
    0x256A0: 'zhùn',  # 𥚠
    # 0x256A1: '',  # 𥚡
    # 0x256A2: '',  # 𥚢
    # 0x256A3: '',  # 𥚣
    # 0x256A4: '',  # 𥚤
    # 0x256A5: '',  # 𥚥
    0x256A6: 'hóu',  # 𥚦
    # 0x256A7: '',  # 𥚧
    # 0x256A8: '',  # 𥚨
    0x256A9: 'xǔ',  # 𥚩
    # 0x256AA: '',  # 𥚪
    # 0x256AB: '',  # 𥚫
    # 0x256AC: '',  # 𥚬
    # 0x256AD: '',  # 𥚭
    # 0x256AE: '',  # 𥚮
    # 0x256AF: '',  # 𥚯
    # 0x256B0: '',  # 𥚰
    # 0x256B1: '',  # 𥚱
    # 0x256B2: '',  # 𥚲
    # 0x256B3: '',  # 𥚳
    # 0x256B4: '',  # 𥚴
    # 0x256B5: '',  # 𥚵
    # 0x256B6: '',  # 𥚶
    # 0x256B7: '',  # 𥚷
    # 0x256B8: '',  # 𥚸
    # 0x256B9: '',  # 𥚹
    # 0x256BA: '',  # 𥚺
    # 0x256BB: '',  # 𥚻
    # 0x256BC: '',  # 𥚼
    # 0x256BD: '',  # 𥚽
    0x256BE: 'zōng',  # 𥚾
    0x256BF: 'yìng',  # 𥚿
    # 0x256C0: '',  # 𥛀
    # 0x256C1: '',  # 𥛁
    0x256C2: 'zhū',  # 𥛂
    # 0x256C3: '',  # 𥛃
    # 0x256C4: '',  # 𥛄
    0x256C5: 'liù',  # 𥛅
    # 0x256C6: '',  # 𥛆
    # 0x256C7: '',  # 𥛇
    # 0x256C8: '',  # 𥛈
    # 0x256C9: '',  # 𥛉
    # 0x256CA: '',  # 𥛊
    # 0x256CB: '',  # 𥛋
    # 0x256CC: '',  # 𥛌
    # 0x256CD: '',  # 𥛍
    # 0x256CE: '',  # 𥛎
    # 0x256CF: '',  # 𥛏
    # 0x256D0: '',  # 𥛐
    0x256D1: 'nù',  # 𥛑
    # 0x256D2: '',  # 𥛒
    # 0x256D3: '',  # 𥛓
    # 0x256D4: '',  # 𥛔
    # 0x256D5: '',  # 𥛕
    # 0x256D6: '',  # 𥛖
    # 0x256D7: '',  # 𥛗
    0x256D8: 'bì',  # 𥛘
    # 0x256D9: '',  # 𥛙
    0x256DA: 'chì',  # 𥛚
    # 0x256DB: '',  # 𥛛
    0x256DC: 'zǔ',  # 𥛜
    0x256DD: 'féng',  # 𥛝
    0x256DE: 'lù',  # 𥛞
    0x256DF: 'pǔ',  # 𥛟
    # 0x256E0: '',  # 𥛠
    # 0x256E1: '',  # 𥛡
    # 0x256E2: '',  # 𥛢
    # 0x256E3: '',  # 𥛣
    # 0x256E4: '',  # 𥛤
    0x256E5: 'zhuàn',  # 𥛥
    # 0x256E6: '',  # 𥛦
    0x256E7: 'zhé',  # 𥛧
    0x256E8: 'shī',  # 𥛨
    0x256E9: 'yǔ',  # 𥛩
    0x256EA: 'lù',  # 𥛪
    0x256EB: 'liáng',  # 𥛫
    # 0x256EC: '',  # 𥛬
    # 0x256ED: '',  # 𥛭
    # 0x256EE: '',  # 𥛮
    0x256EF: 'jué',  # 𥛯
    0x256F0: 'liào',  # 𥛰
    0x256F1: 'bēng',  # 𥛱
    # 0x256F2: '',  # 𥛲
    # 0x256F3: '',  # 𥛳
    # 0x256F4: '',  # 𥛴
    # 0x256F5: '',  # 𥛵
    # 0x256F6: '',  # 𥛶
    # 0x256F7: '',  # 𥛷
    # 0x256F8: '',  # 𥛸
    # 0x256F9: '',  # 𥛹
    # 0x256FA: '',  # 𥛺
    # 0x256FB: '',  # 𥛻
    # 0x256FC: '',  # 𥛼
    0x256FD: 'liù',  # 𥛽
    # 0x256FE: '',  # 𥛾
    # 0x256FF: '',  # 𥛿
    # 0x25700: '',  # 𥜀
    # 0x25701: '',  # 𥜁
    # 0x25702: '',  # 𥜂
    0x25703: 'yì',  # 𥜃
    0x25704: 'guān',  # 𥜄
    # 0x25705: '',  # 𥜅
    # 0x25706: '',  # 𥜆
    # 0x25707: '',  # 𥜇
    # 0x25708: '',  # 𥜈
    # 0x25709: '',  # 𥜉
    # 0x2570A: '',  # 𥜊
    # 0x2570B: '',  # 𥜋
    0x2570C: 'ǎo',  # 𥜌
    # 0x2570D: '',  # 𥜍
    # 0x2570E: '',  # 𥜎
    0x2570F: 'guì',  # 𥜏
    0x25710: 'mǐn',  # 𥜐
    # 0x25711: '',  # 𥜑
    0x25712: 'yǎn',  # 𥜒
    0x25713: 'lán',  # 𥜓
    # 0x25714: '',  # 𥜔
    # 0x25715: '',  # 𥜕
    0x25716: 'bó',  # 𥜖
    # 0x25717: '',  # 𥜗
    # 0x25718: '',  # 𥜘
    0x25719: 'zàn',  # 𥜙
    0x2571A: 'yǒu',  # 𥜚
    # 0x2571B: '',  # 𥜛
    # 0x2571C: '',  # 𥜜
    # 0x2571D: '',  # 𥜝
    # 0x2571E: '',  # 𥜞
    # 0x2571F: '',  # 𥜟
    # 0x25720: '',  # 𥜠
    # 0x25721: '',  # 𥜡
    # 0x25722: '',  # 𥜢
    # 0x25723: '',  # 𥜣
    # 0x25724: '',  # 𥜤
    0x25725: 'yì',  # 𥜥
    0x25726: 'nǐ,xiǎn',  # 𥜦
    # 0x25727: '',  # 𥜧
    # 0x25728: '',  # 𥜨
    # 0x25729: '',  # 𥜩
    # 0x2572A: '',  # 𥜪
    # 0x2572B: '',  # 𥜫
    0x2572C: 'nǐ,xiǎn',  # 𥜬
    0x2572D: 'guǒ',  # 𥜭
    0x2572E: 'jùn',  # 𥜮
    # 0x2572F: '',  # 𥜯
    0x25730: 'shī',  # 𥜰
    # 0x25731: '',  # 𥜱
    0x25732: 'xiǎn,jiǎn',  # 𥜲
    # 0x25733: '',  # 𥜳
    0x25734: 'qiān',  # 𥜴
    0x25735: 'què',  # 𥜵
    0x25736: 'kuí',  # 𥜶
    # 0x25737: '',  # 𥜷
    # 0x25738: '',  # 𥜸
    # 0x25739: '',  # 𥜹
    # 0x2573A: '',  # 𥜺
    # 0x2573B: '',  # 𥜻
    # 0x2573C: '',  # 𥜼
    # 0x2573D: '',  # 𥜽
    # 0x2573E: '',  # 𥜾
    # 0x2573F: '',  # 𥜿
    0x25740: 'shé',  # 𥝀
    # 0x25741: '',  # 𥝁
    0x25742: 'huò',  # 𥝂
    # 0x25743: '',  # 𥝃
    0x25744: 'wàn',  # 𥝄
    # 0x25745: '',  # 𥝅
    # 0x25746: '',  # 𥝆
    # 0x25747: '',  # 𥝇
    # 0x25748: '',  # 𥝈
    # 0x25749: '',  # 𥝉
    0x2574A: 'fèi',  # 𥝊
    0x2574B: 'fèi',  # 𥝋
    0x2574C: 'jī',  # 𥝌
    0x2574D: 'yù,wáng',  # 𥝍
    # 0x2574E: '',  # 𥝎
    # 0x2574F: '',  # 𥝏
    # 0x25750: '',  # 𥝐
    0x25751: 'zhī',  # 𥝑
    0x25752: 'guà',  # 𥝒
    # 0x25753: '',  # 𥝓
    0x25754: 'jié',  # 𥝔
    0x25755: 'máng',  # 𥝕
    0x25756: 'hé,xié',  # 𥝖
    # 0x25757: '',  # 𥝗
    0x25758: 'yǒu',  # 𥝘
    # 0x25759: '',  # 𥝙
    # 0x2575A: '',  # 𥝚
    # 0x2575B: '',  # 𥝛
    # 0x2575C: '',  # 𥝜
    # 0x2575D: '',  # 𥝝
    # 0x2575E: '',  # 𥝞
    0x2575F: 'dù',  # 𥝟
    0x25760: 'sī,xiù',  # 𥝠
    # 0x25761: '',  # 𥝡
    0x25762: 'lì',  # 𥝢
    # 0x25763: '',  # 𥝣
    # 0x25764: '',  # 𥝤
    0x25765: 'jié',  # 𥝥
    0x25766: 'niǔ',  # 𥝦
    0x25767: 'bà',  # 𥝧
    0x25768: 'yú',  # 𥝨
    0x25769: 'suì',  # 𥝩
    # 0x2576A: '',  # 𥝪
    # 0x2576B: '',  # 𥝫
    # 0x2576C: '',  # 𥝬
    # 0x2576D: '',  # 𥝭
    0x2576E: 'zhī',  # 𥝮
    # 0x2576F: '',  # 𥝯
    # 0x25770: '',  # 𥝰
    # 0x25771: '',  # 𥝱
    # 0x25772: '',  # 𥝲
    # 0x25773: '',  # 𥝳
    # 0x25774: '',  # 𥝴
    # 0x25775: '',  # 𥝵
    # 0x25776: '',  # 𥝶
    # 0x25777: '',  # 𥝷
    0x25778: 'hé',  # 𥝸
    0x25779: 'kē',  # 𥝹
    # 0x2577A: '',  # 𥝺
    # 0x2577B: '',  # 𥝻
    # 0x2577C: '',  # 𥝼
    # 0x2577D: '',  # 𥝽
    0x2577E: 'dù,zhà',  # 𥝾
    0x2577F: 'jiā',  # 𥝿
    # 0x25780: '',  # 𥞀
    0x25781: 'chēn',  # 𥞁
    # 0x25782: '',  # 𥞂
    0x25783: 'chuì,shù',  # 𥞃
    0x25784: 'hé',  # 𥞄
    0x25785: 'zhǎi',  # 𥞅
    # 0x25786: '',  # 𥞆
    # 0x25787: '',  # 𥞇
    # 0x25788: '',  # 𥞈
    # 0x25789: '',  # 𥞉
    0x2578A: 'mèi',  # 𥞊
    # 0x2578B: '',  # 𥞋
    # 0x2578C: '',  # 𥞌
    0x2578D: 'hé',  # 𥞍
    0x2578E: 'zǐ',  # 𥞎
    0x2578F: 'zhú',  # 𥞏
    # 0x25790: '',  # 𥞐
    0x25791: 'zǐ',  # 𥞑
    0x25792: 'tuó',  # 𥞒
    # 0x25793: '',  # 𥞓
    # 0x25794: '',  # 𥞔
    # 0x25795: '',  # 𥞕
    # 0x25796: '',  # 𥞖
    # 0x25797: '',  # 𥞗
    0x25798: 'zùn',  # 𥞘
    # 0x25799: '',  # 𥞙
    0x2579A: 'rú',  # 𥞚
    0x2579B: 'duò',  # 𥞛
    0x2579C: 'jiàng',  # 𥞜
    # 0x2579D: '',  # 𥞝
    # 0x2579E: '',  # 𥞞
    # 0x2579F: '',  # 𥞟
    # 0x257A0: '',  # 𥞠
    # 0x257A1: '',  # 𥞡
    # 0x257A2: '',  # 𥞢
    # 0x257A3: '',  # 𥞣
    # 0x257A4: '',  # 𥞤
    0x257A5: 'liè',  # 𥞥
    # 0x257A6: '',  # 𥞦
    0x257A7: 'héng',  # 𥞧
    # 0x257A8: '',  # 𥞨
    0x257A9: 'bēng',  # 𥞩
    0x257AA: 'mò,mǐ',  # 𥞪
    # 0x257AB: '',  # 𥞫
    # 0x257AC: '',  # 𥞬
    # 0x257AD: '',  # 𥞭
    # 0x257AE: '',  # 𥞮
    0x257AF: 'zú',  # 𥞯
    # 0x257B0: '',  # 𥞰
    # 0x257B1: '',  # 𥞱
    0x257B2: 'biē',  # 𥞲
    # 0x257B3: '',  # 𥞳
    0x257B4: 'kù',  # 𥞴
    0x257B5: 'jiá',  # 𥞵
    # 0x257B6: '',  # 𥞶
    # 0x257B7: '',  # 𥞷
    # 0x257B8: '',  # 𥞸
    # 0x257B9: '',  # 𥞹
    0x257BA: 'zhuō',  # 𥞺
    # 0x257BB: '',  # 𥞻
    0x257BC: 'xiū',  # 𥞼
    # 0x257BD: '',  # 𥞽
    # 0x257BE: '',  # 𥞾
    # 0x257BF: '',  # 𥞿
    # 0x257C0: '',  # 𥟀
    # 0x257C1: '',  # 𥟁
    # 0x257C2: '',  # 𥟂
    0x257C3: 'hé',  # 𥟃
    # 0x257C4: '',  # 𥟄
    0x257C5: 'qiāo',  # 𥟅
    # 0x257C6: '',  # 𥟆
    # 0x257C7: '',  # 𥟇
    # 0x257C8: '',  # 𥟈
    # 0x257C9: '',  # 𥟉
    # 0x257CA: '',  # 𥟊
    # 0x257CB: '',  # 𥟋
    # 0x257CC: '',  # 𥟌
    0x257CD: 'fěi',  # 𥟍
    0x257CE: 'shēng',  # 𥟎
    # 0x257CF: '',  # 𥟏
    # 0x257D0: '',  # 𥟐
    # 0x257D1: '',  # 𥟑
    0x257D2: 'zhuì',  # 𥟒
    0x257D3: 'kuǎn',  # 𥟓
    0x257D4: 'zè',  # 𥟔
    0x257D5: 'xiān',  # 𥟕
    # 0x257D6: '',  # 𥟖
    0x257D7: 'bì',  # 𥟗
    0x257D8: 'yì',  # 𥟘
    # 0x257D9: '',  # 𥟙
    0x257DA: 'chàng',  # 𥟚
    # 0x257DB: '',  # 𥟛
    # 0x257DC: '',  # 𥟜
    # 0x257DD: '',  # 𥟝
    # 0x257DE: '',  # 𥟞
    # 0x257DF: '',  # 𥟟
    # 0x257E0: '',  # 𥟠
    # 0x257E1: '',  # 𥟡
    # 0x257E2: '',  # 𥟢
    # 0x257E3: '',  # 𥟣
    # 0x257E4: '',  # 𥟤
    # 0x257E5: '',  # 𥟥
    # 0x257E6: '',  # 𥟦
    # 0x257E7: '',  # 𥟧
    # 0x257E8: '',  # 𥟨
    # 0x257E9: '',  # 𥟩
    0x257EA: 'mào',  # 𥟪
    # 0x257EB: '',  # 𥟫
    # 0x257EC: '',  # 𥟬
    # 0x257ED: '',  # 𥟭
    # 0x257EE: '',  # 𥟮
    # 0x257EF: '',  # 𥟯
    # 0x257F0: '',  # 𥟰
    # 0x257F1: '',  # 𥟱
    # 0x257F2: '',  # 𥟲
    # 0x257F3: '',  # 𥟳
    # 0x257F4: '',  # 𥟴
    # 0x257F5: '',  # 𥟵
    0x257F6: 'wǎn',  # 𥟶
    # 0x257F7: '',  # 𥟷
    # 0x257F8: '',  # 𥟸
    # 0x257F9: '',  # 𥟹
    # 0x257FA: '',  # 𥟺
    # 0x257FB: '',  # 𥟻
    # 0x257FC: '',  # 𥟼
    0x257FD: 'wū',  # 𥟽
    0x257FE: 'kū',  # 𥟾
    0x257FF: 'wǒ',  # 𥟿
    0x25800: 'xīng',  # 𥠀
    0x25801: 'kē',  # 𥠁
    # 0x25802: '',  # 𥠂
    0x25803: 'jiū',  # 𥠃
    0x25804: 'duān',  # 𥠄
    0x25805: 'huàn',  # 𥠅
    # 0x25806: '',  # 𥠆
    # 0x25807: '',  # 𥠇
    0x25808: 'zhì,jì',  # 𥠈
    0x25809: 'cè',  # 𥠉
    0x2580A: 'róu',  # 𥠊
    0x2580B: 'jí',  # 𥠋
    # 0x2580C: '',  # 𥠌
    0x2580D: 'yè',  # 𥠍
    # 0x2580E: '',  # 𥠎
    # 0x2580F: '',  # 𥠏
    # 0x25810: '',  # 𥠐
    # 0x25811: '',  # 𥠑
    # 0x25812: '',  # 𥠒
    # 0x25813: '',  # 𥠓
    # 0x25814: '',  # 𥠔
    # 0x25815: '',  # 𥠕
    # 0x25816: '',  # 𥠖
    # 0x25817: '',  # 𥠗
    # 0x25818: '',  # 𥠘
    # 0x25819: '',  # 𥠙
    # 0x2581A: '',  # 𥠚
    0x2581B: 'jīng',  # 𥠛
    0x2581C: 'yàng',  # 𥠜
    # 0x2581D: '',  # 𥠝
    # 0x2581E: '',  # 𥠞
    # 0x2581F: '',  # 𥠟
    # 0x25820: '',  # 𥠠
    0x25821: 'zǒng',  # 𥠡
    # 0x25822: '',  # 𥠢
    # 0x25823: '',  # 𥠣
    # 0x25824: '',  # 𥠤
    # 0x25825: '',  # 𥠥
    # 0x25826: '',  # 𥠦
    # 0x25827: '',  # 𥠧
    # 0x25828: '',  # 𥠨
    0x25829: 'cǎn',  # 𥠩
    # 0x2582A: '',  # 𥠪
    # 0x2582B: '',  # 𥠫
    # 0x2582C: '',  # 𥠬
    # 0x2582D: '',  # 𥠭
    # 0x2582E: '',  # 𥠮
    # 0x2582F: '',  # 𥠯
    # 0x25830: '',  # 𥠰
    0x25831: 'sī',  # 𥠱
    0x25832: 'lì',  # 𥠲
    0x25833: 'gǔ',  # 𥠳
    0x25834: 'chàng',  # 𥠴
    # 0x25835: '',  # 𥠵
    0x25836: 'fěi',  # 𥠶
    0x25837: 'liú',  # 𥠷
    # 0x25838: '',  # 𥠸
    0x25839: 'jié',  # 𥠹
    0x2583A: 'yūn',  # 𥠺
    # 0x2583B: '',  # 𥠻
    # 0x2583C: '',  # 𥠼
    0x2583D: 'zhì',  # 𥠽
    # 0x2583E: '',  # 𥠾
    # 0x2583F: '',  # 𥠿
    0x25840: 'chóu',  # 𥡀
    0x25841: 'biē',  # 𥡁
    # 0x25842: '',  # 𥡂
    0x25843: 'huāng',  # 𥡃
    # 0x25844: '',  # 𥡄
    0x25845: 'gāo',  # 𥡅
    # 0x25846: '',  # 𥡆
    # 0x25847: '',  # 𥡇
    # 0x25848: '',  # 𥡈
    # 0x25849: '',  # 𥡉
    # 0x2584A: '',  # 𥡊
    # 0x2584B: '',  # 𥡋
    # 0x2584C: '',  # 𥡌
    # 0x2584D: '',  # 𥡍
    # 0x2584E: '',  # 𥡎
    # 0x2584F: '',  # 𥡏
    # 0x25850: '',  # 𥡐
    # 0x25851: '',  # 𥡑
    0x25852: 'jī',  # 𥡒
    # 0x25853: '',  # 𥡓
    # 0x25854: '',  # 𥡔
    # 0x25855: '',  # 𥡕
    # 0x25856: '',  # 𥡖
    # 0x25857: '',  # 𥡗
    # 0x25858: '',  # 𥡘
    # 0x25859: '',  # 𥡙
    # 0x2585A: '',  # 𥡚
    # 0x2585B: '',  # 𥡛
    0x2585C: 'luó,suì',  # 𥡜
    0x2585D: 'jiān,qiān',  # 𥡝
    # 0x2585E: '',  # 𥡞
    0x2585F: 'chuāng',  # 𥡟
    0x25860: 'shuǎng',  # 𥡠
    # 0x25861: '',  # 𥡡
    0x25862: 'lǜ',  # 𥡢
    0x25863: 'jùn',  # 𥡣
    0x25864: 'jiào',  # 𥡤
    # 0x25865: '',  # 𥡥
    0x25866: 'tì,dì',  # 𥡦
    0x25867: 'zhā',  # 𥡧
    # 0x25868: '',  # 𥡨
    # 0x25869: '',  # 𥡩
    0x2586A: 'yì',  # 𥡪
    # 0x2586B: '',  # 𥡫
    0x2586C: 'cōng',  # 𥡬
    0x2586D: 'něi',  # 𥡭
    0x2586E: 'jiā',  # 𥡮
    # 0x2586F: '',  # 𥡯
    # 0x25870: '',  # 𥡰
    # 0x25871: '',  # 𥡱
    # 0x25872: '',  # 𥡲
    # 0x25873: '',  # 𥡳
    0x25874: 'jì',  # 𥡴
    # 0x25875: '',  # 𥡵
    # 0x25876: '',  # 𥡶
    # 0x25877: '',  # 𥡷
    # 0x25878: '',  # 𥡸
    # 0x25879: '',  # 𥡹
    # 0x2587A: '',  # 𥡺
    # 0x2587B: '',  # 𥡻
    # 0x2587C: '',  # 𥡼
    0x2587D: 'ài',  # 𥡽
    # 0x2587E: '',  # 𥡾
    # 0x2587F: '',  # 𥡿
    # 0x25880: '',  # 𥢀
    # 0x25881: '',  # 𥢁
    # 0x25882: '',  # 𥢂
    # 0x25883: '',  # 𥢃
    # 0x25884: '',  # 𥢄
    # 0x25885: '',  # 𥢅
    # 0x25886: '',  # 𥢆
    0x25887: 'jiǎn',  # 𥢇
    # 0x25888: '',  # 𥢈
    # 0x25889: '',  # 𥢉
    0x2588A: 'bèn',  # 𥢊
    # 0x2588B: '',  # 𥢋
    0x2588C: 'fán',  # 𥢌
    0x2588D: 'suì',  # 𥢍
    0x2588E: 'zùn',  # 𥢎
    # 0x2588F: '',  # 𥢏
    0x25890: 'gāo',  # 𥢐
    0x25891: 'gǎo,hào',  # 𥢑
    0x25892: 'láo,lào',  # 𥢒
    # 0x25893: '',  # 𥢓
    0x25894: 'zhuó,zhào',  # 𥢔
    # 0x25895: '',  # 𥢕
    # 0x25896: '',  # 𥢖
    # 0x25897: '',  # 𥢗
    # 0x25898: '',  # 𥢘
    # 0x25899: '',  # 𥢙
    # 0x2589A: '',  # 𥢚
    # 0x2589B: '',  # 𥢛
    # 0x2589C: '',  # 𥢜
    # 0x2589D: '',  # 𥢝
    # 0x2589E: '',  # 𥢞
    0x2589F: 'hù',  # 𥢟
    # 0x258A0: '',  # 𥢠
    # 0x258A1: '',  # 𥢡
    # 0x258A2: '',  # 𥢢
    # 0x258A3: '',  # 𥢣
    # 0x258A4: '',  # 𥢤
    # 0x258A5: '',  # 𥢥
    0x258A6: 'bì',  # 𥢦
    0x258A7: 'jú,yì',  # 𥢧
    # 0x258A8: '',  # 𥢨
    # 0x258A9: '',  # 𥢩
    # 0x258AA: '',  # 𥢪
    # 0x258AB: '',  # 𥢫
    # 0x258AC: '',  # 𥢬
    # 0x258AD: '',  # 𥢭
    0x258AE: 'huá',  # 𥢮
    # 0x258AF: '',  # 𥢯
    # 0x258B0: '',  # 𥢰
    # 0x258B1: '',  # 𥢱
    0x258B2: 'chéng',  # 𥢲
    # 0x258B3: '',  # 𥢳
    # 0x258B4: '',  # 𥢴
    # 0x258B5: '',  # 𥢵
    0x258B6: 'kuài',  # 𥢶
    0x258B7: 'dāng',  # 𥢷
    0x258B8: 'gé',  # 𥢸
    0x258B9: 'xié',  # 𥢹
    # 0x258BA: '',  # 𥢺
    0x258BB: 'jié',  # 𥢻
    # 0x258BC: '',  # 𥢼
    0x258BD: 'cān',  # 𥢽
    # 0x258BE: '',  # 𥢾
    # 0x258BF: '',  # 𥢿
    # 0x258C0: '',  # 𥣀
    # 0x258C1: '',  # 𥣁
    # 0x258C2: '',  # 𥣂
    # 0x258C3: '',  # 𥣃
    # 0x258C4: '',  # 𥣄
    # 0x258C5: '',  # 𥣅
    0x258C6: 'zú',  # 𥣆
    # 0x258C7: '',  # 𥣇
    0x258C8: 'pú',  # 𥣈
    # 0x258C9: '',  # 𥣉
    # 0x258CA: '',  # 𥣊
    0x258CB: 'shǔ',  # 𥣋
    0x258CC: 'bǔ',  # 𥣌
    # 0x258CD: '',  # 𥣍
    # 0x258CE: '',  # 𥣎
    # 0x258CF: '',  # 𥣏
    # 0x258D0: '',  # 𥣐
    # 0x258D1: '',  # 𥣑
    # 0x258D2: '',  # 𥣒
    # 0x258D3: '',  # 𥣓
    # 0x258D4: '',  # 𥣔
    # 0x258D5: '',  # 𥣕
    # 0x258D6: '',  # 𥣖
    0x258D7: 'níng',  # 𥣗
    0x258D8: 'yǎn',  # 𥣘
    0x258D9: 'zhòu,còng',  # 𥣙
    # 0x258DA: '',  # 𥣚
    0x258DB: 'méng',  # 𥣛
    # 0x258DC: '',  # 𥣜
    0x258DD: 'biǎn',  # 𥣝
    # 0x258DE: '',  # 𥣞
    0x258DF: 'xiàng',  # 𥣟
    # 0x258E0: '',  # 𥣠
    # 0x258E1: '',  # 𥣡
    # 0x258E2: '',  # 𥣢
    # 0x258E3: '',  # 𥣣
    0x258E4: 'lù',  # 𥣤
    0x258E5: 'lí',  # 𥣥
    # 0x258E6: '',  # 𥣦
    # 0x258E7: '',  # 𥣧
    # 0x258E8: '',  # 𥣨
    0x258E9: 'jì',  # 𥣩
    # 0x258EA: '',  # 𥣪
    0x258EB: 'miè',  # 𥣫
    0x258EC: 'lèi',  # 𥣬
    # 0x258ED: '',  # 𥣭
    0x258EE: 'zhì',  # 𥣮
    0x258EF: 'yōu',  # 𥣯
    0x258F0: 'biǎn',  # 𥣰
    0x258F1: 'sè',  # 𥣱
    # 0x258F2: '',  # 𥣲
    # 0x258F3: '',  # 𥣳
    # 0x258F4: '',  # 𥣴
    # 0x258F5: '',  # 𥣵
    # 0x258F6: '',  # 𥣶
    # 0x258F7: '',  # 𥣷
    0x258F8: 'mù',  # 𥣸
    0x258F9: 'ràn',  # 𥣹
    # 0x258FA: '',  # 𥣺
    # 0x258FB: '',  # 𥣻
    # 0x258FC: '',  # 𥣼
    # 0x258FD: '',  # 𥣽
    # 0x258FE: '',  # 𥣾
    # 0x258FF: '',  # 𥣿
    # 0x25900: '',  # 𥤀
    # 0x25901: '',  # 𥤁
    0x25902: 'niǎo',  # 𥤂
    # 0x25903: '',  # 𥤃
    # 0x25904: '',  # 𥤄
    # 0x25905: '',  # 𥤅
    # 0x25906: '',  # 𥤆
    # 0x25907: '',  # 𥤇
    # 0x25908: '',  # 𥤈
    # 0x25909: '',  # 𥤉
    0x2590A: 'quán',  # 𥤊
    0x2590B: 'zhé',  # 𥤋
    # 0x2590C: '',  # 𥤌
    # 0x2590D: '',  # 𥤍
    # 0x2590E: '',  # 𥤎
    # 0x2590F: '',  # 𥤏
    0x25910: 'lèi,léi',  # 𥤐
    # 0x25911: '',  # 𥤑
    # 0x25912: '',  # 𥤒
    # 0x25913: '',  # 𥤓
    # 0x25914: '',  # 𥤔
    # 0x25915: '',  # 𥤕
    # 0x25916: '',  # 𥤖
    0x25917: 'dǎng',  # 𥤗
    0x25918: 'jué',  # 𥤘
    # 0x25919: '',  # 𥤙
    # 0x2591A: '',  # 𥤚
    # 0x2591B: '',  # 𥤛
    0x2591C: 'líng',  # 𥤜
    # 0x2591D: '',  # 𥤝
    0x2591E: 'líng',  # 𥤞
    0x2591F: 'yán',  # 𥤟
    # 0x25920: '',  # 𥤠
    0x25921: 'shēn',  # 𥤡
    # 0x25922: '',  # 𥤢
    0x25923: 'yǎo',  # 𥤣
    0x25924: 'zhèn',  # 𥤤
    0x25925: 'qī',  # 𥤥
    0x25926: 'ài',  # 𥤦
    # 0x25927: '',  # 𥤧
    0x25928: 'nú',  # 𥤨
    0x25929: 'mǎng',  # 𥤩
    # 0x2592A: '',  # 𥤪
    # 0x2592B: '',  # 𥤫
    # 0x2592C: '',  # 𥤬
    # 0x2592D: '',  # 𥤭
    # 0x2592E: '',  # 𥤮
    # 0x2592F: '',  # 𥤯
    # 0x25930: '',  # 𥤰
    0x25931: 'kǎn,hān',  # 𥤱
    # 0x25932: '',  # 𥤲
    0x25933: 'jiū,cuàn',  # 𥤳
    0x25934: 'yǎn',  # 𥤴
    0x25935: 'miàn',  # 𥤵
    # 0x25936: '',  # 𥤶
    0x25937: 'yín',  # 𥤷
    0x25938: 'wán',  # 𥤸
    0x25939: 'yào,yǎo',  # 𥤹
    0x2593A: 'wā',  # 𥤺
    0x2593B: 'pí',  # 𥤻
    0x2593C: 'suì',  # 𥤼
    # 0x2593D: '',  # 𥤽
    # 0x2593E: '',  # 𥤾
    # 0x2593F: '',  # 𥤿
    # 0x25940: '',  # 𥥀
    # 0x25941: '',  # 𥥁
    # 0x25942: '',  # 𥥂
    # 0x25943: '',  # 𥥃
    # 0x25944: '',  # 𥥄
    0x25945: 'kǒng',  # 𥥅
    # 0x25946: '',  # 𥥆
    # 0x25947: '',  # 𥥇
    0x25948: 'hóng,wòng',  # 𥥈
    # 0x25949: '',  # 𥥉
    0x2594A: 'mǐng',  # 𥥊
    0x2594B: 'líng',  # 𥥋
    0x2594C: 'yì,dié',  # 𥥌
    0x2594D: 'shēn,shèn',  # 𥥍
    # 0x2594E: '',  # 𥥎
    0x2594F: 'zuò',  # 𥥏
    # 0x25950: '',  # 𥥐
    # 0x25951: '',  # 𥥑
    # 0x25952: '',  # 𥥒
    # 0x25953: '',  # 𥥓
    # 0x25954: '',  # 𥥔
    # 0x25955: '',  # 𥥕
    # 0x25956: '',  # 𥥖
    # 0x25957: '',  # 𥥗
    # 0x25958: '',  # 𥥘
    # 0x25959: '',  # 𥥙
    # 0x2595A: '',  # 𥥚
    0x2595B: 'tū,bá',  # 𥥛
    # 0x2595C: '',  # 𥥜
    0x2595D: 'yòng',  # 𥥝
    # 0x2595E: '',  # 𥥞
    0x2595F: 'wà',  # 𥥟
    0x25960: 'guǐ',  # 𥥠
    0x25961: 'hòng',  # 𥥡
    # 0x25962: '',  # 𥥢
    # 0x25963: '',  # 𥥣
    # 0x25964: '',  # 𥥤
    0x25965: 'shì',  # 𥥥
    # 0x25966: '',  # 𥥦
    0x25967: 'xiòng',  # 𥥧
    # 0x25968: '',  # 𥥨
    0x25969: 'ā,xiàng',  # 𥥩
    # 0x2596A: '',  # 𥥪
    # 0x2596B: '',  # 𥥫
    # 0x2596C: '',  # 𥥬
    # 0x2596D: '',  # 𥥭
    # 0x2596E: '',  # 𥥮
    # 0x2596F: '',  # 𥥯
    # 0x25970: '',  # 𥥰
    0x25971: 'chéng',  # 𥥱
    # 0x25972: '',  # 𥥲
    0x25973: 'kēng',  # 𥥳
    0x25974: 'yì',  # 𥥴
    0x25975: 'yàng',  # 𥥵
    0x25976: 'tíng',  # 𥥶
    0x25977: 'dòu',  # 𥥷
    0x25978: 'chá',  # 𥥸
    0x25979: 'liù',  # 𥥹
    # 0x2597A: '',  # 𥥺
    0x2597B: 'qìng',  # 𥥻
    # 0x2597C: '',  # 𥥼
    0x2597D: 'qiú',  # 𥥽
    0x2597E: 'xuǎn',  # 𥥾
    0x2597F: 'shēn',  # 𥥿
    0x25980: 'kuān,mì',  # 𥦀
    0x25981: 'tòng',  # 𥦁
    # 0x25982: '',  # 𥦂
    0x25983: 'qiǎn',  # 𥦃
    # 0x25984: '',  # 𥦄
    0x25985: 'chòu',  # 𥦅
    # 0x25986: '',  # 𥦆
    # 0x25987: '',  # 𥦇
    # 0x25988: '',  # 𥦈
    # 0x25989: '',  # 𥦉
    0x2598A: 'wěn',  # 𥦊
    # 0x2598B: '',  # 𥦋
    0x2598C: 'lòng',  # 𥦌
    0x2598D: 'ǎn,yǎn',  # 𥦍
    # 0x2598E: '',  # 𥦎
    # 0x2598F: '',  # 𥦏
    # 0x25990: '',  # 𥦐
    # 0x25991: '',  # 𥦑
    # 0x25992: '',  # 𥦒
    # 0x25993: '',  # 𥦓
    0x25994: 'kǎn',  # 𥦔
    # 0x25995: '',  # 𥦕
    0x25996: 'yǎo',  # 𥦖
    0x25997: 'chuāng',  # 𥦗
    0x25998: 'fú',  # 𥦘
    # 0x25999: '',  # 𥦙
    # 0x2599A: '',  # 𥦚
    # 0x2599B: '',  # 𥦛
    0x2599C: 'bèng',  # 𥦜
    0x2599D: 'lǎn',  # 𥦝
    0x2599E: 'qià',  # 𥦞
    0x2599F: 'diàn',  # 𥦟
    # 0x259A0: '',  # 𥦠
    # 0x259A1: '',  # 𥦡
    0x259A2: 'jiào',  # 𥦢
    0x259A3: 'guī',  # 𥦣
    # 0x259A4: '',  # 𥦤
    0x259A5: 'xiòng',  # 𥦥
    # 0x259A6: '',  # 𥦦
    # 0x259A7: '',  # 𥦧
    0x259A8: 'kè',  # 𥦨
    # 0x259A9: '',  # 𥦩
    # 0x259AA: '',  # 𥦪
    # 0x259AB: '',  # 𥦫
    # 0x259AC: '',  # 𥦬
    # 0x259AD: '',  # 𥦭
    # 0x259AE: '',  # 𥦮
    # 0x259AF: '',  # 𥦯
    # 0x259B0: '',  # 𥦰
    # 0x259B1: '',  # 𥦱
    # 0x259B2: '',  # 𥦲
    # 0x259B3: '',  # 𥦳
    # 0x259B4: '',  # 𥦴
    # 0x259B5: '',  # 𥦵
    0x259B6: 'xiàn',  # 𥦶
    0x259B7: 'wòng',  # 𥦷
    # 0x259B8: '',  # 𥦸
    # 0x259B9: '',  # 𥦹
    # 0x259BA: '',  # 𥦺
    # 0x259BB: '',  # 𥦻
    # 0x259BC: '',  # 𥦼
    # 0x259BD: '',  # 𥦽
    # 0x259BE: '',  # 𥦾
    0x259BF: 'jiào',  # 𥦿
    # 0x259C0: '',  # 𥧀
    # 0x259C1: '',  # 𥧁
    0x259C2: 'gǒng',  # 𥧂
    # 0x259C3: '',  # 𥧃
    # 0x259C4: '',  # 𥧄
    # 0x259C5: '',  # 𥧅
    0x259C6: 'ǒu',  # 𥧆
    0x259C7: 'kē,cháo',  # 𥧇
    # 0x259C8: '',  # 𥧈
    # 0x259C9: '',  # 𥧉
    # 0x259CA: '',  # 𥧊
    0x259CB: 'kū',  # 𥧋
    # 0x259CC: '',  # 𥧌
    # 0x259CD: '',  # 𥧍
    # 0x259CE: '',  # 𥧎
    # 0x259CF: '',  # 𥧏
    # 0x259D0: '',  # 𥧐
    0x259D1: 'tián,diān,yǎn,chǎn',  # 𥧑
    0x259D2: 'gòu',  # 𥧒
    0x259D3: 'mǎ',  # 𥧓
    0x259D4: 'pì',  # 𥧔
    0x259D5: 'liù',  # 𥧕
    # 0x259D6: '',  # 𥧖
    # 0x259D7: '',  # 𥧗
    # 0x259D8: '',  # 𥧘
    0x259D9: 'wèi',  # 𥧙
    0x259DA: 'wěn',  # 𥧚
    # 0x259DB: '',  # 𥧛
    # 0x259DC: '',  # 𥧜
    # 0x259DD: '',  # 𥧝
    # 0x259DE: '',  # 𥧞
    # 0x259DF: '',  # 𥧟
    # 0x259E0: '',  # 𥧠
    0x259E1: 'gòng',  # 𥧡
    # 0x259E2: '',  # 𥧢
    0x259E3: 'tú',  # 𥧣
    0x259E4: 'níng',  # 𥧤
    # 0x259E5: '',  # 𥧥
    0x259E6: 'jiào',  # 𥧦
    0x259E7: 'mì',  # 𥧧
    # 0x259E8: '',  # 𥧨
    # 0x259E9: '',  # 𥧩
    # 0x259EA: '',  # 𥧪
    0x259EB: 'láng',  # 𥧫
    0x259EC: 'qiǎn',  # 𥧬
    0x259ED: 'mán',  # 𥧭
    0x259EE: 'zhé',  # 𥧮
    # 0x259EF: '',  # 𥧯
    0x259F0: 'huà',  # 𥧰
    0x259F1: 'yōng',  # 𥧱
    0x259F2: 'jìn,jǐn',  # 𥧲
    # 0x259F3: '',  # 𥧳
    0x259F4: 'mèi',  # 𥧴
    # 0x259F5: '',  # 𥧵
    # 0x259F6: '',  # 𥧶
    0x259F7: 'fú',  # 𥧷
    # 0x259F8: '',  # 𥧸
    # 0x259F9: '',  # 𥧹
    # 0x259FA: '',  # 𥧺
    0x259FB: 'qú',  # 𥧻
    # 0x259FC: '',  # 𥧼
    # 0x259FD: '',  # 𥧽
    # 0x259FE: '',  # 𥧾
    # 0x259FF: '',  # 𥧿
    # 0x25A00: '',  # 𥨀
    # 0x25A01: '',  # 𥨁
    # 0x25A02: '',  # 𥨂
    # 0x25A03: '',  # 𥨃
    # 0x25A04: '',  # 𥨄
    # 0x25A05: '',  # 𥨅
    # 0x25A06: '',  # 𥨆
    # 0x25A07: '',  # 𥨇
    # 0x25A08: '',  # 𥨈
    0x25A09: 'hū',  # 𥨉
    # 0x25A0A: '',  # 𥨊
    # 0x25A0B: '',  # 𥨋
    0x25A0C: 'liù',  # 𥨌
    0x25A0D: 'fù',  # 𥨍
    0x25A0E: 'dàn',  # 𥨎
    # 0x25A0F: '',  # 𥨏
    0x25A10: 'gǒng',  # 𥨐
    # 0x25A11: '',  # 𥨑
    0x25A12: 'cuì,cuàn',  # 𥨒
    # 0x25A13: '',  # 𥨓
    # 0x25A14: '',  # 𥨔
    0x25A15: 'xǐng',  # 𥨕
    # 0x25A16: '',  # 𥨖
    # 0x25A17: '',  # 𥨗
    # 0x25A18: '',  # 𥨘
    # 0x25A19: '',  # 𥨙
    # 0x25A1A: '',  # 𥨚
    # 0x25A1B: '',  # 𥨛
    0x25A1C: 'tū',  # 𥨜
    0x25A1D: 'shòu',  # 𥨝
    # 0x25A1E: '',  # 𥨞
    # 0x25A1F: '',  # 𥨟
    # 0x25A20: '',  # 𥨠
    # 0x25A21: '',  # 𥨡
    # 0x25A22: '',  # 𥨢
    # 0x25A23: '',  # 𥨣
    # 0x25A24: '',  # 𥨤
    # 0x25A25: '',  # 𥨥
    # 0x25A26: '',  # 𥨦
    # 0x25A27: '',  # 𥨧
    # 0x25A28: '',  # 𥨨
    # 0x25A29: '',  # 𥨩
    0x25A2A: 'qióng',  # 𥨪
    # 0x25A2B: '',  # 𥨫
    # 0x25A2C: '',  # 𥨬
    # 0x25A2D: '',  # 𥨭
    # 0x25A2E: '',  # 𥨮
    # 0x25A2F: '',  # 𥨯
    # 0x25A30: '',  # 𥨰
    # 0x25A31: '',  # 𥨱
    # 0x25A32: '',  # 𥨲
    0x25A33: 'róng',  # 𥨳
    # 0x25A34: '',  # 𥨴
    # 0x25A35: '',  # 𥨵
    # 0x25A36: '',  # 𥨶
    # 0x25A37: '',  # 𥨷
    # 0x25A38: '',  # 𥨸
    # 0x25A39: '',  # 𥨹
    # 0x25A3A: '',  # 𥨺
    0x25A3B: 'lì',  # 𥨻
    # 0x25A3C: '',  # 𥨼
    # 0x25A3D: '',  # 𥨽
    # 0x25A3E: '',  # 𥨾
    0x25A3F: 'jī',  # 𥨿
    0x25A40: 'tuò',  # 𥩀
    # 0x25A41: '',  # 𥩁
    # 0x25A42: '',  # 𥩂
    # 0x25A43: '',  # 𥩃
    # 0x25A44: '',  # 𥩄
    # 0x25A45: '',  # 𥩅
    # 0x25A46: '',  # 𥩆
    # 0x25A47: '',  # 𥩇
    # 0x25A48: '',  # 𥩈
    # 0x25A49: '',  # 𥩉
    # 0x25A4A: '',  # 𥩊
    # 0x25A4B: '',  # 𥩋
    0x25A4C: 'tóng',  # 𥩌
    # 0x25A4D: '',  # 𥩍
    # 0x25A4E: '',  # 𥩎
    # 0x25A4F: '',  # 𥩏
    # 0x25A50: '',  # 𥩐
    # 0x25A51: '',  # 𥩑
    0x25A52: 'tán',  # 𥩒
    0x25A53: 'qiè',  # 𥩓
    0x25A54: 'líng',  # 𥩔
    # 0x25A55: '',  # 𥩕
    0x25A56: 'yì',  # 𥩖
    0x25A57: 'ruǎn',  # 𥩗
    # 0x25A58: '',  # 𥩘
    0x25A59: 'pǎ',  # 𥩙
    # 0x25A5A: '',  # 𥩚
    # 0x25A5B: '',  # 𥩛
    # 0x25A5C: '',  # 𥩜
    0x25A5D: 'cà',  # 𥩝
    # 0x25A5E: '',  # 𥩞
    # 0x25A5F: '',  # 𥩟
    # 0x25A60: '',  # 𥩠
    0x25A61: 'yuè',  # 𥩡
    0x25A62: 'què',  # 𥩢
    0x25A63: 'zhù',  # 𥩣
    0x25A64: 'hài',  # 𥩤
    # 0x25A65: '',  # 𥩥
    # 0x25A66: '',  # 𥩦
    # 0x25A67: '',  # 𥩧
    # 0x25A68: '',  # 𥩨
    # 0x25A69: '',  # 𥩩
    # 0x25A6A: '',  # 𥩪
    # 0x25A6B: '',  # 𥩫
    # 0x25A6C: '',  # 𥩬
    # 0x25A6D: '',  # 𥩭
    0x25A6E: 'è',  # 𥩮
    # 0x25A6F: '',  # 𥩯
    # 0x25A70: '',  # 𥩰
    0x25A71: 'fá',  # 𥩱
    0x25A72: 'hài',  # 𥩲
    # 0x25A73: '',  # 𥩳
    # 0x25A74: '',  # 𥩴
    # 0x25A75: '',  # 𥩵
    # 0x25A76: '',  # 𥩶
    # 0x25A77: '',  # 𥩷
    # 0x25A78: '',  # 𥩸
    # 0x25A79: '',  # 𥩹
    # 0x25A7A: '',  # 𥩺
    # 0x25A7B: '',  # 𥩻
    # 0x25A7C: '',  # 𥩼
    # 0x25A7D: '',  # 𥩽
    # 0x25A7E: '',  # 𥩾
    # 0x25A7F: '',  # 𥩿
    0x25A80: 'bū',  # 𥪀
    0x25A81: 'pīng',  # 𥪁
    0x25A82: 'liè',  # 𥪂
    # 0x25A83: '',  # 𥪃
    # 0x25A84: '',  # 𥪄
    # 0x25A85: '',  # 𥪅
    # 0x25A86: '',  # 𥪆
    # 0x25A87: '',  # 𥪇
    # 0x25A88: '',  # 𥪈
    # 0x25A89: '',  # 𥪉
    0x25A8A: 'kuǐ,jué',  # 𥪊
    0x25A8B: 'fú',  # 𥪋
    0x25A8C: 'tiǎn',  # 𥪌
    0x25A8D: 'wò',  # 𥪍
    # 0x25A8E: '',  # 𥪎
    0x25A8F: 'jū',  # 𥪏
    # 0x25A90: '',  # 𥪐
    # 0x25A91: '',  # 𥪑
    # 0x25A92: '',  # 𥪒
    # 0x25A93: '',  # 𥪓
    # 0x25A94: '',  # 𥪔
    # 0x25A95: '',  # 𥪕
    # 0x25A96: '',  # 𥪖
    # 0x25A97: '',  # 𥪗
    0x25A98: 'zhēn',  # 𥪘
    # 0x25A99: '',  # 𥪙
    0x25A9A: 'fú',  # 𥪚
    # 0x25A9B: '',  # 𥪛
    # 0x25A9C: '',  # 𥪜
    # 0x25A9D: '',  # 𥪝
    # 0x25A9E: '',  # 𥪞
    # 0x25A9F: '',  # 𥪟
    # 0x25AA0: '',  # 𥪠
    0x25AA1: 'shù',  # 𥪡
    0x25AA2: 'lóng',  # 𥪢
    # 0x25AA3: '',  # 𥪣
    # 0x25AA4: '',  # 𥪤
    # 0x25AA5: '',  # 𥪥
    0x25AA6: 'xì',  # 𥪦
    0x25AA7: 'tián',  # 𥪧
    # 0x25AA8: '',  # 𥪨
    # 0x25AA9: '',  # 𥪩
    # 0x25AAA: '',  # 𥪪
    0x25AAB: 'jì',  # 𥪫
    # 0x25AAC: '',  # 𥪬
    # 0x25AAD: '',  # 𥪭
    # 0x25AAE: '',  # 𥪮
    0x25AAF: 'yào,qiáo',  # 𥪯
    # 0x25AB0: '',  # 𥪰
    0x25AB1: 'cù',  # 𥪱
    # 0x25AB2: '',  # 𥪲
    # 0x25AB3: '',  # 𥪳
    0x25AB4: 'pàng',  # 𥪴
    0x25AB5: 'qiè',  # 𥪵
    # 0x25AB6: '',  # 𥪶
    # 0x25AB7: '',  # 𥪷
    # 0x25AB8: '',  # 𥪸
    # 0x25AB9: '',  # 𥪹
    # 0x25ABA: '',  # 𥪺
    0x25ABB: 'lóng',  # 𥪻
    0x25ABC: 'jǐ',  # 𥪼
    # 0x25ABD: '',  # 𥪽
    # 0x25ABE: '',  # 𥪾
    # 0x25ABF: '',  # 𥪿
    0x25AC0: 'wāi',  # 𥫀
    # 0x25AC1: '',  # 𥫁
    0x25AC2: 'tóng',  # 𥫂
    0x25AC3: 'yí',  # 𥫃
    # 0x25AC4: '',  # 𥫄
    0x25AC5: 'chāng',  # 𥫅
    # 0x25AC6: '',  # 𥫆
    # 0x25AC7: '',  # 𥫇
    # 0x25AC8: '',  # 𥫈
    # 0x25AC9: '',  # 𥫉
    # 0x25ACA: '',  # 𥫊
    0x25ACB: 'gōng',  # 𥫋
    # 0x25ACC: '',  # 𥫌
    # 0x25ACD: '',  # 𥫍
    0x25ACE: 'dòng',  # 𥫎
    # 0x25ACF: '',  # 𥫏
    # 0x25AD0: '',  # 𥫐
    # 0x25AD1: '',  # 𥫑
    # 0x25AD2: '',  # 𥫒
    # 0x25AD3: '',  # 𥫓
    0x25AD4: 'gòng',  # 𥫔
    # 0x25AD5: '',  # 𥫕
    0x25AD6: 'xiāng',  # 𥫖
    # 0x25AD7: '',  # 𥫗
    # 0x25AD8: '',  # 𥫘
    0x25AD9: 'tǐng',  # 𥫙
    # 0x25ADA: '',  # 𥫚
    0x25ADB: 'zhuān',  # 𥫛
    0x25ADC: 'yǐ',  # 𥫜
    0x25ADD: 'yì',  # 𥫝
    0x25ADE: 'zǐ',  # 𥫞
    0x25ADF: 'qǐ',  # 𥫟
    # 0x25AE0: '',  # 𥫠
    # 0x25AE1: '',  # 𥫡
    0x25AE2: 'chǎ',  # 𥫢
    # 0x25AE3: '',  # 𥫣
    # 0x25AE4: '',  # 𥫤
    # 0x25AE5: '',  # 𥫥
    # 0x25AE6: '',  # 𥫦
    # 0x25AE7: '',  # 𥫧
    # 0x25AE8: '',  # 𥫨
    # 0x25AE9: '',  # 𥫩
    # 0x25AEA: '',  # 𥫪
    # 0x25AEB: '',  # 𥫫
    0x25AEC: 'dùn',  # 𥫬
    # 0x25AED: '',  # 𥫭
    # 0x25AEE: '',  # 𥫮
    0x25AEF: 'chōng',  # 𥫯
    0x25AF0: 'lù',  # 𥫰
    0x25AF1: 'dùn',  # 𥫱
    # 0x25AF2: '',  # 𥫲
    0x25AF3: 'fāng',  # 𥫳
    0x25AF4: 'shì',  # 𥫴
    0x25AF5: 'tì',  # 𥫵
    0x25AF6: 'jī',  # 𥫶
    0x25AF7: 'qiū',  # 𥫷
    0x25AF8: 'shuǐ',  # 𥫸
    0x25AF9: 'chén',  # 𥫹
    # 0x25AFA: '',  # 𥫺
    # 0x25AFB: '',  # 𥫻
    0x25AFC: 'huàng',  # 𥫼
    0x25AFD: 'shi',  # 𥫽
    # 0x25AFE: '',  # 𥫾
    # 0x25AFF: '',  # 𥫿
    # 0x25B00: '',  # 𥬀
    # 0x25B01: '',  # 𥬁
    # 0x25B02: '',  # 𥬂
    # 0x25B03: '',  # 𥬃
    # 0x25B04: '',  # 𥬄
    # 0x25B05: '',  # 𥬅
    0x25B06: 'lóng',  # 𥬆
    # 0x25B07: '',  # 𥬇
    0x25B08: 'mǎn',  # 𥬈
    0x25B09: 'gōu',  # 𥬉
    # 0x25B0A: '',  # 𥬊
    # 0x25B0B: '',  # 𥬋
    # 0x25B0C: '',  # 𥬌
    0x25B0D: 'xiān',  # 𥬍
    0x25B0E: 'mò',  # 𥬎
    # 0x25B0F: '',  # 𥬏
    0x25B10: 'shěn',  # 𥬐
    # 0x25B11: '',  # 𥬑
    0x25B12: 'pō',  # 𥬒
    0x25B13: 'yào',  # 𥬓
    0x25B14: 'qū',  # 𥬔
    0x25B15: 'rǎn',  # 𥬕
    # 0x25B16: '',  # 𥬖
    # 0x25B17: '',  # 𥬗
    # 0x25B18: '',  # 𥬘
    0x25B19: 'jù',  # 𥬙
    # 0x25B1A: '',  # 𥬚
    # 0x25B1B: '',  # 𥬛
    0x25B1C: 'yǐn',  # 𥬜
    0x25B1D: 'bái',  # 𥬝
    # 0x25B1E: '',  # 𥬞
    # 0x25B1F: '',  # 𥬟
    # 0x25B20: '',  # 𥬠
    # 0x25B21: '',  # 𥬡
    # 0x25B22: '',  # 𥬢
    # 0x25B23: '',  # 𥬣
    # 0x25B24: '',  # 𥬤
    # 0x25B25: '',  # 𥬥
    # 0x25B26: '',  # 𥬦
    # 0x25B27: '',  # 𥬧
    # 0x25B28: '',  # 𥬨
    # 0x25B29: '',  # 𥬩
    0x25B2A: 'róng',  # 𥬪
    0x25B2B: 'chuǎn',  # 𥬫
    0x25B2C: 'niè',  # 𥬬
    0x25B2D: 'lì,liè',  # 𥬭
    0x25B2E: 'jiāng',  # 𥬮
    0x25B2F: 'kǎo',  # 𥬯
    0x25B30: 'cè,zhà',  # 𥬰
    0x25B31: 'chòng',  # 𥬱
    0x25B32: 'zhuā,duò',  # 𥬲
    0x25B33: 'zǐ',  # 𥬳
    0x25B34: 'yáng',  # 𥬴
    # 0x25B35: '',  # 𥬵
    # 0x25B36: '',  # 𥬶
    # 0x25B37: '',  # 𥬷
    # 0x25B38: '',  # 𥬸
    # 0x25B39: '',  # 𥬹
    # 0x25B3A: '',  # 𥬺
    # 0x25B3B: '',  # 𥬻
    0x25B3C: 'wěn',  # 𥬼
    # 0x25B3D: '',  # 𥬽
    # 0x25B3E: '',  # 𥬾
    # 0x25B3F: '',  # 𥬿
    # 0x25B40: '',  # 𥭀
    # 0x25B41: '',  # 𥭁
    # 0x25B42: '',  # 𥭂
    # 0x25B43: '',  # 𥭃
    # 0x25B44: '',  # 𥭄
    # 0x25B45: '',  # 𥭅
    # 0x25B46: '',  # 𥭆
    # 0x25B47: '',  # 𥭇
    # 0x25B48: '',  # 𥭈
    # 0x25B49: '',  # 𥭉
    # 0x25B4A: '',  # 𥭊
    0x25B4B: 'jì',  # 𥭋
    0x25B4C: 'jì',  # 𥭌
    # 0x25B4D: '',  # 𥭍
    # 0x25B4E: '',  # 𥭎
    # 0x25B4F: '',  # 𥭏
    0x25B50: 'lǜ',  # 𥭐
    0x25B51: 'qiú',  # 𥭑
    0x25B52: 'dùn',  # 𥭒
    0x25B53: 'báo',  # 𥭓
    0x25B54: 'chān',  # 𥭔
    # 0x25B55: '',  # 𥭕
    0x25B56: 'bó',  # 𥭖
    # 0x25B57: '',  # 𥭗
    0x25B58: 'chī',  # 𥭘
    0x25B59: 'zhè,niè',  # 𥭙
    0x25B5A: 'màng',  # 𥭚
    # 0x25B5B: '',  # 𥭛
    0x25B5C: 'jì',  # 𥭜
    0x25B5D: 'miào',  # 𥭝
    0x25B5E: 'yuàn',  # 𥭞
    0x25B5F: 'suō',  # 𥭟
    0x25B60: 'wú',  # 𥭠
    0x25B61: 'zhì',  # 𥭡
    0x25B62: 'pīng',  # 𥭢
    # 0x25B63: '',  # 𥭣
    # 0x25B64: '',  # 𥭤
    0x25B65: 'chōng',  # 𥭥
    # 0x25B66: '',  # 𥭦
    # 0x25B67: '',  # 𥭧
    # 0x25B68: '',  # 𥭨
    # 0x25B69: '',  # 𥭩
    # 0x25B6A: '',  # 𥭪
    0x25B6B: 'mí',  # 𥭫
    0x25B6C: 'féi',  # 𥭬
    0x25B6D: 'cuō',  # 𥭭
    0x25B6E: 'méng',  # 𥭮
    # 0x25B6F: '',  # 𥭯
    # 0x25B70: '',  # 𥭰
    # 0x25B71: '',  # 𥭱
    # 0x25B72: '',  # 𥭲
    # 0x25B73: '',  # 𥭳
    # 0x25B74: '',  # 𥭴
    # 0x25B75: '',  # 𥭵
    # 0x25B76: '',  # 𥭶
    # 0x25B77: '',  # 𥭷
    # 0x25B78: '',  # 𥭸
    # 0x25B79: '',  # 𥭹
    # 0x25B7A: '',  # 𥭺
    # 0x25B7B: '',  # 𥭻
    # 0x25B7C: '',  # 𥭼
    # 0x25B7D: '',  # 𥭽
    # 0x25B7E: '',  # 𥭾
    # 0x25B7F: '',  # 𥭿
    # 0x25B80: '',  # 𥮀
    # 0x25B81: '',  # 𥮁
    # 0x25B82: '',  # 𥮂
    # 0x25B83: '',  # 𥮃
    # 0x25B84: '',  # 𥮄
    # 0x25B85: '',  # 𥮅
    # 0x25B86: '',  # 𥮆
    # 0x25B87: '',  # 𥮇
    # 0x25B88: '',  # 𥮈
    # 0x25B89: '',  # 𥮉
    # 0x25B8A: '',  # 𥮊
    # 0x25B8B: '',  # 𥮋
    # 0x25B8C: '',  # 𥮌
    0x25B8D: 'yín',  # 𥮍
    0x25B8E: 'mǎng',  # 𥮎
    0x25B8F: 'diǎn',  # 𥮏
    0x25B90: 'diāo',  # 𥮐
    # 0x25B91: '',  # 𥮑
    0x25B92: 'qián,zhān',  # 𥮒
    # 0x25B93: '',  # 𥮓
    # 0x25B94: '',  # 𥮔
    0x25B95: 'hàng',  # 𥮕
    0x25B96: 'zhí',  # 𥮖
    0x25B97: 'jú',  # 𥮗
    0x25B98: 'niàn',  # 𥮘
    # 0x25B99: '',  # 𥮙
    0x25B9A: 'sān',  # 𥮚
    # 0x25B9B: '',  # 𥮛
    # 0x25B9C: '',  # 𥮜
    0x25B9D: 'gǔ',  # 𥮝
    # 0x25B9E: '',  # 𥮞
    # 0x25B9F: '',  # 𥮟
    # 0x25BA0: '',  # 𥮠
    # 0x25BA1: '',  # 𥮡
    # 0x25BA2: '',  # 𥮢
    0x25BA3: 'zhuā',  # 𥮣
    0x25BA4: 'niè',  # 𥮤
    0x25BA5: 'zhuó',  # 𥮥
    # 0x25BA6: '',  # 𥮦
    0x25BA7: 'yè',  # 𥮧
    0x25BA8: 'còng',  # 𥮨
    # 0x25BA9: '',  # 𥮩
    0x25BAA: 'xū,jí',  # 𥮪
    # 0x25BAB: '',  # 𥮫
    0x25BAC: 'xì',  # 𥮬
    # 0x25BAD: '',  # 𥮭
    # 0x25BAE: '',  # 𥮮
    0x25BAF: 'bō',  # 𥮯
    # 0x25BB0: '',  # 𥮰
    # 0x25BB1: '',  # 𥮱
    # 0x25BB2: '',  # 𥮲
    # 0x25BB3: '',  # 𥮳
    # 0x25BB4: '',  # 𥮴
    # 0x25BB5: '',  # 𥮵
    # 0x25BB6: '',  # 𥮶
    # 0x25BB7: '',  # 𥮷
    # 0x25BB8: '',  # 𥮸
    # 0x25BB9: '',  # 𥮹
    # 0x25BBA: '',  # 𥮺
    # 0x25BBB: '',  # 𥮻
    # 0x25BBC: '',  # 𥮼
    # 0x25BBD: '',  # 𥮽
    # 0x25BBE: '',  # 𥮾
    # 0x25BBF: '',  # 𥮿
    # 0x25BC0: '',  # 𥯀
    # 0x25BC1: '',  # 𥯁
    # 0x25BC2: '',  # 𥯂
    0x25BC3: 'yǎn',  # 𥯃
    # 0x25BC4: '',  # 𥯄
    # 0x25BC5: '',  # 𥯅
    # 0x25BC6: '',  # 𥯆
    # 0x25BC7: '',  # 𥯇
    # 0x25BC8: '',  # 𥯈
    # 0x25BC9: '',  # 𥯉
    # 0x25BCA: '',  # 𥯊
    # 0x25BCB: '',  # 𥯋
    # 0x25BCC: '',  # 𥯌
    # 0x25BCD: '',  # 𥯍
    # 0x25BCE: '',  # 𥯎
    # 0x25BCF: '',  # 𥯏
    # 0x25BD0: '',  # 𥯐
    0x25BD1: 'jǐn',  # 𥯑
    # 0x25BD2: '',  # 𥯒
    # 0x25BD3: '',  # 𥯓
    0x25BD4: 'jǔ',  # 𥯔
    0x25BD5: 'dàng',  # 𥯕
    0x25BD6: 'dù',  # 𥯖
    # 0x25BD7: '',  # 𥯗
    0x25BD8: 'yé',  # 𥯘
    0x25BD9: 'jìng',  # 𥯙
    0x25BDA: 'kè',  # 𥯚
    0x25BDB: 'luò',  # 𥯛
    0x25BDC: 'wěi',  # 𥯜
    0x25BDD: 'tū',  # 𥯝
    0x25BDE: 'yóu',  # 𥯞
    0x25BDF: 'pài',  # 𥯟
    # 0x25BE0: '',  # 𥯠
    0x25BE1: 'pí',  # 𥯡
    0x25BE2: 'dìng',  # 𥯢
    0x25BE3: 'miè',  # 𥯣
    0x25BE4: 'wěi',  # 𥯤
    0x25BE5: 'chè',  # 𥯥
    0x25BE6: 'jiàn,shà',  # 𥯦
    # 0x25BE7: '',  # 𥯧
    0x25BE8: 'sī',  # 𥯨
    0x25BE9: 'zhuó',  # 𥯩
    0x25BEA: 'sòu',  # 𥯪
    # 0x25BEB: '',  # 𥯫
    0x25BEC: 'ruǎn',  # 𥯬
    # 0x25BED: '',  # 𥯭
    0x25BEE: 'yú',  # 𥯮
    # 0x25BEF: '',  # 𥯯
    # 0x25BF0: '',  # 𥯰
    # 0x25BF1: '',  # 𥯱
    # 0x25BF2: '',  # 𥯲
    0x25BF3: 'è',  # 𥯳
    # 0x25BF4: '',  # 𥯴
    # 0x25BF5: '',  # 𥯵
    0x25BF6: 'kǔ',  # 𥯶
    # 0x25BF7: '',  # 𥯷
    0x25BF8: 'zhù',  # 𥯸
    # 0x25BF9: '',  # 𥯹
    # 0x25BFA: '',  # 𥯺
    # 0x25BFB: '',  # 𥯻
    # 0x25BFC: '',  # 𥯼
    # 0x25BFD: '',  # 𥯽
    0x25BFE: 'xiá',  # 𥯾
    # 0x25BFF: '',  # 𥯿
    # 0x25C00: '',  # 𥰀
    # 0x25C01: '',  # 𥰁
    # 0x25C02: '',  # 𥰂
    # 0x25C03: '',  # 𥰃
    # 0x25C04: '',  # 𥰄
    # 0x25C05: '',  # 𥰅
    # 0x25C06: '',  # 𥰆
    # 0x25C07: '',  # 𥰇
    # 0x25C08: '',  # 𥰈
    # 0x25C09: '',  # 𥰉
    # 0x25C0A: '',  # 𥰊
    # 0x25C0B: '',  # 𥰋
    # 0x25C0C: '',  # 𥰌
    # 0x25C0D: '',  # 𥰍
    # 0x25C0E: '',  # 𥰎
    # 0x25C0F: '',  # 𥰏
    # 0x25C10: '',  # 𥰐
    # 0x25C11: '',  # 𥰑
    # 0x25C12: '',  # 𥰒
    # 0x25C13: '',  # 𥰓
    # 0x25C14: '',  # 𥰔
    # 0x25C15: '',  # 𥰕
    # 0x25C16: '',  # 𥰖
    # 0x25C17: '',  # 𥰗
    # 0x25C18: '',  # 𥰘
    # 0x25C19: '',  # 𥰙
    # 0x25C1A: '',  # 𥰚
    0x25C1B: 'fú',  # 𥰛
    0x25C1C: 'táo',  # 𥰜
    0x25C1D: 'xī',  # 𥰝
    0x25C1E: 'chōu,sǒu',  # 𥰞
    0x25C1F: 'gǎn,lǒng',  # 𥰟
    0x25C20: 'lǘ',  # 𥰠
    0x25C21: 'cè',  # 𥰡
    0x25C22: 'shàn',  # 𥰢
    0x25C23: 'liú',  # 𥰣
    # 0x25C24: '',  # 𥰤
    0x25C25: 'xì',  # 𥰥
    0x25C26: 'jī',  # 𥰦
    0x25C27: 'yǐ',  # 𥰧
    0x25C28: 'tán',  # 𥰨
    # 0x25C29: '',  # 𥰩
    0x25C2A: 'hú',  # 𥰪
    0x25C2B: 'shì',  # 𥰫
    # 0x25C2C: '',  # 𥰬
    0x25C2D: 'cuō,zhǎ,cī',  # 𥰭
    0x25C2E: 'gě',  # 𥰮
    # 0x25C2F: '',  # 𥰯
    0x25C30: 'shì,shé',  # 𥰰
    0x25C31: 'sāo',  # 𥰱
    0x25C32: 'hòng',  # 𥰲
    0x25C33: 'xiàn',  # 𥰳
    # 0x25C34: '',  # 𥰴
    # 0x25C35: '',  # 𥰵
    0x25C36: 'xiá',  # 𥰶
    # 0x25C37: '',  # 𥰷
    # 0x25C38: '',  # 𥰸
    # 0x25C39: '',  # 𥰹
    # 0x25C3A: '',  # 𥰺
    0x25C3B: 'mù',  # 𥰻
    0x25C3C: 'suǒ',  # 𥰼
    # 0x25C3D: '',  # 𥰽
    0x25C3E: 'zhài',  # 𥰾
    # 0x25C3F: '',  # 𥰿
    0x25C40: 'fū',  # 𥱀
    0x25C41: 'sè',  # 𥱁
    0x25C42: 'nú',  # 𥱂
    0x25C43: 'yì',  # 𥱃
    # 0x25C44: '',  # 𥱄
    # 0x25C45: '',  # 𥱅
    # 0x25C46: '',  # 𥱆
    # 0x25C47: '',  # 𥱇
    # 0x25C48: '',  # 𥱈
    # 0x25C49: '',  # 𥱉
    # 0x25C4A: '',  # 𥱊
    # 0x25C4B: '',  # 𥱋
    # 0x25C4C: '',  # 𥱌
    # 0x25C4D: '',  # 𥱍
    # 0x25C4E: '',  # 𥱎
    # 0x25C4F: '',  # 𥱏
    # 0x25C50: '',  # 𥱐
    # 0x25C51: '',  # 𥱑
    0x25C52: 'shì',  # 𥱒
    # 0x25C53: '',  # 𥱓
    # 0x25C54: '',  # 𥱔
    # 0x25C55: '',  # 𥱕
    # 0x25C56: '',  # 𥱖
    # 0x25C57: '',  # 𥱗
    # 0x25C58: '',  # 𥱘
    # 0x25C59: '',  # 𥱙
    # 0x25C5A: '',  # 𥱚
    # 0x25C5B: '',  # 𥱛
    # 0x25C5C: '',  # 𥱜
    # 0x25C5D: '',  # 𥱝
    # 0x25C5E: '',  # 𥱞
    # 0x25C5F: '',  # 𥱟
    # 0x25C60: '',  # 𥱠
    # 0x25C61: '',  # 𥱡
    # 0x25C62: '',  # 𥱢
    # 0x25C63: '',  # 𥱣
    # 0x25C64: '',  # 𥱤
    # 0x25C65: '',  # 𥱥
    # 0x25C66: '',  # 𥱦
    0x25C67: 'qín',  # 𥱧
    0x25C68: 'qìng',  # 𥱨
    # 0x25C69: '',  # 𥱩
    # 0x25C6A: '',  # 𥱪
    # 0x25C6B: '',  # 𥱫
    # 0x25C6C: '',  # 𥱬
    # 0x25C6D: '',  # 𥱭
    # 0x25C6E: '',  # 𥱮
    # 0x25C6F: '',  # 𥱯
    # 0x25C70: '',  # 𥱰
    # 0x25C71: '',  # 𥱱
    # 0x25C72: '',  # 𥱲
    # 0x25C73: '',  # 𥱳
    # 0x25C74: '',  # 𥱴
    0x25C75: 'huì,suì,xí',  # 𥱵
    0x25C76: 'shuǎng',  # 𥱶
    0x25C77: 'dǎn',  # 𥱷
    0x25C78: 'ōu',  # 𥱸
    0x25C79: 'mò',  # 𥱹
    0x25C7A: 'qiān',  # 𥱺
    0x25C7B: 'chì,tú',  # 𥱻
    0x25C7C: 'pái,pì',  # 𥱼
    0x25C7D: 'juàn',  # 𥱽
    # 0x25C7E: '',  # 𥱾
    # 0x25C7F: '',  # 𥱿
    0x25C80: 'cháo',  # 𥲀
    0x25C81: 'liè',  # 𥲁
    0x25C82: 'bīng',  # 𥲂
    0x25C83: 'kòu',  # 𥲃
    0x25C84: 'dàn',  # 𥲄
    0x25C85: 'chóu',  # 𥲅
    0x25C86: 'tōng',  # 𥲆
    0x25C87: 'dàn',  # 𥲇
    0x25C88: 'mǎn',  # 𥲈
    0x25C89: 'hù',  # 𥲉
    0x25C8A: 'liáo',  # 𥲊
    0x25C8B: 'xián',  # 𥲋
    # 0x25C8C: '',  # 𥲌
    0x25C8D: 'cáo',  # 𥲍
    0x25C8E: 'lù',  # 𥲎
    0x25C8F: 'chuàn',  # 𥲏
    0x25C90: 'wú',  # 𥲐
    0x25C91: 'mán',  # 𥲑
    # 0x25C92: '',  # 𥲒
    # 0x25C93: '',  # 𥲓
    # 0x25C94: '',  # 𥲔
    0x25C95: 'zǐ',  # 𥲕
    # 0x25C96: '',  # 𥲖
    0x25C97: 'dù',  # 𥲗
    # 0x25C98: '',  # 𥲘
    # 0x25C99: '',  # 𥲙
    0x25C9A: 'shuàng',  # 𥲚
    0x25C9B: 'fù',  # 𥲛
    0x25C9C: 'jù',  # 𥲜
    0x25C9D: 'zhòu',  # 𥲝
    # 0x25C9E: '',  # 𥲞
    0x25C9F: 'diào',  # 𥲟
    0x25CA0: 'wàng',  # 𥲠
    0x25CA1: 'chuāng',  # 𥲡
    0x25CA2: 'qiān',  # 𥲢
    0x25CA3: 'tuì',  # 𥲣
    # 0x25CA4: '',  # 𥲤
    0x25CA5: 'lián',  # 𥲥
    0x25CA6: 'biāo',  # 𥲦
    0x25CA7: 'lí',  # 𥲧
    # 0x25CA8: '',  # 𥲨
    # 0x25CA9: '',  # 𥲩
    0x25CAA: 'lí',  # 𥲪
    # 0x25CAB: '',  # 𥲫
    # 0x25CAC: '',  # 𥲬
    # 0x25CAD: '',  # 𥲭
    # 0x25CAE: '',  # 𥲮
    # 0x25CAF: '',  # 𥲯
    # 0x25CB0: '',  # 𥲰
    # 0x25CB1: '',  # 𥲱
    # 0x25CB2: '',  # 𥲲
    # 0x25CB3: '',  # 𥲳
    # 0x25CB4: '',  # 𥲴
    # 0x25CB5: '',  # 𥲵
    # 0x25CB6: '',  # 𥲶
    # 0x25CB7: '',  # 𥲷
    # 0x25CB8: '',  # 𥲸
    # 0x25CB9: '',  # 𥲹
    # 0x25CBA: '',  # 𥲺
    # 0x25CBB: '',  # 𥲻
    # 0x25CBC: '',  # 𥲼
    0x25CBD: 'cuó',  # 𥲽
    # 0x25CBE: '',  # 𥲾
    # 0x25CBF: '',  # 𥲿
    # 0x25CC0: '',  # 𥳀
    # 0x25CC1: '',  # 𥳁
    # 0x25CC2: '',  # 𥳂
    # 0x25CC3: '',  # 𥳃
    # 0x25CC4: '',  # 𥳄
    # 0x25CC5: '',  # 𥳅
    0x25CC6: 'bì',  # 𥳆
    0x25CC7: 'fù',  # 𥳇
    0x25CC8: 'cuì',  # 𥳈
    0x25CC9: 'dū',  # 𥳉
    # 0x25CCA: '',  # 𥳊
    0x25CCB: 'zàn,zān',  # 𥳋
    0x25CCC: 'lóng',  # 𥳌
    0x25CCD: 'xún',  # 𥳍
    0x25CCE: 'qióng',  # 𥳎
    0x25CCF: 'jī',  # 𥳏
    0x25CD0: 'qiǎn',  # 𥳐
    # 0x25CD1: '',  # 𥳑
    0x25CD2: 'jiǎn',  # 𥳒
    0x25CD3: 'shāo',  # 𥳓
    0x25CD4: 'duò',  # 𥳔
    0x25CD5: 'shū',  # 𥳕
    0x25CD6: 'bù',  # 𥳖
    0x25CD7: 'xū',  # 𥳗
    0x25CD8: 'dǒng',  # 𥳘
    # 0x25CD9: '',  # 𥳙
    0x25CDA: 'rán',  # 𥳚
    # 0x25CDB: '',  # 𥳛
    0x25CDC: 'yáng',  # 𥳜
    0x25CDD: 'ruǐ',  # 𥳝
    0x25CDE: 'lìn',  # 𥳞
    0x25CDF: 'jiǎn',  # 𥳟
    0x25CE0: 'dì',  # 𥳠
    0x25CE1: 'fén',  # 𥳡
    0x25CE2: 'diàn',  # 𥳢
    0x25CE3: 'zuì',  # 𥳣
    # 0x25CE4: '',  # 𥳤
    0x25CE5: 'nǐng',  # 𥳥
    # 0x25CE6: '',  # 𥳦
    # 0x25CE7: '',  # 𥳧
    # 0x25CE8: '',  # 𥳨
    # 0x25CE9: '',  # 𥳩
    0x25CEA: 'suàn',  # 𥳪
    0x25CEB: 'tiǎn',  # 𥳫
    0x25CEC: 'àn',  # 𥳬
    # 0x25CED: '',  # 𥳭
    # 0x25CEE: '',  # 𥳮
    0x25CEF: 'cè',  # 𥳯
    0x25CF0: 'dìng',  # 𥳰
    0x25CF1: 'shēn',  # 𥳱
    0x25CF2: 'dù',  # 𥳲
    0x25CF3: 'tí',  # 𥳳
    0x25CF4: 'jiǎo',  # 𥳴
    0x25CF5: 'zuì',  # 𥳵
    0x25CF6: 'zhǎng',  # 𥳶
    0x25CF7: 'jiǎn',  # 𥳷
    0x25CF8: 'dàn',  # 𥳸
    0x25CF9: 'dǎn',  # 𥳹
    0x25CFA: 'sǒng',  # 𥳺
    # 0x25CFB: '',  # 𥳻
    # 0x25CFC: '',  # 𥳼
    0x25CFD: 'qī',  # 𥳽
    # 0x25CFE: '',  # 𥳾
    # 0x25CFF: '',  # 𥳿
    # 0x25D00: '',  # 𥴀
    # 0x25D01: '',  # 𥴁
    # 0x25D02: '',  # 𥴂
    # 0x25D03: '',  # 𥴃
    # 0x25D04: '',  # 𥴄
    # 0x25D05: '',  # 𥴅
    # 0x25D06: '',  # 𥴆
    # 0x25D07: '',  # 𥴇
    # 0x25D08: '',  # 𥴈
    # 0x25D09: '',  # 𥴉
    # 0x25D0A: '',  # 𥴊
    # 0x25D0B: '',  # 𥴋
    # 0x25D0C: '',  # 𥴌
    # 0x25D0D: '',  # 𥴍
    # 0x25D0E: '',  # 𥴎
    # 0x25D0F: '',  # 𥴏
    0x25D10: 'zhǎn',  # 𥴐
    0x25D11: 'tíng',  # 𥴑
    0x25D12: 'zhì',  # 𥴒
    # 0x25D13: '',  # 𥴓
    # 0x25D14: '',  # 𥴔
    0x25D15: 'yóu',  # 𥴕
    0x25D16: 'pái',  # 𥴖
    # 0x25D17: '',  # 𥴗
    # 0x25D18: '',  # 𥴘
    # 0x25D19: '',  # 𥴙
    # 0x25D1A: '',  # 𥴚
    # 0x25D1B: '',  # 𥴛
    # 0x25D1C: '',  # 𥴜
    # 0x25D1D: '',  # 𥴝
    # 0x25D1E: '',  # 𥴞
    # 0x25D1F: '',  # 𥴟
    # 0x25D20: '',  # 𥴠
    0x25D21: 'lǐ',  # 𥴡
    # 0x25D22: '',  # 𥴢
    # 0x25D23: '',  # 𥴣
    0x25D24: 'qián',  # 𥴤
    # 0x25D25: '',  # 𥴥
    0x25D26: 'suì,dí',  # 𥴦
    0x25D27: 'jǔ',  # 𥴧
    0x25D28: 'ài',  # 𥴨
    0x25D29: 'gé',  # 𥴩
    0x25D2A: 'jù',  # 𥴪
    0x25D2B: 'tún,diàn',  # 𥴫
    0x25D2C: 'bì',  # 𥴬
    0x25D2D: 'qià',  # 𥴭
    0x25D2E: 'bó',  # 𥴮
    0x25D2F: 'huì',  # 𥴯
    # 0x25D30: '',  # 𥴰
    0x25D31: 'jiàn',  # 𥴱
    # 0x25D32: '',  # 𥴲
    # 0x25D33: '',  # 𥴳
    0x25D34: 'gōu',  # 𥴴
    0x25D35: 'suàn',  # 𥴵
    # 0x25D36: '',  # 𥴶
    # 0x25D37: '',  # 𥴷
    # 0x25D38: '',  # 𥴸
    # 0x25D39: '',  # 𥴹
    0x25D3A: 'cí',  # 𥴺
    0x25D3B: 'qiàng',  # 𥴻
    # 0x25D3C: '',  # 𥴼
    # 0x25D3D: '',  # 𥴽
    # 0x25D3E: '',  # 𥴾
    0x25D3F: 'yán',  # 𥴿
    # 0x25D40: '',  # 𥵀
    # 0x25D41: '',  # 𥵁
    # 0x25D42: '',  # 𥵂
    # 0x25D43: '',  # 𥵃
    # 0x25D44: '',  # 𥵄
    # 0x25D45: '',  # 𥵅
    # 0x25D46: '',  # 𥵆
    # 0x25D47: '',  # 𥵇
    # 0x25D48: '',  # 𥵈
    # 0x25D49: '',  # 𥵉
    # 0x25D4A: '',  # 𥵊
    # 0x25D4B: '',  # 𥵋
    # 0x25D4C: '',  # 𥵌
    # 0x25D4D: '',  # 𥵍
    # 0x25D4E: '',  # 𥵎
    0x25D4F: 'diàn',  # 𥵏
    # 0x25D50: '',  # 𥵐
    # 0x25D51: '',  # 𥵑
    0x25D52: 'miè',  # 𥵒
    # 0x25D53: '',  # 𥵓
    # 0x25D54: '',  # 𥵔
    # 0x25D55: '',  # 𥵕
    # 0x25D56: '',  # 𥵖
    # 0x25D57: '',  # 𥵗
    # 0x25D58: '',  # 𥵘
    # 0x25D59: '',  # 𥵙
    # 0x25D5A: '',  # 𥵚
    # 0x25D5B: '',  # 𥵛
    0x25D5C: 'pò',  # 𥵜
    0x25D5D: 'lǐng',  # 𥵝
    0x25D5E: 'jié',  # 𥵞
    0x25D5F: 'zhù',  # 𥵟
    0x25D60: 'gǔ',  # 𥵠
    # 0x25D61: '',  # 𥵡
    # 0x25D62: '',  # 𥵢
    0x25D63: 'duān',  # 𥵣
    0x25D64: 'zhào',  # 𥵤
    # 0x25D65: '',  # 𥵥
    0x25D66: 'shǎo',  # 𥵦
    0x25D67: 'qǐn',  # 𥵧
    0x25D68: 'mí',  # 𥵨
    # 0x25D69: '',  # 𥵩
    0x25D6A: 'píng',  # 𥵪
    0x25D6B: 'cóng',  # 𥵫
    0x25D6C: 'chōu',  # 𥵬
    # 0x25D6D: '',  # 𥵭
    # 0x25D6E: '',  # 𥵮
    0x25D6F: 'sà',  # 𥵯
    # 0x25D70: '',  # 𥵰
    # 0x25D71: '',  # 𥵱
    # 0x25D72: '',  # 𥵲
    # 0x25D73: '',  # 𥵳
    # 0x25D74: '',  # 𥵴
    # 0x25D75: '',  # 𥵵
    0x25D76: 'tiǎn',  # 𥵶
    # 0x25D77: '',  # 𥵷
    0x25D78: 'mí',  # 𥵸
    # 0x25D79: '',  # 𥵹
    # 0x25D7A: '',  # 𥵺
    # 0x25D7B: '',  # 𥵻
    # 0x25D7C: '',  # 𥵼
    # 0x25D7D: '',  # 𥵽
    # 0x25D7E: '',  # 𥵾
    # 0x25D7F: '',  # 𥵿
    # 0x25D80: '',  # 𥶀
    # 0x25D81: '',  # 𥶁
    # 0x25D82: '',  # 𥶂
    # 0x25D83: '',  # 𥶃
    # 0x25D84: '',  # 𥶄
    0x25D85: 'liú',  # 𥶅
    0x25D86: 'lǘ',  # 𥶆
    0x25D87: 'lǔ',  # 𥶇
    0x25D88: 'zōu',  # 𥶈
    # 0x25D89: '',  # 𥶉
    # 0x25D8A: '',  # 𥶊
    # 0x25D8B: '',  # 𥶋
    0x25D8C: 'lǜ',  # 𥶌
    0x25D8D: 'huǎn',  # 𥶍
    # 0x25D8E: '',  # 𥶎
    0x25D8F: 'tiáo',  # 𥶏
    0x25D90: 'tuí',  # 𥶐
    0x25D91: 'qiǎng',  # 𥶑
    0x25D92: 'lìn',  # 𥶒
    0x25D93: 'bēi',  # 𥶓
    0x25D94: 'páo',  # 𥶔
    0x25D95: 'zhān',  # 𥶕
    # 0x25D96: '',  # 𥶖
    0x25D97: 'lì',  # 𥶗
    # 0x25D98: '',  # 𥶘
    # 0x25D99: '',  # 𥶙
    # 0x25D9A: '',  # 𥶚
    0x25D9B: 'tí',  # 𥶛
    0x25D9C: 'hú',  # 𥶜
    # 0x25D9D: '',  # 𥶝
    # 0x25D9E: '',  # 𥶞
    # 0x25D9F: '',  # 𥶟
    # 0x25DA0: '',  # 𥶠
    # 0x25DA1: '',  # 𥶡
    0x25DA2: 'liè',  # 𥶢
    # 0x25DA3: '',  # 𥶣
    # 0x25DA4: '',  # 𥶤
    # 0x25DA5: '',  # 𥶥
    # 0x25DA6: '',  # 𥶦
    # 0x25DA7: '',  # 𥶧
    # 0x25DA8: '',  # 𥶨
    # 0x25DA9: '',  # 𥶩
    # 0x25DAA: '',  # 𥶪
    # 0x25DAB: '',  # 𥶫
    # 0x25DAC: '',  # 𥶬
    # 0x25DAD: '',  # 𥶭
    # 0x25DAE: '',  # 𥶮
    # 0x25DAF: '',  # 𥶯
    # 0x25DB0: '',  # 𥶰
    # 0x25DB1: '',  # 𥶱
    # 0x25DB2: '',  # 𥶲
    # 0x25DB3: '',  # 𥶳
    # 0x25DB4: '',  # 𥶴
    0x25DB5: 'huǐ',  # 𥶵
    0x25DB6: 'qū',  # 𥶶
    0x25DB7: 'xuǎn',  # 𥶷
    # 0x25DB8: '',  # 𥶸
    0x25DB9: 'jìng',  # 𥶹
    0x25DBA: 'dié',  # 𥶺
    0x25DBB: 'suí',  # 𥶻
    # 0x25DBC: '',  # 𥶼
    0x25DBD: 'wèi',  # 𥶽
    # 0x25DBE: '',  # 𥶾
    0x25DBF: 'yán',  # 𥶿
    0x25DC0: 'yān',  # 𥷀
    0x25DC1: 'bàn',  # 𥷁
    # 0x25DC2: '',  # 𥷂
    0x25DC3: 'jiǎng',  # 𥷃
    0x25DC4: 'nǐ',  # 𥷄
    0x25DC5: 'lì',  # 𥷅
    0x25DC6: 'hú',  # 𥷆
    0x25DC7: 'qì',  # 𥷇
    0x25DC8: 'zhōng',  # 𥷈
    # 0x25DC9: '',  # 𥷉
    # 0x25DCA: '',  # 𥷊
    # 0x25DCB: '',  # 𥷋
    # 0x25DCC: '',  # 𥷌
    # 0x25DCD: '',  # 𥷍
    # 0x25DCE: '',  # 𥷎
    # 0x25DCF: '',  # 𥷏
    # 0x25DD0: '',  # 𥷐
    # 0x25DD1: '',  # 𥷑
    # 0x25DD2: '',  # 𥷒
    # 0x25DD3: '',  # 𥷓
    0x25DD4: 'yú',  # 𥷔
    0x25DD5: 'dié',  # 𥷕
    0x25DD6: 'lìn',  # 𥷖
    0x25DD7: 'lì',  # 𥷗
    0x25DD8: 'zhuó',  # 𥷘
    0x25DD9: 'jì',  # 𥷙
    0x25DDA: 'jū',  # 𥷚
    # 0x25DDB: '',  # 𥷛
    0x25DDC: 'fēng',  # 𥷜
    # 0x25DDD: '',  # 𥷝
    0x25DDE: 'yù',  # 𥷞
    # 0x25DDF: '',  # 𥷟
    # 0x25DE0: '',  # 𥷠
    # 0x25DE1: '',  # 𥷡
    # 0x25DE2: '',  # 𥷢
    # 0x25DE3: '',  # 𥷣
    # 0x25DE4: '',  # 𥷤
    # 0x25DE5: '',  # 𥷥
    # 0x25DE6: '',  # 𥷦
    # 0x25DE7: '',  # 𥷧
    0x25DE8: 'liè',  # 𥷨
    0x25DE9: 'zá',  # 𥷩
    0x25DEA: 'qián',  # 𥷪
    0x25DEB: 'jiē',  # 𥷫
    0x25DEC: 'guān',  # 𥷬
    # 0x25DED: '',  # 𥷭
    0x25DEE: 'zhuó,zhāo',  # 𥷮
    # 0x25DEF: '',  # 𥷯
    # 0x25DF0: '',  # 𥷰
    0x25DF1: 'fù',  # 𥷱
    # 0x25DF2: '',  # 𥷲
    # 0x25DF3: '',  # 𥷳
    # 0x25DF4: '',  # 𥷴
    # 0x25DF5: '',  # 𥷵
    # 0x25DF6: '',  # 𥷶
    # 0x25DF7: '',  # 𥷷
    # 0x25DF8: '',  # 𥷸
    0x25DF9: 'sè',  # 𥷹
    # 0x25DFA: '',  # 𥷺
    # 0x25DFB: '',  # 𥷻
    0x25DFC: 'cù',  # 𥷼
    # 0x25DFD: '',  # 𥷽
    # 0x25DFE: '',  # 𥷾
    # 0x25DFF: '',  # 𥷿
    # 0x25E00: '',  # 𥸀
    # 0x25E01: '',  # 𥸁
    # 0x25E02: '',  # 𥸂
    0x25E03: 'huǐ',  # 𥸃
    # 0x25E04: '',  # 𥸄
    0x25E05: 'biān',  # 𥸅
    # 0x25E06: '',  # 𥸆
    # 0x25E07: '',  # 𥸇
    0x25E08: 'dàng',  # 𥸈
    0x25E09: 'lóng',  # 𥸉
    0x25E0A: 'yì',  # 𥸊
    # 0x25E0B: '',  # 𥸋
    # 0x25E0C: '',  # 𥸌
    # 0x25E0D: '',  # 𥸍
    # 0x25E0E: '',  # 𥸎
    # 0x25E0F: '',  # 𥸏
    # 0x25E10: '',  # 𥸐
    # 0x25E11: '',  # 𥸑
    # 0x25E12: '',  # 𥸒
    # 0x25E13: '',  # 𥸓
    # 0x25E14: '',  # 𥸔
    # 0x25E15: '',  # 𥸕
    # 0x25E16: '',  # 𥸖
    0x25E17: 'sǎ',  # 𥸗
    0x25E18: 'yuè',  # 𥸘
    # 0x25E19: '',  # 𥸙
    0x25E1A: 'dí',  # 𥸚
    # 0x25E1B: '',  # 𥸛
    # 0x25E1C: '',  # 𥸜
    # 0x25E1D: '',  # 𥸝
    # 0x25E1E: '',  # 𥸞
    # 0x25E1F: '',  # 𥸟
    # 0x25E20: '',  # 𥸠
    0x25E21: 'gǎn',  # 𥸡
    0x25E22: 'zān',  # 𥸢
    0x25E23: 'shàn',  # 𥸣
    0x25E24: 'yù',  # 𥸤
    0x25E25: 'bǒ',  # 𥸥
    # 0x25E26: '',  # 𥸦
    0x25E27: 'dìng',  # 𥸧
    0x25E28: 'fán,bǒ,bǔ',  # 𥸨
    # 0x25E29: '',  # 𥸩
    0x25E2A: 'yù',  # 𥸪
    # 0x25E2B: '',  # 𥸫
    0x25E2C: 'shēn',  # 𥸬
    # 0x25E2D: '',  # 𥸭
    # 0x25E2E: '',  # 𥸮
    # 0x25E2F: '',  # 𥸯
    # 0x25E30: '',  # 𥸰
    # 0x25E31: '',  # 𥸱
    0x25E32: 'gōng',  # 𥸲
    # 0x25E33: '',  # 𥸳
    0x25E34: 'miè',  # 𥸴
    0x25E35: 'tún',  # 𥸵
    # 0x25E36: '',  # 𥸶
    # 0x25E37: '',  # 𥸷
    0x25E38: 'liè',  # 𥸸
    # 0x25E39: '',  # 𥸹
    # 0x25E3A: '',  # 𥸺
    # 0x25E3B: '',  # 𥸻
    # 0x25E3C: '',  # 𥸼
    # 0x25E3D: '',  # 𥸽
    # 0x25E3E: '',  # 𥸾
    # 0x25E3F: '',  # 𥸿
    # 0x25E40: '',  # 𥹀
    0x25E41: 'zhā,zuò',  # 𥹁
    0x25E42: 'pēi',  # 𥹂
    # 0x25E43: '',  # 𥹃
    0x25E44: 'mí',  # 𥹄
    # 0x25E45: '',  # 𥹅
    0x25E46: 'míng',  # 𥹆
    0x25E47: 'fàn',  # 𥹇
    0x25E48: 'tuó',  # 𥹈
    0x25E49: 'nà',  # 𥹉
    0x25E4A: 'sì',  # 𥹊
    0x25E4B: 'yí',  # 𥹋
    0x25E4C: 'jiā',  # 𥹌
    0x25E4D: 'zhù',  # 𥹍
    # 0x25E4E: '',  # 𥹎
    # 0x25E4F: '',  # 𥹏
    # 0x25E50: '',  # 𥹐
    # 0x25E51: '',  # 𥹑
    # 0x25E52: '',  # 𥹒
    0x25E53: 'bān',  # 𥹓
    0x25E54: 'yù',  # 𥹔
    # 0x25E55: '',  # 𥹕
    0x25E56: 'pǒ',  # 𥹖
    # 0x25E57: '',  # 𥹗
    # 0x25E58: '',  # 𥹘
    # 0x25E59: '',  # 𥹙
    0x25E5A: 'huān',  # 𥹚
    0x25E5B: 'càn',  # 𥹛
    0x25E5C: 'jiāo',  # 𥹜
    # 0x25E5D: '',  # 𥹝
    # 0x25E5E: '',  # 𥹞
    # 0x25E5F: '',  # 𥹟
    0x25E60: 'tán',  # 𥹠
    # 0x25E61: '',  # 𥹡
    # 0x25E62: '',  # 𥹢
    # 0x25E63: '',  # 𥹣
    # 0x25E64: '',  # 𥹤
    # 0x25E65: '',  # 𥹥
    # 0x25E66: '',  # 𥹦
    # 0x25E67: '',  # 𥹧
    # 0x25E68: '',  # 𥹨
    0x25E69: 'zhì',  # 𥹩
    # 0x25E6A: '',  # 𥹪
    0x25E6B: 'mǐ',  # 𥹫
    0x25E6C: 'kǎo',  # 𥹬
    # 0x25E6D: '',  # 𥹭
    # 0x25E6E: '',  # 𥹮
    # 0x25E6F: '',  # 𥹯
    # 0x25E70: '',  # 𥹰
    0x25E71: 'yāo',  # 𥹱
    0x25E72: 'duì',  # 𥹲
    0x25E73: 'quǎn,huán',  # 𥹳
    0x25E74: 'bù',  # 𥹴
    0x25E75: 'chù',  # 𥹵
    0x25E76: 'qiǎo',  # 𥹶
    0x25E77: 'liú',  # 𥹷
    0x25E78: 'bó',  # 𥹸
    # 0x25E79: '',  # 𥹹
    0x25E7A: 'kāng',  # 𥹺
    0x25E7B: 'fèn',  # 𥹻
    # 0x25E7C: '',  # 𥹼
    # 0x25E7D: '',  # 𥹽
    # 0x25E7E: '',  # 𥹾
    # 0x25E7F: '',  # 𥹿
    # 0x25E80: '',  # 𥺀
    # 0x25E81: '',  # 𥺁
    # 0x25E82: '',  # 𥺂
    # 0x25E83: '',  # 𥺃
    # 0x25E84: '',  # 𥺄
    # 0x25E85: '',  # 𥺅
    # 0x25E86: '',  # 𥺆
    # 0x25E87: '',  # 𥺇
    # 0x25E88: '',  # 𥺈
    0x25E89: 'dòu',  # 𥺉
    0x25E8A: 'gé',  # 𥺊
    # 0x25E8B: '',  # 𥺋
    # 0x25E8C: '',  # 𥺌
    # 0x25E8D: '',  # 𥺍
    # 0x25E8E: '',  # 𥺎
    # 0x25E8F: '',  # 𥺏
    # 0x25E90: '',  # 𥺐
    # 0x25E91: '',  # 𥺑
    # 0x25E92: '',  # 𥺒
    # 0x25E93: '',  # 𥺓
    # 0x25E94: '',  # 𥺔
    # 0x25E95: '',  # 𥺕
    # 0x25E96: '',  # 𥺖
    # 0x25E97: '',  # 𥺗
    # 0x25E98: '',  # 𥺘
    0x25E99: 'líng',  # 𥺙
    0x25E9A: 'xí',  # 𥺚
    # 0x25E9B: '',  # 𥺛
    0x25E9C: 'nì',  # 𥺜
    0x25E9D: 'zhōu',  # 𥺝
    0x25E9E: 'zhōu,yù',  # 𥺞
    # 0x25E9F: '',  # 𥺟
    # 0x25EA0: '',  # 𥺠
    0x25EA1: 'chī',  # 𥺡
    # 0x25EA2: '',  # 𥺢
    0x25EA3: 'chōu',  # 𥺣
    # 0x25EA4: '',  # 𥺤
    # 0x25EA5: '',  # 𥺥
    # 0x25EA6: '',  # 𥺦
    # 0x25EA7: '',  # 𥺧
    # 0x25EA8: '',  # 𥺨
    # 0x25EA9: '',  # 𥺩
    # 0x25EAA: '',  # 𥺪
    # 0x25EAB: '',  # 𥺫
    # 0x25EAC: '',  # 𥺬
    # 0x25EAD: '',  # 𥺭
    # 0x25EAE: '',  # 𥺮
    # 0x25EAF: '',  # 𥺯
    # 0x25EB0: '',  # 𥺰
    # 0x25EB1: '',  # 𥺱
    # 0x25EB2: '',  # 𥺲
    # 0x25EB3: '',  # 𥺳
    0x25EB4: 'niān',  # 𥺴
    0x25EB5: 'jī',  # 𥺵
    # 0x25EB6: '',  # 𥺶
    0x25EB7: 'qū',  # 𥺷
    # 0x25EB8: '',  # 𥺸
    # 0x25EB9: '',  # 𥺹
    # 0x25EBA: '',  # 𥺺
    # 0x25EBB: '',  # 𥺻
    # 0x25EBC: '',  # 𥺼
    # 0x25EBD: '',  # 𥺽
    # 0x25EBE: '',  # 𥺾
    # 0x25EBF: '',  # 𥺿
    # 0x25EC0: '',  # 𥻀
    # 0x25EC1: '',  # 𥻁
    # 0x25EC2: '',  # 𥻂
    # 0x25EC3: '',  # 𥻃
    0x25EC4: 'kāi',  # 𥻄
    # 0x25EC5: '',  # 𥻅
    0x25EC6: 'sù',  # 𥻆
    0x25EC7: 'xiàn',  # 𥻇
    # 0x25EC8: '',  # 𥻈
    0x25EC9: 'hé',  # 𥻉
    # 0x25ECA: '',  # 𥻊
    0x25ECB: 'lín',  # 𥻋
    # 0x25ECC: '',  # 𥻌
    0x25ECD: 'zī',  # 𥻍
    # 0x25ECE: '',  # 𥻎
    # 0x25ECF: '',  # 𥻏
    # 0x25ED0: '',  # 𥻐
    0x25ED1: 'ǒu,lì',  # 𥻑
    0x25ED2: 'cù,mì',  # 𥻒
    # 0x25ED3: '',  # 𥻓
    # 0x25ED4: '',  # 𥻔
    # 0x25ED5: '',  # 𥻕
    # 0x25ED6: '',  # 𥻖
    0x25ED7: 'chá',  # 𥻗
    # 0x25ED8: '',  # 𥻘
    # 0x25ED9: '',  # 𥻙
    # 0x25EDA: '',  # 𥻚
    # 0x25EDB: '',  # 𥻛
    # 0x25EDC: '',  # 𥻜
    0x25EDD: 'zhòng',  # 𥻝
    0x25EDE: 'bú',  # 𥻞
    # 0x25EDF: '',  # 𥻟
    # 0x25EE0: '',  # 𥻠
    # 0x25EE1: '',  # 𥻡
    # 0x25EE2: '',  # 𥻢
    # 0x25EE3: '',  # 𥻣
    0x25EE4: 'chōu',  # 𥻤
    0x25EE5: 'xì',  # 𥻥
    0x25EE6: 'sà',  # 𥻦
    0x25EE7: 'xián,jiān',  # 𥻧
    0x25EE8: 'sè',  # 𥻨
    0x25EE9: 'miàn',  # 𥻩
    # 0x25EEA: '',  # 𥻪
    0x25EEB: 'fán',  # 𥻫
    0x25EEC: 'zhī',  # 𥻬
    # 0x25EED: '',  # 𥻭
    0x25EEE: 'cuì',  # 𥻮
    # 0x25EEF: '',  # 𥻯
    # 0x25EF0: '',  # 𥻰
    # 0x25EF1: '',  # 𥻱
    # 0x25EF2: '',  # 𥻲
    # 0x25EF3: '',  # 𥻳
    0x25EF4: 'xià',  # 𥻴
    0x25EF5: 'cí',  # 𥻵
    # 0x25EF6: '',  # 𥻶
    # 0x25EF7: '',  # 𥻷
    # 0x25EF8: '',  # 𥻸
    # 0x25EF9: '',  # 𥻹
    # 0x25EFA: '',  # 𥻺
    # 0x25EFB: '',  # 𥻻
    # 0x25EFC: '',  # 𥻼
    # 0x25EFD: '',  # 𥻽
    0x25EFE: 'nuò',  # 𥻾
    0x25EFF: 'lí',  # 𥻿
    0x25F00: 'zú',  # 𥼀
    # 0x25F01: '',  # 𥼁
    0x25F02: 'cuī',  # 𥼂
    0x25F03: 'zé',  # 𥼃
    # 0x25F04: '',  # 𥼄
    0x25F05: 'lí',  # 𥼅
    # 0x25F06: '',  # 𥼆
    # 0x25F07: '',  # 𥼇
    # 0x25F08: '',  # 𥼈
    # 0x25F09: '',  # 𥼉
    # 0x25F0A: '',  # 𥼊
    0x25F0B: 'lí',  # 𥼋
    # 0x25F0C: '',  # 𥼌
    # 0x25F0D: '',  # 𥼍
    # 0x25F0E: '',  # 𥼎
    # 0x25F0F: '',  # 𥼏
    # 0x25F10: '',  # 𥼐
    # 0x25F11: '',  # 𥼑
    # 0x25F12: '',  # 𥼒
    0x25F13: 'bèi',  # 𥼓
    # 0x25F14: '',  # 𥼔
    # 0x25F15: '',  # 𥼕
    # 0x25F16: '',  # 𥼖
    # 0x25F17: '',  # 𥼗
    0x25F18: 'qí',  # 𥼘
    # 0x25F19: '',  # 𥼙
    0x25F1A: 'zhuō',  # 𥼚
    0x25F1B: 'cuì',  # 𥼛
    0x25F1C: 'pū',  # 𥼜
    0x25F1D: 'chī',  # 𥼝
    0x25F1E: 'fán',  # 𥼞
    0x25F1F: 'tán',  # 𥼟
    # 0x25F20: '',  # 𥼠
    # 0x25F21: '',  # 𥼡
    # 0x25F22: '',  # 𥼢
    # 0x25F23: '',  # 𥼣
    # 0x25F24: '',  # 𥼤
    # 0x25F25: '',  # 𥼥
    # 0x25F26: '',  # 𥼦
    # 0x25F27: '',  # 𥼧
    # 0x25F28: '',  # 𥼨
    0x25F29: 'zī',  # 𥼩
    0x25F2A: 'zǔ',  # 𥼪
    0x25F2B: 'zhōu',  # 𥼫
    0x25F2C: 'róng',  # 𥼬
    0x25F2D: 'lín',  # 𥼭
    0x25F2E: 'tán',  # 𥼮
    # 0x25F2F: '',  # 𥼯
    # 0x25F30: '',  # 𥼰
    # 0x25F31: '',  # 𥼱
    # 0x25F32: '',  # 𥼲
    # 0x25F33: '',  # 𥼳
    # 0x25F34: '',  # 𥼴
    # 0x25F35: '',  # 𥼵
    0x25F36: 'shì',  # 𥼶
    # 0x25F37: '',  # 𥼷
    0x25F38: 'líng',  # 𥼸
    # 0x25F39: '',  # 𥼹
    0x25F3A: 'cuǐ',  # 𥼺
    0x25F3B: 'zī',  # 𥼻
    0x25F3C: 'fū',  # 𥼼
    # 0x25F3D: '',  # 𥼽
    # 0x25F3E: '',  # 𥼾
    # 0x25F3F: '',  # 𥼿
    # 0x25F40: '',  # 𥽀
    0x25F41: 'xiào',  # 𥽁
    # 0x25F42: '',  # 𥽂
    # 0x25F43: '',  # 𥽃
    # 0x25F44: '',  # 𥽄
    # 0x25F45: '',  # 𥽅
    # 0x25F46: '',  # 𥽆
    # 0x25F47: '',  # 𥽇
    0x25F48: 'fēng,lǐ',  # 𥽈
    # 0x25F49: '',  # 𥽉
    # 0x25F4A: '',  # 𥽊
    # 0x25F4B: '',  # 𥽋
    # 0x25F4C: '',  # 𥽌
    # 0x25F4D: '',  # 𥽍
    # 0x25F4E: '',  # 𥽎
    0x25F4F: 'xiàn',  # 𥽏
    0x25F50: 'jiàn',  # 𥽐
    # 0x25F51: '',  # 𥽑
    0x25F52: 'fèn',  # 𥽒
    # 0x25F53: '',  # 𥽓
    # 0x25F54: '',  # 𥽔
    # 0x25F55: '',  # 𥽕
    # 0x25F56: '',  # 𥽖
    0x25F57: 'lì',  # 𥽗
    0x25F58: 'mò,miè',  # 𥽘
    # 0x25F59: '',  # 𥽙
    # 0x25F5A: '',  # 𥽚
    # 0x25F5B: '',  # 𥽛
    # 0x25F5C: '',  # 𥽜
    # 0x25F5D: '',  # 𥽝
    # 0x25F5E: '',  # 𥽞
    0x25F5F: 'yōu',  # 𥽟
    # 0x25F60: '',  # 𥽠
    # 0x25F61: '',  # 𥽡
    # 0x25F62: '',  # 𥽢
    0x25F63: 'líng',  # 𥽣
    # 0x25F64: '',  # 𥽤
    0x25F65: 'huò',  # 𥽥
    # 0x25F66: '',  # 𥽦
    0x25F67: 'qū',  # 𥽧
    # 0x25F68: '',  # 𥽨
    # 0x25F69: '',  # 𥽩
    # 0x25F6A: '',  # 𥽪
    # 0x25F6B: '',  # 𥽫
    0x25F6C: 'niàng',  # 𥽬
    # 0x25F6D: '',  # 𥽭
    # 0x25F6E: '',  # 𥽮
    # 0x25F6F: '',  # 𥽯
    0x25F70: 'mí',  # 𥽰
    # 0x25F71: '',  # 𥽱
    # 0x25F72: '',  # 𥽲
    0x25F73: 'qì',  # 𥽳
    # 0x25F74: '',  # 𥽴
    # 0x25F75: '',  # 𥽵
    0x25F76: 'hé',  # 𥽶
    # 0x25F77: '',  # 𥽷
    0x25F78: 'liàn',  # 𥽸
    0x25F79: 'cào',  # 𥽹
    # 0x25F7A: '',  # 𥽺
    # 0x25F7B: '',  # 𥽻
    # 0x25F7C: '',  # 𥽼
    # 0x25F7D: '',  # 𥽽
    # 0x25F7E: '',  # 𥽾
    0x25F7F: 'zuò',  # 𥽿
    # 0x25F80: '',  # 𥾀
    # 0x25F81: '',  # 𥾁
    0x25F82: 'líng',  # 𥾂
    # 0x25F83: '',  # 𥾃
    # 0x25F84: '',  # 𥾄
    0x25F85: 'zhú',  # 𥾅
    # 0x25F86: '',  # 𥾆
    0x25F87: 'niǎo',  # 𥾇
    # 0x25F88: '',  # 𥾈
    # 0x25F89: '',  # 𥾉
    0x25F8A: 'jǐ',  # 𥾊
    0x25F8B: 'réng',  # 𥾋
    0x25F8C: 'jié',  # 𥾌
    0x25F8D: 'gǎn',  # 𥾍
    # 0x25F8E: '',  # 𥾎
    # 0x25F8F: '',  # 𥾏
    0x25F90: 'yì',  # 𥾐
    # 0x25F91: '',  # 𥾑
    # 0x25F92: '',  # 𥾒
    0x25F93: 'zhóu',  # 𥾓
    # 0x25F94: '',  # 𥾔
    0x25F95: 'wù',  # 𥾕
    # 0x25F96: '',  # 𥾖
    # 0x25F97: '',  # 𥾗
    # 0x25F98: '',  # 𥾘
    # 0x25F99: '',  # 𥾙
    0x25F9A: 'gěng,dǎn',  # 𥾚
    0x25F9B: 'cù',  # 𥾛
    # 0x25F9C: '',  # 𥾜
    0x25F9D: 'miè,miǎn',  # 𥾝
    # 0x25F9E: '',  # 𥾞
    # 0x25F9F: '',  # 𥾟
    # 0x25FA0: '',  # 𥾠
    0x25FA1: 'xún,jī',  # 𥾡
    # 0x25FA2: '',  # 𥾢
    0x25FA3: 'zhī',  # 𥾣
    0x25FA4: 'xiáo',  # 𥾤
    # 0x25FA5: '',  # 𥾥
    # 0x25FA6: '',  # 𥾦
    0x25FA7: 'fú',  # 𥾧
    0x25FA8: 'hú',  # 𥾨
    # 0x25FA9: '',  # 𥾩
    # 0x25FAA: '',  # 𥾪
    # 0x25FAB: '',  # 𥾫
    0x25FAC: 'dī',  # 𥾬
    # 0x25FAD: '',  # 𥾭
    0x25FAE: 'jué',  # 𥾮
    0x25FAF: 'diào',  # 𥾯
    # 0x25FB0: '',  # 𥾰
    # 0x25FB1: '',  # 𥾱
    # 0x25FB2: '',  # 𥾲
    # 0x25FB3: '',  # 𥾳
    # 0x25FB4: '',  # 𥾴
    # 0x25FB5: '',  # 𥾵
    # 0x25FB6: '',  # 𥾶
    # 0x25FB7: '',  # 𥾷
    # 0x25FB8: '',  # 𥾸
    0x25FB9: 'shǒu',  # 𥾹
    # 0x25FBA: '',  # 𥾺
    # 0x25FBB: '',  # 𥾻
    0x25FBC: 'wǎng',  # 𥾼
    # 0x25FBD: '',  # 𥾽
    # 0x25FBE: '',  # 𥾾
    # 0x25FBF: '',  # 𥾿
    # 0x25FC0: '',  # 𥿀
    # 0x25FC1: '',  # 𥿁
    # 0x25FC2: '',  # 𥿂
    0x25FC3: 'nà',  # 𥿃
    0x25FC4: 'dī',  # 𥿄
    0x25FC5: 'shì',  # 𥿅
    0x25FC6: 'cí',  # 𥿆
    0x25FC7: 'shū',  # 𥿇
    # 0x25FC8: '',  # 𥿈
    0x25FC9: 'wà,mò',  # 𥿉
    0x25FCA: 'chè',  # 𥿊
    0x25FCB: 'fán,biàn',  # 𥿋
    # 0x25FCC: '',  # 𥿌
    0x25FCD: 'gū',  # 𥿍
    0x25FCE: 'yuān,wǎn',  # 𥿎
    # 0x25FCF: '',  # 𥿏
    # 0x25FD0: '',  # 𥿐
    0x25FD1: 'guān,lún',  # 𥿑
    # 0x25FD2: '',  # 𥿒
    # 0x25FD3: '',  # 𥿓
    # 0x25FD4: '',  # 𥿔
    # 0x25FD5: '',  # 𥿕
    # 0x25FD6: '',  # 𥿖
    # 0x25FD7: '',  # 𥿗
    # 0x25FD8: '',  # 𥿘
    # 0x25FD9: '',  # 𥿙
    0x25FDA: 'qiè',  # 𥿚
    # 0x25FDB: '',  # 𥿛
    0x25FDC: 'zhǎn,zhěn',  # 𥿜
    0x25FDD: 'dài',  # 𥿝
    0x25FDE: 'shē',  # 𥿞
    # 0x25FDF: '',  # 𥿟
    # 0x25FE0: '',  # 𥿠
    # 0x25FE1: '',  # 𥿡
    # 0x25FE2: '',  # 𥿢
    # 0x25FE3: '',  # 𥿣
    # 0x25FE4: '',  # 𥿤
    # 0x25FE5: '',  # 𥿥
    0x25FE6: 'zhōu',  # 𥿦
    0x25FE7: 'xiǎng',  # 𥿧
    0x25FE8: 'míng',  # 𥿨
    0x25FE9: 'zì',  # 𥿩
    0x25FEA: 'huāng',  # 𥿪
    0x25FEB: 'mí,yì,wèi',  # 𥿫
    # 0x25FEC: '',  # 𥿬
    0x25FED: 'xì',  # 𥿭
    0x25FEE: 'zhì,shì',  # 𥿮
    0x25FEF: 'pài',  # 𥿯
    0x25FF0: 'duǒ',  # 𥿰
    # 0x25FF1: '',  # 𥿱
    # 0x25FF2: '',  # 𥿲
    # 0x25FF3: '',  # 𥿳
    0x25FF4: 'cì',  # 𥿴
    0x25FF5: 'móu',  # 𥿵
    # 0x25FF6: '',  # 𥿶
    0x25FF7: 'chào',  # 𥿷
    # 0x25FF8: '',  # 𥿸
    0x25FF9: 'yì',  # 𥿹
    0x25FFA: 'gōu',  # 𥿺
    # 0x25FFB: '',  # 𥿻
    # 0x25FFC: '',  # 𥿼
    # 0x25FFD: '',  # 𥿽
    # 0x25FFE: '',  # 𥿾
    # 0x25FFF: '',  # 𥿿
    # 0x26000: '',  # 𦀀
    # 0x26001: '',  # 𦀁
    # 0x26002: '',  # 𦀂
    # 0x26003: '',  # 𦀃
    # 0x26004: '',  # 𦀄
    # 0x26005: '',  # 𦀅
    # 0x26006: '',  # 𦀆
    0x26007: 'jīng',  # 𦀇
    # 0x26008: '',  # 𦀈
    # 0x26009: '',  # 𦀉
    # 0x2600A: '',  # 𦀊
    # 0x2600B: '',  # 𦀋
    # 0x2600C: '',  # 𦀌
    # 0x2600D: '',  # 𦀍
    # 0x2600E: '',  # 𦀎
    # 0x2600F: '',  # 𦀏
    # 0x26010: '',  # 𦀐
    # 0x26011: '',  # 𦀑
    # 0x26012: '',  # 𦀒
    0x26013: 'zēng,jiē',  # 𦀓
    0x26014: 'pīng',  # 𦀔
    0x26015: 'yè',  # 𦀕
    0x26016: 'jié',  # 𦀖
    # 0x26017: '',  # 𦀗
    0x26018: 'pī,bī',  # 𦀘
    # 0x26019: '',  # 𦀙
    # 0x2601A: '',  # 𦀚
    0x2601B: 'shā',  # 𦀛
    0x2601C: 'zhuàng',  # 𦀜
    0x2601D: 'jiǒng',  # 𦀝
    # 0x2601E: '',  # 𦀞
    # 0x2601F: '',  # 𦀟
    0x26020: 'liú',  # 𦀠
    0x26021: 'yǔ',  # 𦀡
    # 0x26022: '',  # 𦀢
    0x26023: 'jū',  # 𦀣
    # 0x26024: '',  # 𦀤
    # 0x26025: '',  # 𦀥
    # 0x26026: '',  # 𦀦
    # 0x26027: '',  # 𦀧
    0x26028: 'nuò',  # 𦀨
    # 0x26029: '',  # 𦀩
    # 0x2602A: '',  # 𦀪
    # 0x2602B: '',  # 𦀫
    # 0x2602C: '',  # 𦀬
    # 0x2602D: '',  # 𦀭
    # 0x2602E: '',  # 𦀮
    # 0x2602F: '',  # 𦀯
    # 0x26030: '',  # 𦀰
    # 0x26031: '',  # 𦀱
    # 0x26032: '',  # 𦀲
    # 0x26033: '',  # 𦀳
    # 0x26034: '',  # 𦀴
    # 0x26035: '',  # 𦀵
    # 0x26036: '',  # 𦀶
    # 0x26037: '',  # 𦀷
    0x26038: 'mào',  # 𦀸
    # 0x26039: '',  # 𦀹
    # 0x2603A: '',  # 𦀺
    # 0x2603B: '',  # 𦀻
    # 0x2603C: '',  # 𦀼
    # 0x2603D: '',  # 𦀽
    # 0x2603E: '',  # 𦀾
    # 0x2603F: '',  # 𦀿
    # 0x26040: '',  # 𦁀
    # 0x26041: '',  # 𦁁
    # 0x26042: '',  # 𦁂
    # 0x26043: '',  # 𦁃
    0x26044: 'chēn',  # 𦁄
    # 0x26045: '',  # 𦁅
    0x26046: 'zhuàn,juàn,shuàn',  # 𦁆
    0x26047: 'niàn',  # 𦁇
    0x26048: 'kòng',  # 𦁈
    0x26049: 'jiē',  # 𦁉
    0x2604A: 'huà',  # 𦁊
    # 0x2604B: '',  # 𦁋
    # 0x2604C: '',  # 𦁌
    0x2604D: 'xīn',  # 𦁍
    0x2604E: 'zuó',  # 𦁎
    0x2604F: 'yàn',  # 𦁏
    0x26050: 'jué',  # 𦁐
    # 0x26051: '',  # 𦁑
    # 0x26052: '',  # 𦁒
    # 0x26053: '',  # 𦁓
    # 0x26054: '',  # 𦁔
    0x26055: 'hū',  # 𦁕
    0x26056: 'zhòu',  # 𦁖
    0x26057: 'shè',  # 𦁗
    # 0x26058: '',  # 𦁘
    0x26059: 'yǎn',  # 𦁙
    # 0x2605A: '',  # 𦁚
    0x2605B: 'xiè,dié',  # 𦁛
    0x2605C: 'dié',  # 𦁜
    # 0x2605D: '',  # 𦁝
    # 0x2605E: '',  # 𦁞
    0x2605F: 'chēn,chén,zhěn',  # 𦁟
    # 0x26060: '',  # 𦁠
    # 0x26061: '',  # 𦁡
    # 0x26062: '',  # 𦁢
    # 0x26063: '',  # 𦁣
    # 0x26064: '',  # 𦁤
    # 0x26065: '',  # 𦁥
    # 0x26066: '',  # 𦁦
    # 0x26067: '',  # 𦁧
    # 0x26068: '',  # 𦁨
    # 0x26069: '',  # 𦁩
    # 0x2606A: '',  # 𦁪
    # 0x2606B: '',  # 𦁫
    # 0x2606C: '',  # 𦁬
    # 0x2606D: '',  # 𦁭
    # 0x2606E: '',  # 𦁮
    # 0x2606F: '',  # 𦁯
    # 0x26070: '',  # 𦁰
    # 0x26071: '',  # 𦁱
    0x26072: 'jiǎn',  # 𦁲
    0x26073: 'jì',  # 𦁳
    # 0x26074: '',  # 𦁴
    # 0x26075: '',  # 𦁵
    0x26076: 'chuò',  # 𦁶
    0x26077: 'hóng',  # 𦁷
    # 0x26078: '',  # 𦁸
    # 0x26079: '',  # 𦁹
    # 0x2607A: '',  # 𦁺
    # 0x2607B: '',  # 𦁻
    # 0x2607C: '',  # 𦁼
    # 0x2607D: '',  # 𦁽
    # 0x2607E: '',  # 𦁾
    # 0x2607F: '',  # 𦁿
    0x26080: 'dá',  # 𦂀
    # 0x26081: '',  # 𦂁
    # 0x26082: '',  # 𦂂
    # 0x26083: '',  # 𦂃
    0x26084: 'kāi',  # 𦂄
    0x26085: 'xīng,xǐ',  # 𦂅
    0x26086: 'huì',  # 𦂆
    0x26087: 'jiǎn',  # 𦂇
    0x26088: 'zhòu',  # 𦂈
    0x26089: 'zhǎ',  # 𦂉
    0x2608A: 'fù',  # 𦂊
    0x2608B: 'chì',  # 𦂋
    0x2608C: 'běng',  # 𦂌
    0x2608D: 'nuò',  # 𦂍
    # 0x2608E: '',  # 𦂎
    # 0x2608F: '',  # 𦂏
    0x26090: 'gōu',  # 𦂐
    0x26091: 'jì',  # 𦂑
    0x26092: 'qián',  # 𦂒
    # 0x26093: '',  # 𦂓
    0x26094: 'wàn',  # 𦂔
    0x26095: 'óu',  # 𦂕
    0x26096: 'bì',  # 𦂖
    0x26097: 'shuò',  # 𦂗
    # 0x26098: '',  # 𦂘
    # 0x26099: '',  # 𦂙
    # 0x2609A: '',  # 𦂚
    # 0x2609B: '',  # 𦂛
    # 0x2609C: '',  # 𦂜
    # 0x2609D: '',  # 𦂝
    # 0x2609E: '',  # 𦂞
    # 0x2609F: '',  # 𦂟
    0x260A0: 'jīng',  # 𦂠
    0x260A1: 'yè',  # 𦂡
    # 0x260A2: '',  # 𦂢
    # 0x260A3: '',  # 𦂣
    # 0x260A4: '',  # 𦂤
    # 0x260A5: '',  # 𦂥
    # 0x260A6: '',  # 𦂦
    # 0x260A7: '',  # 𦂧
    # 0x260A8: '',  # 𦂨
    # 0x260A9: '',  # 𦂩
    # 0x260AA: '',  # 𦂪
    # 0x260AB: '',  # 𦂫
    # 0x260AC: '',  # 𦂬
    # 0x260AD: '',  # 𦂭
    # 0x260AE: '',  # 𦂮
    # 0x260AF: '',  # 𦂯
    # 0x260B0: '',  # 𦂰
    # 0x260B1: '',  # 𦂱
    # 0x260B2: '',  # 𦂲
    # 0x260B3: '',  # 𦂳
    # 0x260B4: '',  # 𦂴
    # 0x260B5: '',  # 𦂵
    0x260B6: 'yǐ',  # 𦂶
    # 0x260B7: '',  # 𦂷
    # 0x260B8: '',  # 𦂸
    # 0x260B9: '',  # 𦂹
    # 0x260BA: '',  # 𦂺
    # 0x260BB: '',  # 𦂻
    # 0x260BC: '',  # 𦂼
    # 0x260BD: '',  # 𦂽
    # 0x260BE: '',  # 𦂾
    # 0x260BF: '',  # 𦂿
    # 0x260C0: '',  # 𦃀
    # 0x260C1: '',  # 𦃁
    # 0x260C2: '',  # 𦃂
    # 0x260C3: '',  # 𦃃
    0x260C4: 'fěi',  # 𦃄
    # 0x260C5: '',  # 𦃅
    # 0x260C6: '',  # 𦃆
    0x260C7: 'lí',  # 𦃇
    # 0x260C8: '',  # 𦃈
    # 0x260C9: '',  # 𦃉
    0x260CA: 'lì',  # 𦃊
    0x260CB: 'pí',  # 𦃋
    # 0x260CC: '',  # 𦃌
    # 0x260CD: '',  # 𦃍
    # 0x260CE: '',  # 𦃎
    # 0x260CF: '',  # 𦃏
    # 0x260D0: '',  # 𦃐
    # 0x260D1: '',  # 𦃑
    0x260D2: 'suì',  # 𦃒
    0x260D3: 'liú',  # 𦃓
    0x260D4: 'hé',  # 𦃔
    0x260D5: 'hǔn',  # 𦃕
    0x260D6: 'tǎn',  # 𦃖
    0x260D7: 'shuò',  # 𦃗
    0x260D8: 'zhì',  # 𦃘
    0x260D9: 'bó',  # 𦃙
    # 0x260DA: '',  # 𦃚
    # 0x260DB: '',  # 𦃛
    # 0x260DC: '',  # 𦃜
    0x260DD: 'xì',  # 𦃝
    # 0x260DE: '',  # 𦃞
    # 0x260DF: '',  # 𦃟
    # 0x260E0: '',  # 𦃠
    0x260E1: 'pó,tāo',  # 𦃡
    0x260E2: 'qǔn',  # 𦃢
    # 0x260E3: '',  # 𦃣
    0x260E4: 'mù',  # 𦃤
    # 0x260E5: '',  # 𦃥
    # 0x260E6: '',  # 𦃦
    # 0x260E7: '',  # 𦃧
    # 0x260E8: '',  # 𦃨
    # 0x260E9: '',  # 𦃩
    # 0x260EA: '',  # 𦃪
    # 0x260EB: '',  # 𦃫
    # 0x260EC: '',  # 𦃬
    # 0x260ED: '',  # 𦃭
    # 0x260EE: '',  # 𦃮
    # 0x260EF: '',  # 𦃯
    # 0x260F0: '',  # 𦃰
    # 0x260F1: '',  # 𦃱
    # 0x260F2: '',  # 𦃲
    # 0x260F3: '',  # 𦃳
    # 0x260F4: '',  # 𦃴
    # 0x260F5: '',  # 𦃵
    # 0x260F6: '',  # 𦃶
    # 0x260F7: '',  # 𦃷
    # 0x260F8: '',  # 𦃸
    # 0x260F9: '',  # 𦃹
    # 0x260FA: '',  # 𦃺
    # 0x260FB: '',  # 𦃻
    # 0x260FC: '',  # 𦃼
    0x260FD: 'yōng',  # 𦃽
    # 0x260FE: '',  # 𦃾
    # 0x260FF: '',  # 𦃿
    # 0x26100: '',  # 𦄀
    # 0x26101: '',  # 𦄁
    0x26102: 'dài',  # 𦄂
    # 0x26103: '',  # 𦄃
    # 0x26104: '',  # 𦄄
    # 0x26105: '',  # 𦄅
    # 0x26106: '',  # 𦄆
    # 0x26107: '',  # 𦄇
    # 0x26108: '',  # 𦄈
    # 0x26109: '',  # 𦄉
    0x2610A: 'qǐ',  # 𦄊
    0x2610B: 'diǎo',  # 𦄋
    0x2610C: 'niè',  # 𦄌
    0x2610D: 'shuǎng',  # 𦄍
    # 0x2610E: '',  # 𦄎
    0x2610F: 'shāo',  # 𦄏
    0x26110: 'kǔn,mí',  # 𦄐
    0x26111: 'suì',  # 𦄑
    # 0x26112: '',  # 𦄒
    0x26113: 'dōu',  # 𦄓
    0x26114: 'dié',  # 𦄔
    # 0x26115: '',  # 𦄕
    # 0x26116: '',  # 𦄖
    # 0x26117: '',  # 𦄗
    # 0x26118: '',  # 𦄘
    # 0x26119: '',  # 𦄙
    # 0x2611A: '',  # 𦄚
    # 0x2611B: '',  # 𦄛
    0x2611C: 'gōng',  # 𦄜
    # 0x2611D: '',  # 𦄝
    # 0x2611E: '',  # 𦄞
    # 0x2611F: '',  # 𦄟
    # 0x26120: '',  # 𦄠
    # 0x26121: '',  # 𦄡
    # 0x26122: '',  # 𦄢
    # 0x26123: '',  # 𦄣
    # 0x26124: '',  # 𦄤
    # 0x26125: '',  # 𦄥
    # 0x26126: '',  # 𦄦
    0x26127: 'sōu',  # 𦄧
    # 0x26128: '',  # 𦄨
    # 0x26129: '',  # 𦄩
    # 0x2612A: '',  # 𦄪
    # 0x2612B: '',  # 𦄫
    # 0x2612C: '',  # 𦄬
    # 0x2612D: '',  # 𦄭
    # 0x2612E: '',  # 𦄮
    0x2612F: 'zhuǎn',  # 𦄯
    0x26130: 'guó',  # 𦄰
    # 0x26131: '',  # 𦄱
    # 0x26132: '',  # 𦄲
    # 0x26133: '',  # 𦄳
    # 0x26134: '',  # 𦄴
    # 0x26135: '',  # 𦄵
    # 0x26136: '',  # 𦄶
    # 0x26137: '',  # 𦄷
    # 0x26138: '',  # 𦄸
    # 0x26139: '',  # 𦄹
    # 0x2613A: '',  # 𦄺
    # 0x2613B: '',  # 𦄻
    0x2613C: 'xū',  # 𦄼
    0x2613D: 'qú',  # 𦄽
    # 0x2613E: '',  # 𦄾
    0x2613F: 'mò',  # 𦄿
    0x26140: 'xún',  # 𦅀
    # 0x26141: '',  # 𦅁
    # 0x26142: '',  # 𦅂
    0x26143: 'jiāo,qiāo',  # 𦅃
    0x26144: 'zhé',  # 𦅄
    # 0x26145: '',  # 𦅅
    0x26146: 'diàn',  # 𦅆
    0x26147: 'sāng',  # 𦅇
    0x26148: 'bēng',  # 𦅈
    # 0x26149: '',  # 𦅉
    0x2614A: 'suǒ',  # 𦅊
    0x2614B: 'qiǎn',  # 𦅋
    # 0x2614C: '',  # 𦅌
    # 0x2614D: '',  # 𦅍
    # 0x2614E: '',  # 𦅎
    0x2614F: 'xū',  # 𦅏
    # 0x26150: '',  # 𦅐
    0x26151: 'xún',  # 𦅑
    # 0x26152: '',  # 𦅒
    # 0x26153: '',  # 𦅓
    0x26154: 'mò',  # 𦅔
    # 0x26155: '',  # 𦅕
    # 0x26156: '',  # 𦅖
    0x26157: 'chǎn',  # 𦅗
    # 0x26158: '',  # 𦅘
    # 0x26159: '',  # 𦅙
    # 0x2615A: '',  # 𦅚
    # 0x2615B: '',  # 𦅛
    # 0x2615C: '',  # 𦅜
    # 0x2615D: '',  # 𦅝
    # 0x2615E: '',  # 𦅞
    # 0x2615F: '',  # 𦅟
    # 0x26160: '',  # 𦅠
    # 0x26161: '',  # 𦅡
    # 0x26162: '',  # 𦅢
    # 0x26163: '',  # 𦅣
    # 0x26164: '',  # 𦅤
    # 0x26165: '',  # 𦅥
    # 0x26166: '',  # 𦅦
    # 0x26167: '',  # 𦅧
    0x26168: 'xǔ',  # 𦅨
    # 0x26169: '',  # 𦅩
    # 0x2616A: '',  # 𦅪
    # 0x2616B: '',  # 𦅫
    # 0x2616C: '',  # 𦅬
    # 0x2616D: '',  # 𦅭
    # 0x2616E: '',  # 𦅮
    # 0x2616F: '',  # 𦅯
    # 0x26170: '',  # 𦅰
    # 0x26171: '',  # 𦅱
    # 0x26172: '',  # 𦅲
    # 0x26173: '',  # 𦅳
    # 0x26174: '',  # 𦅴
    0x26175: 'suì',  # 𦅵
    0x26176: 'là,liè',  # 𦅶
    0x26177: 'zhǔ,zhù',  # 𦅷
    0x26178: 'zhòu',  # 𦅸
    # 0x26179: '',  # 𦅹
    0x2617A: 'lì',  # 𦅺
    0x2617B: 'huǎn',  # 𦅻
    0x2617C: 'dān',  # 𦅼
    0x2617D: 'jú',  # 𦅽
    0x2617E: 'zhuó',  # 𦅾
    0x2617F: 'yùn',  # 𦅿
    0x26180: 'chǎn',  # 𦆀
    0x26181: 'luó',  # 𦆁
    # 0x26182: '',  # 𦆂
    # 0x26183: '',  # 𦆃
    0x26184: 'sè',  # 𦆄
    # 0x26185: '',  # 𦆅
    0x26186: 'lián',  # 𦆆
    # 0x26187: '',  # 𦆇
    0x26188: 'zuǎn,zuí',  # 𦆈
    # 0x26189: '',  # 𦆉
    # 0x2618A: '',  # 𦆊
    0x2618B: 'lài',  # 𦆋
    0x2618C: 'shuǎng',  # 𦆌
    0x2618D: 'qiè',  # 𦆍
    # 0x2618E: '',  # 𦆎
    # 0x2618F: '',  # 𦆏
    # 0x26190: '',  # 𦆐
    # 0x26191: '',  # 𦆑
    # 0x26192: '',  # 𦆒
    # 0x26193: '',  # 𦆓
    # 0x26194: '',  # 𦆔
    # 0x26195: '',  # 𦆕
    # 0x26196: '',  # 𦆖
    # 0x26197: '',  # 𦆗
    0x26198: 'dōu',  # 𦆘
    # 0x26199: '',  # 𦆙
    # 0x2619A: '',  # 𦆚
    # 0x2619B: '',  # 𦆛
    # 0x2619C: '',  # 𦆜
    # 0x2619D: '',  # 𦆝
    0x2619E: 'wù',  # 𦆞
    0x2619F: 'méng',  # 𦆟
    # 0x261A0: '',  # 𦆠
    0x261A1: 'jì',  # 𦆡
    # 0x261A2: '',  # 𦆢
    # 0x261A3: '',  # 𦆣
    0x261A4: 'chī',  # 𦆤
    # 0x261A5: '',  # 𦆥
    0x261A6: 'nǐ',  # 𦆦
    # 0x261A7: '',  # 𦆧
    # 0x261A8: '',  # 𦆨
    # 0x261A9: '',  # 𦆩
    # 0x261AA: '',  # 𦆪
    # 0x261AB: '',  # 𦆫
    # 0x261AC: '',  # 𦆬
    # 0x261AD: '',  # 𦆭
    # 0x261AE: '',  # 𦆮
    # 0x261AF: '',  # 𦆯
    # 0x261B0: '',  # 𦆰
    # 0x261B1: '',  # 𦆱
    0x261B2: 'liào',  # 𦆲
    # 0x261B3: '',  # 𦆳
    # 0x261B4: '',  # 𦆴
    # 0x261B5: '',  # 𦆵
    # 0x261B6: '',  # 𦆶
    # 0x261B7: '',  # 𦆷
    0x261B8: 'yáo',  # 𦆸
    # 0x261B9: '',  # 𦆹
    # 0x261BA: '',  # 𦆺
    0x261BB: 'là',  # 𦆻
    # 0x261BC: '',  # 𦆼
    # 0x261BD: '',  # 𦆽
    0x261BE: 'lǜ',  # 𦆾
    # 0x261BF: '',  # 𦆿
    0x261C0: 'suì',  # 𦇀
    0x261C1: 'fū',  # 𦇁
    # 0x261C2: '',  # 𦇂
    # 0x261C3: '',  # 𦇃
    0x261C4: 'lěi',  # 𦇄
    0x261C5: 'wěi',  # 𦇅
    # 0x261C6: '',  # 𦇆
    # 0x261C7: '',  # 𦇇
    # 0x261C8: '',  # 𦇈
    # 0x261C9: '',  # 𦇉
    # 0x261CA: '',  # 𦇊
    # 0x261CB: '',  # 𦇋
    # 0x261CC: '',  # 𦇌
    # 0x261CD: '',  # 𦇍
    0x261CE: 'cōng',  # 𦇎
    # 0x261CF: '',  # 𦇏
    # 0x261D0: '',  # 𦇐
    # 0x261D1: '',  # 𦇑
    # 0x261D2: '',  # 𦇒
    # 0x261D3: '',  # 𦇓
    0x261D4: 'lì',  # 𦇔
    # 0x261D5: '',  # 𦇕
    0x261D6: 'pín',  # 𦇖
    # 0x261D7: '',  # 𦇗
    0x261D8: 'jūn',  # 𦇘
    0x261D9: 'jǔ',  # 𦇙
    # 0x261DA: '',  # 𦇚
    0x261DB: 'là',  # 𦇛
    # 0x261DC: '',  # 𦇜
    # 0x261DD: '',  # 𦇝
    # 0x261DE: '',  # 𦇞
    # 0x261DF: '',  # 𦇟
    # 0x261E0: '',  # 𦇠
    # 0x261E1: '',  # 𦇡
    # 0x261E2: '',  # 𦇢
    # 0x261E3: '',  # 𦇣
    # 0x261E4: '',  # 𦇤
    # 0x261E5: '',  # 𦇥
    # 0x261E6: '',  # 𦇦
    0x261E7: 'jì',  # 𦇧
    # 0x261E8: '',  # 𦇨
    # 0x261E9: '',  # 𦇩
    0x261EA: 'miè',  # 𦇪
    # 0x261EB: '',  # 𦇫
    0x261EC: 'yào',  # 𦇬
    0x261ED: 'biān',  # 𦇭
    # 0x261EE: '',  # 𦇮
    # 0x261EF: '',  # 𦇯
    # 0x261F0: '',  # 𦇰
    0x261F1: 'cóng',  # 𦇱
    0x261F2: 'sī,chī',  # 𦇲
    # 0x261F3: '',  # 𦇳
    # 0x261F4: '',  # 𦇴
    0x261F5: 'sī',  # 𦇵
    # 0x261F6: '',  # 𦇶
    # 0x261F7: '',  # 𦇷
    0x261F8: 'hé',  # 𦇸
    # 0x261F9: '',  # 𦇹
    # 0x261FA: '',  # 𦇺
    # 0x261FB: '',  # 𦇻
    # 0x261FC: '',  # 𦇼
    # 0x261FD: '',  # 𦇽
    # 0x261FE: '',  # 𦇾
    # 0x261FF: '',  # 𦇿
    # 0x26200: '',  # 𦈀
    # 0x26201: '',  # 𦈁
    # 0x26202: '',  # 𦈂
    0x26203: 'nàng',  # 𦈃
    # 0x26204: '',  # 𦈄
    0x26205: 'dié',  # 𦈅
    # 0x26206: '',  # 𦈆
    # 0x26207: '',  # 𦈇
    0x26208: 'chè',  # 𦈈
    # 0x26209: '',  # 𦈉
    # 0x2620A: '',  # 𦈊
    # 0x2620B: '',  # 𦈋
    # 0x2620C: '',  # 𦈌
    # 0x2620D: '',  # 𦈍
    # 0x2620E: '',  # 𦈎
    # 0x2620F: '',  # 𦈏
    # 0x26210: '',  # 𦈐
    # 0x26211: '',  # 𦈑
    # 0x26212: '',  # 𦈒
    # 0x26213: '',  # 𦈓
    # 0x26214: '',  # 𦈔
    # 0x26215: '',  # 𦈕
    # 0x26216: '',  # 𦈖
    # 0x26217: '',  # 𦈗
    # 0x26218: '',  # 𦈘
    # 0x26219: '',  # 𦈙
    # 0x2621A: '',  # 𦈚
    # 0x2621B: '',  # 𦈛
    # 0x2621C: '',  # 𦈜
    # 0x2621D: '',  # 𦈝
    # 0x2621E: '',  # 𦈞
    # 0x2621F: '',  # 𦈟
    # 0x26220: '',  # 𦈠
    # 0x26221: '',  # 𦈡
    # 0x26222: '',  # 𦈢
    0x26223: 'yú',  # 𦈣
    0x26224: 'xiòng',  # 𦈤
    # 0x26225: '',  # 𦈥
    0x26226: 'qì',  # 𦈦
    0x26227: 'bēi',  # 𦈧
    0x26228: 'xíng',  # 𦈨
    0x26229: 'gǒng',  # 𦈩
    # 0x2622A: '',  # 𦈪
    # 0x2622B: '',  # 𦈫
    0x2622C: 'zuǐ',  # 𦈬
    # 0x2622D: '',  # 𦈭
    # 0x2622E: '',  # 𦈮
    # 0x2622F: '',  # 𦈯
    0x26230: 'jiē',  # 𦈰
    # 0x26231: '',  # 𦈱
    0x26232: 'kāi,gǔ',  # 𦈲
    # 0x26233: '',  # 𦈳
    # 0x26234: '',  # 𦈴
    0x26235: 'xíng',  # 𦈵
    0x26236: 'bēi',  # 𦈶
    0x26237: 'shū',  # 𦈷
    0x26238: 'yù',  # 𦈸
    # 0x26239: '',  # 𦈹
    0x2623A: 'zhǒu',  # 𦈺
    0x2623B: 'zhǎn',  # 𦈻
    # 0x2623C: '',  # 𦈼
    # 0x2623D: '',  # 𦈽
    # 0x2623E: '',  # 𦈾
    # 0x2623F: '',  # 𦈿
    # 0x26240: '',  # 𦉀
    # 0x26241: '',  # 𦉁
    0x26242: 'zhōng',  # 𦉂
    # 0x26243: '',  # 𦉃
    # 0x26244: '',  # 𦉄
    # 0x26245: '',  # 𦉅
    0x26246: 'chá,chà',  # 𦉆
    # 0x26247: '',  # 𦉇
    0x26248: 'chuí',  # 𦉈
    0x26249: 'liù',  # 𦉉
    # 0x2624A: '',  # 𦉊
    # 0x2624B: '',  # 𦉋
    # 0x2624C: '',  # 𦉌
    # 0x2624D: '',  # 𦉍
    0x2624E: 'suī',  # 𦉎
    # 0x2624F: '',  # 𦉏
    0x26250: 'zhǔ',  # 𦉐
    # 0x26251: '',  # 𦉑
    # 0x26252: '',  # 𦉒
    # 0x26253: '',  # 𦉓
    # 0x26254: '',  # 𦉔
    # 0x26255: '',  # 𦉕
    # 0x26256: '',  # 𦉖
    # 0x26257: '',  # 𦉗
    # 0x26258: '',  # 𦉘
    0x26259: 'biàn',  # 𦉙
    # 0x2625A: '',  # 𦉚
    # 0x2625B: '',  # 𦉛
    # 0x2625C: '',  # 𦉜
    0x2625D: 'xìn',  # 𦉝
    # 0x2625E: '',  # 𦉞
    0x2625F: 'yà',  # 𦉟
    # 0x26260: '',  # 𦉠
    # 0x26261: '',  # 𦉡
    0x26262: 'líng',  # 𦉢
    # 0x26263: '',  # 𦉣
    # 0x26264: '',  # 𦉤
    0x26265: 'wèng',  # 𦉥
    # 0x26266: '',  # 𦉦
    0x26267: 'yà',  # 𦉧
    # 0x26268: '',  # 𦉨
    # 0x26269: '',  # 𦉩
    0x2626A: 'wǎng',  # 𦉪
    # 0x2626B: '',  # 𦉫
    0x2626C: 'tīng',  # 𦉬
    # 0x2626D: '',  # 𦉭
    # 0x2626E: '',  # 𦉮
    # 0x2626F: '',  # 𦉯
    # 0x26270: '',  # 𦉰
    # 0x26271: '',  # 𦉱
    # 0x26272: '',  # 𦉲
    # 0x26273: '',  # 𦉳
    # 0x26274: '',  # 𦉴
    # 0x26275: '',  # 𦉵
    # 0x26276: '',  # 𦉶
    # 0x26277: '',  # 𦉷
    # 0x26278: '',  # 𦉸
    0x26279: 'dí',  # 𦉹
    # 0x2627A: '',  # 𦉺
    # 0x2627B: '',  # 𦉻
    # 0x2627C: '',  # 𦉼
    # 0x2627D: '',  # 𦉽
    # 0x2627E: '',  # 𦉾
    # 0x2627F: '',  # 𦉿
    # 0x26280: '',  # 𦊀
    0x26281: 'pí',  # 𦊁
    0x26282: 'hù',  # 𦊂
    0x26283: 'cén',  # 𦊃
    # 0x26284: '',  # 𦊄
    # 0x26285: '',  # 𦊅
    # 0x26286: '',  # 𦊆
    # 0x26287: '',  # 𦊇
    # 0x26288: '',  # 𦊈
    # 0x26289: '',  # 𦊉
    0x2628A: 'tiān',  # 𦊊
    0x2628B: 'mǒu',  # 𦊋
    0x2628C: 'juǎn',  # 𦊌
    0x2628D: 'hù',  # 𦊍
    0x2628E: 'mǒu',  # 𦊎
    # 0x2628F: '',  # 𦊏
    0x26290: 'jù',  # 𦊐
    # 0x26291: '',  # 𦊑
    # 0x26292: '',  # 𦊒
    0x26293: 'lǐng',  # 𦊓
    # 0x26294: '',  # 𦊔
    # 0x26295: '',  # 𦊕
    # 0x26296: '',  # 𦊖
    0x26297: 'liǔ',  # 𦊗
    0x26298: 'hù',  # 𦊘
    # 0x26299: '',  # 𦊙
    # 0x2629A: '',  # 𦊚
    # 0x2629B: '',  # 𦊛
    # 0x2629C: '',  # 𦊜
    # 0x2629D: '',  # 𦊝
    # 0x2629E: '',  # 𦊞
    # 0x2629F: '',  # 𦊟
    # 0x262A0: '',  # 𦊠
    # 0x262A1: '',  # 𦊡
    # 0x262A2: '',  # 𦊢
    # 0x262A3: '',  # 𦊣
    # 0x262A4: '',  # 𦊤
    # 0x262A5: '',  # 𦊥
    0x262A6: 'fú',  # 𦊦
    0x262A7: 'hú',  # 𦊧
    # 0x262A8: '',  # 𦊨
    # 0x262A9: '',  # 𦊩
    0x262AA: 'è',  # 𦊪
    0x262AB: 'gōng',  # 𦊫
    0x262AC: 'gū',  # 𦊬
    # 0x262AD: '',  # 𦊭
    # 0x262AE: '',  # 𦊮
    # 0x262AF: '',  # 𦊯
    # 0x262B0: '',  # 𦊰
    # 0x262B1: '',  # 𦊱
    # 0x262B2: '',  # 𦊲
    # 0x262B3: '',  # 𦊳
    # 0x262B4: '',  # 𦊴
    # 0x262B5: '',  # 𦊵
    # 0x262B6: '',  # 𦊶
    # 0x262B7: '',  # 𦊷
    # 0x262B8: '',  # 𦊸
    0x262B9: 'lüè',  # 𦊹
    # 0x262BA: '',  # 𦊺
    0x262BB: 'fán',  # 𦊻
    0x262BC: 'lǜ',  # 𦊼
    0x262BD: 'méng',  # 𦊽
    0x262BE: 'fú',  # 𦊾
    0x262BF: 'liú',  # 𦊿
    # 0x262C0: '',  # 𦋀
    # 0x262C1: '',  # 𦋁
    # 0x262C2: '',  # 𦋂
    # 0x262C3: '',  # 𦋃
    # 0x262C4: '',  # 𦋄
    0x262C5: 'xié',  # 𦋅
    0x262C6: 'gū',  # 𦋆
    # 0x262C7: '',  # 𦋇
    0x262C8: 'xiàn',  # 𦋈
    0x262C9: 'bó',  # 𦋉
    # 0x262CA: '',  # 𦋊
    0x262CB: 'jì',  # 𦋋
    # 0x262CC: '',  # 𦋌
    # 0x262CD: '',  # 𦋍
    # 0x262CE: '',  # 𦋎
    # 0x262CF: '',  # 𦋏
    # 0x262D0: '',  # 𦋐
    # 0x262D1: '',  # 𦋑
    # 0x262D2: '',  # 𦋒
    0x262D3: 'quān',  # 𦋓
    0x262D4: 'lù',  # 𦋔
    # 0x262D5: '',  # 𦋕
    # 0x262D6: '',  # 𦋖
    # 0x262D7: '',  # 𦋗
    # 0x262D8: '',  # 𦋘
    # 0x262D9: '',  # 𦋙
    # 0x262DA: '',  # 𦋚
    # 0x262DB: '',  # 𦋛
    # 0x262DC: '',  # 𦋜
    # 0x262DD: '',  # 𦋝
    0x262DE: 'shuò',  # 𦋞
    # 0x262DF: '',  # 𦋟
    # 0x262E0: '',  # 𦋠
    0x262E1: 'mǒu',  # 𦋡
    0x262E2: 'yù',  # 𦋢
    0x262E3: 'hàn',  # 𦋣
    # 0x262E4: '',  # 𦋤
    # 0x262E5: '',  # 𦋥
    # 0x262E6: '',  # 𦋦
    # 0x262E7: '',  # 𦋧
    # 0x262E8: '',  # 𦋨
    0x262E9: 'yuè',  # 𦋩
    0x262EA: 'dàn',  # 𦋪
    # 0x262EB: '',  # 𦋫
    # 0x262EC: '',  # 𦋬
    # 0x262ED: '',  # 𦋭
    # 0x262EE: '',  # 𦋮
    0x262EF: 'yú',  # 𦋯
    0x262F0: 'jiān',  # 𦋰
    # 0x262F1: '',  # 𦋱
    # 0x262F2: '',  # 𦋲
    0x262F3: 'gāng',  # 𦋳
    # 0x262F4: '',  # 𦋴
    # 0x262F5: '',  # 𦋵
    # 0x262F6: '',  # 𦋶
    # 0x262F7: '',  # 𦋷
    # 0x262F8: '',  # 𦋸
    0x262F9: 'mò',  # 𦋹
    # 0x262FA: '',  # 𦋺
    # 0x262FB: '',  # 𦋻
    # 0x262FC: '',  # 𦋼
    # 0x262FD: '',  # 𦋽
    # 0x262FE: '',  # 𦋾
    0x262FF: 'cáo',  # 𦋿
    0x26300: 'shèn',  # 𦌀
    0x26301: 'liǔ,lóu',  # 𦌁
    # 0x26302: '',  # 𦌂
    # 0x26303: '',  # 𦌃
    # 0x26304: '',  # 𦌄
    # 0x26305: '',  # 𦌅
    0x26306: 'jiāo',  # 𦌆
    # 0x26307: '',  # 𦌇
    # 0x26308: '',  # 𦌈
    0x26309: 'sù',  # 𦌉
    0x2630A: 'sù',  # 𦌊
    0x2630B: 'zhòng',  # 𦌋
    # 0x2630C: '',  # 𦌌
    # 0x2630D: '',  # 𦌍
    # 0x2630E: '',  # 𦌎
    # 0x2630F: '',  # 𦌏
    # 0x26310: '',  # 𦌐
    # 0x26311: '',  # 𦌑
    0x26312: 'liào',  # 𦌒
    # 0x26313: '',  # 𦌓
    0x26314: 'xuǎn',  # 𦌔
    0x26315: 'lù',  # 𦌕
    # 0x26316: '',  # 𦌖
    0x26317: 'jì',  # 𦌗
    # 0x26318: '',  # 𦌘
    # 0x26319: '',  # 𦌙
    0x2631A: 'yán',  # 𦌚
    # 0x2631B: '',  # 𦌛
    # 0x2631C: '',  # 𦌜
    # 0x2631D: '',  # 𦌝
    # 0x2631E: '',  # 𦌞
    0x2631F: 'lù',  # 𦌟
    # 0x26320: '',  # 𦌠
    0x26321: 'mǐn',  # 𦌡
    0x26322: 'tí',  # 𦌢
    # 0x26323: '',  # 𦌣
    # 0x26324: '',  # 𦌤
    # 0x26325: '',  # 𦌥
    0x26326: 'huàn',  # 𦌦
    # 0x26327: '',  # 𦌧
    # 0x26328: '',  # 𦌨
    0x26329: 'yì',  # 𦌩
    0x2632A: 'tǎn',  # 𦌪
    # 0x2632B: '',  # 𦌫
    0x2632C: 'wǔ,wú',  # 𦌬
    0x2632D: 'jī',  # 𦌭
    # 0x2632E: '',  # 𦌮
    # 0x2632F: '',  # 𦌯
    0x26330: 'jī',  # 𦌰
    # 0x26331: '',  # 𦌱
    # 0x26332: '',  # 𦌲
    # 0x26333: '',  # 𦌳
    # 0x26334: '',  # 𦌴
    # 0x26335: '',  # 𦌵
    # 0x26336: '',  # 𦌶
    0x26337: 'dú',  # 𦌷
    0x26338: 'kūn',  # 𦌸
    # 0x26339: '',  # 𦌹
    0x2633A: 'jūn',  # 𦌺
    # 0x2633B: '',  # 𦌻
    # 0x2633C: '',  # 𦌼
    # 0x2633D: '',  # 𦌽
    0x2633E: 'juàn',  # 𦌾
    0x2633F: 'shī',  # 𦌿
    0x26340: 'nàn',  # 𦍀
    0x26341: 'pò',  # 𦍁
    # 0x26342: '',  # 𦍂
    # 0x26343: '',  # 𦍃
    0x26344: 'shū',  # 𦍄
    0x26345: 'quàn',  # 𦍅
    # 0x26346: '',  # 𦍆
    # 0x26347: '',  # 𦍇
    # 0x26348: '',  # 𦍈
    # 0x26349: '',  # 𦍉
    # 0x2634A: '',  # 𦍊
    # 0x2634B: '',  # 𦍋
    0x2634C: 'rèn',  # 𦍌
    # 0x2634D: '',  # 𦍍
    # 0x2634E: '',  # 𦍎
    0x2634F: 'fén',  # 𦍏
    # 0x26350: '',  # 𦍐
    # 0x26351: '',  # 𦍑
    0x26352: 'tà',  # 𦍒
    0x26353: 'tún',  # 𦍓
    # 0x26354: '',  # 𦍔
    0x26355: 'yáng',  # 𦍕
    # 0x26356: '',  # 𦍖
    # 0x26357: '',  # 𦍗
    # 0x26358: '',  # 𦍘
    # 0x26359: '',  # 𦍙
    0x2635A: 'gāo',  # 𦍚
    # 0x2635B: '',  # 𦍛
    # 0x2635C: '',  # 𦍜
    # 0x2635D: '',  # 𦍝
    # 0x2635E: '',  # 𦍞
    # 0x2635F: '',  # 𦍟
    # 0x26360: '',  # 𦍠
    # 0x26361: '',  # 𦍡
    # 0x26362: '',  # 𦍢
    # 0x26363: '',  # 𦍣
    # 0x26364: '',  # 𦍤
    # 0x26365: '',  # 𦍥
    0x26366: 'duō',  # 𦍦
    0x26367: 'cī',  # 𦍧
    # 0x26368: '',  # 𦍨
    # 0x26369: '',  # 𦍩
    0x2636A: 'fén',  # 𦍪
    # 0x2636B: '',  # 𦍫
    # 0x2636C: '',  # 𦍬
    0x2636D: 'róu',  # 𦍭
    # 0x2636E: '',  # 𦍮
    # 0x2636F: '',  # 𦍯
    # 0x26370: '',  # 𦍰
    0x26371: 'gāo',  # 𦍱
    0x26372: 'xiáng,yàng',  # 𦍲
    # 0x26373: '',  # 𦍳
    0x26374: 'xiáng',  # 𦍴
    0x26375: 'hǒu',  # 𦍵
    # 0x26376: '',  # 𦍶
    0x26377: 'tāo',  # 𦍷
    0x26378: 'shàn',  # 𦍸
    0x26379: 'yáng',  # 𦍹
    0x2637A: 'zì',  # 𦍺
    # 0x2637B: '',  # 𦍻
    0x2637C: 'yuán',  # 𦍼
    # 0x2637D: '',  # 𦍽
    # 0x2637E: '',  # 𦍾
    # 0x2637F: '',  # 𦍿
    # 0x26380: '',  # 𦎀
    # 0x26381: '',  # 𦎁
    # 0x26382: '',  # 𦎂
    # 0x26383: '',  # 𦎃
    0x26384: 'sú',  # 𦎄
    # 0x26385: '',  # 𦎅
    # 0x26386: '',  # 𦎆
    0x26387: 'chuàn',  # 𦎇
    0x26388: 'xiáng,xiè',  # 𦎈
    # 0x26389: '',  # 𦎉
    0x2638A: 'bān',  # 𦎊
    # 0x2638B: '',  # 𦎋
    0x2638C: 'mǎn',  # 𦎌
    # 0x2638D: '',  # 𦎍
    0x2638E: 'fǔ',  # 𦎎
    0x2638F: 'lǎ',  # 𦎏
    0x26390: 'lǐ',  # 𦎐
    # 0x26391: '',  # 𦎑
    0x26392: 'jié',  # 𦎒
    0x26393: 'yōu',  # 𦎓
    # 0x26394: '',  # 𦎔
    # 0x26395: '',  # 𦎕
    # 0x26396: '',  # 𦎖
    # 0x26397: '',  # 𦎗
    0x26398: 'yù',  # 𦎘
    # 0x26399: '',  # 𦎙
    0x2639A: 'chì',  # 𦎚
    # 0x2639B: '',  # 𦎛
    0x2639C: 'chuàn',  # 𦎜
    0x2639D: 'yì',  # 𦎝
    0x2639E: 'shān',  # 𦎞
    # 0x2639F: '',  # 𦎟
    # 0x263A0: '',  # 𦎠
    # 0x263A1: '',  # 𦎡
    0x263A2: 'jí',  # 𦎢
    0x263A3: 'yān',  # 𦎣
    # 0x263A4: '',  # 𦎤
    # 0x263A5: '',  # 𦎥
    0x263A6: 'wù',  # 𦎦
    0x263A7: 'chún,dūn,dùn',  # 𦎧
    0x263A8: 'máng',  # 𦎨
    # 0x263A9: '',  # 𦎩
    # 0x263AA: '',  # 𦎪
    0x263AB: 'chún',  # 𦎫
    # 0x263AC: '',  # 𦎬
    0x263AD: 'fú',  # 𦎭
    0x263AE: 'jiā',  # 𦎮
    0x263AF: 'gòu',  # 𦎯
    0x263B0: 'gú',  # 𦎰
    0x263B1: 'jiá',  # 𦎱
    # 0x263B2: '',  # 𦎲
    # 0x263B3: '',  # 𦎳
    # 0x263B4: '',  # 𦎴
    0x263B5: 'xián',  # 𦎵
    # 0x263B6: '',  # 𦎶
    0x263B7: 'jìn',  # 𦎷
    0x263B8: 'zì',  # 𦎸
    0x263B9: 'lóu',  # 𦎹
    # 0x263BA: '',  # 𦎺
    # 0x263BB: '',  # 𦎻
    0x263BC: 'gòu',  # 𦎼
    # 0x263BD: '',  # 𦎽
    # 0x263BE: '',  # 𦎾
    # 0x263BF: '',  # 𦎿
    0x263C0: 'rén',  # 𦏀
    0x263C1: 'xī',  # 𦏁
    0x263C2: 'shān',  # 𦏂
    # 0x263C3: '',  # 𦏃
    # 0x263C4: '',  # 𦏄
    0x263C5: 'jué',  # 𦏅
    0x263C6: 'tóng',  # 𦏆
    0x263C7: 'yǒu',  # 𦏇
    # 0x263C8: '',  # 𦏈
    # 0x263C9: '',  # 𦏉
    # 0x263CA: '',  # 𦏊
    # 0x263CB: '',  # 𦏋
    # 0x263CC: '',  # 𦏌
    # 0x263CD: '',  # 𦏍
    # 0x263CE: '',  # 𦏎
    # 0x263CF: '',  # 𦏏
    # 0x263D0: '',  # 𦏐
    # 0x263D1: '',  # 𦏑
    # 0x263D2: '',  # 𦏒
    # 0x263D3: '',  # 𦏓
    0x263D4: 'jiān',  # 𦏔
    0x263D5: 'dú',  # 𦏕
    # 0x263D6: '',  # 𦏖
    0x263D7: 'hú',  # 𦏗
    # 0x263D8: '',  # 𦏘
    # 0x263D9: '',  # 𦏙
    # 0x263DA: '',  # 𦏚
    0x263DB: 'sāo',  # 𦏛
    0x263DC: 'yù',  # 𦏜
    # 0x263DD: '',  # 𦏝
    # 0x263DE: '',  # 𦏞
    # 0x263DF: '',  # 𦏟
    # 0x263E0: '',  # 𦏠
    # 0x263E1: '',  # 𦏡
    0x263E2: 'mài',  # 𦏢
    # 0x263E3: '',  # 𦏣
    0x263E4: 'zhī',  # 𦏤
    0x263E5: 'yān',  # 𦏥
    0x263E6: 'gāo',  # 𦏦
    0x263E7: 'shú',  # 𦏧
    0x263E8: 'huài',  # 𦏨
    # 0x263E9: '',  # 𦏩
    # 0x263EA: '',  # 𦏪
    # 0x263EB: '',  # 𦏫
    # 0x263EC: '',  # 𦏬
    # 0x263ED: '',  # 𦏭
    0x263EE: 'quán',  # 𦏮
    # 0x263EF: '',  # 𦏯
    # 0x263F0: '',  # 𦏰
    0x263F1: 'yǎng,chài',  # 𦏱
    # 0x263F2: '',  # 𦏲
    0x263F3: 'zuǐ',  # 𦏳
    # 0x263F4: '',  # 𦏴
    # 0x263F5: '',  # 𦏵
    # 0x263F6: '',  # 𦏶
    0x263F7: 'xiāo',  # 𦏷
    0x263F8: 'yì,chí',  # 𦏸
    0x263F9: 'yǎn',  # 𦏹
    0x263FA: 'hóng,gòng',  # 𦏺
    0x263FB: 'yú,yù',  # 𦏻
    # 0x263FC: '',  # 𦏼
    # 0x263FD: '',  # 𦏽
    # 0x263FE: '',  # 𦏾
    0x263FF: 'chì',  # 𦏿
    # 0x26400: '',  # 𦐀
    0x26401: 'chí',  # 𦐁
    # 0x26402: '',  # 𦐂
    # 0x26403: '',  # 𦐃
    0x26404: 'háng',  # 𦐄
    0x26405: 'sè',  # 𦐅
    0x26406: 'pā',  # 𦐆
    0x26407: 'tà',  # 𦐇
    0x26408: 'fēn',  # 𦐈
    0x26409: 'chī',  # 𦐉
    # 0x2640A: '',  # 𦐊
    # 0x2640B: '',  # 𦐋
    # 0x2640C: '',  # 𦐌
    0x2640D: 'xuè',  # 𦐍
    # 0x2640E: '',  # 𦐎
    # 0x2640F: '',  # 𦐏
    # 0x26410: '',  # 𦐐
    # 0x26411: '',  # 𦐑
    # 0x26412: '',  # 𦐒
    # 0x26413: '',  # 𦐓
    # 0x26414: '',  # 𦐔
    # 0x26415: '',  # 𦐕
    0x26416: 'zhǐ',  # 𦐖
    # 0x26417: '',  # 𦐗
    # 0x26418: '',  # 𦐘
    # 0x26419: '',  # 𦐙
    # 0x2641A: '',  # 𦐚
    0x2641B: 'qú,yù',  # 𦐛
    # 0x2641C: '',  # 𦐜
    # 0x2641D: '',  # 𦐝
    # 0x2641E: '',  # 𦐞
    # 0x2641F: '',  # 𦐟
    0x26420: 'xī',  # 𦐠
    0x26421: 'fú',  # 𦐡
    # 0x26422: '',  # 𦐢
    0x26423: 'shū',  # 𦐣
    0x26424: 'hài',  # 𦐤
    # 0x26425: '',  # 𦐥
    0x26426: 'pò',  # 𦐦
    0x26427: 'yì',  # 𦐧
    0x26428: 'cǐ',  # 𦐨
    # 0x26429: '',  # 𦐩
    # 0x2642A: '',  # 𦐪
    # 0x2642B: '',  # 𦐫
    # 0x2642C: '',  # 𦐬
    # 0x2642D: '',  # 𦐭
    # 0x2642E: '',  # 𦐮
    # 0x2642F: '',  # 𦐯
    0x26430: 'chài',  # 𦐰
    # 0x26431: '',  # 𦐱
    # 0x26432: '',  # 𦐲
    0x26433: 'hōng',  # 𦐳
    # 0x26434: '',  # 𦐴
    # 0x26435: '',  # 𦐵
    # 0x26436: '',  # 𦐶
    # 0x26437: '',  # 𦐷
    0x26438: 'pǎo',  # 𦐸
    0x26439: 'shēn',  # 𦐹
    0x2643A: 'xiāo',  # 𦐺
    # 0x2643B: '',  # 𦐻
    # 0x2643C: '',  # 𦐼
    0x2643D: 'xuān,líng',  # 𦐽
    0x2643E: 'cǐ',  # 𦐾
    0x2643F: 'tíng',  # 𦐿
    0x26440: 'pò',  # 𦑀
    # 0x26441: '',  # 𦑁
    # 0x26442: '',  # 𦑂
    # 0x26443: '',  # 𦑃
    # 0x26444: '',  # 𦑄
    # 0x26445: '',  # 𦑅
    # 0x26446: '',  # 𦑆
    0x26447: 'tà',  # 𦑇
    0x26448: 'chā',  # 𦑈
    # 0x26449: '',  # 𦑉
    # 0x2644A: '',  # 𦑊
    0x2644B: 'zú',  # 𦑋
    0x2644C: 'huò',  # 𦑌
    0x2644D: 'xù',  # 𦑍
    0x2644E: 'yàn',  # 𦑎
    0x2644F: 'chài',  # 𦑏
    # 0x26450: '',  # 𦑐
    0x26451: 'tuó',  # 𦑑
    # 0x26452: '',  # 𦑒
    # 0x26453: '',  # 𦑓
    # 0x26454: '',  # 𦑔
    # 0x26455: '',  # 𦑕
    # 0x26456: '',  # 𦑖
    # 0x26457: '',  # 𦑗
    0x26458: 'xián',  # 𦑘
    0x26459: 'xuān',  # 𦑙
    0x2645A: 'hóu',  # 𦑚
    0x2645B: 'huǎn',  # 𦑛
    0x2645C: 'gé',  # 𦑜
    0x2645D: 'chǒng',  # 𦑝
    0x2645E: 'bì',  # 𦑞
    0x2645F: 'hōng',  # 𦑟
    0x26460: 'hōng',  # 𦑠
    0x26461: 'chí,chī',  # 𦑡
    # 0x26462: '',  # 𦑢
    0x26463: 'chá',  # 𦑣
    # 0x26464: '',  # 𦑤
    # 0x26465: '',  # 𦑥
    # 0x26466: '',  # 𦑦
    # 0x26467: '',  # 𦑧
    # 0x26468: '',  # 𦑨
    # 0x26469: '',  # 𦑩
    # 0x2646A: '',  # 𦑪
    # 0x2646B: '',  # 𦑫
    # 0x2646C: '',  # 𦑬
    0x2646D: 'bì',  # 𦑭
    # 0x2646E: '',  # 𦑮
    0x2646F: 'zhǎ',  # 𦑯
    # 0x26470: '',  # 𦑰
    0x26471: 'zhái,huò',  # 𦑱
    0x26472: 'tà',  # 𦑲
    # 0x26473: '',  # 𦑳
    # 0x26474: '',  # 𦑴
    0x26475: 'pò',  # 𦑵
    0x26476: 'tà',  # 𦑶
    # 0x26477: '',  # 𦑷
    0x26478: 'yóu',  # 𦑸
    0x26479: 'fú',  # 𦑹
    0x2647A: 'cī',  # 𦑺
    0x2647B: 'dá',  # 𦑻
    0x2647C: 'tǎ',  # 𦑼
    # 0x2647D: '',  # 𦑽
    0x2647E: 'liú',  # 𦑾
    # 0x2647F: '',  # 𦑿
    # 0x26480: '',  # 𦒀
    0x26481: 'cī',  # 𦒁
    # 0x26482: '',  # 𦒂
    0x26483: 'hōng',  # 𦒃
    # 0x26484: '',  # 𦒄
    0x26485: 'hàn',  # 𦒅
    0x26486: 'lā',  # 𦒆
    # 0x26487: '',  # 𦒇
    0x26488: 'shī',  # 𦒈
    # 0x26489: '',  # 𦒉
    # 0x2648A: '',  # 𦒊
    0x2648B: 'hàn',  # 𦒋
    # 0x2648C: '',  # 𦒌
    0x2648D: 'tóng',  # 𦒍
    0x2648E: 'huì',  # 𦒎
    0x2648F: 'hé',  # 𦒏
    0x26490: 'piē',  # 𦒐
    0x26491: 'yù',  # 𦒑
    # 0x26492: '',  # 𦒒
    # 0x26493: '',  # 𦒓
    # 0x26494: '',  # 𦒔
    # 0x26495: '',  # 𦒕
    # 0x26496: '',  # 𦒖
    # 0x26497: '',  # 𦒗
    # 0x26498: '',  # 𦒘
    # 0x26499: '',  # 𦒙
    # 0x2649A: '',  # 𦒚
    # 0x2649B: '',  # 𦒛
    0x2649C: 'xiān',  # 𦒜
    0x2649D: 'hǎn',  # 𦒝
    # 0x2649E: '',  # 𦒞
    0x2649F: 'pò',  # 𦒟
    # 0x264A0: '',  # 𦒠
    # 0x264A1: '',  # 𦒡
    0x264A2: 'áo',  # 𦒢
    # 0x264A3: '',  # 𦒣
    # 0x264A4: '',  # 𦒤
    # 0x264A5: '',  # 𦒥
    0x264A6: 'là',  # 𦒦
    0x264A7: 'huò',  # 𦒧
    # 0x264A8: '',  # 𦒨
    # 0x264A9: '',  # 𦒩
    # 0x264AA: '',  # 𦒪
    # 0x264AB: '',  # 𦒫
    # 0x264AC: '',  # 𦒬
    # 0x264AD: '',  # 𦒭
    # 0x264AE: '',  # 𦒮
    # 0x264AF: '',  # 𦒯
    0x264B0: 'tài',  # 𦒰
    # 0x264B1: '',  # 𦒱
    # 0x264B2: '',  # 𦒲
    # 0x264B3: '',  # 𦒳
    0x264B4: 'lǎo',  # 𦒴
    # 0x264B5: '',  # 𦒵
    0x264B6: 'shù',  # 𦒶
    # 0x264B7: '',  # 𦒷
    # 0x264B8: '',  # 𦒸
    # 0x264B9: '',  # 𦒹
    0x264BA: 'dào',  # 𦒺
    0x264BB: 'diǎn',  # 𦒻
    # 0x264BC: '',  # 𦒼
    # 0x264BD: '',  # 𦒽
    # 0x264BE: '',  # 𦒾
    # 0x264BF: '',  # 𦒿
    # 0x264C0: '',  # 𦓀
    # 0x264C1: '',  # 𦓁
    # 0x264C2: '',  # 𦓂
    # 0x264C3: '',  # 𦓃
    # 0x264C4: '',  # 𦓄
    # 0x264C5: '',  # 𦓅
    # 0x264C6: '',  # 𦓆
    # 0x264C7: '',  # 𦓇
    0x264C8: 'xiòng',  # 𦓈
    # 0x264C9: '',  # 𦓉
    # 0x264CA: '',  # 𦓊
    0x264CB: 'wàng',  # 𦓋
    # 0x264CC: '',  # 𦓌
    0x264CD: 'chě',  # 𦓍
    0x264CE: 'nài',  # 𦓎
    # 0x264CF: '',  # 𦓏
    0x264D0: 'jué',  # 𦓐
    # 0x264D1: '',  # 𦓑
    # 0x264D2: '',  # 𦓒
    0x264D3: 'ér,liè',  # 𦓓
    0x264D4: 'ér,xū',  # 𦓔
    0x264D5: 'nǘ',  # 𦓕
    0x264D6: 'nǜ',  # 𦓖
    # 0x264D7: '',  # 𦓗
    # 0x264D8: '',  # 𦓘
    # 0x264D9: '',  # 𦓙
    0x264DA: 'zhuǎn',  # 𦓚
    # 0x264DB: '',  # 𦓛
    # 0x264DC: '',  # 𦓜
    0x264DD: 'zhuǎn',  # 𦓝
    # 0x264DE: '',  # 𦓞
    # 0x264DF: '',  # 𦓟
    # 0x264E0: '',  # 𦓠
    # 0x264E1: '',  # 𦓡
    0x264E2: 'nuò',  # 𦓢
    # 0x264E3: '',  # 𦓣
    0x264E4: 'liè',  # 𦓤
    0x264E5: 'lěi',  # 𦓥
    # 0x264E6: '',  # 𦓦
    0x264E7: 'bā',  # 𦓧
    # 0x264E8: '',  # 𦓨
    # 0x264E9: '',  # 𦓩
    # 0x264EA: '',  # 𦓪
    # 0x264EB: '',  # 𦓫
    0x264EC: 'chēng',  # 𦓬
    # 0x264ED: '',  # 𦓭
    # 0x264EE: '',  # 𦓮
    0x264EF: 'guī',  # 𦓯
    0x264F0: 'quán',  # 𦓰
    0x264F1: 'gè',  # 𦓱
    # 0x264F2: '',  # 𦓲
    0x264F3: 'gǒng',  # 𦓳
    0x264F4: 'shào,shāo',  # 𦓴
    # 0x264F5: '',  # 𦓵
    # 0x264F6: '',  # 𦓶
    # 0x264F7: '',  # 𦓷
    # 0x264F8: '',  # 𦓸
    0x264F9: 'lái',  # 𦓹
    0x264FA: 'zhēng',  # 𦓺
    0x264FB: 'yì',  # 𦓻
    0x264FC: 'gǔn',  # 𦓼
    0x264FD: 'wēi',  # 𦓽
    0x264FE: 'lǔn,kǔn',  # 𦓾
    # 0x264FF: '',  # 𦓿
    # 0x26500: '',  # 𦔀
    # 0x26501: '',  # 𦔁
    0x26502: 'shí',  # 𦔂
    0x26503: 'yīng',  # 𦔃
    0x26504: 'shěng',  # 𦔄
    0x26505: 'tú',  # 𦔅
    0x26506: 'bì',  # 𦔆
    # 0x26507: '',  # 𦔇
    0x26508: 'zé',  # 𦔈
    0x26509: 'zhòng',  # 𦔉
    # 0x2650A: '',  # 𦔊
    0x2650B: 'rǒng',  # 𦔋
    0x2650C: 'qí,sí',  # 𦔌
    0x2650D: 'fù',  # 𦔍
    0x2650E: 'cè',  # 𦔎
    # 0x2650F: '',  # 𦔏
    0x26510: 'yún',  # 𦔐
    # 0x26511: '',  # 𦔑
    # 0x26512: '',  # 𦔒
    0x26513: 'lí',  # 𦔓
    0x26514: 'mán,màn',  # 𦔔
    # 0x26515: '',  # 𦔕
    0x26516: 'lián',  # 𦔖
    0x26517: 'biāo',  # 𦔗
    # 0x26518: '',  # 𦔘
    # 0x26519: '',  # 𦔙
    # 0x2651A: '',  # 𦔚
    0x2651B: 'chuáng',  # 𦔛
    0x2651C: 'yì',  # 𦔜
    # 0x2651D: '',  # 𦔝
    # 0x2651E: '',  # 𦔞
    # 0x2651F: '',  # 𦔟
    0x26520: 'pài',  # 𦔠
    # 0x26521: '',  # 𦔡
    # 0x26522: '',  # 𦔢
    # 0x26523: '',  # 𦔣
    # 0x26524: '',  # 𦔤
    0x26525: 'yì,shì',  # 𦔥
    0x26526: 'kuài',  # 𦔦
    # 0x26527: '',  # 𦔧
    # 0x26528: '',  # 𦔨
    0x26529: 'biāo,pāo',  # 𦔩
    # 0x2652A: '',  # 𦔪
    0x2652B: 'chì,yì',  # 𦔫
    0x2652C: 'qú',  # 𦔬
    0x2652D: 'mò',  # 𦔭
    0x2652E: 'zhé',  # 𦔮
    0x2652F: 'shà',  # 𦔯
    0x26530: 'shà,xū',  # 𦔰
    # 0x26531: '',  # 𦔱
    # 0x26532: '',  # 𦔲
    # 0x26533: '',  # 𦔳
    # 0x26534: '',  # 𦔴
    0x26535: 'wén',  # 𦔵
    # 0x26536: '',  # 𦔶
    0x26537: 'yāo',  # 𦔷
    0x26538: 'gōng',  # 𦔸
    0x26539: 'nài',  # 𦔹
    # 0x2653A: '',  # 𦔺
    0x2653B: 'shèng',  # 𦔻
    0x2653C: 'xiè',  # 𦔼
    # 0x2653D: '',  # 𦔽
    # 0x2653E: '',  # 𦔾
    0x2653F: 'tiàn',  # 𦔿
    # 0x26540: '',  # 𦕀
    # 0x26541: '',  # 𦕁
    # 0x26542: '',  # 𦕂
    # 0x26543: '',  # 𦕃
    # 0x26544: '',  # 𦕄
    # 0x26545: '',  # 𦕅
    0x26546: 'yé',  # 𦕆
    # 0x26547: '',  # 𦕇
    # 0x26548: '',  # 𦕈
    0x26549: 'shā',  # 𦕉
    # 0x2654A: '',  # 𦕊
    # 0x2654B: '',  # 𦕋
    # 0x2654C: '',  # 𦕌
    # 0x2654D: '',  # 𦕍
    # 0x2654E: '',  # 𦕎
    0x2654F: 'sào',  # 𦕏
    # 0x26550: '',  # 𦕐
    # 0x26551: '',  # 𦕑
    0x26552: 'diān',  # 𦕒
    0x26553: 'xù',  # 𦕓
    # 0x26554: '',  # 𦕔
    # 0x26555: '',  # 𦕕
    # 0x26556: '',  # 𦕖
    # 0x26557: '',  # 𦕗
    # 0x26558: '',  # 𦕘
    0x26559: 'qú',  # 𦕙
    # 0x2655A: '',  # 𦕚
    # 0x2655B: '',  # 𦕛
    # 0x2655C: '',  # 𦕜
    # 0x2655D: '',  # 𦕝
    # 0x2655E: '',  # 𦕞
    # 0x2655F: '',  # 𦕟
    0x26560: 'hōng',  # 𦕠
    0x26561: 'shèng',  # 𦕡
    0x26562: 'tìng',  # 𦕢
    # 0x26563: '',  # 𦕣
    # 0x26564: '',  # 𦕤
    # 0x26565: '',  # 𦕥
    # 0x26566: '',  # 𦕦
    # 0x26567: '',  # 𦕧
    # 0x26568: '',  # 𦕨
    # 0x26569: '',  # 𦕩
    # 0x2656A: '',  # 𦕪
    # 0x2656B: '',  # 𦕫
    # 0x2656C: '',  # 𦕬
    # 0x2656D: '',  # 𦕭
    # 0x2656E: '',  # 𦕮
    # 0x2656F: '',  # 𦕯
    0x26570: 'duo',  # 𦕰
    # 0x26571: '',  # 𦕱
    # 0x26572: '',  # 𦕲
    # 0x26573: '',  # 𦕳
    # 0x26574: '',  # 𦕴
    0x26575: 'liáo',  # 𦕵
    # 0x26576: '',  # 𦕶
    0x26577: 'hòng',  # 𦕷
    0x26578: 'lǐ',  # 𦕸
    # 0x26579: '',  # 𦕹
    0x2657A: 'xiǎng,gāo',  # 𦕺
    # 0x2657B: '',  # 𦕻
    # 0x2657C: '',  # 𦕼
    0x2657D: 'shèn',  # 𦕽
    # 0x2657E: '',  # 𦕾
    # 0x2657F: '',  # 𦕿
    0x26580: 'fū',  # 𦖀
    # 0x26581: '',  # 𦖁
    # 0x26582: '',  # 𦖂
    # 0x26583: '',  # 𦖃
    # 0x26584: '',  # 𦖄
    # 0x26585: '',  # 𦖅
    # 0x26586: '',  # 𦖆
    # 0x26587: '',  # 𦖇
    0x26588: 'yǎn',  # 𦖈
    0x26589: 'wǎng',  # 𦖉
    0x2658A: 'qī',  # 𦖊
    0x2658B: 'duǒ',  # 𦖋
    # 0x2658C: '',  # 𦖌
    0x2658D: 'huà',  # 𦖍
    0x2658E: 'qiān',  # 𦖎
    # 0x2658F: '',  # 𦖏
    0x26590: 'xiè',  # 𦖐
    # 0x26591: '',  # 𦖑
    # 0x26592: '',  # 𦖒
    # 0x26593: '',  # 𦖓
    # 0x26594: '',  # 𦖔
    # 0x26595: '',  # 𦖕
    # 0x26596: '',  # 𦖖
    # 0x26597: '',  # 𦖗
    # 0x26598: '',  # 𦖘
    # 0x26599: '',  # 𦖙
    # 0x2659A: '',  # 𦖚
    # 0x2659B: '',  # 𦖛
    # 0x2659C: '',  # 𦖜
    0x2659D: 'cì',  # 𦖝
    0x2659E: 'shēng,wén',  # 𦖞
    # 0x2659F: '',  # 𦖟
    # 0x265A0: '',  # 𦖠
    # 0x265A1: '',  # 𦖡
    0x265A2: 'èr',  # 𦖢
    # 0x265A3: '',  # 𦖣
    0x265A4: 'xīng',  # 𦖤
    # 0x265A5: '',  # 𦖥
    0x265A6: 'tuì',  # 𦖦
    0x265A7: 'yàn',  # 𦖧
    # 0x265A8: '',  # 𦖨
    0x265A9: 'liè',  # 𦖩
    # 0x265AA: '',  # 𦖪
    # 0x265AB: '',  # 𦖫
    0x265AC: 'mí',  # 𦖬
    # 0x265AD: '',  # 𦖭
    # 0x265AE: '',  # 𦖮
    # 0x265AF: '',  # 𦖯
    # 0x265B0: '',  # 𦖰
    # 0x265B1: '',  # 𦖱
    # 0x265B2: '',  # 𦖲
    # 0x265B3: '',  # 𦖳
    # 0x265B4: '',  # 𦖴
    # 0x265B5: '',  # 𦖵
    # 0x265B6: '',  # 𦖶
    # 0x265B7: '',  # 𦖷
    0x265B8: 'zòng',  # 𦖸
    # 0x265B9: '',  # 𦖹
    0x265BA: 'zī',  # 𦖺
    # 0x265BB: '',  # 𦖻
    0x265BC: 'hú',  # 𦖼
    0x265BD: 'yíng',  # 𦖽
    0x265BE: 'lián',  # 𦖾
    0x265BF: 'dā',  # 𦖿
    0x265C0: 'tián',  # 𦗀
    0x265C1: 'tiàn',  # 𦗁
    # 0x265C2: '',  # 𦗂
    # 0x265C3: '',  # 𦗃
    # 0x265C4: '',  # 𦗄
    # 0x265C5: '',  # 𦗅
    # 0x265C6: '',  # 𦗆
    # 0x265C7: '',  # 𦗇
    # 0x265C8: '',  # 𦗈
    # 0x265C9: '',  # 𦗉
    # 0x265CA: '',  # 𦗊
    0x265CB: 'róng',  # 𦗋
    # 0x265CC: '',  # 𦗌
    0x265CD: 'ài',  # 𦗍
    # 0x265CE: '',  # 𦗎
    # 0x265CF: '',  # 𦗏
    0x265D0: 'ài',  # 𦗐
    0x265D1: 'zhé',  # 𦗑
    0x265D2: 'guō',  # 𦗒
    0x265D3: 'lù',  # 𦗓
    0x265D4: 'zhāo',  # 𦗔
    0x265D5: 'mí',  # 𦗕
    0x265D6: 'liáo',  # 𦗖
    0x265D7: 'zhé',  # 𦗗
    # 0x265D8: '',  # 𦗘
    # 0x265D9: '',  # 𦗙
    # 0x265DA: '',  # 𦗚
    0x265DB: 'qǔ',  # 𦗛
    0x265DC: 'cōng',  # 𦗜
    # 0x265DD: '',  # 𦗝
    # 0x265DE: '',  # 𦗞
    0x265DF: 'tīng,tè',  # 𦗟
    # 0x265E0: '',  # 𦗠
    0x265E1: 'tán',  # 𦗡
    0x265E2: 'zhǎn',  # 𦗢
    0x265E3: 'hú',  # 𦗣
    # 0x265E4: '',  # 𦗤
    0x265E5: 'piē',  # 𦗥
    # 0x265E6: '',  # 𦗦
    0x265E7: 'dā',  # 𦗧
    0x265E8: 'róng',  # 𦗨
    # 0x265E9: '',  # 𦗩
    # 0x265EA: '',  # 𦗪
    # 0x265EB: '',  # 𦗫
    # 0x265EC: '',  # 𦗬
    # 0x265ED: '',  # 𦗭
    0x265EE: 'nǎo',  # 𦗮
    # 0x265EF: '',  # 𦗯
    # 0x265F0: '',  # 𦗰
    # 0x265F1: '',  # 𦗱
    # 0x265F2: '',  # 𦗲
    0x265F3: 'náng',  # 𦗳
    0x265F4: 'dāng',  # 𦗴
    0x265F5: 'jiǎo',  # 𦗵
    # 0x265F6: '',  # 𦗶
    # 0x265F7: '',  # 𦗷
    # 0x265F8: '',  # 𦗸
    # 0x265F9: '',  # 𦗹
    # 0x265FA: '',  # 𦗺
    0x265FB: 'jù',  # 𦗻
    0x265FC: 'ěr',  # 𦗼
    # 0x265FD: '',  # 𦗽
    # 0x265FE: '',  # 𦗾
    # 0x265FF: '',  # 𦗿
    # 0x26600: '',  # 𦘀
    # 0x26601: '',  # 𦘁
    # 0x26602: '',  # 𦘂
    # 0x26603: '',  # 𦘃
    # 0x26604: '',  # 𦘄
    # 0x26605: '',  # 𦘅
    # 0x26606: '',  # 𦘆
    # 0x26607: '',  # 𦘇
    # 0x26608: '',  # 𦘈
    # 0x26609: '',  # 𦘉
    0x2660A: 'lì',  # 𦘊
    # 0x2660B: '',  # 𦘋
    0x2660C: 'guō',  # 𦘌
    0x2660D: 'wài,wà',  # 𦘍
    # 0x2660E: '',  # 𦘎
    # 0x2660F: '',  # 𦘏
    # 0x26610: '',  # 𦘐
    # 0x26611: '',  # 𦘑
    0x26612: 'niè',  # 𦘒
    # 0x26613: '',  # 𦘓
    0x26614: 'jīn',  # 𦘔
    # 0x26615: '',  # 𦘕
    # 0x26616: '',  # 𦘖
    # 0x26617: '',  # 𦘗
    # 0x26618: '',  # 𦘘
    # 0x26619: '',  # 𦘙
    # 0x2661A: '',  # 𦘚
    # 0x2661B: '',  # 𦘛
    # 0x2661C: '',  # 𦘜
    0x2661D: 'sù',  # 𦘝
    # 0x2661E: '',  # 𦘞
    # 0x2661F: '',  # 𦘟
    # 0x26620: '',  # 𦘠
    # 0x26621: '',  # 𦘡
    # 0x26622: '',  # 𦘢
    # 0x26623: '',  # 𦘣
    # 0x26624: '',  # 𦘤
    # 0x26625: '',  # 𦘥
    # 0x26626: '',  # 𦘦
    # 0x26627: '',  # 𦘧
    # 0x26628: '',  # 𦘨
    0x26629: 'pǐ',  # 𦘩
    0x2662A: 'chì',  # 𦘪
    # 0x2662B: '',  # 𦘫
    # 0x2662C: '',  # 𦘬
    # 0x2662D: '',  # 𦘭
    # 0x2662E: '',  # 𦘮
    # 0x2662F: '',  # 𦘯
    # 0x26630: '',  # 𦘰
    # 0x26631: '',  # 𦘱
    0x26632: 'pǐ',  # 𦘲
    0x26633: 'yì',  # 𦘳
    0x26634: 'dū',  # 𦘴
    0x26635: 'wǎ',  # 𦘵
    0x26636: 'xūn',  # 𦘶
    # 0x26637: '',  # 𦘷
    0x26638: 'qì',  # 𦘸
    0x26639: 'shàn,yuè',  # 𦘹
    # 0x2663A: '',  # 𦘺
    # 0x2663B: '',  # 𦘻
    0x2663C: 'xū',  # 𦘼
    # 0x2663D: '',  # 𦘽
    # 0x2663E: '',  # 𦘾
    0x2663F: 'hē',  # 𦘿
    0x26640: 'pàn',  # 𦙀
    # 0x26641: '',  # 𦙁
    0x26642: 'pēi',  # 𦙂
    # 0x26643: '',  # 𦙃
    0x26644: 'xiōng',  # 𦙄
    # 0x26645: '',  # 𦙅
    0x26646: 'chǐ',  # 𦙆
    0x26647: 'tān',  # 𦙇
    0x26648: 'zuì,cuì',  # 𦙈
    0x26649: 'zuǎn',  # 𦙉
    0x2664A: 'qì',  # 𦙊
    0x2664B: 'dū',  # 𦙋
    # 0x2664C: '',  # 𦙌
    0x2664D: 'yìn',  # 𦙍
    # 0x2664E: '',  # 𦙎
    # 0x2664F: '',  # 𦙏
    # 0x26650: '',  # 𦙐
    # 0x26651: '',  # 𦙑
    # 0x26652: '',  # 𦙒
    # 0x26653: '',  # 𦙓
    # 0x26654: '',  # 𦙔
    # 0x26655: '',  # 𦙕
    # 0x26656: '',  # 𦙖
    # 0x26657: '',  # 𦙗
    # 0x26658: '',  # 𦙘
    0x26659: 'shuǐ',  # 𦙙
    # 0x2665A: '',  # 𦙚
    # 0x2665B: '',  # 𦙛
    0x2665C: 'nǎ',  # 𦙜
    0x2665D: 'xī',  # 𦙝
    # 0x2665E: '',  # 𦙞
    # 0x2665F: '',  # 𦙟
    # 0x26660: '',  # 𦙠
    # 0x26661: '',  # 𦙡
    # 0x26662: '',  # 𦙢
    # 0x26663: '',  # 𦙣
    # 0x26664: '',  # 𦙤
    # 0x26665: '',  # 𦙥
    # 0x26666: '',  # 𦙦
    0x26667: 'chǎo',  # 𦙧
    0x26668: 'yì',  # 𦙨
    # 0x26669: '',  # 𦙩
    0x2666A: 'jiān',  # 𦙪
    0x2666B: 'zhēng',  # 𦙫
    # 0x2666C: '',  # 𦙬
    # 0x2666D: '',  # 𦙭
    0x2666E: 'jú',  # 𦙮
    0x2666F: 'dài',  # 𦙯
    # 0x26670: '',  # 𦙰
    0x26671: 'sān',  # 𦙱
    # 0x26672: '',  # 𦙲
    # 0x26673: '',  # 𦙳
    0x26674: 'zhù',  # 𦙴
    0x26675: 'wàn',  # 𦙵
    0x26676: 'gǔ',  # 𦙶
    # 0x26677: '',  # 𦙷
    0x26678: 'sān',  # 𦙸
    0x26679: 'bàn',  # 𦙹
    0x2667A: 'jià,jiā',  # 𦙺
    0x2667B: 'mài',  # 𦙻
    # 0x2667C: '',  # 𦙼
    # 0x2667D: '',  # 𦙽
    # 0x2667E: '',  # 𦙾
    0x2667F: 'kuàng',  # 𦙿
    # 0x26680: '',  # 𦚀
    # 0x26681: '',  # 𦚁
    # 0x26682: '',  # 𦚂
    # 0x26683: '',  # 𦚃
    # 0x26684: '',  # 𦚄
    # 0x26685: '',  # 𦚅
    # 0x26686: '',  # 𦚆
    # 0x26687: '',  # 𦚇
    0x26688: 'tuò,dù',  # 𦚈
    # 0x26689: '',  # 𦚉
    0x2668A: 'qì',  # 𦚊
    # 0x2668B: '',  # 𦚋
    # 0x2668C: '',  # 𦚌
    # 0x2668D: '',  # 𦚍
    # 0x2668E: '',  # 𦚎
    0x2668F: 'zhuāng',  # 𦚏
    0x26690: 'tuó',  # 𦚐
    # 0x26691: '',  # 𦚑
    # 0x26692: '',  # 𦚒
    0x26693: 'píng',  # 𦚓
    # 0x26694: '',  # 𦚔
    # 0x26695: '',  # 𦚕
    # 0x26696: '',  # 𦚖
    # 0x26697: '',  # 𦚗
    # 0x26698: '',  # 𦚘
    0x26699: 'zǐ',  # 𦚙
    # 0x2669A: '',  # 𦚚
    # 0x2669B: '',  # 𦚛
    # 0x2669C: '',  # 𦚜
    0x2669D: 'pēng',  # 𦚝
    0x2669E: 'kuāng,kuàng',  # 𦚞
    0x2669F: 'yí',  # 𦚟
    # 0x266A0: '',  # 𦚠
    0x266A1: 'xiè,mài',  # 𦚡
    0x266A2: 'yuē',  # 𦚢
    0x266A3: 'hén',  # 𦚣
    # 0x266A4: '',  # 𦚤
    0x266A5: 'hóu,yóu',  # 𦚥
    0x266A6: 'zhēng',  # 𦚦
    0x266A7: 'chǔn',  # 𦚧
    0x266A8: 'shì',  # 𦚨
    0x266A9: 'wǎ',  # 𦚩
    # 0x266AA: '',  # 𦚪
    0x266AB: 'xié',  # 𦚫
    # 0x266AC: '',  # 𦚬
    # 0x266AD: '',  # 𦚭
    # 0x266AE: '',  # 𦚮
    # 0x266AF: '',  # 𦚯
    # 0x266B0: '',  # 𦚰
    # 0x266B1: '',  # 𦚱
    # 0x266B2: '',  # 𦚲
    # 0x266B3: '',  # 𦚳
    # 0x266B4: '',  # 𦚴
    # 0x266B5: '',  # 𦚵
    # 0x266B6: '',  # 𦚶
    # 0x266B7: '',  # 𦚷
    0x266B8: 'gèng',  # 𦚸
    # 0x266B9: '',  # 𦚹
    # 0x266BA: '',  # 𦚺
    # 0x266BB: '',  # 𦚻
    # 0x266BC: '',  # 𦚼
    # 0x266BD: '',  # 𦚽
    # 0x266BE: '',  # 𦚾
    # 0x266BF: '',  # 𦚿
    # 0x266C0: '',  # 𦛀
    # 0x266C1: '',  # 𦛁
    # 0x266C2: '',  # 𦛂
    # 0x266C3: '',  # 𦛃
    # 0x266C4: '',  # 𦛄
    0x266C5: 'è',  # 𦛅
    0x266C6: 'chéng',  # 𦛆
    # 0x266C7: '',  # 𦛇
    # 0x266C8: '',  # 𦛈
    # 0x266C9: '',  # 𦛉
    0x266CA: 'cún',  # 𦛊
    # 0x266CB: '',  # 𦛋
    # 0x266CC: '',  # 𦛌
    # 0x266CD: '',  # 𦛍
    # 0x266CE: '',  # 𦛎
    0x266CF: 'kú',  # 𦛏
    0x266D0: 'nà',  # 𦛐
    # 0x266D1: '',  # 𦛑
    # 0x266D2: '',  # 𦛒
    0x266D3: 'jū',  # 𦛓
    0x266D4: 'xuàn',  # 𦛔
    0x266D5: 'qū',  # 𦛕
    0x266D6: 'chè',  # 𦛖
    0x266D7: 'lǚ',  # 𦛗
    0x266D8: 'hé',  # 𦛘
    0x266D9: 'shèng',  # 𦛙
    0x266DA: 'nàn',  # 𦛚
    # 0x266DB: '',  # 𦛛
    0x266DC: 'hé,hán',  # 𦛜
    0x266DD: 'chá',  # 𦛝
    0x266DE: 'yān',  # 𦛞
    0x266DF: 'gěng',  # 𦛟
    0x266E0: 'niè',  # 𦛠
    # 0x266E1: '',  # 𦛡
    0x266E2: 'guó',  # 𦛢
    0x266E3: 'yán',  # 𦛣
    0x266E4: 'guǎn',  # 𦛤
    # 0x266E5: '',  # 𦛥
    # 0x266E6: '',  # 𦛦
    0x266E7: 'zhì',  # 𦛧
    # 0x266E8: '',  # 𦛨
    # 0x266E9: '',  # 𦛩
    # 0x266EA: '',  # 𦛪
    # 0x266EB: '',  # 𦛫
    # 0x266EC: '',  # 𦛬
    # 0x266ED: '',  # 𦛭
    # 0x266EE: '',  # 𦛮
    0x266EF: 'dǔ',  # 𦛯
    0x266F0: 'qì',  # 𦛰
    0x266F1: 'qū',  # 𦛱
    0x266F2: 'jué',  # 𦛲
    # 0x266F3: '',  # 𦛳
    # 0x266F4: '',  # 𦛴
    # 0x266F5: '',  # 𦛵
    # 0x266F6: '',  # 𦛶
    # 0x266F7: '',  # 𦛷
    # 0x266F8: '',  # 𦛸
    0x266F9: 'zì',  # 𦛹
    # 0x266FA: '',  # 𦛺
    # 0x266FB: '',  # 𦛻
    # 0x266FC: '',  # 𦛼
    # 0x266FD: '',  # 𦛽
    # 0x266FE: '',  # 𦛾
    # 0x266FF: '',  # 𦛿
    # 0x26700: '',  # 𦜀
    0x26701: 'fēng',  # 𦜁
    # 0x26702: '',  # 𦜂
    0x26703: 'xù',  # 𦜃
    0x26704: 'tuì',  # 𦜄
    # 0x26705: '',  # 𦜅
    0x26706: 'hán',  # 𦜆
    0x26707: 'kū',  # 𦜇
    # 0x26708: '',  # 𦜈
    # 0x26709: '',  # 𦜉
    0x2670A: 'shēn',  # 𦜊
    0x2670B: 'zhì',  # 𦜋
    # 0x2670C: '',  # 𦜌
    0x2670D: 'pàng',  # 𦜍
    0x2670E: 'zhēng',  # 𦜎
    0x2670F: 'lì',  # 𦜏
    0x26710: 'wǎn',  # 𦜐
    # 0x26711: '',  # 𦜑
    0x26712: 'fǎn',  # 𦜒
    0x26713: 'xìn',  # 𦜓
    # 0x26714: '',  # 𦜔
    # 0x26715: '',  # 𦜕
    0x26716: 'yà',  # 𦜖
    # 0x26717: '',  # 𦜗
    # 0x26718: '',  # 𦜘
    # 0x26719: '',  # 𦜙
    # 0x2671A: '',  # 𦜚
    0x2671B: 'jū',  # 𦜛
    0x2671C: 'shèn',  # 𦜜
    0x2671D: 'qí',  # 𦜝
    # 0x2671E: '',  # 𦜞
    0x2671F: 'bù',  # 𦜟
    # 0x26720: '',  # 𦜠
    # 0x26721: '',  # 𦜡
    # 0x26722: '',  # 𦜢
    # 0x26723: '',  # 𦜣
    # 0x26724: '',  # 𦜤
    # 0x26725: '',  # 𦜥
    # 0x26726: '',  # 𦜦
    # 0x26727: '',  # 𦜧
    # 0x26728: '',  # 𦜨
    # 0x26729: '',  # 𦜩
    # 0x2672A: '',  # 𦜪
    # 0x2672B: '',  # 𦜫
    # 0x2672C: '',  # 𦜬
    0x2672D: 'mǎng',  # 𦜭
    # 0x2672E: '',  # 𦜮
    0x2672F: 'tǔn',  # 𦜯
    0x26730: 'zhuó',  # 𦜰
    0x26731: 'xī',  # 𦜱
    0x26732: 'yìn',  # 𦜲
    0x26733: 'jīng',  # 𦜳
    0x26734: 'tún',  # 𦜴
    # 0x26735: '',  # 𦜵
    # 0x26736: '',  # 𦜶
    0x26737: 'gèng',  # 𦜷
    0x26738: 'jì',  # 𦜸
    # 0x26739: '',  # 𦜹
    # 0x2673A: '',  # 𦜺
    # 0x2673B: '',  # 𦜻
    # 0x2673C: '',  # 𦜼
    # 0x2673D: '',  # 𦜽
    # 0x2673E: '',  # 𦜾
    # 0x2673F: '',  # 𦜿
    # 0x26740: '',  # 𦝀
    # 0x26741: '',  # 𦝁
    # 0x26742: '',  # 𦝂
    # 0x26743: '',  # 𦝃
    # 0x26744: '',  # 𦝄
    # 0x26745: '',  # 𦝅
    # 0x26746: '',  # 𦝆
    # 0x26747: '',  # 𦝇
    # 0x26748: '',  # 𦝈
    # 0x26749: '',  # 𦝉
    # 0x2674A: '',  # 𦝊
    # 0x2674B: '',  # 𦝋
    # 0x2674C: '',  # 𦝌
    # 0x2674D: '',  # 𦝍
    # 0x2674E: '',  # 𦝎
    0x2674F: 'zhuǎn,shuàn',  # 𦝏
    # 0x26750: '',  # 𦝐
    # 0x26751: '',  # 𦝑
    0x26752: 'tiē',  # 𦝒
    # 0x26753: '',  # 𦝓
    0x26754: 'zhī',  # 𦝔
    # 0x26755: '',  # 𦝕
    0x26756: 'jí',  # 𦝖
    # 0x26757: '',  # 𦝗
    # 0x26758: '',  # 𦝘
    # 0x26759: '',  # 𦝙
    0x2675A: 'yíng',  # 𦝚
    0x2675B: 'wèi',  # 𦝛
    # 0x2675C: '',  # 𦝜
    0x2675D: 'huàn',  # 𦝝
    0x2675E: 'tíng',  # 𦝞
    0x2675F: 'chán',  # 𦝟
    # 0x26760: '',  # 𦝠
    # 0x26761: '',  # 𦝡
    0x26762: 'kuí',  # 𦝢
    0x26763: 'qià,kē',  # 𦝣
    0x26764: 'bàn',  # 𦝤
    0x26765: 'chā,zhá',  # 𦝥
    0x26766: 'tuǒ',  # 𦝦
    0x26767: 'nǎn',  # 𦝧
    0x26768: 'jiē',  # 𦝨
    # 0x26769: '',  # 𦝩
    0x2676A: 'yān',  # 𦝪
    # 0x2676B: '',  # 𦝫
    0x2676C: 'tú',  # 𦝬
    0x2676D: 'lǜ',  # 𦝭
    0x2676E: 'wěn',  # 𦝮
    # 0x2676F: '',  # 𦝯
    0x26770: 'cōng',  # 𦝰
    # 0x26771: '',  # 𦝱
    # 0x26772: '',  # 𦝲
    0x26773: 'xù',  # 𦝳
    0x26774: 'yìn',  # 𦝴
    # 0x26775: '',  # 𦝵
    # 0x26776: '',  # 𦝶
    0x26777: 'bèng',  # 𦝷
    # 0x26778: '',  # 𦝸
    # 0x26779: '',  # 𦝹
    # 0x2677A: '',  # 𦝺
    # 0x2677B: '',  # 𦝻
    # 0x2677C: '',  # 𦝼
    # 0x2677D: '',  # 𦝽
    # 0x2677E: '',  # 𦝾
    # 0x2677F: '',  # 𦝿
    # 0x26780: '',  # 𦞀
    0x26781: 'zāi',  # 𦞁
    0x26782: 'dā,da',  # 𦞂
    # 0x26783: '',  # 𦞃
    # 0x26784: '',  # 𦞄
    # 0x26785: '',  # 𦞅
    0x26786: 'niè',  # 𦞆
    0x26787: 'jǔ',  # 𦞇
    0x26788: 'hóu',  # 𦞈
    # 0x26789: '',  # 𦞉
    # 0x2678A: '',  # 𦞊
    # 0x2678B: '',  # 𦞋
    0x2678C: 'gèng',  # 𦞌
    # 0x2678D: '',  # 𦞍
    # 0x2678E: '',  # 𦞎
    # 0x2678F: '',  # 𦞏
    # 0x26790: '',  # 𦞐
    # 0x26791: '',  # 𦞑
    # 0x26792: '',  # 𦞒
    # 0x26793: '',  # 𦞓
    # 0x26794: '',  # 𦞔
    0x26795: 'hóu',  # 𦞕
    0x26796: 'kān',  # 𦞖
    0x26797: 'gōng',  # 𦞗
    # 0x26798: '',  # 𦞘
    0x26799: 'huǐ',  # 𦞙
    0x2679A: 'xiè',  # 𦞚
    # 0x2679B: '',  # 𦞛
    # 0x2679C: '',  # 𦞜
    0x2679D: 'xì',  # 𦞝
    0x2679E: 'hán',  # 𦞞
    0x2679F: 'mí',  # 𦞟
    # 0x267A0: '',  # 𦞠
    0x267A1: 'wěng',  # 𦞡
    0x267A2: 'hùn',  # 𦞢
    0x267A3: 'sāo,sào',  # 𦞣
    0x267A4: 'xìn,zǐ',  # 𦞤
    0x267A5: 'zhé',  # 𦞥
    0x267A6: 'hè',  # 𦞦
    # 0x267A7: '',  # 𦞧
    0x267A8: 'gōng',  # 𦞨
    # 0x267A9: '',  # 𦞩
    # 0x267AA: '',  # 𦞪
    0x267AB: 'sài',  # 𦞫
    0x267AC: 'jīn,jiàn',  # 𦞬
    0x267AD: 'wā',  # 𦞭
    # 0x267AE: '',  # 𦞮
    # 0x267AF: '',  # 𦞯
    # 0x267B0: '',  # 𦞰
    0x267B1: 'duǐ',  # 𦞱
    0x267B2: 'chī',  # 𦞲
    # 0x267B3: '',  # 𦞳
    # 0x267B4: '',  # 𦞴
    # 0x267B5: '',  # 𦞵
    # 0x267B6: '',  # 𦞶
    # 0x267B7: '',  # 𦞷
    # 0x267B8: '',  # 𦞸
    # 0x267B9: '',  # 𦞹
    # 0x267BA: '',  # 𦞺
    # 0x267BB: '',  # 𦞻
    # 0x267BC: '',  # 𦞼
    0x267BD: 'xī,wèi,jí',  # 𦞽
    # 0x267BE: '',  # 𦞾
    # 0x267BF: '',  # 𦞿
    0x267C0: 'luó',  # 𦟀
    0x267C1: 'huāng',  # 𦟁
    0x267C2: 'mí',  # 𦟂
    0x267C3: 'zāng',  # 𦟃
    0x267C4: 'sǎng,sào',  # 𦟄
    # 0x267C5: '',  # 𦟅
    # 0x267C6: '',  # 𦟆
    # 0x267C7: '',  # 𦟇
    # 0x267C8: '',  # 𦟈
    # 0x267C9: '',  # 𦟉
    # 0x267CA: '',  # 𦟊
    # 0x267CB: '',  # 𦟋
    0x267CC: 'jiǎn',  # 𦟌
    # 0x267CD: '',  # 𦟍
    # 0x267CE: '',  # 𦟎
    # 0x267CF: '',  # 𦟏
    0x267D0: 'mā',  # 𦟐
    # 0x267D1: '',  # 𦟑
    # 0x267D2: '',  # 𦟒
    0x267D3: 'tún',  # 𦟓
    0x267D4: 'zhì',  # 𦟔
    0x267D5: 'wěn',  # 𦟕
    # 0x267D6: '',  # 𦟖
    # 0x267D7: '',  # 𦟗
    0x267D8: 'yín',  # 𦟘
    0x267D9: 'tǔn',  # 𦟙
    # 0x267DA: '',  # 𦟚
    0x267DB: 'chōng',  # 𦟛
    0x267DC: 'zé',  # 𦟜
    # 0x267DD: '',  # 𦟝
    0x267DE: 'xiāo',  # 𦟞
    0x267DF: 'mó',  # 𦟟
    0x267E0: 'cù',  # 𦟠
    # 0x267E1: '',  # 𦟡
    # 0x267E2: '',  # 𦟢
    0x267E3: 'biǎn',  # 𦟣
    0x267E4: 'xiū',  # 𦟤
    # 0x267E5: '',  # 𦟥
    # 0x267E6: '',  # 𦟦
    0x267E7: 'yí',  # 𦟧
    # 0x267E8: '',  # 𦟨
    # 0x267E9: '',  # 𦟩
    # 0x267EA: '',  # 𦟪
    # 0x267EB: '',  # 𦟫
    # 0x267EC: '',  # 𦟬
    # 0x267ED: '',  # 𦟭
    0x267EE: 'huǎng',  # 𦟮
    # 0x267EF: '',  # 𦟯
    0x267F0: 'zhā',  # 𦟰
    0x267F1: 'suō',  # 𦟱
    0x267F2: 'hún',  # 𦟲
    0x267F3: 'jù',  # 𦟳
    # 0x267F4: '',  # 𦟴
    # 0x267F5: '',  # 𦟵
    # 0x267F6: '',  # 𦟶
    # 0x267F7: '',  # 𦟷
    # 0x267F8: '',  # 𦟸
    # 0x267F9: '',  # 𦟹
    # 0x267FA: '',  # 𦟺
    # 0x267FB: '',  # 𦟻
    # 0x267FC: '',  # 𦟼
    # 0x267FD: '',  # 𦟽
    0x267FE: 'ōu',  # 𦟾
    # 0x267FF: '',  # 𦟿
    # 0x26800: '',  # 𦠀
    0x26801: 'cù',  # 𦠁
    # 0x26802: '',  # 𦠂
    # 0x26803: '',  # 𦠃
    0x26804: 'jī',  # 𦠄
    0x26805: 'xún',  # 𦠅
    0x26806: 'sǔn,zhuàn',  # 𦠆
    0x26807: 'céng',  # 𦠇
    # 0x26808: '',  # 𦠈
    0x26809: 'yì',  # 𦠉
    # 0x2680A: '',  # 𦠊
    # 0x2680B: '',  # 𦠋
    # 0x2680C: '',  # 𦠌
    # 0x2680D: '',  # 𦠍
    0x2680E: 'biāo',  # 𦠎
    # 0x2680F: '',  # 𦠏
    # 0x26810: '',  # 𦠐
    # 0x26811: '',  # 𦠑
    0x26812: 'jué',  # 𦠒
    0x26813: 'lì',  # 𦠓
    # 0x26814: '',  # 𦠔
    # 0x26815: '',  # 𦠕
    0x26816: 'pào',  # 𦠖
    # 0x26817: '',  # 𦠗
    # 0x26818: '',  # 𦠘
    # 0x26819: '',  # 𦠙
    # 0x2681A: '',  # 𦠚
    0x2681B: 'zā',  # 𦠛
    0x2681C: 'yè',  # 𦠜
    # 0x2681D: '',  # 𦠝
    0x2681E: 'bì',  # 𦠞
    0x2681F: 'zhè',  # 𦠟
    0x26820: 'zhè',  # 𦠠
    # 0x26821: '',  # 𦠡
    0x26822: 'jiù',  # 𦠢
    0x26823: 'zhé',  # 𦠣
    # 0x26824: '',  # 𦠤
    # 0x26825: '',  # 𦠥
    0x26826: 'shù',  # 𦠦
    # 0x26827: '',  # 𦠧
    # 0x26828: '',  # 𦠨
    # 0x26829: '',  # 𦠩
    0x2682A: 'xī',  # 𦠪
    # 0x2682B: '',  # 𦠫
    # 0x2682C: '',  # 𦠬
    # 0x2682D: '',  # 𦠭
    # 0x2682E: '',  # 𦠮
    # 0x2682F: '',  # 𦠯
    # 0x26830: '',  # 𦠰
    # 0x26831: '',  # 𦠱
    # 0x26832: '',  # 𦠲
    # 0x26833: '',  # 𦠳
    # 0x26834: '',  # 𦠴
    # 0x26835: '',  # 𦠵
    # 0x26836: '',  # 𦠶
    0x26837: 'xǔ',  # 𦠷
    0x26838: 'nǎi',  # 𦠸
    0x26839: 'xián',  # 𦠹
    0x2683A: 'gǔn',  # 𦠺
    0x2683B: 'wèi',  # 𦠻
    # 0x2683C: '',  # 𦠼
    # 0x2683D: '',  # 𦠽
    0x2683E: 'jí',  # 𦠾
    0x2683F: 'sà',  # 𦠿
    # 0x26840: '',  # 𦡀
    # 0x26841: '',  # 𦡁
    0x26842: 'dǒng',  # 𦡂
    0x26843: 'nuó,nié',  # 𦡃
    0x26844: 'dù',  # 𦡄
    0x26845: 'zhēng',  # 𦡅
    0x26846: 'kū',  # 𦡆
    # 0x26847: '',  # 𦡇
    # 0x26848: '',  # 𦡈
    0x26849: 'míng',  # 𦡉
    # 0x2684A: '',  # 𦡊
    # 0x2684B: '',  # 𦡋
    # 0x2684C: '',  # 𦡌
    # 0x2684D: '',  # 𦡍
    # 0x2684E: '',  # 𦡎
    # 0x2684F: '',  # 𦡏
    # 0x26850: '',  # 𦡐
    # 0x26851: '',  # 𦡑
    # 0x26852: '',  # 𦡒
    # 0x26853: '',  # 𦡓
    # 0x26854: '',  # 𦡔
    0x26855: 'báo',  # 𦡕
    0x26856: 'huì',  # 𦡖
    # 0x26857: '',  # 𦡗
    # 0x26858: '',  # 𦡘
    0x26859: 'zōng',  # 𦡙
    # 0x2685A: '',  # 𦡚
    # 0x2685B: '',  # 𦡛
    # 0x2685C: '',  # 𦡜
    # 0x2685D: '',  # 𦡝
    # 0x2685E: '',  # 𦡞
    # 0x2685F: '',  # 𦡟
    # 0x26860: '',  # 𦡠
    # 0x26861: '',  # 𦡡
    # 0x26862: '',  # 𦡢
    # 0x26863: '',  # 𦡣
    # 0x26864: '',  # 𦡤
    # 0x26865: '',  # 𦡥
    # 0x26866: '',  # 𦡦
    # 0x26867: '',  # 𦡧
    0x26868: 'sàn',  # 𦡨
    # 0x26869: '',  # 𦡩
    0x2686A: 'tēng',  # 𦡪
    0x2686B: 'yí',  # 𦡫
    # 0x2686C: '',  # 𦡬
    0x2686D: 'yù',  # 𦡭
    # 0x2686E: '',  # 𦡮
    # 0x2686F: '',  # 𦡯
    # 0x26870: '',  # 𦡰
    0x26871: 'yào,shào',  # 𦡱
    0x26872: 'nǐng',  # 𦡲
    # 0x26873: '',  # 𦡳
    0x26874: 'chóu,zhǒu',  # 𦡴
    0x26875: 'hùn',  # 𦡵
    # 0x26876: '',  # 𦡶
    0x26877: 'duì',  # 𦡷
    # 0x26878: '',  # 𦡸
    0x26879: 'qì',  # 𦡹
    0x2687A: 'yǐng',  # 𦡺
    0x2687B: 'bìng',  # 𦡻
    0x2687C: 'níng',  # 𦡼
    0x2687D: 'huáng',  # 𦡽
    # 0x2687E: '',  # 𦡾
    # 0x2687F: '',  # 𦡿
    # 0x26880: '',  # 𦢀
    # 0x26881: '',  # 𦢁
    0x26882: 'pú',  # 𦢂
    # 0x26883: '',  # 𦢃
    # 0x26884: '',  # 𦢄
    # 0x26885: '',  # 𦢅
    0x26886: 'yǐng',  # 𦢆
    # 0x26887: '',  # 𦢇
    # 0x26888: '',  # 𦢈
    # 0x26889: '',  # 𦢉
    0x2688A: 'báo,bó',  # 𦢊
    # 0x2688B: '',  # 𦢋
    # 0x2688C: '',  # 𦢌
    # 0x2688D: '',  # 𦢍
    0x2688E: 'guàng',  # 𦢎
    0x2688F: 'lěi',  # 𦢏
    0x26890: 'zǔn',  # 𦢐
    # 0x26891: '',  # 𦢑
    # 0x26892: '',  # 𦢒
    # 0x26893: '',  # 𦢓
    # 0x26894: '',  # 𦢔
    # 0x26895: '',  # 𦢕
    # 0x26896: '',  # 𦢖
    # 0x26897: '',  # 𦢗
    # 0x26898: '',  # 𦢘
    0x26899: 'chǎn,qiān,xiān',  # 𦢙
    # 0x2689A: '',  # 𦢚
    # 0x2689B: '',  # 𦢛
    # 0x2689C: '',  # 𦢜
    # 0x2689D: '',  # 𦢝
    # 0x2689E: '',  # 𦢞
    # 0x2689F: '',  # 𦢟
    # 0x268A0: '',  # 𦢠
    # 0x268A1: '',  # 𦢡
    # 0x268A2: '',  # 𦢢
    0x268A3: 'jiǎn',  # 𦢣
    # 0x268A4: '',  # 𦢤
    # 0x268A5: '',  # 𦢥
    # 0x268A6: '',  # 𦢦
    0x268A7: 'méng',  # 𦢧
    # 0x268A8: '',  # 𦢨
    0x268A9: 'xiào,sōu',  # 𦢩
    # 0x268AA: '',  # 𦢪
    # 0x268AB: '',  # 𦢫
    # 0x268AC: '',  # 𦢬
    # 0x268AD: '',  # 𦢭
    # 0x268AE: '',  # 𦢮
    0x268AF: 'xìn,xìng',  # 𦢯
    # 0x268B0: '',  # 𦢰
    0x268B1: 'lí',  # 𦢱
    # 0x268B2: '',  # 𦢲
    # 0x268B3: '',  # 𦢳
    # 0x268B4: '',  # 𦢴
    # 0x268B5: '',  # 𦢵
    # 0x268B6: '',  # 𦢶
    # 0x268B7: '',  # 𦢷
    # 0x268B8: '',  # 𦢸
    # 0x268B9: '',  # 𦢹
    0x268BA: 'qiǎo',  # 𦢺
    0x268BB: 'yīng',  # 𦢻
    # 0x268BC: '',  # 𦢼
    # 0x268BD: '',  # 𦢽
    # 0x268BE: '',  # 𦢾
    0x268BF: 'wěi,juǎn',  # 𦢿
    0x268C0: 'nà,niè,zhé',  # 𦣀
    # 0x268C1: '',  # 𦣁
    0x268C2: 'pāng',  # 𦣂
    # 0x268C3: '',  # 𦣃
    0x268C4: 'léi',  # 𦣄
    # 0x268C5: '',  # 𦣅
    # 0x268C6: '',  # 𦣆
    0x268C7: 'luó',  # 𦣇
    # 0x268C8: '',  # 𦣈
    # 0x268C9: '',  # 𦣉
    # 0x268CA: '',  # 𦣊
    0x268CB: 'luán',  # 𦣋
    # 0x268CC: '',  # 𦣌
    0x268CD: 'gēng',  # 𦣍
    # 0x268CE: '',  # 𦣎
    0x268CF: 'luán',  # 𦣏
    # 0x268D0: '',  # 𦣐
    # 0x268D1: '',  # 𦣑
    0x268D2: 'qú',  # 𦣒
    # 0x268D3: '',  # 𦣓
    # 0x268D4: '',  # 𦣔
    # 0x268D5: '',  # 𦣕
    0x268D6: 'luó',  # 𦣖
    # 0x268D7: '',  # 𦣗
    0x268D8: 'náng',  # 𦣘
    # 0x268D9: '',  # 𦣙
    # 0x268DA: '',  # 𦣚
    0x268DB: 'luó',  # 𦣛
    0x268DC: 'yuè',  # 𦣜
    0x268DD: 'yí',  # 𦣝
    0x268DE: 'yí',  # 𦣞
    # 0x268DF: '',  # 𦣟
    # 0x268E0: '',  # 𦣠
    # 0x268E1: '',  # 𦣡
    0x268E2: 'shuì',  # 𦣢
    # 0x268E3: '',  # 𦣣
    # 0x268E4: '',  # 𦣤
    0x268E5: 'mì',  # 𦣥
    0x268E6: 'wáng',  # 𦣦
    0x268E7: 'cè',  # 𦣧
    0x268E8: 'jiān',  # 𦣨
    0x268E9: 'wǎng',  # 𦣩
    # 0x268EA: '',  # 𦣪
    # 0x268EB: '',  # 𦣫
    # 0x268EC: '',  # 𦣬
    # 0x268ED: '',  # 𦣭
    # 0x268EE: '',  # 𦣮
    0x268EF: 'jiā',  # 𦣯
    # 0x268F0: '',  # 𦣰
    0x268F1: 'zé',  # 𦣱
    # 0x268F2: '',  # 𦣲
    # 0x268F3: '',  # 𦣳
    0x268F4: 'huán',  # 𦣴
    # 0x268F5: '',  # 𦣵
    # 0x268F6: '',  # 𦣶
    # 0x268F7: '',  # 𦣷
    0x268F8: 'liàn',  # 𦣸
    0x268F9: 'zì',  # 𦣹
    0x268FA: 'bái',  # 𦣺
    0x268FB: 'shǒu,bǎi',  # 𦣻
    # 0x268FC: '',  # 𦣼
    # 0x268FD: '',  # 𦣽
    0x268FE: 'wǎn',  # 𦣾
    # 0x268FF: '',  # 𦣿
    # 0x26900: '',  # 𦤀
    # 0x26901: '',  # 𦤁
    0x26902: 'shū',  # 𦤂
    # 0x26903: '',  # 𦤃
    # 0x26904: '',  # 𦤄
    # 0x26905: '',  # 𦤅
    # 0x26906: '',  # 𦤆
    0x26907: 'guī',  # 𦤇
    0x26908: 'xī',  # 𦤈
    # 0x26909: '',  # 𦤉
    0x2690A: 'rú',  # 𦤊
    0x2690B: 'yào',  # 𦤋
    # 0x2690C: '',  # 𦤌
    # 0x2690D: '',  # 𦤍
    0x2690E: 'gāo',  # 𦤎
    # 0x2690F: '',  # 𦤏
    # 0x26910: '',  # 𦤐
    # 0x26911: '',  # 𦤑
    # 0x26912: '',  # 𦤒
    # 0x26913: '',  # 𦤓
    # 0x26914: '',  # 𦤔
    0x26915: 'yuè',  # 𦤕
    # 0x26916: '',  # 𦤖
    # 0x26917: '',  # 𦤗
    0x26918: 'yōng',  # 𦤘
    0x26919: 'wà',  # 𦤙
    0x2691A: 'bó',  # 𦤚
    # 0x2691B: '',  # 𦤛
    # 0x2691C: '',  # 𦤜
    0x2691D: 'mián',  # 𦤝
    # 0x2691E: '',  # 𦤞
    0x2691F: 'xìn',  # 𦤟
    # 0x26920: '',  # 𦤠
    # 0x26921: '',  # 𦤡
    0x26922: 'pì',  # 𦤢
    0x26923: 'bó',  # 𦤣
    # 0x26924: '',  # 𦤤
    # 0x26925: '',  # 𦤥
    0x26926: 'hài,hè,ài',  # 𦤦
    0x26927: 'zhài',  # 𦤧
    0x26928: 'wò',  # 𦤨
    # 0x26929: '',  # 𦤩
    0x2692A: 'yè',  # 𦤪
    0x2692B: 'bì,bí',  # 𦤫
    0x2692C: 'hài',  # 𦤬
    # 0x2692D: '',  # 𦤭
    # 0x2692E: '',  # 𦤮
    # 0x2692F: '',  # 𦤯
    # 0x26930: '',  # 𦤰
    # 0x26931: '',  # 𦤱
    # 0x26932: '',  # 𦤲
    # 0x26933: '',  # 𦤳
    # 0x26934: '',  # 𦤴
    # 0x26935: '',  # 𦤵
    # 0x26936: '',  # 𦤶
    # 0x26937: '',  # 𦤷
    0x26938: 'chì',  # 𦤸
    # 0x26939: '',  # 𦤹
    # 0x2693A: '',  # 𦤺
    0x2693B: 'zhì',  # 𦤻
    # 0x2693C: '',  # 𦤼
    0x2693D: 'ní',  # 𦤽
    # 0x2693E: '',  # 𦤾
    # 0x2693F: '',  # 𦤿
    # 0x26940: '',  # 𦥀
    0x26941: 'wú',  # 𦥁
    0x26942: 'ǎi',  # 𦥂
    # 0x26943: '',  # 𦥃
    # 0x26944: '',  # 𦥄
    # 0x26945: '',  # 𦥅
    # 0x26946: '',  # 𦥆
    # 0x26947: '',  # 𦥇
    0x26948: 'ǎi',  # 𦥈
    0x26949: 'yǔ',  # 𦥉
    0x2694A: 'chì',  # 𦥊
    # 0x2694B: '',  # 𦥋
    # 0x2694C: '',  # 𦥌
    0x2694D: 'jìng',  # 𦥍
    0x2694E: 'zhì',  # 𦥎
    0x2694F: 'zhì',  # 𦥏
    0x26950: 'zhì',  # 𦥐
    0x26951: 'jú,jǔ',  # 𦥑
    # 0x26952: '',  # 𦥒
    # 0x26953: '',  # 𦥓
    # 0x26954: '',  # 𦥔
    # 0x26955: '',  # 𦥕
    0x26956: 'hán,xián',  # 𦥖
    # 0x26957: '',  # 𦥗
    # 0x26958: '',  # 𦥘
    # 0x26959: '',  # 𦥙
    0x2695A: 'pīng',  # 𦥚
    # 0x2695B: '',  # 𦥛
    # 0x2695C: '',  # 𦥜
    0x2695D: 'yǎo',  # 𦥝
    # 0x2695E: '',  # 𦥞
    # 0x2695F: '',  # 𦥟
    # 0x26960: '',  # 𦥠
    # 0x26961: '',  # 𦥡
    # 0x26962: '',  # 𦥢
    0x26963: 'yóu',  # 𦥣
    0x26964: 'pīng',  # 𦥤
    # 0x26965: '',  # 𦥥
    0x26966: 'mò',  # 𦥦
    # 0x26967: '',  # 𦥧
    # 0x26968: '',  # 𦥨
    # 0x26969: '',  # 𦥩
    # 0x2696A: '',  # 𦥪
    # 0x2696B: '',  # 𦥫
    0x2696C: 'zuò',  # 𦥬
    0x2696D: 'pò',  # 𦥭
    # 0x2696E: '',  # 𦥮
    0x2696F: 'xué',  # 𦥯
    0x26970: 'kuáng',  # 𦥰
    0x26971: 'yì',  # 𦥱
    0x26972: 'pò',  # 𦥲
    # 0x26973: '',  # 𦥳
    # 0x26974: '',  # 𦥴
    # 0x26975: '',  # 𦥵
    # 0x26976: '',  # 𦥶
    # 0x26977: '',  # 𦥷
    # 0x26978: '',  # 𦥸
    # 0x26979: '',  # 𦥹
    # 0x2697A: '',  # 𦥺
    0x2697B: 'zhuì',  # 𦥻
    # 0x2697C: '',  # 𦥼
    # 0x2697D: '',  # 𦥽
    # 0x2697E: '',  # 𦥾
    # 0x2697F: '',  # 𦥿
    # 0x26980: '',  # 𦦀
    # 0x26981: '',  # 𦦁
    # 0x26982: '',  # 𦦂
    0x26983: 'ní',  # 𦦃
    0x26984: 'qiǔ',  # 𦦄
    0x26985: 'còu',  # 𦦅
    # 0x26986: '',  # 𦦆
    # 0x26987: '',  # 𦦇
    # 0x26988: '',  # 𦦈
    # 0x26989: '',  # 𦦉
    # 0x2698A: '',  # 𦦊
    # 0x2698B: '',  # 𦦋
    0x2698C: 'yǎo',  # 𦦌
    # 0x2698D: '',  # 𦦍
    # 0x2698E: '',  # 𦦎
    # 0x2698F: '',  # 𦦏
    # 0x26990: '',  # 𦦐
    0x26991: 'fén',  # 𦦑
    # 0x26992: '',  # 𦦒
    # 0x26993: '',  # 𦦓
    # 0x26994: '',  # 𦦔
    0x26995: 'xiá',  # 𦦕
    # 0x26996: '',  # 𦦖
    0x26997: 'jiāng',  # 𦦗
    0x26998: 'chā',  # 𦦘
    # 0x26999: '',  # 𦦙
    # 0x2699A: '',  # 𦦚
    0x2699B: 'xiào',  # 𦦛
    0x2699C: 'chā',  # 𦦜
    # 0x2699D: '',  # 𦦝
    # 0x2699E: '',  # 𦦞
    # 0x2699F: '',  # 𦦟
    # 0x269A0: '',  # 𦦠
    # 0x269A1: '',  # 𦦡
    0x269A2: 'chéng',  # 𦦢
    0x269A3: 'cuì',  # 𦦣
    # 0x269A4: '',  # 𦦤
    # 0x269A5: '',  # 𦦥
    # 0x269A6: '',  # 𦦦
    0x269A7: 'qióng,gǒng',  # 𦦧
    # 0x269A8: '',  # 𦦨
    0x269A9: 'yù',  # 𦦩
    # 0x269AA: '',  # 𦦪
    0x269AB: 'yú',  # 𦦫
    # 0x269AC: '',  # 𦦬
    # 0x269AD: '',  # 𦦭
    # 0x269AE: '',  # 𦦮
    0x269AF: 'wèn',  # 𦦯
    # 0x269B0: '',  # 𦦰
    0x269B1: 'chā',  # 𦦱
    0x269B2: 'yǔ,yù',  # 𦦲
    # 0x269B3: '',  # 𦦳
    # 0x269B4: '',  # 𦦴
    # 0x269B5: '',  # 𦦵
    # 0x269B6: '',  # 𦦶
    # 0x269B7: '',  # 𦦷
    # 0x269B8: '',  # 𦦸
    0x269B9: 'zuó',  # 𦦹
    0x269BA: 'dǎo',  # 𦦺
    # 0x269BB: '',  # 𦦻
    # 0x269BC: '',  # 𦦼
    0x269BD: 'juàn,fàn',  # 𦦽
    0x269BE: 'dǎo',  # 𦦾
    0x269BF: 'yīng',  # 𦦿
    # 0x269C0: '',  # 𦧀
    0x269C1: 'fěng',  # 𦧁
    # 0x269C2: '',  # 𦧂
    # 0x269C3: '',  # 𦧃
    # 0x269C4: '',  # 𦧄
    0x269C5: 'wèng',  # 𦧅
    # 0x269C6: '',  # 𦧆
    # 0x269C7: '',  # 𦧇
    0x269C8: 'jìn',  # 𦧈
    0x269C9: 'qì',  # 𦧉
    # 0x269CA: '',  # 𦧊
    0x269CB: 'qìn',  # 𦧋
    # 0x269CC: '',  # 𦧌
    0x269CD: 'kuò',  # 𦧍
    # 0x269CE: '',  # 𦧎
    0x269CF: 'tān',  # 𦧏
    0x269D0: 'xiān',  # 𦧐
    # 0x269D1: '',  # 𦧑
    0x269D2: 'tiān',  # 𦧒
    # 0x269D3: '',  # 𦧓
    0x269D4: 'kuò',  # 𦧔
    # 0x269D5: '',  # 𦧕
    0x269D6: 'tiàn',  # 𦧖
    # 0x269D7: '',  # 𦧗
    0x269D8: 'hú',  # 𦧘
    0x269D9: 'zhū',  # 𦧙
    0x269DA: 'zhān',  # 𦧚
    0x269DB: 'tà',  # 𦧛
    # 0x269DC: '',  # 𦧜
    0x269DD: 'tiān',  # 𦧝
    0x269DE: 'tà',  # 𦧞
    0x269DF: 'tà',  # 𦧟
    0x269E0: 'huá',  # 𦧠
    0x269E1: 'yǎn,tiàn',  # 𦧡
    0x269E2: 'tiè',  # 𦧢
    # 0x269E3: '',  # 𦧣
    0x269E4: 'tiè',  # 𦧤
    0x269E5: 'tà',  # 𦧥
    # 0x269E6: '',  # 𦧦
    # 0x269E7: '',  # 𦧧
    # 0x269E8: '',  # 𦧨
    # 0x269E9: '',  # 𦧩
    # 0x269EA: '',  # 𦧪
    # 0x269EB: '',  # 𦧫
    0x269EC: 'huài',  # 𦧬
    # 0x269ED: '',  # 𦧭
    0x269EE: 'jiá',  # 𦧮
    0x269EF: 'qì',  # 𦧯
    # 0x269F0: '',  # 𦧰
    0x269F1: 'tà',  # 𦧱
    0x269F2: 'luó',  # 𦧲
    # 0x269F3: '',  # 𦧳
    0x269F4: 'tān',  # 𦧴
    0x269F5: 'huà',  # 𦧵
    # 0x269F6: '',  # 𦧶
    # 0x269F7: '',  # 𦧷
    0x269F8: 'zhuàn',  # 𦧸
    0x269F9: 'huā',  # 𦧹
    0x269FA: 'lài',  # 𦧺
    # 0x269FB: '',  # 𦧻
    0x269FC: 'lán',  # 𦧼
    # 0x269FD: '',  # 𦧽
    # 0x269FE: '',  # 𦧾
    # 0x269FF: '',  # 𦧿
    # 0x26A00: '',  # 𦨀
    # 0x26A01: '',  # 𦨁
    # 0x26A02: '',  # 𦨂
    # 0x26A03: '',  # 𦨃
    # 0x26A04: '',  # 𦨄
    # 0x26A05: '',  # 𦨅
    0x26A06: 'zūn',  # 𦨆
    0x26A07: 'yì',  # 𦨇
    0x26A08: 'fú',  # 𦨈
    0x26A09: 'wù',  # 𦨉
    # 0x26A0A: '',  # 𦨊
    0x26A0B: 'fú',  # 𦨋
    # 0x26A0C: '',  # 𦨌
    0x26A0D: 'dīng',  # 𦨍
    0x26A0E: 'tà',  # 𦨎
    # 0x26A0F: '',  # 𦨏
    # 0x26A10: '',  # 𦨐
    # 0x26A11: '',  # 𦨑
    # 0x26A12: '',  # 𦨒
    # 0x26A13: '',  # 𦨓
    # 0x26A14: '',  # 𦨔
    # 0x26A15: '',  # 𦨕
    0x26A16: 'chào',  # 𦨖
    # 0x26A17: '',  # 𦨗
    # 0x26A18: '',  # 𦨘
    0x26A19: 'rì',  # 𦨙
    0x26A1A: 'quǎn',  # 𦨚
    # 0x26A1B: '',  # 𦨛
    0x26A1C: 'gē',  # 𦨜
    # 0x26A1D: '',  # 𦨝
    # 0x26A1E: '',  # 𦨞
    # 0x26A1F: '',  # 𦨟
    # 0x26A20: '',  # 𦨠
    0x26A21: 'fú',  # 𦨡
    0x26A22: 'dì',  # 𦨢
    0x26A23: 'diāo',  # 𦨣
    0x26A24: 'yǒng',  # 𦨤
    # 0x26A25: '',  # 𦨥
    0x26A26: 'jià',  # 𦨦
    # 0x26A27: '',  # 𦨧
    # 0x26A28: '',  # 𦨨
    # 0x26A29: '',  # 𦨩
    # 0x26A2A: '',  # 𦨪
    # 0x26A2B: '',  # 𦨫
    0x26A2C: 'yǒng',  # 𦨬
    0x26A2D: 'pí',  # 𦨭
    # 0x26A2E: '',  # 𦨮
    0x26A2F: 'huó',  # 𦨯
    0x26A30: 'qióng',  # 𦨰
    # 0x26A31: '',  # 𦨱
    0x26A32: 'fán',  # 𦨲
    0x26A33: 'wú',  # 𦨳
    0x26A34: 'tóng',  # 𦨴
    0x26A35: 'háng',  # 𦨵
    # 0x26A36: '',  # 𦨶
    # 0x26A37: '',  # 𦨷
    0x26A38: 'tān',  # 𦨸
    # 0x26A39: '',  # 𦨹
    # 0x26A3A: '',  # 𦨺
    # 0x26A3B: '',  # 𦨻
    # 0x26A3C: '',  # 𦨼
    # 0x26A3D: '',  # 𦨽
    0x26A3E: 'hēng',  # 𦨾
    # 0x26A3F: '',  # 𦨿
    # 0x26A40: '',  # 𦩀
    # 0x26A41: '',  # 𦩁
    # 0x26A42: '',  # 𦩂
    # 0x26A43: '',  # 𦩃
    0x26A44: 'tiāo',  # 𦩄
    # 0x26A45: '',  # 𦩅
    # 0x26A46: '',  # 𦩆
    # 0x26A47: '',  # 𦩇
    0x26A48: 'zhōu',  # 𦩈
    # 0x26A49: '',  # 𦩉
    # 0x26A4A: '',  # 𦩊
    0x26A4B: 'bài',  # 𦩋
    0x26A4C: 'xiè',  # 𦩌
    0x26A4D: 'dāo,diāo',  # 𦩍
    # 0x26A4E: '',  # 𦩎
    0x26A4F: 'jīn,wéi',  # 𦩏
    # 0x26A50: '',  # 𦩐
    # 0x26A51: '',  # 𦩑
    # 0x26A52: '',  # 𦩒
    # 0x26A53: '',  # 𦩓
    # 0x26A54: '',  # 𦩔
    0x26A55: 'hū',  # 𦩕
    0x26A56: 'bēi',  # 𦩖
    # 0x26A57: '',  # 𦩗
    0x26A58: 'dìng',  # 𦩘
    # 0x26A59: '',  # 𦩙
    # 0x26A5A: '',  # 𦩚
    # 0x26A5B: '',  # 𦩛
    0x26A5C: 'nuó',  # 𦩜
    0x26A5D: 'wèi',  # 𦩝
    0x26A5E: 'yú',  # 𦩞
    # 0x26A5F: '',  # 𦩟
    0x26A60: 'xīng',  # 𦩠
    0x26A61: 'fú',  # 𦩡
    0x26A62: 'xiàn',  # 𦩢
    0x26A63: 'qì',  # 𦩣
    0x26A64: 'tū',  # 𦩤
    # 0x26A65: '',  # 𦩥
    # 0x26A66: '',  # 𦩦
    0x26A67: 'jí',  # 𦩧
    # 0x26A68: '',  # 𦩨
    0x26A69: 'yìng',  # 𦩩
    # 0x26A6A: '',  # 𦩪
    0x26A6B: 'dèng,téng',  # 𦩫
    0x26A6C: 'wēi',  # 𦩬
    0x26A6D: 'xī',  # 𦩭
    # 0x26A6E: '',  # 𦩮
    0x26A6F: 'pái',  # 𦩯
    # 0x26A70: '',  # 𦩰
    0x26A71: 'shéng',  # 𦩱
    0x26A72: 'yǒu',  # 𦩲
    # 0x26A73: '',  # 𦩳
    0x26A74: 'ái',  # 𦩴
    0x26A75: 'jiàn',  # 𦩵
    # 0x26A76: '',  # 𦩶
    0x26A77: 'gōu',  # 𦩷
    0x26A78: 'ruò',  # 𦩸
    # 0x26A79: '',  # 𦩹
    # 0x26A7A: '',  # 𦩺
    0x26A7B: 'zhāo',  # 𦩻
    0x26A7C: 'gòng',  # 𦩼
    # 0x26A7D: '',  # 𦩽
    # 0x26A7E: '',  # 𦩾
    0x26A7F: 'shà',  # 𦩿
    0x26A80: 'táng',  # 𦪀
    # 0x26A81: '',  # 𦪁
    # 0x26A82: '',  # 𦪂
    # 0x26A83: '',  # 𦪃
    # 0x26A84: '',  # 𦪄
    # 0x26A85: '',  # 𦪅
    # 0x26A86: '',  # 𦪆
    0x26A87: 'lù',  # 𦪇
    0x26A88: 'áo',  # 𦪈
    # 0x26A89: '',  # 𦪉
    0x26A8A: 'qì',  # 𦪊
    0x26A8B: 'xiū',  # 𦪋
    # 0x26A8C: '',  # 𦪌
    0x26A8D: 'dāi',  # 𦪍
    # 0x26A8E: '',  # 𦪎
    # 0x26A8F: '',  # 𦪏
    # 0x26A90: '',  # 𦪐
    0x26A91: 'fá',  # 𦪑
    0x26A92: 'wèi',  # 𦪒
    # 0x26A93: '',  # 𦪓
    0x26A94: 'dùn',  # 𦪔
    0x26A95: 'liáo',  # 𦪕
    0x26A96: 'fān',  # 𦪖
    0x26A97: 'huáng,héng',  # 𦪗
    0x26A98: 'jué',  # 𦪘
    0x26A99: 'tà',  # 𦪙
    0x26A9A: 'zùn',  # 𦪚
    0x26A9B: 'ráo',  # 𦪛
    0x26A9C: 'cān',  # 𦪜
    0x26A9D: 'téng',  # 𦪝
    # 0x26A9E: '',  # 𦪞
    # 0x26A9F: '',  # 𦪟
    0x26AA0: 'huà',  # 𦪠
    0x26AA1: 'xū',  # 𦪡
    # 0x26AA2: '',  # 𦪢
    0x26AA3: 'zhān',  # 𦪣
    # 0x26AA4: '',  # 𦪤
    # 0x26AA5: '',  # 𦪥
    # 0x26AA6: '',  # 𦪦
    0x26AA7: 'gǎn',  # 𦪧
    # 0x26AA8: '',  # 𦪨
    # 0x26AA9: '',  # 𦪩
    0x26AAA: 'péng',  # 𦪪
    0x26AAB: 'cān',  # 𦪫
    0x26AAC: 'xiē',  # 𦪬
    0x26AAD: 'dá',  # 𦪭
    # 0x26AAE: '',  # 𦪮
    # 0x26AAF: '',  # 𦪯
    # 0x26AB0: '',  # 𦪰
    0x26AB1: 'jì',  # 𦪱
    # 0x26AB2: '',  # 𦪲
    # 0x26AB3: '',  # 𦪳
    # 0x26AB4: '',  # 𦪴
    # 0x26AB5: '',  # 𦪵
    0x26AB6: 'lǐ',  # 𦪶
    # 0x26AB7: '',  # 𦪷
    # 0x26AB8: '',  # 𦪸
    0x26AB9: 'pán',  # 𦪹
    # 0x26ABA: '',  # 𦪺
    # 0x26ABB: '',  # 𦪻
    # 0x26ABC: '',  # 𦪼
    0x26ABD: 'lóng,lǒng',  # 𦪽
    0x26ABE: 'lì',  # 𦪾
    0x26ABF: 'xí',  # 𦪿
    0x26AC0: 'téng',  # 𦫀
    # 0x26AC1: '',  # 𦫁
    # 0x26AC2: '',  # 𦫂
    0x26AC3: 'líng',  # 𦫃
    # 0x26AC4: '',  # 𦫄
    # 0x26AC5: '',  # 𦫅
    # 0x26AC6: '',  # 𦫆
    # 0x26AC7: '',  # 𦫇
    0x26AC8: 'lǐ',  # 𦫈
    0x26AC9: 'rán',  # 𦫉
    0x26ACA: 'líng',  # 𦫊
    # 0x26ACB: '',  # 𦫋
    # 0x26ACC: '',  # 𦫌
    # 0x26ACD: '',  # 𦫍
    0x26ACE: 'gǔn',  # 𦫎
    # 0x26ACF: '',  # 𦫏
    # 0x26AD0: '',  # 𦫐
    # 0x26AD1: '',  # 𦫑
    # 0x26AD2: '',  # 𦫒
    # 0x26AD3: '',  # 𦫓
    0x26AD4: 'pō',  # 𦫔
    0x26AD5: 'mò',  # 𦫕
    0x26AD6: 'pāi',  # 𦫖
    # 0x26AD7: '',  # 𦫗
    # 0x26AD8: '',  # 𦫘
    0x26AD9: 'bà',  # 𦫙
    # 0x26ADA: '',  # 𦫚
    # 0x26ADB: '',  # 𦫛
    # 0x26ADC: '',  # 𦫜
    # 0x26ADD: '',  # 𦫝
    # 0x26ADE: '',  # 𦫞
    # 0x26ADF: '',  # 𦫟
    # 0x26AE0: '',  # 𦫠
    0x26AE1: 'qí',  # 𦫡
    # 0x26AE2: '',  # 𦫢
    # 0x26AE3: '',  # 𦫣
    0x26AE4: 'yán',  # 𦫤
    # 0x26AE5: '',  # 𦫥
    # 0x26AE6: '',  # 𦫦
    # 0x26AE7: '',  # 𦫧
    # 0x26AE8: '',  # 𦫨
    # 0x26AE9: '',  # 𦫩
    0x26AEA: 'wà',  # 𦫪
    0x26AEB: 'ǎng',  # 𦫫
    # 0x26AEC: '',  # 𦫬
    0x26AED: 'mìng',  # 𦫭
    0x26AEE: 'mǐn',  # 𦫮
    0x26AEF: 'xùn',  # 𦫯
    0x26AF0: 'méng',  # 𦫰
    # 0x26AF1: '',  # 𦫱
    # 0x26AF2: '',  # 𦫲
    0x26AF3: 'guǎi',  # 𦫳
    # 0x26AF4: '',  # 𦫴
    # 0x26AF5: '',  # 𦫵
    0x26AF6: 'jiāo',  # 𦫶
    # 0x26AF7: '',  # 𦫷
    # 0x26AF8: '',  # 𦫸
    # 0x26AF9: '',  # 𦫹
    # 0x26AFA: '',  # 𦫺
    0x26AFB: 'gǎi',  # 𦫻
    0x26AFC: 'kǎi',  # 𦫼
    # 0x26AFD: '',  # 𦫽
    # 0x26AFE: '',  # 𦫾
    # 0x26AFF: '',  # 𦫿
    # 0x26B00: '',  # 𦬀
    0x26B01: 'cái',  # 𦬁
    0x26B02: 'wù',  # 𦬂
    0x26B03: 'zhé',  # 𦬃
    0x26B04: 'rěn',  # 𦬄
    0x26B05: 'kōu',  # 𦬅
    0x26B06: 'máng',  # 𦬆
    # 0x26B07: '',  # 𦬇
    # 0x26B08: '',  # 𦬈
    # 0x26B09: '',  # 𦬉
    # 0x26B0A: '',  # 𦬊
    # 0x26B0B: '',  # 𦬋
    # 0x26B0C: '',  # 𦬌
    # 0x26B0D: '',  # 𦬍
    # 0x26B0E: '',  # 𦬎
    # 0x26B0F: '',  # 𦬏
    # 0x26B10: '',  # 𦬐
    # 0x26B11: '',  # 𦬑
    # 0x26B12: '',  # 𦬒
    # 0x26B13: '',  # 𦬓
    0x26B14: 'zhǎo',  # 𦬔
    0x26B15: 'zhōng',  # 𦬕
    0x26B16: 'qiú',  # 𦬖
    0x26B17: 'guō',  # 𦬗
    0x26B18: 'gōng,sōng',  # 𦬘
    0x26B19: 'pū',  # 𦬙
    0x26B1A: 'hù',  # 𦬚
    0x26B1B: 'miǎn',  # 𦬛
    # 0x26B1C: '',  # 𦬜
    # 0x26B1D: '',  # 𦬝
    0x26B1E: 'tiān',  # 𦬞
    # 0x26B1F: '',  # 𦬟
    # 0x26B20: '',  # 𦬠
    # 0x26B21: '',  # 𦬡
    0x26B22: 'pútí',  # 𦬢
    0x26B23: 'wǎng',  # 𦬣
    # 0x26B24: '',  # 𦬤
    # 0x26B25: '',  # 𦬥
    # 0x26B26: '',  # 𦬦
    # 0x26B27: '',  # 𦬧
    # 0x26B28: '',  # 𦬨
    # 0x26B29: '',  # 𦬩
    # 0x26B2A: '',  # 𦬪
    # 0x26B2B: '',  # 𦬫
    # 0x26B2C: '',  # 𦬬
    # 0x26B2D: '',  # 𦬭
    # 0x26B2E: '',  # 𦬮
    # 0x26B2F: '',  # 𦬯
    # 0x26B30: '',  # 𦬰
    # 0x26B31: '',  # 𦬱
    # 0x26B32: '',  # 𦬲
    # 0x26B33: '',  # 𦬳
    # 0x26B34: '',  # 𦬴
    # 0x26B35: '',  # 𦬵
    # 0x26B36: '',  # 𦬶
    # 0x26B37: '',  # 𦬷
    0x26B38: 'zhú',  # 𦬸
    0x26B39: 'dá,dàn',  # 𦬹
    0x26B3A: 'xiòng,huǎng',  # 𦬺
    0x26B3B: 'ná',  # 𦬻
    # 0x26B3C: '',  # 𦬼
    # 0x26B3D: '',  # 𦬽
    0x26B3E: 'juān',  # 𦬾
    # 0x26B3F: '',  # 𦬿
    # 0x26B40: '',  # 𦭀
    0x26B41: 'niǎn',  # 𦭁
    # 0x26B42: '',  # 𦭂
    # 0x26B43: '',  # 𦭃
    # 0x26B44: '',  # 𦭄
    # 0x26B45: '',  # 𦭅
    # 0x26B46: '',  # 𦭆
    # 0x26B47: '',  # 𦭇
    0x26B48: 'hù',  # 𦭈
    0x26B49: 'shā',  # 𦭉
    # 0x26B4A: '',  # 𦭊
    # 0x26B4B: '',  # 𦭋
    # 0x26B4C: '',  # 𦭌
    # 0x26B4D: '',  # 𦭍
    # 0x26B4E: '',  # 𦭎
    # 0x26B4F: '',  # 𦭏
    # 0x26B50: '',  # 𦭐
    # 0x26B51: '',  # 𦭑
    # 0x26B52: '',  # 𦭒
    # 0x26B53: '',  # 𦭓
    # 0x26B54: '',  # 𦭔
    # 0x26B55: '',  # 𦭕
    # 0x26B56: '',  # 𦭖
    # 0x26B57: '',  # 𦭗
    0x26B58: 'yuán',  # 𦭘
    # 0x26B59: '',  # 𦭙
    # 0x26B5A: '',  # 𦭚
    # 0x26B5B: '',  # 𦭛
    0x26B5C: 'zhī',  # 𦭜
    # 0x26B5D: '',  # 𦭝
    # 0x26B5E: '',  # 𦭞
    0x26B5F: 'tā',  # 𦭟
    # 0x26B60: '',  # 𦭠
    0x26B61: 'sī',  # 𦭡
    # 0x26B62: '',  # 𦭢
    # 0x26B63: '',  # 𦭣
    # 0x26B64: '',  # 𦭤
    0x26B65: 'yì',  # 𦭥
    # 0x26B66: '',  # 𦭦
    # 0x26B67: '',  # 𦭧
    # 0x26B68: '',  # 𦭨
    # 0x26B69: '',  # 𦭩
    # 0x26B6A: '',  # 𦭪
    # 0x26B6B: '',  # 𦭫
    # 0x26B6C: '',  # 𦭬
    0x26B6D: 'qióng',  # 𦭭
    0x26B6E: 'zhì',  # 𦭮
    0x26B6F: 'lǚ,lóu',  # 𦭯
    0x26B70: 'rú',  # 𦭰
    # 0x26B71: '',  # 𦭱
    0x26B72: 'qí',  # 𦭲
    0x26B73: 'yǔ',  # 𦭳
    0x26B74: 'zhōu',  # 𦭴
    0x26B75: 'yáng',  # 𦭵
    0x26B76: 'xiǎn',  # 𦭶
    0x26B77: 'móu',  # 𦭷
    0x26B78: 'chóu',  # 𦭸
    0x26B79: 'huī',  # 𦭹
    0x26B7A: 'jiū',  # 𦭺
    0x26B7B: 'jiù',  # 𦭻
    0x26B7C: 'piǎo,bì',  # 𦭼
    # 0x26B7D: '',  # 𦭽
    # 0x26B7E: '',  # 𦭾
    # 0x26B7F: '',  # 𦭿
    # 0x26B80: '',  # 𦮀
    0x26B81: 'jiào',  # 𦮁
    # 0x26B82: '',  # 𦮂
    0x26B83: 'guāi,kuā',  # 𦮃
    # 0x26B84: '',  # 𦮄
    0x26B85: 'mò',  # 𦮅
    # 0x26B86: '',  # 𦮆
    # 0x26B87: '',  # 𦮇
    # 0x26B88: '',  # 𦮈
    # 0x26B89: '',  # 𦮉
    # 0x26B8A: '',  # 𦮊
    # 0x26B8B: '',  # 𦮋
    # 0x26B8C: '',  # 𦮌
    # 0x26B8D: '',  # 𦮍
    # 0x26B8E: '',  # 𦮎
    # 0x26B8F: '',  # 𦮏
    0x26B90: 'xī',  # 𦮐
    0x26B91: 'pú',  # 𦮑
    # 0x26B92: '',  # 𦮒
    # 0x26B93: '',  # 𦮓
    # 0x26B94: '',  # 𦮔
    # 0x26B95: '',  # 𦮕
    # 0x26B96: '',  # 𦮖
    # 0x26B97: '',  # 𦮗
    # 0x26B98: '',  # 𦮘
    0x26B99: 'kuí',  # 𦮙
    # 0x26B9A: '',  # 𦮚
    # 0x26B9B: '',  # 𦮛
    # 0x26B9C: '',  # 𦮜
    # 0x26B9D: '',  # 𦮝
    # 0x26B9E: '',  # 𦮞
    # 0x26B9F: '',  # 𦮟
    # 0x26BA0: '',  # 𦮠
    # 0x26BA1: '',  # 𦮡
    # 0x26BA2: '',  # 𦮢
    # 0x26BA3: '',  # 𦮣
    # 0x26BA4: '',  # 𦮤
    # 0x26BA5: '',  # 𦮥
    # 0x26BA6: '',  # 𦮦
    # 0x26BA7: '',  # 𦮧
    # 0x26BA8: '',  # 𦮨
    # 0x26BA9: '',  # 𦮩
    # 0x26BAA: '',  # 𦮪
    # 0x26BAB: '',  # 𦮫
    # 0x26BAC: '',  # 𦮬
    # 0x26BAD: '',  # 𦮭
    # 0x26BAE: '',  # 𦮮
    0x26BAF: 'jì',  # 𦮯
    # 0x26BB0: '',  # 𦮰
    # 0x26BB1: '',  # 𦮱
    # 0x26BB2: '',  # 𦮲
    # 0x26BB3: '',  # 𦮳
    # 0x26BB4: '',  # 𦮴
    # 0x26BB5: '',  # 𦮵
    0x26BB6: 'wěn',  # 𦮶
    0x26BB7: 'bèi',  # 𦮷
    0x26BB8: 'yǐ',  # 𦮸
    0x26BB9: 'fú',  # 𦮹
    0x26BBA: 'sī',  # 𦮺
    0x26BBB: 'juān',  # 𦮻
    0x26BBC: 'jì,qí',  # 𦮼
    # 0x26BBD: '',  # 𦮽
    0x26BBE: 'nì',  # 𦮾
    # 0x26BBF: '',  # 𦮿
    0x26BC0: 'bèn',  # 𦯀
    # 0x26BC1: '',  # 𦯁
    # 0x26BC2: '',  # 𦯂
    # 0x26BC3: '',  # 𦯃
    # 0x26BC4: '',  # 𦯄
    0x26BC5: 'xù',  # 𦯅
    0x26BC6: 'mǎo',  # 𦯆
    # 0x26BC7: '',  # 𦯇
    0x26BC8: 'qǐn',  # 𦯈
    0x26BC9: 'bó',  # 𦯉
    # 0x26BCA: '',  # 𦯊
    # 0x26BCB: '',  # 𦯋
    0x26BCC: 'wáng',  # 𦯌
    0x26BCD: 'zhè',  # 𦯍
    # 0x26BCE: '',  # 𦯎
    0x26BCF: 'wò',  # 𦯏
    0x26BD0: 'sháo',  # 𦯐
    0x26BD1: 'zào',  # 𦯑
    0x26BD2: 'yǎng',  # 𦯒
    # 0x26BD3: '',  # 𦯓
    # 0x26BD4: '',  # 𦯔
    0x26BD5: 'sòng',  # 𦯕
    0x26BD6: 'niè',  # 𦯖
    # 0x26BD7: '',  # 𦯗
    # 0x26BD8: '',  # 𦯘
    # 0x26BD9: '',  # 𦯙
    # 0x26BDA: '',  # 𦯚
    0x26BDB: 'bì',  # 𦯛
    # 0x26BDC: '',  # 𦯜
    # 0x26BDD: '',  # 𦯝
    # 0x26BDE: '',  # 𦯞
    # 0x26BDF: '',  # 𦯟
    # 0x26BE0: '',  # 𦯠
    # 0x26BE1: '',  # 𦯡
    # 0x26BE2: '',  # 𦯢
    0x26BE3: 'cú',  # 𦯣
    0x26BE4: 'qiāng',  # 𦯤
    # 0x26BE5: '',  # 𦯥
    # 0x26BE6: '',  # 𦯦
    # 0x26BE7: '',  # 𦯧
    # 0x26BE8: '',  # 𦯨
    # 0x26BE9: '',  # 𦯩
    0x26BEA: 'xiào',  # 𦯪
    0x26BEB: 'zhī',  # 𦯫
    0x26BEC: 'shé',  # 𦯬
    # 0x26BED: '',  # 𦯭
    # 0x26BEE: '',  # 𦯮
    0x26BEF: 'zhì',  # 𦯯
    0x26BF0: 'pēng',  # 𦯰
    # 0x26BF1: '',  # 𦯱
    # 0x26BF2: '',  # 𦯲
    # 0x26BF3: '',  # 𦯳
    # 0x26BF4: '',  # 𦯴
    # 0x26BF5: '',  # 𦯵
    # 0x26BF6: '',  # 𦯶
    # 0x26BF7: '',  # 𦯷
    # 0x26BF8: '',  # 𦯸
    # 0x26BF9: '',  # 𦯹
    # 0x26BFA: '',  # 𦯺
    # 0x26BFB: '',  # 𦯻
    # 0x26BFC: '',  # 𦯼
    # 0x26BFD: '',  # 𦯽
    # 0x26BFE: '',  # 𦯾
    # 0x26BFF: '',  # 𦯿
    # 0x26C00: '',  # 𦰀
    # 0x26C01: '',  # 𦰁
    # 0x26C02: '',  # 𦰂
    # 0x26C03: '',  # 𦰃
    # 0x26C04: '',  # 𦰄
    # 0x26C05: '',  # 𦰅
    # 0x26C06: '',  # 𦰆
    # 0x26C07: '',  # 𦰇
    # 0x26C08: '',  # 𦰈
    # 0x26C09: '',  # 𦰉
    # 0x26C0A: '',  # 𦰊
    # 0x26C0B: '',  # 𦰋
    # 0x26C0C: '',  # 𦰌
    # 0x26C0D: '',  # 𦰍
    # 0x26C0E: '',  # 𦰎
    # 0x26C0F: '',  # 𦰏
    # 0x26C10: '',  # 𦰐
    # 0x26C11: '',  # 𦰑
    # 0x26C12: '',  # 𦰒
    # 0x26C13: '',  # 𦰓
    # 0x26C14: '',  # 𦰔
    # 0x26C15: '',  # 𦰕
    0x26C16: 'wò',  # 𦰖
    0x26C17: 'huá,huà,huā',  # 𦰗
    0x26C18: 'zhǐ',  # 𦰘
    0x26C19: 'bì',  # 𦰙
    # 0x26C1A: '',  # 𦰚
    0x26C1B: 'fén',  # 𦰛
    # 0x26C1C: '',  # 𦰜
    # 0x26C1D: '',  # 𦰝
    # 0x26C1E: '',  # 𦰞
    # 0x26C1F: '',  # 𦰟
    # 0x26C20: '',  # 𦰠
    0x26C21: 'nà,nuó',  # 𦰡
    # 0x26C22: '',  # 𦰢
    # 0x26C23: '',  # 𦰣
    # 0x26C24: '',  # 𦰤
    0x26C25: 'bāng',  # 𦰥
    # 0x26C26: '',  # 𦰦
    # 0x26C27: '',  # 𦰧
    # 0x26C28: '',  # 𦰨
    # 0x26C29: '',  # 𦰩
    0x26C2A: 'qiú',  # 𦰪
    0x26C2B: 'nǐ',  # 𦰫
    0x26C2C: 'bó',  # 𦰬
    0x26C2D: 'dùn',  # 𦰭
    # 0x26C2E: '',  # 𦰮
    0x26C2F: 'shǐ',  # 𦰯
    0x26C30: 'xū',  # 𦰰
    0x26C31: 'cháng',  # 𦰱
    0x26C32: 'xū',  # 𦰲
    0x26C33: 'yé',  # 𦰳
    # 0x26C34: '',  # 𦰴
    # 0x26C35: '',  # 𦰵
    # 0x26C36: '',  # 𦰶
    # 0x26C37: '',  # 𦰷
    0x26C38: 'xīn',  # 𦰸
    0x26C39: 'zhuó',  # 𦰹
    0x26C3A: 'fù',  # 𦰺
    # 0x26C3B: '',  # 𦰻
    # 0x26C3C: '',  # 𦰼
    0x26C3D: 'pǐ',  # 𦰽
    0x26C3E: 'xuè',  # 𦰾
    # 0x26C3F: '',  # 𦰿
    0x26C40: 'yù',  # 𦱀
    0x26C41: 'xián',  # 𦱁
    0x26C42: 'yù',  # 𦱂
    0x26C43: 'yú',  # 𦱃
    0x26C44: 'gū',  # 𦱄
    0x26C45: 'jū',  # 𦱅
    0x26C46: 'tā',  # 𦱆
    0x26C47: 'kōng',  # 𦱇
    # 0x26C48: '',  # 𦱈
    # 0x26C49: '',  # 𦱉
    0x26C4A: 'zhēng',  # 𦱊
    0x26C4B: 'méng',  # 𦱋
    0x26C4C: 'gāng',  # 𦱌
    # 0x26C4D: '',  # 𦱍
    # 0x26C4E: '',  # 𦱎
    # 0x26C4F: '',  # 𦱏
    # 0x26C50: '',  # 𦱐
    # 0x26C51: '',  # 𦱑
    0x26C52: 'mù',  # 𦱒
    0x26C53: 'xǐ',  # 𦱓
    0x26C54: 'bì',  # 𦱔
    # 0x26C55: '',  # 𦱕
    0x26C56: 'fù',  # 𦱖
    # 0x26C57: '',  # 𦱗
    # 0x26C58: '',  # 𦱘
    # 0x26C59: '',  # 𦱙
    # 0x26C5A: '',  # 𦱚
    # 0x26C5B: '',  # 𦱛
    0x26C5C: 'xiào',  # 𦱜
    # 0x26C5D: '',  # 𦱝
    # 0x26C5E: '',  # 𦱞
    # 0x26C5F: '',  # 𦱟
    0x26C60: 'jiū',  # 𦱠
    # 0x26C61: '',  # 𦱡
    # 0x26C62: '',  # 𦱢
    0x26C63: 'gǒu',  # 𦱣
    # 0x26C64: '',  # 𦱤
    # 0x26C65: '',  # 𦱥
    # 0x26C66: '',  # 𦱦
    # 0x26C67: '',  # 𦱧
    # 0x26C68: '',  # 𦱨
    # 0x26C69: '',  # 𦱩
    # 0x26C6A: '',  # 𦱪
    # 0x26C6B: '',  # 𦱫
    # 0x26C6C: '',  # 𦱬
    # 0x26C6D: '',  # 𦱭
    # 0x26C6E: '',  # 𦱮
    # 0x26C6F: '',  # 𦱯
    0x26C70: 'chí',  # 𦱰
    0x26C71: 'jiū',  # 𦱱
    0x26C72: 'jiū',  # 𦱲
    # 0x26C73: '',  # 𦱳
    # 0x26C74: '',  # 𦱴
    0x26C75: 'shā',  # 𦱵
    # 0x26C76: '',  # 𦱶
    0x26C77: 'fēi',  # 𦱷
    # 0x26C78: '',  # 𦱸
    # 0x26C79: '',  # 𦱹
    # 0x26C7A: '',  # 𦱺
    # 0x26C7B: '',  # 𦱻
    # 0x26C7C: '',  # 𦱼
    # 0x26C7D: '',  # 𦱽
    # 0x26C7E: '',  # 𦱾
    # 0x26C7F: '',  # 𦱿
    # 0x26C80: '',  # 𦲀
    # 0x26C81: '',  # 𦲁
    # 0x26C82: '',  # 𦲂
    # 0x26C83: '',  # 𦲃
    # 0x26C84: '',  # 𦲄
    # 0x26C85: '',  # 𦲅
    # 0x26C86: '',  # 𦲆
    # 0x26C87: '',  # 𦲇
    # 0x26C88: '',  # 𦲈
    # 0x26C89: '',  # 𦲉
    # 0x26C8A: '',  # 𦲊
    # 0x26C8B: '',  # 𦲋
    # 0x26C8C: '',  # 𦲌
    # 0x26C8D: '',  # 𦲍
    # 0x26C8E: '',  # 𦲎
    # 0x26C8F: '',  # 𦲏
    # 0x26C90: '',  # 𦲐
    # 0x26C91: '',  # 𦲑
    # 0x26C92: '',  # 𦲒
    # 0x26C93: '',  # 𦲓
    # 0x26C94: '',  # 𦲔
    # 0x26C95: '',  # 𦲕
    # 0x26C96: '',  # 𦲖
    # 0x26C97: '',  # 𦲗
    # 0x26C98: '',  # 𦲘
    # 0x26C99: '',  # 𦲙
    # 0x26C9A: '',  # 𦲚
    # 0x26C9B: '',  # 𦲛
    # 0x26C9C: '',  # 𦲜
    # 0x26C9D: '',  # 𦲝
    # 0x26C9E: '',  # 𦲞
    # 0x26C9F: '',  # 𦲟
    # 0x26CA0: '',  # 𦲠
    # 0x26CA1: '',  # 𦲡
    # 0x26CA2: '',  # 𦲢
    # 0x26CA3: '',  # 𦲣
    # 0x26CA4: '',  # 𦲤
    # 0x26CA5: '',  # 𦲥
    # 0x26CA6: '',  # 𦲦
    # 0x26CA7: '',  # 𦲧
    # 0x26CA8: '',  # 𦲨
    # 0x26CA9: '',  # 𦲩
    # 0x26CAA: '',  # 𦲪
    0x26CAB: 'fú',  # 𦲫
    # 0x26CAC: '',  # 𦲬
    # 0x26CAD: '',  # 𦲭
    # 0x26CAE: '',  # 𦲮
    0x26CAF: 'wàn',  # 𦲯
    0x26CB0: 'xū',  # 𦲰
    0x26CB1: 'bō',  # 𦲱
    # 0x26CB2: '',  # 𦲲
    # 0x26CB3: '',  # 𦲳
    # 0x26CB4: '',  # 𦲴
    # 0x26CB5: '',  # 𦲵
    # 0x26CB6: '',  # 𦲶
    0x26CB7: 'lì',  # 𦲷
    # 0x26CB8: '',  # 𦲸
    # 0x26CB9: '',  # 𦲹
    # 0x26CBA: '',  # 𦲺
    # 0x26CBB: '',  # 𦲻
    # 0x26CBC: '',  # 𦲼
    # 0x26CBD: '',  # 𦲽
    # 0x26CBE: '',  # 𦲾
    # 0x26CBF: '',  # 𦲿
    # 0x26CC0: '',  # 𦳀
    0x26CC1: 'hào,mào',  # 𦳁
    # 0x26CC2: '',  # 𦳂
    0x26CC3: 'xié',  # 𦳃
    0x26CC4: 'pián',  # 𦳄
    0x26CC5: 'yǔ',  # 𦳅
    # 0x26CC6: '',  # 𦳆
    0x26CC7: 'tián',  # 𦳇
    0x26CC8: 'pí,bì',  # 𦳈
    # 0x26CC9: '',  # 𦳉
    0x26CCA: 'shǐ',  # 𦳊
    0x26CCB: 'kuǎi',  # 𦳋
    0x26CCC: 'jī',  # 𦳌
    # 0x26CCD: '',  # 𦳍
    # 0x26CCE: '',  # 𦳎
    0x26CCF: 'zhā',  # 𦳏
    0x26CD0: 'nài,nà',  # 𦳐
    0x26CD1: 'mǒu',  # 𦳑
    # 0x26CD2: '',  # 𦳒
    0x26CD3: 'fú',  # 𦳓
    0x26CD4: 'dù',  # 𦳔
    # 0x26CD5: '',  # 𦳕
    # 0x26CD6: '',  # 𦳖
    0x26CD7: 'shěng',  # 𦳗
    0x26CD8: 'chá',  # 𦳘
    0x26CD9: 'zhì',  # 𦳙
    0x26CDA: 'chí',  # 𦳚
    0x26CDB: 'guǐ',  # 𦳛
    0x26CDC: 'mín',  # 𦳜
    0x26CDD: 'tāng,dàng',  # 𦳝
    0x26CDE: 'bài',  # 𦳞
    0x26CDF: 'qiāng',  # 𦳟
    # 0x26CE0: '',  # 𦳠
    0x26CE1: 'zhuó',  # 𦳡
    0x26CE2: 'wèi',  # 𦳢
    0x26CE3: 'xún',  # 𦳣
    # 0x26CE4: '',  # 𦳤
    0x26CE5: 'miǎo',  # 𦳥
    0x26CE6: 'zāi',  # 𦳦
    0x26CE7: 'yóu',  # 𦳧
    # 0x26CE8: '',  # 𦳨
    0x26CE9: 'yòu',  # 𦳩
    # 0x26CEA: '',  # 𦳪
    0x26CEB: 'shān',  # 𦳫
    0x26CEC: 'hé',  # 𦳬
    0x26CED: 'lǚ',  # 𦳭
    0x26CEE: 'zhí',  # 𦳮
    # 0x26CEF: '',  # 𦳯
    # 0x26CF0: '',  # 𦳰
    # 0x26CF1: '',  # 𦳱
    0x26CF2: 'jìng',  # 𦳲
    0x26CF3: 'zhēn',  # 𦳳
    # 0x26CF4: '',  # 𦳴
    # 0x26CF5: '',  # 𦳵
    0x26CF6: 'méng',  # 𦳶
    0x26CF7: 'yóu',  # 𦳷
    # 0x26CF8: '',  # 𦳸
    0x26CF9: 'wò',  # 𦳹
    0x26CFA: 'bá',  # 𦳺
    # 0x26CFB: '',  # 𦳻
    # 0x26CFC: '',  # 𦳼
    0x26CFD: 'juàn',  # 𦳽
    0x26CFE: 'rú',  # 𦳾
    0x26CFF: 'còu',  # 𦳿
    0x26D00: 'zhī',  # 𦴀
    # 0x26D01: '',  # 𦴁
    # 0x26D02: '',  # 𦴂
    # 0x26D03: '',  # 𦴃
    # 0x26D04: '',  # 𦴄
    # 0x26D05: '',  # 𦴅
    # 0x26D06: '',  # 𦴆
    # 0x26D07: '',  # 𦴇
    # 0x26D08: '',  # 𦴈
    0x26D09: 'hú',  # 𦴉
    0x26D0A: 'yāng',  # 𦴊
    # 0x26D0B: '',  # 𦴋
    0x26D0C: 'jùn',  # 𦴌
    0x26D0D: 'shé',  # 𦴍
    0x26D0E: 'kòu',  # 𦴎
    # 0x26D0F: '',  # 𦴏
    # 0x26D10: '',  # 𦴐
    0x26D11: 'qián',  # 𦴑
    # 0x26D12: '',  # 𦴒
    # 0x26D13: '',  # 𦴓
    0x26D14: 'méng',  # 𦴔
    # 0x26D15: '',  # 𦴕
    # 0x26D16: '',  # 𦴖
    # 0x26D17: '',  # 𦴗
    # 0x26D18: '',  # 𦴘
    # 0x26D19: '',  # 𦴙
    0x26D1A: 'tiáo',  # 𦴚
    # 0x26D1B: '',  # 𦴛
    # 0x26D1C: '',  # 𦴜
    # 0x26D1D: '',  # 𦴝
    # 0x26D1E: '',  # 𦴞
    # 0x26D1F: '',  # 𦴟
    # 0x26D20: '',  # 𦴠
    # 0x26D21: '',  # 𦴡
    # 0x26D22: '',  # 𦴢
    # 0x26D23: '',  # 𦴣
    # 0x26D24: '',  # 𦴤
    # 0x26D25: '',  # 𦴥
    # 0x26D26: '',  # 𦴦
    # 0x26D27: '',  # 𦴧
    # 0x26D28: '',  # 𦴨
    # 0x26D29: '',  # 𦴩
    # 0x26D2A: '',  # 𦴪
    # 0x26D2B: '',  # 𦴫
    # 0x26D2C: '',  # 𦴬
    # 0x26D2D: '',  # 𦴭
    # 0x26D2E: '',  # 𦴮
    # 0x26D2F: '',  # 𦴯
    # 0x26D30: '',  # 𦴰
    # 0x26D31: '',  # 𦴱
    # 0x26D32: '',  # 𦴲
    # 0x26D33: '',  # 𦴳
    # 0x26D34: '',  # 𦴴
    # 0x26D35: '',  # 𦴵
    # 0x26D36: '',  # 𦴶
    # 0x26D37: '',  # 𦴷
    # 0x26D38: '',  # 𦴸
    # 0x26D39: '',  # 𦴹
    # 0x26D3A: '',  # 𦴺
    # 0x26D3B: '',  # 𦴻
    # 0x26D3C: '',  # 𦴼
    # 0x26D3D: '',  # 𦴽
    # 0x26D3E: '',  # 𦴾
    # 0x26D3F: '',  # 𦴿
    # 0x26D40: '',  # 𦵀
    # 0x26D41: '',  # 𦵁
    # 0x26D42: '',  # 𦵂
    # 0x26D43: '',  # 𦵃
    # 0x26D44: '',  # 𦵄
    # 0x26D45: '',  # 𦵅
    # 0x26D46: '',  # 𦵆
    # 0x26D47: '',  # 𦵇
    # 0x26D48: '',  # 𦵈
    # 0x26D49: '',  # 𦵉
    # 0x26D4A: '',  # 𦵊
    # 0x26D4B: '',  # 𦵋
    # 0x26D4C: '',  # 𦵌
    # 0x26D4D: '',  # 𦵍
    # 0x26D4E: '',  # 𦵎
    # 0x26D4F: '',  # 𦵏
    0x26D50: 'niè',  # 𦵐
    # 0x26D51: '',  # 𦵑
    # 0x26D52: '',  # 𦵒
    # 0x26D53: '',  # 𦵓
    # 0x26D54: '',  # 𦵔
    # 0x26D55: '',  # 𦵕
    # 0x26D56: '',  # 𦵖
    # 0x26D57: '',  # 𦵗
    # 0x26D58: '',  # 𦵘
    # 0x26D59: '',  # 𦵙
    # 0x26D5A: '',  # 𦵚
    # 0x26D5B: '',  # 𦵛
    # 0x26D5C: '',  # 𦵜
    # 0x26D5D: '',  # 𦵝
    # 0x26D5E: '',  # 𦵞
    0x26D5F: 'chí',  # 𦵟
    # 0x26D60: '',  # 𦵠
    0x26D61: 'xiōng,gōng',  # 𦵡
    # 0x26D62: '',  # 𦵢
    0x26D63: 'hùn',  # 𦵣
    # 0x26D64: '',  # 𦵤
    # 0x26D65: '',  # 𦵥
    0x26D66: 'dí',  # 𦵦
    0x26D67: 'láng',  # 𦵧
    # 0x26D68: '',  # 𦵨
    0x26D69: 'zāo,qiú',  # 𦵩
    0x26D6A: 'cè',  # 𦵪
    0x26D6B: 'suǒ',  # 𦵫
    0x26D6C: 'zù',  # 𦵬
    0x26D6D: 'suī',  # 𦵭
    # 0x26D6E: '',  # 𦵮
    0x26D6F: 'xiá',  # 𦵯
    # 0x26D70: '',  # 𦵰
    0x26D71: 'xiè',  # 𦵱
    # 0x26D72: '',  # 𦵲
    # 0x26D73: '',  # 𦵳
    0x26D74: 'jié',  # 𦵴
    0x26D75: 'yóu',  # 𦵵
    # 0x26D76: '',  # 𦵶
    0x26D77: 'gòu',  # 𦵷
    0x26D78: 'gěng',  # 𦵸
    0x26D79: 'tǎn',  # 𦵹
    # 0x26D7A: '',  # 𦵺
    # 0x26D7B: '',  # 𦵻
    0x26D7C: 'jùn',  # 𦵼
    0x26D7D: 'huǎng',  # 𦵽
    0x26D7E: 'jí',  # 𦵾
    0x26D7F: 'pōu',  # 𦵿
    0x26D80: 'wū',  # 𦶀
    # 0x26D81: '',  # 𦶁
    0x26D82: 'yì',  # 𦶂
    # 0x26D83: '',  # 𦶃
    # 0x26D84: '',  # 𦶄
    0x26D85: 'nǎi',  # 𦶅
    # 0x26D86: '',  # 𦶆
    0x26D87: 'rǒng,ruǎn',  # 𦶇
    0x26D88: 'nán',  # 𦶈
    # 0x26D89: '',  # 𦶉
    0x26D8A: 'píng',  # 𦶊
    0x26D8B: 'shàn',  # 𦶋
    0x26D8C: 'diāo',  # 𦶌
    0x26D8D: 'jí',  # 𦶍
    0x26D8E: 'huā',  # 𦶎
    0x26D8F: 'duì',  # 𦶏
    0x26D90: 'kǒng',  # 𦶐
    0x26D91: 'tà',  # 𦶑
    # 0x26D92: '',  # 𦶒
    0x26D93: 'hòng',  # 𦶓
    # 0x26D94: '',  # 𦶔
    0x26D95: 'shū',  # 𦶕
    # 0x26D96: '',  # 𦶖
    # 0x26D97: '',  # 𦶗
    # 0x26D98: '',  # 𦶘
    0x26D99: 'héng',  # 𦶙
    0x26D9A: 'fěn',  # 𦶚
    # 0x26D9B: '',  # 𦶛
    # 0x26D9C: '',  # 𦶜
    # 0x26D9D: '',  # 𦶝
    # 0x26D9E: '',  # 𦶞
    0x26D9F: 'ruò',  # 𦶟
    # 0x26DA0: '',  # 𦶠
    # 0x26DA1: '',  # 𦶡
    # 0x26DA2: '',  # 𦶢
    # 0x26DA3: '',  # 𦶣
    # 0x26DA4: '',  # 𦶤
    # 0x26DA5: '',  # 𦶥
    # 0x26DA6: '',  # 𦶦
    # 0x26DA7: '',  # 𦶧
    # 0x26DA8: '',  # 𦶨
    # 0x26DA9: '',  # 𦶩
    # 0x26DAA: '',  # 𦶪
    # 0x26DAB: '',  # 𦶫
    # 0x26DAC: '',  # 𦶬
    # 0x26DAD: '',  # 𦶭
    # 0x26DAE: '',  # 𦶮
    # 0x26DAF: '',  # 𦶯
    # 0x26DB0: '',  # 𦶰
    # 0x26DB1: '',  # 𦶱
    0x26DB2: 'kòu',  # 𦶲
    # 0x26DB3: '',  # 𦶳
    # 0x26DB4: '',  # 𦶴
    # 0x26DB5: '',  # 𦶵
    # 0x26DB6: '',  # 𦶶
    # 0x26DB7: '',  # 𦶷
    # 0x26DB8: '',  # 𦶸
    # 0x26DB9: '',  # 𦶹
    # 0x26DBA: '',  # 𦶺
    # 0x26DBB: '',  # 𦶻
    # 0x26DBC: '',  # 𦶼
    # 0x26DBD: '',  # 𦶽
    # 0x26DBE: '',  # 𦶾
    # 0x26DBF: '',  # 𦶿
    # 0x26DC0: '',  # 𦷀
    # 0x26DC1: '',  # 𦷁
    # 0x26DC2: '',  # 𦷂
    # 0x26DC3: '',  # 𦷃
    # 0x26DC4: '',  # 𦷄
    # 0x26DC5: '',  # 𦷅
    # 0x26DC6: '',  # 𦷆
    # 0x26DC7: '',  # 𦷇
    # 0x26DC8: '',  # 𦷈
    # 0x26DC9: '',  # 𦷉
    # 0x26DCA: '',  # 𦷊
    # 0x26DCB: '',  # 𦷋
    # 0x26DCC: '',  # 𦷌
    # 0x26DCD: '',  # 𦷍
    # 0x26DCE: '',  # 𦷎
    # 0x26DCF: '',  # 𦷏
    # 0x26DD0: '',  # 𦷐
    # 0x26DD1: '',  # 𦷑
    # 0x26DD2: '',  # 𦷒
    # 0x26DD3: '',  # 𦷓
    # 0x26DD4: '',  # 𦷔
    # 0x26DD5: '',  # 𦷕
    # 0x26DD6: '',  # 𦷖
    # 0x26DD7: '',  # 𦷗
    # 0x26DD8: '',  # 𦷘
    0x26DD9: 'nián',  # 𦷙
    # 0x26DDA: '',  # 𦷚
    # 0x26DDB: '',  # 𦷛
    # 0x26DDC: '',  # 𦷜
    0x26DDD: 'chú',  # 𦷝
    # 0x26DDE: '',  # 𦷞
    # 0x26DDF: '',  # 𦷟
    # 0x26DE0: '',  # 𦷠
    # 0x26DE1: '',  # 𦷡
    # 0x26DE2: '',  # 𦷢
    # 0x26DE3: '',  # 𦷣
    # 0x26DE4: '',  # 𦷤
    # 0x26DE5: '',  # 𦷥
    0x26DE6: 'qiàng',  # 𦷦
    # 0x26DE7: '',  # 𦷧
    # 0x26DE8: '',  # 𦷨
    # 0x26DE9: '',  # 𦷩
    # 0x26DEA: '',  # 𦷪
    # 0x26DEB: '',  # 𦷫
    # 0x26DEC: '',  # 𦷬
    # 0x26DED: '',  # 𦷭
    # 0x26DEE: '',  # 𦷮
    # 0x26DEF: '',  # 𦷯
    # 0x26DF0: '',  # 𦷰
    # 0x26DF1: '',  # 𦷱
    0x26DF2: 'xì',  # 𦷲
    0x26DF3: 'hú',  # 𦷳
    0x26DF4: 'sòng',  # 𦷴
    0x26DF5: 'wò',  # 𦷵
    # 0x26DF6: '',  # 𦷶
    0x26DF7: 'hài',  # 𦷷
    0x26DF8: 'rú',  # 𦷸
    0x26DF9: 'méng',  # 𦷹
    # 0x26DFA: '',  # 𦷺
    0x26DFB: 'sǎn',  # 𦷻
    # 0x26DFC: '',  # 𦷼
    0x26DFD: 'wú',  # 𦷽
    # 0x26DFE: '',  # 𦷾
    0x26DFF: 'yóu',  # 𦷿
    # 0x26E00: '',  # 𦸀
    0x26E01: 'tān',  # 𦸁
    0x26E02: 'shēn',  # 𦸂
    # 0x26E03: '',  # 𦸃
    # 0x26E04: '',  # 𦸄
    # 0x26E05: '',  # 𦸅
    0x26E06: 'qǐ',  # 𦸆
    # 0x26E07: '',  # 𦸇
    0x26E08: 'guó',  # 𦸈
    0x26E09: 'qià',  # 𦸉
    0x26E0A: 'xiān',  # 𦸊
    # 0x26E0B: '',  # 𦸋
    # 0x26E0C: '',  # 𦸌
    # 0x26E0D: '',  # 𦸍
    # 0x26E0E: '',  # 𦸎
    0x26E0F: 'suī',  # 𦸏
    0x26E10: 'lù',  # 𦸐
    # 0x26E11: '',  # 𦸑
    # 0x26E12: '',  # 𦸒
    0x26E13: 'qī',  # 𦸓
    0x26E14: 'diāo',  # 𦸔
    # 0x26E15: '',  # 𦸕
    # 0x26E16: '',  # 𦸖
    0x26E17: 'qí',  # 𦸗
    0x26E18: 'jiá',  # 𦸘
    0x26E19: 'yóu',  # 𦸙
    0x26E1A: 'xí',  # 𦸚
    0x26E1B: 'cháo',  # 𦸛
    # 0x26E1C: '',  # 𦸜
    # 0x26E1D: '',  # 𦸝
    # 0x26E1E: '',  # 𦸞
    # 0x26E1F: '',  # 𦸟
    # 0x26E20: '',  # 𦸠
    0x26E21: 'mì',  # 𦸡
    0x26E22: 'lòu',  # 𦸢
    0x26E23: 'bǐ',  # 𦸣
    # 0x26E24: '',  # 𦸤
    # 0x26E25: '',  # 𦸥
    # 0x26E26: '',  # 𦸦
    # 0x26E27: '',  # 𦸧
    # 0x26E28: '',  # 𦸨
    # 0x26E29: '',  # 𦸩
    0x26E2A: 'péi',  # 𦸪
    # 0x26E2B: '',  # 𦸫
    # 0x26E2C: '',  # 𦸬
    # 0x26E2D: '',  # 𦸭
    0x26E2E: 'zhēn',  # 𦸮
    0x26E2F: 'shēn',  # 𦸯
    0x26E30: 'chǎn',  # 𦸰
    0x26E31: 'fù',  # 𦸱
    # 0x26E32: '',  # 𦸲
    # 0x26E33: '',  # 𦸳
    # 0x26E34: '',  # 𦸴
    # 0x26E35: '',  # 𦸵
    0x26E36: 'qū',  # 𦸶
    0x26E37: 'sī',  # 𦸷
    # 0x26E38: '',  # 𦸸
    # 0x26E39: '',  # 𦸹
    0x26E3A: 'zuī',  # 𦸺
    # 0x26E3B: '',  # 𦸻
    # 0x26E3C: '',  # 𦸼
    # 0x26E3D: '',  # 𦸽
    # 0x26E3E: '',  # 𦸾
    # 0x26E3F: '',  # 𦸿
    # 0x26E40: '',  # 𦹀
    # 0x26E41: '',  # 𦹁
    # 0x26E42: '',  # 𦹂
    # 0x26E43: '',  # 𦹃
    # 0x26E44: '',  # 𦹄
    # 0x26E45: '',  # 𦹅
    # 0x26E46: '',  # 𦹆
    # 0x26E47: '',  # 𦹇
    # 0x26E48: '',  # 𦹈
    # 0x26E49: '',  # 𦹉
    # 0x26E4A: '',  # 𦹊
    # 0x26E4B: '',  # 𦹋
    # 0x26E4C: '',  # 𦹌
    # 0x26E4D: '',  # 𦹍
    # 0x26E4E: '',  # 𦹎
    # 0x26E4F: '',  # 𦹏
    # 0x26E50: '',  # 𦹐
    # 0x26E51: '',  # 𦹑
    # 0x26E52: '',  # 𦹒
    # 0x26E53: '',  # 𦹓
    # 0x26E54: '',  # 𦹔
    # 0x26E55: '',  # 𦹕
    # 0x26E56: '',  # 𦹖
    # 0x26E57: '',  # 𦹗
    # 0x26E58: '',  # 𦹘
    # 0x26E59: '',  # 𦹙
    # 0x26E5A: '',  # 𦹚
    # 0x26E5B: '',  # 𦹛
    # 0x26E5C: '',  # 𦹜
    # 0x26E5D: '',  # 𦹝
    # 0x26E5E: '',  # 𦹞
    # 0x26E5F: '',  # 𦹟
    # 0x26E60: '',  # 𦹠
    # 0x26E61: '',  # 𦹡
    # 0x26E62: '',  # 𦹢
    # 0x26E63: '',  # 𦹣
    # 0x26E64: '',  # 𦹤
    # 0x26E65: '',  # 𦹥
    # 0x26E66: '',  # 𦹦
    # 0x26E67: '',  # 𦹧
    # 0x26E68: '',  # 𦹨
    # 0x26E69: '',  # 𦹩
    # 0x26E6A: '',  # 𦹪
    0x26E6B: 'zhào',  # 𦹫
    # 0x26E6C: '',  # 𦹬
    # 0x26E6D: '',  # 𦹭
    # 0x26E6E: '',  # 𦹮
    # 0x26E6F: '',  # 𦹯
    # 0x26E70: '',  # 𦹰
    # 0x26E71: '',  # 𦹱
    # 0x26E72: '',  # 𦹲
    # 0x26E73: '',  # 𦹳
    # 0x26E74: '',  # 𦹴
    # 0x26E75: '',  # 𦹵
    # 0x26E76: '',  # 𦹶
    # 0x26E77: '',  # 𦹷
    # 0x26E78: '',  # 𦹸
    # 0x26E79: '',  # 𦹹
    # 0x26E7A: '',  # 𦹺
    # 0x26E7B: '',  # 𦹻
    # 0x26E7C: '',  # 𦹼
    0x26E7D: 'pí',  # 𦹽
    # 0x26E7E: '',  # 𦹾
    # 0x26E7F: '',  # 𦹿
    0x26E80: 'còu',  # 𦺀
    # 0x26E81: '',  # 𦺁
    # 0x26E82: '',  # 𦺂
    # 0x26E83: '',  # 𦺃
    # 0x26E84: '',  # 𦺄
    # 0x26E85: '',  # 𦺅
    0x26E86: 'gāo',  # 𦺆
    0x26E87: 'dú',  # 𦺇
    # 0x26E88: '',  # 𦺈
    0x26E89: 'fū',  # 𦺉
    0x26E8A: 'guān',  # 𦺊
    0x26E8B: 'sǎo',  # 𦺋
    0x26E8C: 'sǒu',  # 𦺌
    0x26E8D: 'jiǎn',  # 𦺍
    0x26E8E: 'póu',  # 𦺎
    # 0x26E8F: '',  # 𦺏
    0x26E90: 'cán',  # 𦺐
    0x26E91: 'bèng',  # 𦺑
    0x26E92: 'mòu',  # 𦺒
    0x26E93: 'zhāo',  # 𦺓
    0x26E94: 'xiáo',  # 𦺔
    # 0x26E95: '',  # 𦺕
    0x26E96: 'jú',  # 𦺖
    0x26E97: 'shū',  # 𦺗
    0x26E98: 'jiǎn',  # 𦺘
    0x26E99: 'lí',  # 𦺙
    # 0x26E9A: '',  # 𦺚
    0x26E9B: 'chuàn',  # 𦺛
    0x26E9C: 'lào,láo',  # 𦺜
    0x26E9D: 'níng',  # 𦺝
    0x26E9E: 'hè',  # 𦺞
    0x26E9F: 'hú',  # 𦺟
    0x26EA0: 'gū',  # 𦺠
    0x26EA1: 'zhǎng',  # 𦺡
    0x26EA2: 'jié',  # 𦺢
    0x26EA3: 'xiàng',  # 𦺣
    # 0x26EA4: '',  # 𦺤
    0x26EA5: 'dū',  # 𦺥
    0x26EA6: 'hán',  # 𦺦
    0x26EA7: 'jiá',  # 𦺧
    0x26EA8: 'xiàng',  # 𦺨
    0x26EA9: 'jí',  # 𦺩
    0x26EAA: 'shǔ',  # 𦺪
    0x26EAB: 'làng',  # 𦺫
    0x26EAC: 'jī',  # 𦺬
    0x26EAD: 'shān',  # 𦺭
    # 0x26EAE: '',  # 𦺮
    # 0x26EAF: '',  # 𦺯
    0x26EB0: 'tāo,tiáo',  # 𦺰
    0x26EB1: 'zī',  # 𦺱
    0x26EB2: 'shuàn',  # 𦺲
    0x26EB3: 'yì',  # 𦺳
    0x26EB4: 'jí',  # 𦺴
    0x26EB5: 'chù',  # 𦺵
    0x26EB6: 'jì',  # 𦺶
    0x26EB7: 'shēn',  # 𦺷
    0x26EB8: 'lìn,lín',  # 𦺸
    0x26EB9: 'liáo',  # 𦺹
    # 0x26EBA: '',  # 𦺺
    0x26EBB: 'sǎn',  # 𦺻
    # 0x26EBC: '',  # 𦺼
    0x26EBD: 'ǎn',  # 𦺽
    0x26EBE: 'ruǎn',  # 𦺾
    # 0x26EBF: '',  # 𦺿
    0x26EC0: 'tí,tái',  # 𦻀
    0x26EC1: 'dàn',  # 𦻁
    # 0x26EC2: '',  # 𦻂
    0x26EC3: 'huán',  # 𦻃
    # 0x26EC4: '',  # 𦻄
    0x26EC5: 'sà',  # 𦻅
    # 0x26EC6: '',  # 𦻆
    # 0x26EC7: '',  # 𦻇
    # 0x26EC8: '',  # 𦻈
    # 0x26EC9: '',  # 𦻉
    # 0x26ECA: '',  # 𦻊
    # 0x26ECB: '',  # 𦻋
    # 0x26ECC: '',  # 𦻌
    # 0x26ECD: '',  # 𦻍
    # 0x26ECE: '',  # 𦻎
    # 0x26ECF: '',  # 𦻏
    0x26ED0: 'zhào',  # 𦻐
    # 0x26ED1: '',  # 𦻑
    # 0x26ED2: '',  # 𦻒
    # 0x26ED3: '',  # 𦻓
    # 0x26ED4: '',  # 𦻔
    # 0x26ED5: '',  # 𦻕
    # 0x26ED6: '',  # 𦻖
    # 0x26ED7: '',  # 𦻗
    # 0x26ED8: '',  # 𦻘
    # 0x26ED9: '',  # 𦻙
    # 0x26EDA: '',  # 𦻚
    # 0x26EDB: '',  # 𦻛
    # 0x26EDC: '',  # 𦻜
    # 0x26EDD: '',  # 𦻝
    # 0x26EDE: '',  # 𦻞
    # 0x26EDF: '',  # 𦻟
    # 0x26EE0: '',  # 𦻠
    # 0x26EE1: '',  # 𦻡
    # 0x26EE2: '',  # 𦻢
    # 0x26EE3: '',  # 𦻣
    # 0x26EE4: '',  # 𦻤
    # 0x26EE5: '',  # 𦻥
    # 0x26EE6: '',  # 𦻦
    # 0x26EE7: '',  # 𦻧
    # 0x26EE8: '',  # 𦻨
    # 0x26EE9: '',  # 𦻩
    # 0x26EEA: '',  # 𦻪
    # 0x26EEB: '',  # 𦻫
    # 0x26EEC: '',  # 𦻬
    # 0x26EED: '',  # 𦻭
    # 0x26EEE: '',  # 𦻮
    # 0x26EEF: '',  # 𦻯
    # 0x26EF0: '',  # 𦻰
    # 0x26EF1: '',  # 𦻱
    # 0x26EF2: '',  # 𦻲
    # 0x26EF3: '',  # 𦻳
    # 0x26EF4: '',  # 𦻴
    # 0x26EF5: '',  # 𦻵
    # 0x26EF6: '',  # 𦻶
    # 0x26EF7: '',  # 𦻷
    # 0x26EF8: '',  # 𦻸
    # 0x26EF9: '',  # 𦻹
    # 0x26EFA: '',  # 𦻺
    # 0x26EFB: '',  # 𦻻
    # 0x26EFC: '',  # 𦻼
    # 0x26EFD: '',  # 𦻽
    # 0x26EFE: '',  # 𦻾
    # 0x26EFF: '',  # 𦻿
    # 0x26F00: '',  # 𦼀
    # 0x26F01: '',  # 𦼁
    # 0x26F02: '',  # 𦼂
    # 0x26F03: '',  # 𦼃
    # 0x26F04: '',  # 𦼄
    # 0x26F05: '',  # 𦼅
    0x26F06: 'ruí',  # 𦼆
    0x26F07: 'wū',  # 𦼇
    0x26F08: 'jù',  # 𦼈
    0x26F09: 'huán',  # 𦼉
    0x26F0A: 'léng',  # 𦼊
    0x26F0B: 'lù',  # 𦼋
    # 0x26F0C: '',  # 𦼌
    # 0x26F0D: '',  # 𦼍
    0x26F0E: 'tān',  # 𦼎
    0x26F0F: 'zēng',  # 𦼏
    # 0x26F10: '',  # 𦼐
    # 0x26F11: '',  # 𦼑
    # 0x26F12: '',  # 𦼒
    0x26F13: 'qián',  # 𦼓
    # 0x26F14: '',  # 𦼔
    # 0x26F15: '',  # 𦼕
    # 0x26F16: '',  # 𦼖
    0x26F17: 'xī',  # 𦼗
    # 0x26F18: '',  # 𦼘
    # 0x26F19: '',  # 𦼙
    # 0x26F1A: '',  # 𦼚
    # 0x26F1B: '',  # 𦼛
    # 0x26F1C: '',  # 𦼜
    # 0x26F1D: '',  # 𦼝
    # 0x26F1E: '',  # 𦼞
    # 0x26F1F: '',  # 𦼟
    # 0x26F20: '',  # 𦼠
    0x26F21: 'cǐ',  # 𦼡
    0x26F22: 'shé',  # 𦼢
    # 0x26F23: '',  # 𦼣
    # 0x26F24: '',  # 𦼤
    # 0x26F25: '',  # 𦼥
    # 0x26F26: '',  # 𦼦
    0x26F27: 'sà',  # 𦼧
    # 0x26F28: '',  # 𦼨
    # 0x26F29: '',  # 𦼩
    0x26F2A: 'mào',  # 𦼪
    0x26F2B: 'qú',  # 𦼫
    # 0x26F2C: '',  # 𦼬
    0x26F2D: 'bó',  # 𦼭
    0x26F2E: 'gǎn,gàn',  # 𦼮
    # 0x26F2F: '',  # 𦼯
    0x26F30: 'qiè,hé',  # 𦼰
    0x26F31: 'juàn',  # 𦼱
    0x26F32: 'dāng',  # 𦼲
    0x26F33: 'cháng',  # 𦼳
    0x26F34: 'yáng',  # 𦼴
    0x26F35: 'hé',  # 𦼵
    # 0x26F36: '',  # 𦼶
    0x26F37: 'jī',  # 𦼷
    # 0x26F38: '',  # 𦼸
    0x26F39: 'bǐng',  # 𦼹
    # 0x26F3A: '',  # 𦼺
    0x26F3B: 'méi',  # 𦼻
    # 0x26F3C: '',  # 𦼼
    # 0x26F3D: '',  # 𦼽
    # 0x26F3E: '',  # 𦼾
    0x26F3F: 'dūn',  # 𦼿
    0x26F40: 'ǎo',  # 𦽀
    0x26F41: 'jīng',  # 𦽁
    0x26F42: 'lù',  # 𦽂
    0x26F43: 'miàn',  # 𦽃
    0x26F44: 'diàn',  # 𦽄
    0x26F45: 'hè',  # 𦽅
    # 0x26F46: '',  # 𦽆
    0x26F47: 'jiān',  # 𦽇
    # 0x26F48: '',  # 𦽈
    # 0x26F49: '',  # 𦽉
    0x26F4A: 'huá',  # 𦽊
    0x26F4B: 'gōu',  # 𦽋
    # 0x26F4C: '',  # 𦽌
    # 0x26F4D: '',  # 𦽍
    0x26F4E: 'lù',  # 𦽎
    0x26F4F: 'fú',  # 𦽏
    0x26F50: 'huǐ',  # 𦽐
    # 0x26F51: '',  # 𦽑
    0x26F52: 'zéi',  # 𦽒
    # 0x26F53: '',  # 𦽓
    0x26F54: 'jìn',  # 𦽔
    0x26F55: 'sī',  # 𦽕
    0x26F56: 'qūn',  # 𦽖
    # 0x26F57: '',  # 𦽗
    # 0x26F58: '',  # 𦽘
    # 0x26F59: '',  # 𦽙
    # 0x26F5A: '',  # 𦽚
    # 0x26F5B: '',  # 𦽛
    0x26F5C: 'dàn',  # 𦽜
    # 0x26F5D: '',  # 𦽝
    0x26F5E: 'wàn',  # 𦽞
    0x26F5F: 'biǎn',  # 𦽟
    # 0x26F60: '',  # 𦽠
    0x26F61: 'mào',  # 𦽡
    # 0x26F62: '',  # 𦽢
    # 0x26F63: '',  # 𦽣
    0x26F64: 'jiá',  # 𦽤
    # 0x26F65: '',  # 𦽥
    # 0x26F66: '',  # 𦽦
    # 0x26F67: '',  # 𦽧
    # 0x26F68: '',  # 𦽨
    # 0x26F69: '',  # 𦽩
    # 0x26F6A: '',  # 𦽪
    0x26F6B: 'dǎn',  # 𦽫
    0x26F6C: 'jiū',  # 𦽬
    0x26F6D: 'xián',  # 𦽭
    0x26F6E: 'bó',  # 𦽮
    # 0x26F6F: '',  # 𦽯
    # 0x26F70: '',  # 𦽰
    # 0x26F71: '',  # 𦽱
    # 0x26F72: '',  # 𦽲
    # 0x26F73: '',  # 𦽳
    # 0x26F74: '',  # 𦽴
    # 0x26F75: '',  # 𦽵
    # 0x26F76: '',  # 𦽶
    # 0x26F77: '',  # 𦽷
    # 0x26F78: '',  # 𦽸
    # 0x26F79: '',  # 𦽹
    # 0x26F7A: '',  # 𦽺
    # 0x26F7B: '',  # 𦽻
    # 0x26F7C: '',  # 𦽼
    # 0x26F7D: '',  # 𦽽
    # 0x26F7E: '',  # 𦽾
    # 0x26F7F: '',  # 𦽿
    # 0x26F80: '',  # 𦾀
    # 0x26F81: '',  # 𦾁
    # 0x26F82: '',  # 𦾂
    # 0x26F83: '',  # 𦾃
    # 0x26F84: '',  # 𦾄
    # 0x26F85: '',  # 𦾅
    # 0x26F86: '',  # 𦾆
    # 0x26F87: '',  # 𦾇
    # 0x26F88: '',  # 𦾈
    # 0x26F89: '',  # 𦾉
    # 0x26F8A: '',  # 𦾊
    # 0x26F8B: '',  # 𦾋
    # 0x26F8C: '',  # 𦾌
    # 0x26F8D: '',  # 𦾍
    # 0x26F8E: '',  # 𦾎
    0x26F8F: 'xiá',  # 𦾏
    # 0x26F90: '',  # 𦾐
    0x26F91: 'biāo',  # 𦾑
    # 0x26F92: '',  # 𦾒
    # 0x26F93: '',  # 𦾓
    # 0x26F94: '',  # 𦾔
    0x26F95: 'pò',  # 𦾕
    # 0x26F96: '',  # 𦾖
    # 0x26F97: '',  # 𦾗
    0x26F98: 'sǎo',  # 𦾘
    0x26F99: 'bèi',  # 𦾙
    0x26F9A: 'shà',  # 𦾚
    0x26F9B: 'wěi',  # 𦾛
    # 0x26F9C: '',  # 𦾜
    0x26F9D: 'cāng',  # 𦾝
    0x26F9E: 'lù',  # 𦾞
    # 0x26F9F: '',  # 𦾟
    # 0x26FA0: '',  # 𦾠
    # 0x26FA1: '',  # 𦾡
    # 0x26FA2: '',  # 𦾢
    # 0x26FA3: '',  # 𦾣
    # 0x26FA4: '',  # 𦾤
    # 0x26FA5: '',  # 𦾥
    # 0x26FA6: '',  # 𦾦
    # 0x26FA7: '',  # 𦾧
    # 0x26FA8: '',  # 𦾨
    0x26FA9: 'dàn',  # 𦾩
    # 0x26FAA: '',  # 𦾪
    0x26FAB: 'gǔ',  # 𦾫
    0x26FAC: 'zā',  # 𦾬
    0x26FAD: 'bǎng',  # 𦾭
    0x26FAE: 'gàn,gǎn',  # 𦾮
    # 0x26FAF: '',  # 𦾯
    # 0x26FB0: '',  # 𦾰
    0x26FB1: 'chāo',  # 𦾱
    0x26FB2: 'jì',  # 𦾲
    0x26FB3: 'liē',  # 𦾳
    0x26FB4: 'fán',  # 𦾴
    0x26FB5: 'qióng',  # 𦾵
    0x26FB6: 'jiàn',  # 𦾶
    0x26FB7: 'lù',  # 𦾷
    0x26FB8: 'duān',  # 𦾸
    0x26FB9: 'suān',  # 𦾹
    0x26FBA: 'yáo',  # 𦾺
    0x26FBB: 'yǐn',  # 𦾻
    # 0x26FBC: '',  # 𦾼
    0x26FBD: 'tà',  # 𦾽
    0x26FBE: 'yáo',  # 𦾾
    0x26FBF: 'jīng',  # 𦾿
    0x26FC0: 'chú',  # 𦿀
    0x26FC1: 'fú',  # 𦿁
    0x26FC2: 'yuán',  # 𦿂
    0x26FC3: 'shǎo',  # 𦿃
    # 0x26FC4: '',  # 𦿄
    0x26FC5: 'bìng',  # 𦿅
    0x26FC6: 'dàng',  # 𦿆
    0x26FC7: 'shì',  # 𦿇
    # 0x26FC8: '',  # 𦿈
    # 0x26FC9: '',  # 𦿉
    0x26FCA: 'lú',  # 𦿊
    0x26FCB: 'qiè',  # 𦿋
    0x26FCC: 'luó',  # 𦿌
    0x26FCD: 'pò',  # 𦿍
    # 0x26FCE: '',  # 𦿎
    0x26FCF: 'méng,mèng',  # 𦿏
    0x26FD0: 'jié',  # 𦿐
    # 0x26FD1: '',  # 𦿑
    # 0x26FD2: '',  # 𦿒
    0x26FD3: 'jī',  # 𦿓
    # 0x26FD4: '',  # 𦿔
    # 0x26FD5: '',  # 𦿕
    0x26FD6: 'lù',  # 𦿖
    # 0x26FD7: '',  # 𦿗
    # 0x26FD8: '',  # 𦿘
    # 0x26FD9: '',  # 𦿙
    # 0x26FDA: '',  # 𦿚
    # 0x26FDB: '',  # 𦿛
    # 0x26FDC: '',  # 𦿜
    # 0x26FDD: '',  # 𦿝
    # 0x26FDE: '',  # 𦿞
    # 0x26FDF: '',  # 𦿟
    # 0x26FE0: '',  # 𦿠
    # 0x26FE1: '',  # 𦿡
    # 0x26FE2: '',  # 𦿢
    # 0x26FE3: '',  # 𦿣
    # 0x26FE4: '',  # 𦿤
    # 0x26FE5: '',  # 𦿥
    # 0x26FE6: '',  # 𦿦
    # 0x26FE7: '',  # 𦿧
    # 0x26FE8: '',  # 𦿨
    # 0x26FE9: '',  # 𦿩
    # 0x26FEA: '',  # 𦿪
    # 0x26FEB: '',  # 𦿫
    # 0x26FEC: '',  # 𦿬
    # 0x26FED: '',  # 𦿭
    # 0x26FEE: '',  # 𦿮
    # 0x26FEF: '',  # 𦿯
    # 0x26FF0: '',  # 𦿰
    # 0x26FF1: '',  # 𦿱
    # 0x26FF2: '',  # 𦿲
    # 0x26FF3: '',  # 𦿳
    # 0x26FF4: '',  # 𦿴
    # 0x26FF5: '',  # 𦿵
    # 0x26FF6: '',  # 𦿶
    # 0x26FF7: '',  # 𦿷
    # 0x26FF8: '',  # 𦿸
    # 0x26FF9: '',  # 𦿹
    # 0x26FFA: '',  # 𦿺
    # 0x26FFB: '',  # 𦿻
    # 0x26FFC: '',  # 𦿼
    # 0x26FFD: '',  # 𦿽
    # 0x26FFE: '',  # 𦿾
    # 0x26FFF: '',  # 𦿿
    # 0x27000: '',  # 𧀀
    # 0x27001: '',  # 𧀁
    # 0x27002: '',  # 𧀂
    # 0x27003: '',  # 𧀃
    0x27004: 'chàng',  # 𧀄
    0x27005: 'miè,mò',  # 𧀅
    0x27006: 'méng',  # 𧀆
    0x27007: 'jiǎn',  # 𧀇
    # 0x27008: '',  # 𧀈
    # 0x27009: '',  # 𧀉
    0x2700A: 'cǎi',  # 𧀊
    # 0x2700B: '',  # 𧀋
    0x2700C: 'sù',  # 𧀌
    0x2700D: 'qū',  # 𧀍
    # 0x2700E: '',  # 𧀎
    # 0x2700F: '',  # 𧀏
    # 0x27010: '',  # 𧀐
    # 0x27011: '',  # 𧀑
    # 0x27012: '',  # 𧀒
    # 0x27013: '',  # 𧀓
    0x27014: 'hè',  # 𧀔
    0x27015: 'sà',  # 𧀕
    # 0x27016: '',  # 𧀖
    0x27017: 'zī',  # 𧀗
    0x27018: 'kēng',  # 𧀘
    0x27019: 'gěng',  # 𧀙
    0x2701A: 'sī',  # 𧀚
    # 0x2701B: '',  # 𧀛
    # 0x2701C: '',  # 𧀜
    # 0x2701D: '',  # 𧀝
    # 0x2701E: '',  # 𧀞
    # 0x2701F: '',  # 𧀟
    0x27020: 'tí',  # 𧀠
    0x27021: 'zhàn',  # 𧀡
    0x27022: 'xiè',  # 𧀢
    0x27023: 'shuí',  # 𧀣
    0x27024: 'chǐ',  # 𧀤
    0x27025: 'yōu',  # 𧀥
    0x27026: 'lǔ',  # 𧀦
    0x27027: 'mèng',  # 𧀧
    0x27028: 'liè',  # 𧀨
    0x27029: 'sì',  # 𧀩
    # 0x2702A: '',  # 𧀪
    # 0x2702B: '',  # 𧀫
    0x2702C: 'xī',  # 𧀬
    0x2702D: 'fán',  # 𧀭
    0x2702E: 'fū',  # 𧀮
    0x2702F: 'shěn',  # 𧀯
    0x27030: 'tí',  # 𧀰
    0x27031: 'chài',  # 𧀱
    0x27032: 'yuè',  # 𧀲
    0x27033: 'sì',  # 𧀳
    0x27034: 'fū',  # 𧀴
    0x27035: 'jiàn,shǎn',  # 𧀵
    0x27036: 'dì',  # 𧀶
    # 0x27037: '',  # 𧀷
    # 0x27038: '',  # 𧀸
    0x27039: 'zhè',  # 𧀹
    0x2703A: 'xié',  # 𧀺
    0x2703B: 'dān',  # 𧀻
    0x2703C: 'xuē',  # 𧀼
    # 0x2703D: '',  # 𧀽
    # 0x2703E: '',  # 𧀾
    0x2703F: 'zhí',  # 𧀿
    # 0x27040: '',  # 𧁀
    # 0x27041: '',  # 𧁁
    # 0x27042: '',  # 𧁂
    0x27043: 'xù',  # 𧁃
    # 0x27044: '',  # 𧁄
    # 0x27045: '',  # 𧁅
    # 0x27046: '',  # 𧁆
    # 0x27047: '',  # 𧁇
    0x27048: 'niè',  # 𧁈
    0x27049: 'fàn',  # 𧁉
    0x2704A: 'méng',  # 𧁊
    0x2704B: 'mǐn',  # 𧁋
    # 0x2704C: '',  # 𧁌
    # 0x2704D: '',  # 𧁍
    # 0x2704E: '',  # 𧁎
    # 0x2704F: '',  # 𧁏
    # 0x27050: '',  # 𧁐
    # 0x27051: '',  # 𧁑
    # 0x27052: '',  # 𧁒
    # 0x27053: '',  # 𧁓
    # 0x27054: '',  # 𧁔
    # 0x27055: '',  # 𧁕
    # 0x27056: '',  # 𧁖
    # 0x27057: '',  # 𧁗
    # 0x27058: '',  # 𧁘
    # 0x27059: '',  # 𧁙
    # 0x2705A: '',  # 𧁚
    # 0x2705B: '',  # 𧁛
    # 0x2705C: '',  # 𧁜
    # 0x2705D: '',  # 𧁝
    # 0x2705E: '',  # 𧁞
    # 0x2705F: '',  # 𧁟
    # 0x27060: '',  # 𧁠
    # 0x27061: '',  # 𧁡
    # 0x27062: '',  # 𧁢
    # 0x27063: '',  # 𧁣
    # 0x27064: '',  # 𧁤
    # 0x27065: '',  # 𧁥
    # 0x27066: '',  # 𧁦
    # 0x27067: '',  # 𧁧
    # 0x27068: '',  # 𧁨
    # 0x27069: '',  # 𧁩
    # 0x2706A: '',  # 𧁪
    # 0x2706B: '',  # 𧁫
    # 0x2706C: '',  # 𧁬
    # 0x2706D: '',  # 𧁭
    # 0x2706E: '',  # 𧁮
    # 0x2706F: '',  # 𧁯
    # 0x27070: '',  # 𧁰
    # 0x27071: '',  # 𧁱
    # 0x27072: '',  # 𧁲
    # 0x27073: '',  # 𧁳
    # 0x27074: '',  # 𧁴
    # 0x27075: '',  # 𧁵
    # 0x27076: '',  # 𧁶
    # 0x27077: '',  # 𧁷
    # 0x27078: '',  # 𧁸
    # 0x27079: '',  # 𧁹
    # 0x2707A: '',  # 𧁺
    # 0x2707B: '',  # 𧁻
    # 0x2707C: '',  # 𧁼
    # 0x2707D: '',  # 𧁽
    0x2707E: 'lóu',  # 𧁾
    0x2707F: 'dú,shǔ',  # 𧁿
    0x27080: 'mò',  # 𧂀
    0x27081: 'zhàn',  # 𧂁
    0x27082: 'jiàn',  # 𧂂
    0x27083: 'hàn',  # 𧂃
    0x27084: 'dàn',  # 𧂄
    0x27085: 'sēn',  # 𧂅
    0x27086: 'jiàn',  # 𧂆
    0x27087: 'tán,xún',  # 𧂇
    0x27088: 'jiǎo',  # 𧂈
    0x27089: 'pó',  # 𧂉
    # 0x2708A: '',  # 𧂊
    0x2708B: 'píng',  # 𧂋
    # 0x2708C: '',  # 𧂌
    0x2708D: 'zhuàn,sūn',  # 𧂍
    # 0x2708E: '',  # 𧂎
    0x2708F: 'liáo',  # 𧂏
    0x27090: 'zì',  # 𧂐
    # 0x27091: '',  # 𧂑
    0x27092: 'zhuó',  # 𧂒
    # 0x27093: '',  # 𧂓
    0x27094: 'hù',  # 𧂔
    # 0x27095: '',  # 𧂕
    # 0x27096: '',  # 𧂖
    # 0x27097: '',  # 𧂗
    # 0x27098: '',  # 𧂘
    0x27099: 'xì',  # 𧂙
    # 0x2709A: '',  # 𧂚
    0x2709B: 'méng',  # 𧂛
    0x2709C: 'jù',  # 𧂜
    0x2709D: 'miè',  # 𧂝
    0x2709E: 'xián',  # 𧂞
    # 0x2709F: '',  # 𧂟
    0x270A0: 'kuì',  # 𧂠
    0x270A1: 'méng',  # 𧂡
    0x270A2: 'jiān',  # 𧂢
    # 0x270A3: '',  # 𧂣
    # 0x270A4: '',  # 𧂤
    # 0x270A5: '',  # 𧂥
    0x270A6: 'nóu',  # 𧂦
    # 0x270A7: '',  # 𧂧
    0x270A8: 'dì',  # 𧂨
    0x270A9: 'sāo',  # 𧂩
    # 0x270AA: '',  # 𧂪
    # 0x270AB: '',  # 𧂫
    # 0x270AC: '',  # 𧂬
    # 0x270AD: '',  # 𧂭
    # 0x270AE: '',  # 𧂮
    # 0x270AF: '',  # 𧂯
    # 0x270B0: '',  # 𧂰
    # 0x270B1: '',  # 𧂱
    # 0x270B2: '',  # 𧂲
    # 0x270B3: '',  # 𧂳
    # 0x270B4: '',  # 𧂴
    # 0x270B5: '',  # 𧂵
    # 0x270B6: '',  # 𧂶
    # 0x270B7: '',  # 𧂷
    # 0x270B8: '',  # 𧂸
    # 0x270B9: '',  # 𧂹
    # 0x270BA: '',  # 𧂺
    # 0x270BB: '',  # 𧂻
    # 0x270BC: '',  # 𧂼
    # 0x270BD: '',  # 𧂽
    # 0x270BE: '',  # 𧂾
    # 0x270BF: '',  # 𧂿
    # 0x270C0: '',  # 𧃀
    # 0x270C1: '',  # 𧃁
    # 0x270C2: '',  # 𧃂
    # 0x270C3: '',  # 𧃃
    # 0x270C4: '',  # 𧃄
    # 0x270C5: '',  # 𧃅
    # 0x270C6: '',  # 𧃆
    # 0x270C7: '',  # 𧃇
    # 0x270C8: '',  # 𧃈
    # 0x270C9: '',  # 𧃉
    # 0x270CA: '',  # 𧃊
    # 0x270CB: '',  # 𧃋
    # 0x270CC: '',  # 𧃌
    # 0x270CD: '',  # 𧃍
    # 0x270CE: '',  # 𧃎
    0x270CF: 'chù',  # 𧃏
    0x270D0: 'zhí',  # 𧃐
    0x270D1: 'qián',  # 𧃑
    0x270D2: 'lǚ',  # 𧃒
    # 0x270D3: '',  # 𧃓
    0x270D4: 'zhuó',  # 𧃔
    # 0x270D5: '',  # 𧃕
    # 0x270D6: '',  # 𧃖
    # 0x270D7: '',  # 𧃗
    0x270D8: 'zuò',  # 𧃘
    0x270D9: 'hán',  # 𧃙
    0x270DA: 'suǐ',  # 𧃚
    0x270DB: 'gòu',  # 𧃛
    # 0x270DC: '',  # 𧃜
    0x270DD: 'chǒu',  # 𧃝
    0x270DE: 'jì',  # 𧃞
    0x270DF: 'yì',  # 𧃟
    0x270E0: 'yú',  # 𧃠
    # 0x270E1: '',  # 𧃡
    # 0x270E2: '',  # 𧃢
    0x270E3: 'kūn',  # 𧃣
    # 0x270E4: '',  # 𧃤
    # 0x270E5: '',  # 𧃥
    # 0x270E6: '',  # 𧃦
    # 0x270E7: '',  # 𧃧
    0x270E8: 'nóu',  # 𧃨
    0x270E9: 'nǐ',  # 𧃩
    0x270EA: 'ruò',  # 𧃪
    # 0x270EB: '',  # 𧃫
    # 0x270EC: '',  # 𧃬
    # 0x270ED: '',  # 𧃭
    0x270EE: 'lín',  # 𧃮
    # 0x270EF: '',  # 𧃯
    # 0x270F0: '',  # 𧃰
    0x270F1: 'níng',  # 𧃱
    # 0x270F2: '',  # 𧃲
    # 0x270F3: '',  # 𧃳
    # 0x270F4: '',  # 𧃴
    # 0x270F5: '',  # 𧃵
    # 0x270F6: '',  # 𧃶
    # 0x270F7: '',  # 𧃷
    # 0x270F8: '',  # 𧃸
    0x270F9: 'zhá',  # 𧃹
    # 0x270FA: '',  # 𧃺
    # 0x270FB: '',  # 𧃻
    # 0x270FC: '',  # 𧃼
    # 0x270FD: '',  # 𧃽
    # 0x270FE: '',  # 𧃾
    # 0x270FF: '',  # 𧃿
    # 0x27100: '',  # 𧄀
    # 0x27101: '',  # 𧄁
    # 0x27102: '',  # 𧄂
    # 0x27103: '',  # 𧄃
    # 0x27104: '',  # 𧄄
    # 0x27105: '',  # 𧄅
    # 0x27106: '',  # 𧄆
    # 0x27107: '',  # 𧄇
    # 0x27108: '',  # 𧄈
    # 0x27109: '',  # 𧄉
    # 0x2710A: '',  # 𧄊
    # 0x2710B: '',  # 𧄋
    # 0x2710C: '',  # 𧄌
    0x2710D: 'qiáo',  # 𧄍
    0x2710E: 'yáo',  # 𧄎
    0x2710F: 'fù',  # 𧄏
    0x27110: 'shuāng',  # 𧄐
    0x27111: 'kuì',  # 𧄑
    0x27112: 'qú',  # 𧄒
    0x27113: 'dǒng',  # 𧄓
    0x27114: 'shǔ',  # 𧄔
    # 0x27115: '',  # 𧄕
    # 0x27116: '',  # 𧄖
    # 0x27117: '',  # 𧄗
    # 0x27118: '',  # 𧄘
    # 0x27119: '',  # 𧄙
    0x2711A: 'lí',  # 𧄚
    0x2711B: 'jú',  # 𧄛
    0x2711C: 'ruǐ',  # 𧄜
    # 0x2711D: '',  # 𧄝
    # 0x2711E: '',  # 𧄞
    # 0x2711F: '',  # 𧄟
    0x27120: 'zhá',  # 𧄠
    # 0x27121: '',  # 𧄡
    # 0x27122: '',  # 𧄢
    # 0x27123: '',  # 𧄣
    0x27124: 'xiāo',  # 𧄤
    # 0x27125: '',  # 𧄥
    # 0x27126: '',  # 𧄦
    # 0x27127: '',  # 𧄧
    # 0x27128: '',  # 𧄨
    # 0x27129: '',  # 𧄩
    # 0x2712A: '',  # 𧄪
    # 0x2712B: '',  # 𧄫
    # 0x2712C: '',  # 𧄬
    # 0x2712D: '',  # 𧄭
    # 0x2712E: '',  # 𧄮
    # 0x2712F: '',  # 𧄯
    # 0x27130: '',  # 𧄰
    # 0x27131: '',  # 𧄱
    # 0x27132: '',  # 𧄲
    # 0x27133: '',  # 𧄳
    # 0x27134: '',  # 𧄴
    # 0x27135: '',  # 𧄵
    # 0x27136: '',  # 𧄶
    # 0x27137: '',  # 𧄷
    0x27138: 'mén,wěi',  # 𧄸
    0x27139: 'shí',  # 𧄹
    0x2713A: 'diān',  # 𧄺
    0x2713B: 'lì',  # 𧄻
    0x2713C: 'dèng,téng',  # 𧄼
    0x2713D: 'zàn,zā',  # 𧄽
    # 0x2713E: '',  # 𧄾
    0x2713F: 'luó',  # 𧄿
    0x27140: 'cán',  # 𧅀
    # 0x27141: '',  # 𧅁
    # 0x27142: '',  # 𧅂
    0x27143: 'āo',  # 𧅃
    # 0x27144: '',  # 𧅄
    # 0x27145: '',  # 𧅅
    0x27146: 'jiǎn',  # 𧅆
    # 0x27147: '',  # 𧅇
    0x27148: 'diào',  # 𧅈
    # 0x27149: '',  # 𧅉
    # 0x2714A: '',  # 𧅊
    0x2714B: 'yíng',  # 𧅋
    # 0x2714C: '',  # 𧅌
    # 0x2714D: '',  # 𧅍
    # 0x2714E: '',  # 𧅎
    # 0x2714F: '',  # 𧅏
    # 0x27150: '',  # 𧅐
    # 0x27151: '',  # 𧅑
    # 0x27152: '',  # 𧅒
    # 0x27153: '',  # 𧅓
    # 0x27154: '',  # 𧅔
    # 0x27155: '',  # 𧅕
    0x27156: 'yì',  # 𧅖
    0x27157: 'dǎng',  # 𧅗
    0x27158: 'nóu',  # 𧅘
    # 0x27159: '',  # 𧅙
    0x2715A: 'yuè',  # 𧅚
    # 0x2715B: '',  # 𧅛
    # 0x2715C: '',  # 𧅜
    # 0x2715D: '',  # 𧅝
    # 0x2715E: '',  # 𧅞
    # 0x2715F: '',  # 𧅟
    # 0x27160: '',  # 𧅠
    # 0x27161: '',  # 𧅡
    # 0x27162: '',  # 𧅢
    # 0x27163: '',  # 𧅣
    # 0x27164: '',  # 𧅤
    # 0x27165: '',  # 𧅥
    # 0x27166: '',  # 𧅦
    # 0x27167: '',  # 𧅧
    # 0x27168: '',  # 𧅨
    # 0x27169: '',  # 𧅩
    # 0x2716A: '',  # 𧅪
    # 0x2716B: '',  # 𧅫
    # 0x2716C: '',  # 𧅬
    # 0x2716D: '',  # 𧅭
    0x2716E: 'lǐ',  # 𧅮
    0x2716F: 'lí',  # 𧅯
    0x27170: 'hù',  # 𧅰
    # 0x27171: '',  # 𧅱
    0x27172: 'yòu',  # 𧅲
    # 0x27173: '',  # 𧅳
    # 0x27174: '',  # 𧅴
    # 0x27175: '',  # 𧅵
    # 0x27176: '',  # 𧅶
    # 0x27177: '',  # 𧅷
    # 0x27178: '',  # 𧅸
    # 0x27179: '',  # 𧅹
    0x2717A: 'nàng',  # 𧅺
    0x2717B: 'hàn',  # 𧅻
    # 0x2717C: '',  # 𧅼
    # 0x2717D: '',  # 𧅽
    # 0x2717E: '',  # 𧅾
    # 0x2717F: '',  # 𧅿
    # 0x27180: '',  # 𧆀
    # 0x27181: '',  # 𧆁
    0x27182: 'chèn',  # 𧆂
    # 0x27183: '',  # 𧆃
    # 0x27184: '',  # 𧆄
    # 0x27185: '',  # 𧆅
    # 0x27186: '',  # 𧆆
    # 0x27187: '',  # 𧆇
    0x27188: 'yì',  # 𧆈
    0x27189: 'fēng',  # 𧆉
    0x2718A: 'biē',  # 𧆊
    # 0x2718B: '',  # 𧆋
    # 0x2718C: '',  # 𧆌
    # 0x2718D: '',  # 𧆍
    # 0x2718E: '',  # 𧆎
    0x2718F: 'mǎn',  # 𧆏
    0x27190: 'gàn',  # 𧆐
    0x27191: 'huò,suǐ',  # 𧆑
    # 0x27192: '',  # 𧆒
    0x27193: 'cū',  # 𧆓
    # 0x27194: '',  # 𧆔
    0x27195: 'yǒu',  # 𧆕
    # 0x27196: '',  # 𧆖
    # 0x27197: '',  # 𧆗
    0x27198: 'yòu',  # 𧆘
    # 0x27199: '',  # 𧆙
    # 0x2719A: '',  # 𧆚
    # 0x2719B: '',  # 𧆛
    0x2719C: 'xū',  # 𧆜
    # 0x2719D: '',  # 𧆝
    # 0x2719E: '',  # 𧆞
    # 0x2719F: '',  # 𧆟
    # 0x271A0: '',  # 𧆠
    0x271A1: 'xù',  # 𧆡
    0x271A2: 'hǔ',  # 𧆢
    0x271A3: 'lú',  # 𧆣
    # 0x271A4: '',  # 𧆤
    0x271A5: 'xiá',  # 𧆥
    0x271A6: 'yì',  # 𧆦
    # 0x271A7: '',  # 𧆧
    # 0x271A8: '',  # 𧆨
    # 0x271A9: '',  # 𧆩
    # 0x271AA: '',  # 𧆪
    # 0x271AB: '',  # 𧆫
    # 0x271AC: '',  # 𧆬
    # 0x271AD: '',  # 𧆭
    0x271AE: 'hǔ',  # 𧆮
    0x271AF: 'hù',  # 𧆯
    0x271B0: 'zǐ',  # 𧆰
    # 0x271B1: '',  # 𧆱
    # 0x271B2: '',  # 𧆲
    # 0x271B3: '',  # 𧆳
    # 0x271B4: '',  # 𧆴
    # 0x271B5: '',  # 𧆵
    # 0x271B6: '',  # 𧆶
    0x271B7: 'gōng',  # 𧆷
    0x271B8: 'tuī',  # 𧆸
    0x271B9: 'wū',  # 𧆹
    0x271BA: 'líng',  # 𧆺
    0x271BB: 'gū',  # 𧆻
    0x271BC: 'zhōng,dōng',  # 𧆼
    # 0x271BD: '',  # 𧆽
    # 0x271BE: '',  # 𧆾
    # 0x271BF: '',  # 𧆿
    # 0x271C0: '',  # 𧇀
    # 0x271C1: '',  # 𧇁
    # 0x271C2: '',  # 𧇂
    # 0x271C3: '',  # 𧇃
    0x271C4: 'lú',  # 𧇄
    # 0x271C5: '',  # 𧇅
    # 0x271C6: '',  # 𧇆
    # 0x271C7: '',  # 𧇇
    0x271C8: 'zù',  # 𧇈
    # 0x271C9: '',  # 𧇉
    # 0x271CA: '',  # 𧇊
    # 0x271CB: '',  # 𧇋
    0x271CC: 'tóng',  # 𧇌
    0x271CD: 'xiā',  # 𧇍
    0x271CE: 'hé',  # 𧇎
    # 0x271CF: '',  # 𧇏
    # 0x271D0: '',  # 𧇐
    # 0x271D1: '',  # 𧇑
    0x271D2: 'bào',  # 𧇒
    0x271D3: 'yuè',  # 𧇓
    # 0x271D4: '',  # 𧇔
    # 0x271D5: '',  # 𧇕
    # 0x271D6: '',  # 𧇖
    # 0x271D7: '',  # 𧇗
    # 0x271D8: '',  # 𧇘
    0x271D9: 'nán',  # 𧇙
    0x271DA: 'bó',  # 𧇚
    0x271DB: 'hū',  # 𧇛
    0x271DC: 'qì',  # 𧇜
    0x271DD: 'shú',  # 𧇝
    0x271DE: 'qiāng',  # 𧇞
    0x271DF: 'zhōu',  # 𧇟
    0x271E0: 'yào',  # 𧇠
    0x271E1: 'gū',  # 𧇡
    # 0x271E2: '',  # 𧇢
    # 0x271E3: '',  # 𧇣
    # 0x271E4: '',  # 𧇤
    0x271E5: 'bān',  # 𧇥
    0x271E6: 'kǎn',  # 𧇦
    # 0x271E7: '',  # 𧇧
    # 0x271E8: '',  # 𧇨
    # 0x271E9: '',  # 𧇩
    # 0x271EA: '',  # 𧇪
    # 0x271EB: '',  # 𧇫
    # 0x271EC: '',  # 𧇬
    # 0x271ED: '',  # 𧇭
    0x271EE: 'hé',  # 𧇮
    0x271EF: 'jì',  # 𧇯
    0x271F0: 'hú',  # 𧇰
    0x271F1: 'yán',  # 𧇱
    # 0x271F2: '',  # 𧇲
    # 0x271F3: '',  # 𧇳
    # 0x271F4: '',  # 𧇴
    # 0x271F5: '',  # 𧇵
    0x271F6: 'chūn',  # 𧇶
    0x271F7: 'dǐng',  # 𧇷
    0x271F8: 'qiū',  # 𧇸
    0x271F9: 'hóu',  # 𧇹
    # 0x271FA: '',  # 𧇺
    # 0x271FB: '',  # 𧇻
    0x271FC: 'hào',  # 𧇼
    0x271FD: 'jù',  # 𧇽
    # 0x271FE: '',  # 𧇾
    0x271FF: 'zù',  # 𧇿
    # 0x27200: '',  # 𧈀
    0x27201: 'xián',  # 𧈁
    # 0x27202: '',  # 𧈂
    # 0x27203: '',  # 𧈃
    0x27204: 'xià',  # 𧈄
    0x27205: 'xì',  # 𧈅
    # 0x27206: '',  # 𧈆
    # 0x27207: '',  # 𧈇
    0x27208: 'sè,xì',  # 𧈈
    # 0x27209: '',  # 𧈉
    # 0x2720A: '',  # 𧈊
    # 0x2720B: '',  # 𧈋
    0x2720C: 'gé',  # 𧈌
    0x2720D: 'xì',  # 𧈍
    # 0x2720E: '',  # 𧈎
    # 0x2720F: '',  # 𧈏
    # 0x27210: '',  # 𧈐
    0x27211: 'gé',  # 𧈑
    # 0x27212: '',  # 𧈒
    # 0x27213: '',  # 𧈓
    0x27214: 'lǚ',  # 𧈔
    # 0x27215: '',  # 𧈕
    0x27216: 'gé',  # 𧈖
    0x27217: 'kè',  # 𧈗
    # 0x27218: '',  # 𧈘
    0x27219: 'shòu',  # 𧈙
    0x2721A: 'zhù',  # 𧈚
    # 0x2721B: '',  # 𧈛
    0x2721C: 'téng',  # 𧈜
    0x2721D: 'yà',  # 𧈝
    0x2721E: 'nì',  # 𧈞
    # 0x2721F: '',  # 𧈟
    # 0x27220: '',  # 𧈠
    # 0x27221: '',  # 𧈡
    # 0x27222: '',  # 𧈢
    # 0x27223: '',  # 𧈣
    # 0x27224: '',  # 𧈤
    # 0x27225: '',  # 𧈥
    0x27226: 'luò',  # 𧈦
    0x27227: 'suī,méng',  # 𧈧
    # 0x27228: '',  # 𧈨
    # 0x27229: '',  # 𧈩
    0x2722A: 'chǎn',  # 𧈪
    # 0x2722B: '',  # 𧈫
    # 0x2722C: '',  # 𧈬
    0x2722D: 'wù',  # 𧈭
    # 0x2722E: '',  # 𧈮
    0x2722F: 'yū',  # 𧈯
    # 0x27230: '',  # 𧈰
    # 0x27231: '',  # 𧈱
    # 0x27232: '',  # 𧈲
    # 0x27233: '',  # 𧈳
    # 0x27234: '',  # 𧈴
    # 0x27235: '',  # 𧈵
    # 0x27236: '',  # 𧈶
    # 0x27237: '',  # 𧈷
    # 0x27238: '',  # 𧈸
    0x27239: 'zǎo',  # 𧈹
    # 0x2723A: '',  # 𧈺
    0x2723B: 'yì',  # 𧈻
    0x2723C: 'xī,jí',  # 𧈼
    0x2723D: 'hóng',  # 𧈽
    0x2723E: 'quán',  # 𧈾
    0x2723F: 'wǎng',  # 𧈿
    0x27240: 'chǐ',  # 𧉀
    0x27241: 'xì',  # 𧉁
    0x27242: 'tiǎn',  # 𧉂
    0x27243: 'yǔn',  # 𧉃
    0x27244: 'mián',  # 𧉄
    0x27245: 'yī',  # 𧉅
    0x27246: 'jí',  # 𧉆
    0x27247: 'huī',  # 𧉇
    0x27248: 'fóu,fú',  # 𧉈
    # 0x27249: '',  # 𧉉
    0x2724A: 'fǔ',  # 𧉊
    # 0x2724B: '',  # 𧉋
    # 0x2724C: '',  # 𧉌
    0x2724D: 'jí',  # 𧉍
    0x2724E: 'xuán',  # 𧉎
    # 0x2724F: '',  # 𧉏
    # 0x27250: '',  # 𧉐
    0x27251: 'tài',  # 𧉑
    # 0x27252: '',  # 𧉒
    # 0x27253: '',  # 𧉓
    # 0x27254: '',  # 𧉔
    # 0x27255: '',  # 𧉕
    # 0x27256: '',  # 𧉖
    0x27257: 'yuán',  # 𧉗
    # 0x27258: '',  # 𧉘
    # 0x27259: '',  # 𧉙
    # 0x2725A: '',  # 𧉚
    0x2725B: 'dì',  # 𧉛
    # 0x2725C: '',  # 𧉜
    # 0x2725D: '',  # 𧉝
    0x2725E: 'zhǔ',  # 𧉞
    0x2725F: 'tāi',  # 𧉟
    # 0x27260: '',  # 𧉠
    0x27261: 'rǒng',  # 𧉡
    0x27262: 'xué',  # 𧉢
    0x27263: 'yù',  # 𧉣
    0x27264: 'fàn',  # 𧉤
    0x27265: 'běi',  # 𧉥
    # 0x27266: '',  # 𧉦
    0x27267: 'qǔ,jié',  # 𧉧
    # 0x27268: '',  # 𧉨
    0x27269: 'bù',  # 𧉩
    0x2726A: 'jiā',  # 𧉪
    0x2726B: 'zhá',  # 𧉫
    # 0x2726C: '',  # 𧉬
    0x2726D: 'nǔ',  # 𧉭
    0x2726E: 'shé,yán,yí',  # 𧉮
    # 0x2726F: '',  # 𧉯
    # 0x27270: '',  # 𧉰
    # 0x27271: '',  # 𧉱
    0x27272: 'lì',  # 𧉲
    # 0x27273: '',  # 𧉳
    # 0x27274: '',  # 𧉴
    # 0x27275: '',  # 𧉵
    # 0x27276: '',  # 𧉶
    # 0x27277: '',  # 𧉷
    # 0x27278: '',  # 𧉸
    0x27279: 'zhā',  # 𧉹
    # 0x2727A: '',  # 𧉺
    # 0x2727B: '',  # 𧉻
    # 0x2727C: '',  # 𧉼
    # 0x2727D: '',  # 𧉽
    # 0x2727E: '',  # 𧉾
    # 0x2727F: '',  # 𧉿
    # 0x27280: '',  # 𧊀
    # 0x27281: '',  # 𧊁
    # 0x27282: '',  # 𧊂
    # 0x27283: '',  # 𧊃
    0x27284: 'guǐ',  # 𧊄
    0x27285: 'guǎi',  # 𧊅
    # 0x27286: '',  # 𧊆
    0x27287: 'dài,dé',  # 𧊇
    # 0x27288: '',  # 𧊈
    # 0x27289: '',  # 𧊉
    # 0x2728A: '',  # 𧊊
    # 0x2728B: '',  # 𧊋
    # 0x2728C: '',  # 𧊌
    # 0x2728D: '',  # 𧊍
    # 0x2728E: '',  # 𧊎
    0x2728F: 'gāi',  # 𧊏
    # 0x27290: '',  # 𧊐
    # 0x27291: '',  # 𧊑
    0x27292: 'cì',  # 𧊒
    # 0x27293: '',  # 𧊓
    0x27294: 'yǎn',  # 𧊔
    0x27295: 'sōng',  # 𧊕
    0x27296: 'shì',  # 𧊖
    # 0x27297: '',  # 𧊗
    0x27298: 'kù',  # 𧊘
    0x27299: 'zhǐ',  # 𧊙
    0x2729A: 'tóng',  # 𧊚
    0x2729B: 'qú',  # 𧊛
    0x2729C: 'è',  # 𧊜
    0x2729D: 'hē',  # 𧊝
    0x2729E: 'xíng',  # 𧊞
    0x2729F: 'rú',  # 𧊟
    0x272A0: 'yú,shū',  # 𧊠
    # 0x272A1: '',  # 𧊡
    # 0x272A2: '',  # 𧊢
    0x272A3: 'yì',  # 𧊣
    0x272A4: 'yì',  # 𧊤
    0x272A5: 'xù',  # 𧊥
    0x272A6: 'fǒu',  # 𧊦
    0x272A7: 'gé,è',  # 𧊧
    0x272A8: 'rán',  # 𧊨
    # 0x272A9: '',  # 𧊩
    # 0x272AA: '',  # 𧊪
    # 0x272AB: '',  # 𧊫
    0x272AC: 'hé',  # 𧊬
    0x272AD: 'yīn',  # 𧊭
    # 0x272AE: '',  # 𧊮
    0x272AF: 'hòng',  # 𧊯
    # 0x272B0: '',  # 𧊰
    0x272B1: 'duǒ',  # 𧊱
    # 0x272B2: '',  # 𧊲
    # 0x272B3: '',  # 𧊳
    # 0x272B4: '',  # 𧊴
    # 0x272B5: '',  # 𧊵
    # 0x272B6: '',  # 𧊶
    # 0x272B7: '',  # 𧊷
    # 0x272B8: '',  # 𧊸
    # 0x272B9: '',  # 𧊹
    # 0x272BA: '',  # 𧊺
    # 0x272BB: '',  # 𧊻
    # 0x272BC: '',  # 𧊼
    0x272BD: 'xíng',  # 𧊽
    0x272BE: 'fán',  # 𧊾
    # 0x272BF: '',  # 𧊿
    # 0x272C0: '',  # 𧋀
    # 0x272C1: '',  # 𧋁
    # 0x272C2: '',  # 𧋂
    # 0x272C3: '',  # 𧋃
    # 0x272C4: '',  # 𧋄
    # 0x272C5: '',  # 𧋅
    # 0x272C6: '',  # 𧋆
    # 0x272C7: '',  # 𧋇
    # 0x272C8: '',  # 𧋈
    0x272C9: 'qī',  # 𧋉
    0x272CA: 'shā,shuō',  # 𧋊
    # 0x272CB: '',  # 𧋋
    0x272CC: 'dù',  # 𧋌
    0x272CD: 'dì,xué',  # 𧋍
    0x272CE: 'lí',  # 𧋎
    0x272CF: 'yì',  # 𧋏
    0x272D0: 'xí',  # 𧋐
    0x272D1: 'gěng',  # 𧋑
    0x272D2: 'tóng,shì',  # 𧋒
    0x272D3: 'kào',  # 𧋓
    0x272D4: 'hòng',  # 𧋔
    0x272D5: 'kǔn',  # 𧋕
    0x272D6: 'niè',  # 𧋖
    0x272D7: 'chí',  # 𧋗
    0x272D8: 'tí',  # 𧋘
    # 0x272D9: '',  # 𧋙
    0x272DA: 'tóng',  # 𧋚
    # 0x272DB: '',  # 𧋛
    # 0x272DC: '',  # 𧋜
    # 0x272DD: '',  # 𧋝
    # 0x272DE: '',  # 𧋞
    # 0x272DF: '',  # 𧋟
    0x272E0: 'lí,lǐ',  # 𧋠
    0x272E1: 'nà',  # 𧋡
    0x272E2: 'bō',  # 𧋢
    0x272E3: 'kuò',  # 𧋣
    # 0x272E4: '',  # 𧋤
    # 0x272E5: '',  # 𧋥
    # 0x272E6: '',  # 𧋦
    # 0x272E7: '',  # 𧋧
    # 0x272E8: '',  # 𧋨
    # 0x272E9: '',  # 𧋩
    # 0x272EA: '',  # 𧋪
    # 0x272EB: '',  # 𧋫
    # 0x272EC: '',  # 𧋬
    # 0x272ED: '',  # 𧋭
    # 0x272EE: '',  # 𧋮
    # 0x272EF: '',  # 𧋯
    # 0x272F0: '',  # 𧋰
    0x272F1: 'zhān',  # 𧋱
    0x272F2: 'běi',  # 𧋲
    # 0x272F3: '',  # 𧋳
    # 0x272F4: '',  # 𧋴
    # 0x272F5: '',  # 𧋵
    # 0x272F6: '',  # 𧋶
    # 0x272F7: '',  # 𧋷
    # 0x272F8: '',  # 𧋸
    # 0x272F9: '',  # 𧋹
    # 0x272FA: '',  # 𧋺
    # 0x272FB: '',  # 𧋻
    # 0x272FC: '',  # 𧋼
    # 0x272FD: '',  # 𧋽
    # 0x272FE: '',  # 𧋾
    # 0x272FF: '',  # 𧋿
    # 0x27300: '',  # 𧌀
    0x27301: 'tiáo',  # 𧌁
    # 0x27302: '',  # 𧌂
    0x27303: 'zā',  # 𧌃
    0x27304: 'è,yè',  # 𧌄
    0x27305: 'shòu',  # 𧌅
    0x27306: 'kōng',  # 𧌆
    0x27307: 'péng',  # 𧌇
    0x27308: 'fù',  # 𧌈
    0x27309: 'lù',  # 𧌉
    0x2730A: 'xiè',  # 𧌊
    0x2730B: 'xiè',  # 𧌋
    0x2730C: 'xiū',  # 𧌌
    0x2730D: 'lù',  # 𧌍
    0x2730E: 'tiǎn',  # 𧌎
    0x2730F: 'tà',  # 𧌏
    0x27310: 'cì',  # 𧌐
    0x27311: 'qū',  # 𧌑
    # 0x27312: '',  # 𧌒
    0x27313: 'fù',  # 𧌓
    0x27314: 'zhī',  # 𧌔
    # 0x27315: '',  # 𧌕
    0x27316: 'xiè,shè',  # 𧌖
    0x27317: 'zǒu',  # 𧌗
    0x27318: 'fèi',  # 𧌘
    0x27319: 'mín',  # 𧌙
    0x2731A: 'xīng',  # 𧌚
    # 0x2731B: '',  # 𧌛
    # 0x2731C: '',  # 𧌜
    0x2731D: 'tóng',  # 𧌝
    0x2731E: 'qí',  # 𧌞
    # 0x2731F: '',  # 𧌟
    0x27320: 'piāo',  # 𧌠
    # 0x27321: '',  # 𧌡
    0x27322: 'suì',  # 𧌢
    0x27323: 'ěr',  # 𧌣
    # 0x27324: '',  # 𧌤
    # 0x27325: '',  # 𧌥
    # 0x27326: '',  # 𧌦
    0x27327: 'hǔ',  # 𧌧
    # 0x27328: '',  # 𧌨
    # 0x27329: '',  # 𧌩
    # 0x2732A: '',  # 𧌪
    # 0x2732B: '',  # 𧌫
    # 0x2732C: '',  # 𧌬
    # 0x2732D: '',  # 𧌭
    # 0x2732E: '',  # 𧌮
    # 0x2732F: '',  # 𧌯
    # 0x27330: '',  # 𧌰
    # 0x27331: '',  # 𧌱
    # 0x27332: '',  # 𧌲
    # 0x27333: '',  # 𧌳
    0x27334: 'qí',  # 𧌴
    # 0x27335: '',  # 𧌵
    # 0x27336: '',  # 𧌶
    # 0x27337: '',  # 𧌷
    # 0x27338: '',  # 𧌸
    # 0x27339: '',  # 𧌹
    # 0x2733A: '',  # 𧌺
    0x2733B: 'sōng',  # 𧌻
    # 0x2733C: '',  # 𧌼
    0x2733D: 'biē',  # 𧌽
    0x2733E: 'dīng',  # 𧌾
    0x2733F: 'bǎn',  # 𧌿
    0x27340: 'shī,lǐ',  # 𧍀
    0x27341: 'xiè',  # 𧍁
    0x27342: 'xiáo',  # 𧍂
    0x27343: 'fěi',  # 𧍃
    # 0x27344: '',  # 𧍄
    # 0x27345: '',  # 𧍅
    # 0x27346: '',  # 𧍆
    # 0x27347: '',  # 𧍇
    # 0x27348: '',  # 𧍈
    # 0x27349: '',  # 𧍉
    # 0x2734A: '',  # 𧍊
    # 0x2734B: '',  # 𧍋
    # 0x2734C: '',  # 𧍌
    # 0x2734D: '',  # 𧍍
    # 0x2734E: '',  # 𧍎
    # 0x2734F: '',  # 𧍏
    # 0x27350: '',  # 𧍐
    # 0x27351: '',  # 𧍑
    0x27352: 'chuǎn,chuǎi',  # 𧍒
    0x27353: 'shuài',  # 𧍓
    0x27354: 'yāo',  # 𧍔
    0x27355: 'jué',  # 𧍕
    0x27356: 'shěng,nìng',  # 𧍖
    # 0x27357: '',  # 𧍗
    0x27358: 'yōu',  # 𧍘
    0x27359: 'fàn',  # 𧍙
    # 0x2735A: '',  # 𧍚
    # 0x2735B: '',  # 𧍛
    0x2735C: 'kuí',  # 𧍜
    0x2735D: 'dì',  # 𧍝
    # 0x2735E: '',  # 𧍞
    0x2735F: 'máo',  # 𧍟
    0x27360: 'jié',  # 𧍠
    # 0x27361: '',  # 𧍡
    0x27362: 'yán,yǐn',  # 𧍢
    0x27363: 'chài',  # 𧍣
    # 0x27364: '',  # 𧍤
    0x27365: 'wēi',  # 𧍥
    # 0x27366: '',  # 𧍦
    # 0x27367: '',  # 𧍧
    0x27368: 'sāng',  # 𧍨
    0x27369: 'jié',  # 𧍩
    0x2736A: 'yú',  # 𧍪
    0x2736B: 'wèi',  # 𧍫
    0x2736C: 'è',  # 𧍬
    0x2736D: 'quán',  # 𧍭
    0x2736E: 'jiǒng',  # 𧍮
    0x2736F: 'féng',  # 𧍯
    0x27370: 'lóng',  # 𧍰
    0x27371: 'dié',  # 𧍱
    0x27372: 'pián',  # 𧍲
    # 0x27373: '',  # 𧍳
    0x27374: 'liàn',  # 𧍴
    0x27375: 'hú',  # 𧍵
    0x27376: 'lǜ',  # 𧍶
    # 0x27377: '',  # 𧍷
    0x27378: 'zhōng',  # 𧍸
    # 0x27379: '',  # 𧍹
    # 0x2737A: '',  # 𧍺
    # 0x2737B: '',  # 𧍻
    # 0x2737C: '',  # 𧍼
    # 0x2737D: '',  # 𧍽
    # 0x2737E: '',  # 𧍾
    0x2737F: 'diàn',  # 𧍿
    # 0x27380: '',  # 𧎀
    # 0x27381: '',  # 𧎁
    # 0x27382: '',  # 𧎂
    0x27383: 'cuì',  # 𧎃
    0x27384: 'móu,wù',  # 𧎄
    # 0x27385: '',  # 𧎅
    # 0x27386: '',  # 𧎆
    # 0x27387: '',  # 𧎇
    # 0x27388: '',  # 𧎈
    # 0x27389: '',  # 𧎉
    # 0x2738A: '',  # 𧎊
    # 0x2738B: '',  # 𧎋
    # 0x2738C: '',  # 𧎌
    # 0x2738D: '',  # 𧎍
    # 0x2738E: '',  # 𧎎
    # 0x2738F: '',  # 𧎏
    # 0x27390: '',  # 𧎐
    # 0x27391: '',  # 𧎑
    # 0x27392: '',  # 𧎒
    # 0x27393: '',  # 𧎓
    # 0x27394: '',  # 𧎔
    0x27395: 'wáng',  # 𧎕
    0x27396: 'juān',  # 𧎖
    0x27397: 'kē',  # 𧎗
    0x27398: 'yán',  # 𧎘
    0x27399: 'jiǎo',  # 𧎙
    # 0x2739A: '',  # 𧎚
    # 0x2739B: '',  # 𧎛
    # 0x2739C: '',  # 𧎜
    # 0x2739D: '',  # 𧎝
    # 0x2739E: '',  # 𧎞
    # 0x2739F: '',  # 𧎟
    # 0x273A0: '',  # 𧎠
    0x273A1: 'gōng',  # 𧎡
    0x273A2: 'tè',  # 𧎢
    0x273A3: 'róng',  # 𧎣
    0x273A4: 'sūn',  # 𧎤
    0x273A5: 'shàn',  # 𧎥
    # 0x273A6: '',  # 𧎦
    # 0x273A7: '',  # 𧎧
    0x273A8: 'chí',  # 𧎨
    # 0x273A9: '',  # 𧎩
    0x273AA: 'qí',  # 𧎪
    0x273AB: 'suǒ',  # 𧎫
    # 0x273AC: '',  # 𧎬
    0x273AD: 'yè',  # 𧎭
    0x273AE: 'zǎo',  # 𧎮
    0x273AF: 'quē',  # 𧎯
    0x273B0: 'zhǎn',  # 𧎰
    0x273B1: 'bā',  # 𧎱
    0x273B2: 'zú',  # 𧎲
    0x273B3: 'suǒ',  # 𧎳
    0x273B4: 'zhé',  # 𧎴
    0x273B5: 'xì',  # 𧎵
    # 0x273B6: '',  # 𧎶
    0x273B7: 'chǔ',  # 𧎷
    0x273B8: 'jiǎo',  # 𧎸
    0x273B9: 'zuì',  # 𧎹
    0x273BA: 'gē',  # 𧎺
    0x273BB: 'wù,móu',  # 𧎻
    # 0x273BC: '',  # 𧎼
    # 0x273BD: '',  # 𧎽
    0x273BE: 'lüè',  # 𧎾
    0x273BF: 'jí',  # 𧎿
    # 0x273C0: '',  # 𧏀
    # 0x273C1: '',  # 𧏁
    0x273C2: 'xié',  # 𧏂
    0x273C3: 'xié',  # 𧏃
    # 0x273C4: '',  # 𧏄
    # 0x273C5: '',  # 𧏅
    0x273C6: 'dǒu',  # 𧏆
    # 0x273C7: '',  # 𧏇
    # 0x273C8: '',  # 𧏈
    # 0x273C9: '',  # 𧏉
    # 0x273CA: '',  # 𧏊
    0x273CB: 'qiū',  # 𧏋
    # 0x273CC: '',  # 𧏌
    # 0x273CD: '',  # 𧏍
    # 0x273CE: '',  # 𧏎
    # 0x273CF: '',  # 𧏏
    # 0x273D0: '',  # 𧏐
    0x273D1: 'píng',  # 𧏑
    # 0x273D2: '',  # 𧏒
    0x273D3: 'liú',  # 𧏓
    # 0x273D4: '',  # 𧏔
    # 0x273D5: '',  # 𧏕
    # 0x273D6: '',  # 𧏖
    # 0x273D7: '',  # 𧏗
    # 0x273D8: '',  # 𧏘
    # 0x273D9: '',  # 𧏙
    # 0x273DA: '',  # 𧏚
    # 0x273DB: '',  # 𧏛
    # 0x273DC: '',  # 𧏜
    # 0x273DD: '',  # 𧏝
    # 0x273DE: '',  # 𧏞
    # 0x273DF: '',  # 𧏟
    # 0x273E0: '',  # 𧏠
    # 0x273E1: '',  # 𧏡
    # 0x273E2: '',  # 𧏢
    # 0x273E3: '',  # 𧏣
    # 0x273E4: '',  # 𧏤
    0x273E5: 'jié',  # 𧏥
    # 0x273E6: '',  # 𧏦
    0x273E7: 'huì',  # 𧏧
    # 0x273E8: '',  # 𧏨
    # 0x273E9: '',  # 𧏩
    # 0x273EA: '',  # 𧏪
    0x273EB: 'shà',  # 𧏫
    # 0x273EC: '',  # 𧏬
    # 0x273ED: '',  # 𧏭
    # 0x273EE: '',  # 𧏮
    # 0x273EF: '',  # 𧏯
    # 0x273F0: '',  # 𧏰
    # 0x273F1: '',  # 𧏱
    # 0x273F2: '',  # 𧏲
    # 0x273F3: '',  # 𧏳
    # 0x273F4: '',  # 𧏴
    # 0x273F5: '',  # 𧏵
    # 0x273F6: '',  # 𧏶
    # 0x273F7: '',  # 𧏷
    0x273F8: 'zhí',  # 𧏸
    0x273F9: 'ài',  # 𧏹
    0x273FA: 'xù,òu',  # 𧏺
    0x273FB: 'bì',  # 𧏻
    # 0x273FC: '',  # 𧏼
    0x273FD: 'yē',  # 𧏽
    0x273FE: 'nì',  # 𧏾
    0x273FF: 'zhú',  # 𧏿
    # 0x27400: '',  # 𧐀
    0x27401: 'sù',  # 𧐁
    0x27402: 'shí',  # 𧐂
    0x27403: 'xié',  # 𧐃
    0x27404: 'yù,yú',  # 𧐄
    0x27405: 'qū',  # 𧐅
    # 0x27406: '',  # 𧐆
    # 0x27407: '',  # 𧐇
    0x27408: 'zú',  # 𧐈
    0x27409: 'zhī',  # 𧐉
    0x2740A: 'zhāng',  # 𧐊
    0x2740B: 'lüè',  # 𧐋
    0x2740C: 'wěi',  # 𧐌
    0x2740D: 'chōng',  # 𧐍
    0x2740E: 'mì',  # 𧐎
    # 0x2740F: '',  # 𧐏
    0x27410: 'jī',  # 𧐐
    # 0x27411: '',  # 𧐑
    0x27412: 'sù',  # 𧐒
    0x27413: 'yě',  # 𧐓
    0x27414: 'xí,yì',  # 𧐔
    0x27415: 'tuán',  # 𧐕
    0x27416: 'lián,liàn',  # 𧐖
    0x27417: 'xuán',  # 𧐗
    # 0x27418: '',  # 𧐘
    0x27419: 'wù',  # 𧐙
    # 0x2741A: '',  # 𧐚
    # 0x2741B: '',  # 𧐛
    # 0x2741C: '',  # 𧐜
    # 0x2741D: '',  # 𧐝
    # 0x2741E: '',  # 𧐞
    0x2741F: 'máo',  # 𧐟
    # 0x27420: '',  # 𧐠
    # 0x27421: '',  # 𧐡
    0x27422: 'háo',  # 𧐢
    # 0x27423: '',  # 𧐣
    # 0x27424: '',  # 𧐤
    # 0x27425: '',  # 𧐥
    # 0x27426: '',  # 𧐦
    # 0x27427: '',  # 𧐧
    # 0x27428: '',  # 𧐨
    # 0x27429: '',  # 𧐩
    # 0x2742A: '',  # 𧐪
    # 0x2742B: '',  # 𧐫
    0x2742C: 'hóng',  # 𧐬
    # 0x2742D: '',  # 𧐭
    # 0x2742E: '',  # 𧐮
    0x2742F: 'lüè',  # 𧐯
    0x27430: 'dú',  # 𧐰
    0x27431: 'cóng',  # 𧐱
    0x27432: 'chán',  # 𧐲
    0x27433: 'lù',  # 𧐳
    0x27434: 'sù',  # 𧐴
    # 0x27435: '',  # 𧐵
    # 0x27436: '',  # 𧐶
    # 0x27437: '',  # 𧐷
    # 0x27438: '',  # 𧐸
    # 0x27439: '',  # 𧐹
    # 0x2743A: '',  # 𧐺
    # 0x2743B: '',  # 𧐻
    # 0x2743C: '',  # 𧐼
    # 0x2743D: '',  # 𧐽
    # 0x2743E: '',  # 𧐾
    # 0x2743F: '',  # 𧐿
    0x27440: 'lüè',  # 𧑀
    # 0x27441: '',  # 𧑁
    # 0x27442: '',  # 𧑂
    # 0x27443: '',  # 𧑃
    # 0x27444: '',  # 𧑄
    # 0x27445: '',  # 𧑅
    0x27446: 'zhōng',  # 𧑆
    0x27447: 'lí',  # 𧑇
    0x27448: 'fèi',  # 𧑈
    # 0x27449: '',  # 𧑉
    0x2744A: 'jǐng',  # 𧑊
    0x2744B: 'kuì',  # 𧑋
    0x2744C: 'yì',  # 𧑌
    0x2744D: 'huá',  # 𧑍
    0x2744E: 'cuì',  # 𧑎
    # 0x2744F: '',  # 𧑏
    0x27450: 'yù',  # 𧑐
    0x27451: 'běng',  # 𧑑
    0x27452: 'tūn',  # 𧑒
    0x27453: 'shǔ',  # 𧑓
    0x27454: 'dài',  # 𧑔
    0x27455: 'wū',  # 𧑕
    0x27456: 'cì',  # 𧑖
    0x27457: 'nìng',  # 𧑗
    0x27458: 'dàng',  # 𧑘
    0x27459: 'zú',  # 𧑙
    0x2745A: 'hán',  # 𧑚
    # 0x2745B: '',  # 𧑛
    0x2745C: 'pí',  # 𧑜
    0x2745D: 'chuàn',  # 𧑝
    # 0x2745E: '',  # 𧑞
    # 0x2745F: '',  # 𧑟
    0x27460: 'dù',  # 𧑠
    0x27461: 'pá',  # 𧑡
    # 0x27462: '',  # 𧑢
    # 0x27463: '',  # 𧑣
    0x27464: 'zhū',  # 𧑤
    # 0x27465: '',  # 𧑥
    0x27466: 'xié',  # 𧑦
    0x27467: 'zhé',  # 𧑧
    0x27468: 'qiè',  # 𧑨
    0x27469: 'xuān',  # 𧑩
    # 0x2746A: '',  # 𧑪
    0x2746B: 'sào',  # 𧑫
    # 0x2746C: '',  # 𧑬
    # 0x2746D: '',  # 𧑭
    # 0x2746E: '',  # 𧑮
    # 0x2746F: '',  # 𧑯
    # 0x27470: '',  # 𧑰
    # 0x27471: '',  # 𧑱
    # 0x27472: '',  # 𧑲
    # 0x27473: '',  # 𧑳
    # 0x27474: '',  # 𧑴
    # 0x27475: '',  # 𧑵
    # 0x27476: '',  # 𧑶
    # 0x27477: '',  # 𧑷
    # 0x27478: '',  # 𧑸
    # 0x27479: '',  # 𧑹
    # 0x2747A: '',  # 𧑺
    # 0x2747B: '',  # 𧑻
    # 0x2747C: '',  # 𧑼
    # 0x2747D: '',  # 𧑽
    # 0x2747E: '',  # 𧑾
    # 0x2747F: '',  # 𧑿
    0x27480: 'bì',  # 𧒀
    # 0x27481: '',  # 𧒁
    0x27482: 'fù',  # 𧒂
    # 0x27483: '',  # 𧒃
    # 0x27484: '',  # 𧒄
    # 0x27485: '',  # 𧒅
    # 0x27486: '',  # 𧒆
    # 0x27487: '',  # 𧒇
    0x27488: 'lì',  # 𧒈
    # 0x27489: '',  # 𧒉
    # 0x2748A: '',  # 𧒊
    # 0x2748B: '',  # 𧒋
    # 0x2748C: '',  # 𧒌
    # 0x2748D: '',  # 𧒍
    0x2748E: 'é',  # 𧒎
    # 0x2748F: '',  # 𧒏
    0x27490: 'yē',  # 𧒐
    0x27491: 'shǔ',  # 𧒑
    # 0x27492: '',  # 𧒒
    0x27493: 'sè',  # 𧒓
    0x27494: 'qiú',  # 𧒔
    0x27495: 'qī',  # 𧒕
    0x27496: 'guò',  # 𧒖
    0x27497: 'sè',  # 𧒗
    0x27498: 'guǒ',  # 𧒘
    0x27499: 'fù',  # 𧒙
    0x2749A: 'máo',  # 𧒚
    # 0x2749B: '',  # 𧒛
    0x2749C: 'léi',  # 𧒜
    0x2749D: 'zhān',  # 𧒝
    # 0x2749E: '',  # 𧒞
    # 0x2749F: '',  # 𧒟
    # 0x274A0: '',  # 𧒠
    # 0x274A1: '',  # 𧒡
    # 0x274A2: '',  # 𧒢
    # 0x274A3: '',  # 𧒣
    # 0x274A4: '',  # 𧒤
    # 0x274A5: '',  # 𧒥
    # 0x274A6: '',  # 𧒦
    # 0x274A7: '',  # 𧒧
    0x274A8: 'chài',  # 𧒨
    # 0x274A9: '',  # 𧒩
    # 0x274AA: '',  # 𧒪
    # 0x274AB: '',  # 𧒫
    # 0x274AC: '',  # 𧒬
    # 0x274AD: '',  # 𧒭
    # 0x274AE: '',  # 𧒮
    # 0x274AF: '',  # 𧒯
    # 0x274B0: '',  # 𧒰
    # 0x274B1: '',  # 𧒱
    # 0x274B2: '',  # 𧒲
    # 0x274B3: '',  # 𧒳
    # 0x274B4: '',  # 𧒴
    # 0x274B5: '',  # 𧒵
    # 0x274B6: '',  # 𧒶
    # 0x274B7: '',  # 𧒷
    # 0x274B8: '',  # 𧒸
    # 0x274B9: '',  # 𧒹
    # 0x274BA: '',  # 𧒺
    0x274BB: 'xiè',  # 𧒻
    # 0x274BC: '',  # 𧒼
    0x274BD: 'léi',  # 𧒽
    0x274BE: 'dāng',  # 𧒾
    0x274BF: 'zéi',  # 𧒿
    0x274C0: 'yīng',  # 𧓀
    0x274C1: 'ài',  # 𧓁
    0x274C2: 'xiē',  # 𧓂
    # 0x274C3: '',  # 𧓃
    0x274C4: 'bì',  # 𧓄
    # 0x274C5: '',  # 𧓅
    # 0x274C6: '',  # 𧓆
    # 0x274C7: '',  # 𧓇
    # 0x274C8: '',  # 𧓈
    0x274C9: 'qí',  # 𧓉
    # 0x274CA: '',  # 𧓊
    0x274CB: 'chán',  # 𧓋
    # 0x274CC: '',  # 𧓌
    # 0x274CD: '',  # 𧓍
    0x274CE: 'pí,bī',  # 𧓎
    0x274CF: 'cóng',  # 𧓏
    0x274D0: 'liè',  # 𧓐
    0x274D1: 'qí',  # 𧓑
    # 0x274D2: '',  # 𧓒
    0x274D3: 'jì',  # 𧓓
    0x274D4: 'jīng',  # 𧓔
    0x274D5: 'dōng',  # 𧓕
    0x274D6: 'féi',  # 𧓖
    0x274D7: 'yí',  # 𧓗
    0x274D8: 'tuán',  # 𧓘
    # 0x274D9: '',  # 𧓙
    # 0x274DA: '',  # 𧓚
    # 0x274DB: '',  # 𧓛
    # 0x274DC: '',  # 𧓜
    # 0x274DD: '',  # 𧓝
    # 0x274DE: '',  # 𧓞
    # 0x274DF: '',  # 𧓟
    # 0x274E0: '',  # 𧓠
    # 0x274E1: '',  # 𧓡
    # 0x274E2: '',  # 𧓢
    # 0x274E3: '',  # 𧓣
    # 0x274E4: '',  # 𧓤
    # 0x274E5: '',  # 𧓥
    # 0x274E6: '',  # 𧓦
    0x274E7: 'biān',  # 𧓧
    0x274E8: 'měng',  # 𧓨
    0x274E9: 'cán',  # 𧓩
    0x274EA: 'yá',  # 𧓪
    # 0x274EB: '',  # 𧓫
    # 0x274EC: '',  # 𧓬
    # 0x274ED: '',  # 𧓭
    # 0x274EE: '',  # 𧓮
    # 0x274EF: '',  # 𧓯
    # 0x274F0: '',  # 𧓰
    # 0x274F1: '',  # 𧓱
    0x274F2: 'yǎng',  # 𧓲
    # 0x274F3: '',  # 𧓳
    0x274F4: 'tíng',  # 𧓴
    # 0x274F5: '',  # 𧓵
    # 0x274F6: '',  # 𧓶
    # 0x274F7: '',  # 𧓷
    0x274F8: 'zhí',  # 𧓸
    # 0x274F9: '',  # 𧓹
    0x274FA: 'xiè',  # 𧓺
    0x274FB: 'lǜ',  # 𧓻
    # 0x274FC: '',  # 𧓼
    0x274FD: 'lì,chài',  # 𧓽
    # 0x274FE: '',  # 𧓾
    0x274FF: 'máo',  # 𧓿
    # 0x27500: '',  # 𧔀
    # 0x27501: '',  # 𧔁
    0x27502: 'xiá',  # 𧔂
    # 0x27503: '',  # 𧔃
    # 0x27504: '',  # 𧔄
    0x27505: 'sòu',  # 𧔅
    # 0x27506: '',  # 𧔆
    # 0x27507: '',  # 𧔇
    # 0x27508: '',  # 𧔈
    # 0x27509: '',  # 𧔉
    # 0x2750A: '',  # 𧔊
    # 0x2750B: '',  # 𧔋
    # 0x2750C: '',  # 𧔌
    # 0x2750D: '',  # 𧔍
    # 0x2750E: '',  # 𧔎
    # 0x2750F: '',  # 𧔏
    # 0x27510: '',  # 𧔐
    # 0x27511: '',  # 𧔑
    # 0x27512: '',  # 𧔒
    # 0x27513: '',  # 𧔓
    # 0x27514: '',  # 𧔔
    # 0x27515: '',  # 𧔕
    0x27516: 'sū',  # 𧔖
    0x27517: 'xuè',  # 𧔗
    # 0x27518: '',  # 𧔘
    # 0x27519: '',  # 𧔙
    # 0x2751A: '',  # 𧔚
    # 0x2751B: '',  # 𧔛
    # 0x2751C: '',  # 𧔜
    0x2751D: 'lì',  # 𧔝
    0x2751E: 'yuán',  # 𧔞
    # 0x2751F: '',  # 𧔟
    # 0x27520: '',  # 𧔠
    0x27521: 'zhǎn',  # 𧔡
    # 0x27522: '',  # 𧔢
    0x27523: 'tà',  # 𧔣
    0x27524: 'xuán',  # 𧔤
    0x27525: 'wèi',  # 𧔥
    0x27526: 'yè',  # 𧔦
    0x27527: 'páng',  # 𧔧
    0x27528: 'máo',  # 𧔨
    0x27529: 'tí',  # 𧔩
    0x2752A: 'pín',  # 𧔪
    # 0x2752B: '',  # 𧔫
    0x2752C: 'dù',  # 𧔬
    0x2752D: 'qiú',  # 𧔭
    0x2752E: 'yǐ',  # 𧔮
    # 0x2752F: '',  # 𧔯
    # 0x27530: '',  # 𧔰
    # 0x27531: '',  # 𧔱
    # 0x27532: '',  # 𧔲
    0x27533: 'tuó',  # 𧔳
    0x27534: 'chài',  # 𧔴
    # 0x27535: '',  # 𧔵
    # 0x27536: '',  # 𧔶
    0x27537: 'jìn',  # 𧔷
    # 0x27538: '',  # 𧔸
    # 0x27539: '',  # 𧔹
    # 0x2753A: '',  # 𧔺
    # 0x2753B: '',  # 𧔻
    0x2753C: 'é',  # 𧔼
    # 0x2753D: '',  # 𧔽
    # 0x2753E: '',  # 𧔾
    # 0x2753F: '',  # 𧔿
    # 0x27540: '',  # 𧕀
    # 0x27541: '',  # 𧕁
    # 0x27542: '',  # 𧕂
    0x27543: 'chán',  # 𧕃
    0x27544: 'yīng',  # 𧕄
    0x27545: 'líng',  # 𧕅
    # 0x27546: '',  # 𧕆
    0x27547: 'xiǎn',  # 𧕇
    # 0x27548: '',  # 𧕈
    0x27549: 'qī',  # 𧕉
    # 0x2754A: '',  # 𧕊
    0x2754B: 'yuè',  # 𧕋
    0x2754C: 'lüè',  # 𧕌
    0x2754D: 'yíng',  # 𧕍
    0x2754E: 'qú',  # 𧕎
    # 0x2754F: '',  # 𧕏
    0x27550: 'cáo',  # 𧕐
    # 0x27551: '',  # 𧕑
    0x27552: 'fěi',  # 𧕒
    0x27553: 'zī',  # 𧕓
    # 0x27554: '',  # 𧕔
    # 0x27555: '',  # 𧕕
    # 0x27556: '',  # 𧕖
    # 0x27557: '',  # 𧕗
    # 0x27558: '',  # 𧕘
    0x27559: 'qīng',  # 𧕙
    # 0x2755A: '',  # 𧕚
    # 0x2755B: '',  # 𧕛
    # 0x2755C: '',  # 𧕜
    0x2755D: 'níng',  # 𧕝
    0x2755E: 'wèi',  # 𧕞
    0x2755F: 'shuāng',  # 𧕟
    # 0x27560: '',  # 𧕠
    0x27561: 'fù',  # 𧕡
    # 0x27562: '',  # 𧕢
    # 0x27563: '',  # 𧕣
    0x27564: 'mò',  # 𧕤
    0x27565: 'mò',  # 𧕥
    0x27566: 'tuó',  # 𧕦
    0x27567: 'chài',  # 𧕧
    0x27568: 'zàng',  # 𧕨
    # 0x27569: '',  # 𧕩
    # 0x2756A: '',  # 𧕪
    # 0x2756B: '',  # 𧕫
    # 0x2756C: '',  # 𧕬
    # 0x2756D: '',  # 𧕭
    0x2756E: 'lí',  # 𧕮
    0x2756F: 'lí,shī',  # 𧕯
    # 0x27570: '',  # 𧕰
    0x27571: 'xiá',  # 𧕱
    0x27572: 'juǎn',  # 𧕲
    # 0x27573: '',  # 𧕳
    0x27574: 'nán',  # 𧕴
    0x27575: 'mì',  # 𧕵
    # 0x27576: '',  # 𧕶
    # 0x27577: '',  # 𧕷
    0x27578: 'huáng',  # 𧕸
    # 0x27579: '',  # 𧕹
    0x2757A: 'shuàng',  # 𧕺
    # 0x2757B: '',  # 𧕻
    0x2757C: 'xǔ',  # 𧕼
    # 0x2757D: '',  # 𧕽
    # 0x2757E: '',  # 𧕾
    0x2757F: 'fěi',  # 𧕿
    # 0x27580: '',  # 𧖀
    0x27581: 'xiè,wén',  # 𧖁
    # 0x27582: '',  # 𧖂
    # 0x27583: '',  # 𧖃
    # 0x27584: '',  # 𧖄
    0x27585: 'mì',  # 𧖅
    0x27586: 'tà',  # 𧖆
    0x27587: 'yǒng',  # 𧖇
    # 0x27588: '',  # 𧖈
    0x27589: 'zhǎn',  # 𧖉
    # 0x2758A: '',  # 𧖊
    # 0x2758B: '',  # 𧖋
    # 0x2758C: '',  # 𧖌
    # 0x2758D: '',  # 𧖍
    # 0x2758E: '',  # 𧖎
    # 0x2758F: '',  # 𧖏
    # 0x27590: '',  # 𧖐
    0x27591: 'qiáng',  # 𧖑
    0x27592: 'náng',  # 𧖒
    # 0x27593: '',  # 𧖓
    0x27594: 'lìn',  # 𧖔
    0x27595: 'pí',  # 𧖕
    # 0x27596: '',  # 𧖖
    # 0x27597: '',  # 𧖗
    0x27598: 'luán',  # 𧖘
    0x27599: 'xiǎn',  # 𧖙
    0x2759A: 'fú',  # 𧖚
    # 0x2759B: '',  # 𧖛
    0x2759C: 'líng',  # 𧖜
    # 0x2759D: '',  # 𧖝
    # 0x2759E: '',  # 𧖞
    # 0x2759F: '',  # 𧖟
    0x275A0: 'sāo',  # 𧖠
    # 0x275A1: '',  # 𧖡
    0x275A2: 'huì',  # 𧖢
    # 0x275A3: '',  # 𧖣
    # 0x275A4: '',  # 𧖤
    # 0x275A5: '',  # 𧖥
    # 0x275A6: '',  # 𧖦
    # 0x275A7: '',  # 𧖧
    0x275A8: 'tíng',  # 𧖨
    # 0x275A9: '',  # 𧖩
    0x275AA: 'qíng',  # 𧖪
    # 0x275AB: '',  # 𧖫
    0x275AC: 'huāng',  # 𧖬
    # 0x275AD: '',  # 𧖭
    0x275AE: 'àn',  # 𧖮
    # 0x275AF: '',  # 𧖯
    # 0x275B0: '',  # 𧖰
    # 0x275B1: '',  # 𧖱
    # 0x275B2: '',  # 𧖲
    # 0x275B3: '',  # 𧖳
    0x275B4: 'mài',  # 𧖴
    0x275B5: 'mǎn',  # 𧖵
    # 0x275B6: '',  # 𧖶
    0x275B7: 'nì,nǜ',  # 𧖷
    0x275B8: 'méng',  # 𧖸
    # 0x275B9: '',  # 𧖹
    0x275BA: 'tǎn',  # 𧖺
    0x275BB: 'guó',  # 𧖻
    0x275BC: 'ǒu',  # 𧖼
    # 0x275BD: '',  # 𧖽
    # 0x275BE: '',  # 𧖾
    0x275BF: 'xiàng',  # 𧖿
    # 0x275C0: '',  # 𧗀
    0x275C1: 'jīn',  # 𧗁
    # 0x275C2: '',  # 𧗂
    # 0x275C3: '',  # 𧗃
    # 0x275C4: '',  # 𧗄
    # 0x275C5: '',  # 𧗅
    0x275C6: 'zhēng',  # 𧗆
    # 0x275C7: '',  # 𧗇
    0x275C8: 'n',  # 𧗈
    # 0x275C9: '',  # 𧗉
    # 0x275CA: '',  # 𧗊
    0x275CB: 'sàn',  # 𧗋
    0x275CC: 'hù',  # 𧗌
    # 0x275CD: '',  # 𧗍
    0x275CE: 'zú',  # 𧗎
    0x275CF: 'huǐ',  # 𧗏
    # 0x275D0: '',  # 𧗐
    # 0x275D1: '',  # 𧗑
    0x275D2: 'jī',  # 𧗒
    0x275D3: 'jī',  # 𧗓
    # 0x275D4: '',  # 𧗔
    0x275D5: 'nóng',  # 𧗕
    0x275D6: 'yè',  # 𧗖
    # 0x275D7: '',  # 𧗗
    # 0x275D8: '',  # 𧗘
    # 0x275D9: '',  # 𧗙
    # 0x275DA: '',  # 𧗚
    # 0x275DB: '',  # 𧗛
    # 0x275DC: '',  # 𧗜
    # 0x275DD: '',  # 𧗝
    # 0x275DE: '',  # 𧗞
    # 0x275DF: '',  # 𧗟
    # 0x275E0: '',  # 𧗠
    # 0x275E1: '',  # 𧗡
    # 0x275E2: '',  # 𧗢
    # 0x275E3: '',  # 𧗣
    # 0x275E4: '',  # 𧗤
    # 0x275E5: '',  # 𧗥
    0x275E6: 'xíng',  # 𧗦
    # 0x275E7: '',  # 𧗧
    # 0x275E8: '',  # 𧗨
    0x275E9: 'là',  # 𧗩
    0x275EA: 'yù,qú',  # 𧗪
    0x275EB: 'jué',  # 𧗫
    # 0x275EC: '',  # 𧗬
    # 0x275ED: '',  # 𧗭
    # 0x275EE: '',  # 𧗮
    # 0x275EF: '',  # 𧗯
    # 0x275F0: '',  # 𧗰
    0x275F1: 'shù,yù',  # 𧗱
    0x275F2: 'zhēng',  # 𧗲
    0x275F3: 'xuàn',  # 𧗳
    0x275F4: 'yǒng',  # 𧗴
    # 0x275F5: '',  # 𧗵
    0x275F6: 'gē',  # 𧗶
    # 0x275F7: '',  # 𧗷
    0x275F8: 'jiàn',  # 𧗸
    0x275F9: 'xìn,xiān',  # 𧗹
    # 0x275FA: '',  # 𧗺
    # 0x275FB: '',  # 𧗻
    0x275FC: 'huī',  # 𧗼
    # 0x275FD: '',  # 𧗽
    # 0x275FE: '',  # 𧗾
    0x275FF: 'shuài',  # 𧗿
    # 0x27600: '',  # 𧘀
    # 0x27601: '',  # 𧘁
    0x27602: 'chōng,chòng',  # 𧘂
    0x27603: 'háng',  # 𧘃
    # 0x27604: '',  # 𧘄
    # 0x27605: '',  # 𧘅
    # 0x27606: '',  # 𧘆
    # 0x27607: '',  # 𧘇
    0x27608: 'liǎo',  # 𧘈
    0x27609: 'yì',  # 𧘉
    # 0x2760A: '',  # 𧘊
    # 0x2760B: '',  # 𧘋
    # 0x2760C: '',  # 𧘌
    0x2760D: 'jiāng',  # 𧘍
    # 0x2760E: '',  # 𧘎
    0x2760F: 'gōng',  # 𧘏
    0x27610: 'tuō',  # 𧘐
    0x27611: 'zhuó,bào',  # 𧘑
    # 0x27612: '',  # 𧘒
    0x27613: 'tì',  # 𧘓
    # 0x27614: '',  # 𧘔
    # 0x27615: '',  # 𧘕
    # 0x27616: '',  # 𧘖
    0x27617: 'qǐ',  # 𧘗
    # 0x27618: '',  # 𧘘
    # 0x27619: '',  # 𧘙
    # 0x2761A: '',  # 𧘚
    # 0x2761B: '',  # 𧘛
    0x2761C: 'qiān',  # 𧘜
    0x2761D: 'biǎo',  # 𧘝
    0x2761E: 'dǒu',  # 𧘞
    0x2761F: 'pō,bō',  # 𧘟
    # 0x27620: '',  # 𧘠
    # 0x27621: '',  # 𧘡
    0x27622: 'hù',  # 𧘢
    # 0x27623: '',  # 𧘣
    # 0x27624: '',  # 𧘤
    0x27625: 'niǔ',  # 𧘥
    # 0x27626: '',  # 𧘦
    0x27627: 'qì',  # 𧘧
    0x27628: 'diāo',  # 𧘨
    0x27629: 'diāo',  # 𧘩
    # 0x2762A: '',  # 𧘪
    0x2762B: 'lì',  # 𧘫
    # 0x2762C: '',  # 𧘬
    # 0x2762D: '',  # 𧘭
    0x2762E: 'xiōng',  # 𧘮
    # 0x2762F: '',  # 𧘯
    # 0x27630: '',  # 𧘰
    # 0x27631: '',  # 𧘱
    # 0x27632: '',  # 𧘲
    # 0x27633: '',  # 𧘳
    # 0x27634: '',  # 𧘴
    # 0x27635: '',  # 𧘵
    # 0x27636: '',  # 𧘶
    # 0x27637: '',  # 𧘷
    # 0x27638: '',  # 𧘸
    # 0x27639: '',  # 𧘹
    # 0x2763A: '',  # 𧘺
    # 0x2763B: '',  # 𧘻
    # 0x2763C: '',  # 𧘼
    0x2763D: 'ná',  # 𧘽
    # 0x2763E: '',  # 𧘾
    0x2763F: 'zhēng',  # 𧘿
    0x27640: 'là',  # 𧙀
    0x27641: 'zhì,zī,jì,pī',  # 𧙁
    # 0x27642: '',  # 𧙂
    0x27643: 'ě',  # 𧙃
    0x27644: 'bō',  # 𧙄
    0x27645: 'pō',  # 𧙅
    0x27646: 'xū',  # 𧙆
    0x27647: 'yòng,dǎn',  # 𧙇
    0x27648: 'cí',  # 𧙈
    0x27649: 'lì',  # 𧙉
    # 0x2764A: '',  # 𧙊
    0x2764B: 'zhǐ',  # 𧙋
    0x2764C: 'páo',  # 𧙌
    # 0x2764D: '',  # 𧙍
    # 0x2764E: '',  # 𧙎
    0x2764F: 'xiù,yǒu',  # 𧙏
    # 0x27650: '',  # 𧙐
    # 0x27651: '',  # 𧙑
    # 0x27652: '',  # 𧙒
    # 0x27653: '',  # 𧙓
    # 0x27654: '',  # 𧙔
    # 0x27655: '',  # 𧙕
    # 0x27656: '',  # 𧙖
    # 0x27657: '',  # 𧙗
    # 0x27658: '',  # 𧙘
    # 0x27659: '',  # 𧙙
    # 0x2765A: '',  # 𧙚
    0x2765B: 'pù',  # 𧙛
    # 0x2765C: '',  # 𧙜
    0x2765D: 'ché',  # 𧙝
    0x2765E: 'qì',  # 𧙞
    0x2765F: 'yì',  # 𧙟
    # 0x27660: '',  # 𧙠
    0x27661: 'yì',  # 𧙡
    # 0x27662: '',  # 𧙢
    0x27663: 'tí',  # 𧙣
    0x27664: 'duǒ',  # 𧙤
    0x27665: 'lóng,tǒng',  # 𧙥
    # 0x27666: '',  # 𧙦
    0x27667: 'jiàn',  # 𧙧
    # 0x27668: '',  # 𧙨
    # 0x27669: '',  # 𧙩
    # 0x2766A: '',  # 𧙪
    # 0x2766B: '',  # 𧙫
    # 0x2766C: '',  # 𧙬
    0x2766D: 'zhàn',  # 𧙭
    0x2766E: 'yuàn',  # 𧙮
    # 0x2766F: '',  # 𧙯
    # 0x27670: '',  # 𧙰
    # 0x27671: '',  # 𧙱
    # 0x27672: '',  # 𧙲
    # 0x27673: '',  # 𧙳
    # 0x27674: '',  # 𧙴
    # 0x27675: '',  # 𧙵
    0x27676: 'yú',  # 𧙶
    # 0x27677: '',  # 𧙷
    0x27678: 'gēng',  # 𧙸
    # 0x27679: '',  # 𧙹
    0x2767A: 'hòu',  # 𧙺
    # 0x2767B: '',  # 𧙻
    # 0x2767C: '',  # 𧙼
    # 0x2767D: '',  # 𧙽
    0x2767E: 'qǐ',  # 𧙾
    # 0x2767F: '',  # 𧙿
    0x27680: 'mù',  # 𧚀
    0x27681: 'huàn',  # 𧚁
    0x27682: 'lòng',  # 𧚂
    0x27683: 'xì',  # 𧚃
    0x27684: 'é',  # 𧚄
    0x27685: 'lǎng',  # 𧚅
    0x27686: 'fèi',  # 𧚆
    0x27687: 'wǎn,wèn',  # 𧚇
    # 0x27688: '',  # 𧚈
    0x27689: 'cūn',  # 𧚉
    # 0x2768A: '',  # 𧚊
    0x2768B: 'péng',  # 𧚋
    # 0x2768C: '',  # 𧚌
    # 0x2768D: '',  # 𧚍
    # 0x2768E: '',  # 𧚎
    0x2768F: 'cuò',  # 𧚏
    0x27690: 'wēng',  # 𧚐
    # 0x27691: '',  # 𧚑
    # 0x27692: '',  # 𧚒
    # 0x27693: '',  # 𧚓
    0x27694: 'tóng',  # 𧚔
    # 0x27695: '',  # 𧚕
    # 0x27696: '',  # 𧚖
    # 0x27697: '',  # 𧚗
    # 0x27698: '',  # 𧚘
    # 0x27699: '',  # 𧚙
    # 0x2769A: '',  # 𧚚
    # 0x2769B: '',  # 𧚛
    # 0x2769C: '',  # 𧚜
    # 0x2769D: '',  # 𧚝
    # 0x2769E: '',  # 𧚞
    # 0x2769F: '',  # 𧚟
    # 0x276A0: '',  # 𧚠
    0x276A1: 'gǎo',  # 𧚡
    # 0x276A2: '',  # 𧚢
    # 0x276A3: '',  # 𧚣
    # 0x276A4: '',  # 𧚤
    0x276A5: 'cuì',  # 𧚥
    # 0x276A6: '',  # 𧚦
    # 0x276A7: '',  # 𧚧
    0x276A8: 'qì,shà,qiè',  # 𧚨
    0x276A9: 'lí',  # 𧚩
    0x276AA: 'qiè',  # 𧚪
    0x276AB: 'qiàn,jīng',  # 𧚫
    0x276AC: 'kōng',  # 𧚬
    0x276AD: 'běng',  # 𧚭
    # 0x276AE: '',  # 𧚮
    0x276AF: 'shòu',  # 𧚯
    # 0x276B0: '',  # 𧚰
    # 0x276B1: '',  # 𧚱
    # 0x276B2: '',  # 𧚲
    # 0x276B3: '',  # 𧚳
    # 0x276B4: '',  # 𧚴
    # 0x276B5: '',  # 𧚵
    # 0x276B6: '',  # 𧚶
    0x276B7: 'wēi',  # 𧚷
    # 0x276B8: '',  # 𧚸
    # 0x276B9: '',  # 𧚹
    # 0x276BA: '',  # 𧚺
    # 0x276BB: '',  # 𧚻
    # 0x276BC: '',  # 𧚼
    # 0x276BD: '',  # 𧚽
    # 0x276BE: '',  # 𧚾
    # 0x276BF: '',  # 𧚿
    # 0x276C0: '',  # 𧛀
    # 0x276C1: '',  # 𧛁
    # 0x276C2: '',  # 𧛂
    # 0x276C3: '',  # 𧛃
    0x276C4: 'shān',  # 𧛄
    # 0x276C5: '',  # 𧛅
    # 0x276C6: '',  # 𧛆
    # 0x276C7: '',  # 𧛇
    # 0x276C8: '',  # 𧛈
    # 0x276C9: '',  # 𧛉
    # 0x276CA: '',  # 𧛊
    # 0x276CB: '',  # 𧛋
    # 0x276CC: '',  # 𧛌
    # 0x276CD: '',  # 𧛍
    # 0x276CE: '',  # 𧛎
    0x276CF: 'zī',  # 𧛏
    # 0x276D0: '',  # 𧛐
    # 0x276D1: '',  # 𧛑
    0x276D2: 'tì',  # 𧛒
    0x276D3: 'qiān',  # 𧛓
    0x276D4: 'dú',  # 𧛔
    # 0x276D5: '',  # 𧛕
    # 0x276D6: '',  # 𧛖
    0x276D7: 'tú',  # 𧛗
    # 0x276D8: '',  # 𧛘
    # 0x276D9: '',  # 𧛙
    0x276DA: 'wēi',  # 𧛚
    # 0x276DB: '',  # 𧛛
    # 0x276DC: '',  # 𧛜
    # 0x276DD: '',  # 𧛝
    0x276DE: 'hú',  # 𧛞
    0x276DF: 'xīng',  # 𧛟
    # 0x276E0: '',  # 𧛠
    0x276E1: 'shān',  # 𧛡
    0x276E2: 'zhǐ',  # 𧛢
    # 0x276E3: '',  # 𧛣
    # 0x276E4: '',  # 𧛤
    # 0x276E5: '',  # 𧛥
    # 0x276E6: '',  # 𧛦
    0x276E7: 'chǐ',  # 𧛧
    # 0x276E8: '',  # 𧛨
    # 0x276E9: '',  # 𧛩
    # 0x276EA: '',  # 𧛪
    # 0x276EB: '',  # 𧛫
    # 0x276EC: '',  # 𧛬
    # 0x276ED: '',  # 𧛭
    # 0x276EE: '',  # 𧛮
    # 0x276EF: '',  # 𧛯
    # 0x276F0: '',  # 𧛰
    # 0x276F1: '',  # 𧛱
    # 0x276F2: '',  # 𧛲
    # 0x276F3: '',  # 𧛳
    # 0x276F4: '',  # 𧛴
    # 0x276F5: '',  # 𧛵
    # 0x276F6: '',  # 𧛶
    # 0x276F7: '',  # 𧛷
    0x276F8: 'zhòu',  # 𧛸
    0x276F9: 'wēng',  # 𧛹
    0x276FA: 'chí',  # 𧛺
    0x276FB: 'suǒ',  # 𧛻
    0x276FC: 'xiè',  # 𧛼
    0x276FD: 'wèi',  # 𧛽
    0x276FE: 'kè',  # 𧛾
    # 0x276FF: '',  # 𧛿
    # 0x27700: '',  # 𧜀
    0x27701: 'shài,shā,shǎi',  # 𧜁
    0x27702: 'shī',  # 𧜂
    0x27703: 'shòu',  # 𧜃
    # 0x27704: '',  # 𧜄
    0x27705: 'jiè',  # 𧜅
    # 0x27706: '',  # 𧜆
    # 0x27707: '',  # 𧜇
    # 0x27708: '',  # 𧜈
    0x27709: 'gǎo',  # 𧜉
    0x2770A: 'lǚ',  # 𧜊
    # 0x2770B: '',  # 𧜋
    # 0x2770C: '',  # 𧜌
    # 0x2770D: '',  # 𧜍
    # 0x2770E: '',  # 𧜎
    # 0x2770F: '',  # 𧜏
    # 0x27710: '',  # 𧜐
    # 0x27711: '',  # 𧜑
    # 0x27712: '',  # 𧜒
    # 0x27713: '',  # 𧜓
    0x27714: 'xiè',  # 𧜔
    0x27715: 'tì',  # 𧜕
    # 0x27716: '',  # 𧜖
    # 0x27717: '',  # 𧜗
    # 0x27718: '',  # 𧜘
    # 0x27719: '',  # 𧜙
    0x2771A: 'zhǐ',  # 𧜚
    # 0x2771B: '',  # 𧜛
    # 0x2771C: '',  # 𧜜
    # 0x2771D: '',  # 𧜝
    0x2771E: 'mán,màn',  # 𧜞
    # 0x2771F: '',  # 𧜟
    0x27720: 'shuài',  # 𧜠
    0x27721: 'kè',  # 𧜡
    # 0x27722: '',  # 𧜢
    0x27723: 'diǎo',  # 𧜣
    0x27724: 'yī',  # 𧜤
    # 0x27725: '',  # 𧜥
    0x27726: 'sù',  # 𧜦
    0x27727: 'chuāng',  # 𧜧
    # 0x27728: '',  # 𧜨
    # 0x27729: '',  # 𧜩
    # 0x2772A: '',  # 𧜪
    # 0x2772B: '',  # 𧜫
    # 0x2772C: '',  # 𧜬
    # 0x2772D: '',  # 𧜭
    # 0x2772E: '',  # 𧜮
    # 0x2772F: '',  # 𧜯
    # 0x27730: '',  # 𧜰
    0x27731: 'cuì',  # 𧜱
    0x27732: 'tuò',  # 𧜲
    # 0x27733: '',  # 𧜳
    # 0x27734: '',  # 𧜴
    # 0x27735: '',  # 𧜵
    # 0x27736: '',  # 𧜶
    # 0x27737: '',  # 𧜷
    # 0x27738: '',  # 𧜸
    # 0x27739: '',  # 𧜹
    # 0x2773A: '',  # 𧜺
    # 0x2773B: '',  # 𧜻
    # 0x2773C: '',  # 𧜼
    0x2773D: 'xuán',  # 𧜽
    # 0x2773E: '',  # 𧜾
    # 0x2773F: '',  # 𧜿
    # 0x27740: '',  # 𧝀
    # 0x27741: '',  # 𧝁
    0x27742: 'hè',  # 𧝂
    0x27743: 'jué',  # 𧝃
    # 0x27744: '',  # 𧝄
    # 0x27745: '',  # 𧝅
    0x27746: 'tì',  # 𧝆
    0x27747: 'fèi',  # 𧝇
    # 0x27748: '',  # 𧝈
    0x27749: 'zhǐ',  # 𧝉
    0x2774A: 'shì',  # 𧝊
    0x2774B: 'tuí',  # 𧝋
    # 0x2774C: '',  # 𧝌
    # 0x2774D: '',  # 𧝍
    0x2774E: 'chōng,chuáng,chóng',  # 𧝎
    # 0x2774F: '',  # 𧝏
    0x27750: 'tì',  # 𧝐
    0x27751: 'zhàn',  # 𧝑
    0x27752: 'héng',  # 𧝒
    # 0x27753: '',  # 𧝓
    0x27754: 'qú',  # 𧝔
    0x27755: 'wéi',  # 𧝕
    # 0x27756: '',  # 𧝖
    0x27757: 'dūn',  # 𧝗
    0x27758: 'bào',  # 𧝘
    # 0x27759: '',  # 𧝙
    # 0x2775A: '',  # 𧝚
    # 0x2775B: '',  # 𧝛
    0x2775C: 'liáo',  # 𧝜
    # 0x2775D: '',  # 𧝝
    # 0x2775E: '',  # 𧝞
    # 0x2775F: '',  # 𧝟
    # 0x27760: '',  # 𧝠
    # 0x27761: '',  # 𧝡
    # 0x27762: '',  # 𧝢
    # 0x27763: '',  # 𧝣
    0x27764: 'sī',  # 𧝤
    # 0x27765: '',  # 𧝥
    # 0x27766: '',  # 𧝦
    # 0x27767: '',  # 𧝧
    # 0x27768: '',  # 𧝨
    # 0x27769: '',  # 𧝩
    0x2776A: 'biǎo',  # 𧝪
    0x2776B: 'xiè',  # 𧝫
    0x2776C: 'bié,bì',  # 𧝬
    # 0x2776D: '',  # 𧝭
    0x2776E: 'cǒng',  # 𧝮
    # 0x2776F: '',  # 𧝯
    # 0x27770: '',  # 𧝰
    # 0x27771: '',  # 𧝱
    0x27772: 'jù',  # 𧝲
    0x27773: 'hé',  # 𧝳
    # 0x27774: '',  # 𧝴
    0x27775: 'dié',  # 𧝵
    # 0x27776: '',  # 𧝶
    0x27777: 'kuì',  # 𧝷
    0x27778: 'yōng',  # 𧝸
    0x27779: 'luǒ',  # 𧝹
    # 0x2777A: '',  # 𧝺
    # 0x2777B: '',  # 𧝻
    # 0x2777C: '',  # 𧝼
    # 0x2777D: '',  # 𧝽
    # 0x2777E: '',  # 𧝾
    # 0x2777F: '',  # 𧝿
    0x27780: 'shù',  # 𧞀
    # 0x27781: '',  # 𧞁
    # 0x27782: '',  # 𧞂
    # 0x27783: '',  # 𧞃
    # 0x27784: '',  # 𧞄
    # 0x27785: '',  # 𧞅
    # 0x27786: '',  # 𧞆
    # 0x27787: '',  # 𧞇
    # 0x27788: '',  # 𧞈
    # 0x27789: '',  # 𧞉
    # 0x2778A: '',  # 𧞊
    # 0x2778B: '',  # 𧞋
    # 0x2778C: '',  # 𧞌
    0x2778D: 'niè',  # 𧞍
    # 0x2778E: '',  # 𧞎
    0x2778F: 'yú',  # 𧞏
    0x27790: 'zhuó',  # 𧞐
    0x27791: 'méng',  # 𧞑
    0x27792: 'hú',  # 𧞒
    0x27793: 'zī',  # 𧞓
    0x27794: 'jiè',  # 𧞔
    0x27795: 'liè',  # 𧞕
    # 0x27796: '',  # 𧞖
    # 0x27797: '',  # 𧞗
    # 0x27798: '',  # 𧞘
    # 0x27799: '',  # 𧞙
    # 0x2779A: '',  # 𧞚
    # 0x2779B: '',  # 𧞛
    # 0x2779C: '',  # 𧞜
    0x2779D: 'jiē',  # 𧞝
    0x2779E: 'xióng',  # 𧞞
    # 0x2779F: '',  # 𧞟
    # 0x277A0: '',  # 𧞠
    # 0x277A1: '',  # 𧞡
    # 0x277A2: '',  # 𧞢
    0x277A3: 'yǎn',  # 𧞣
    # 0x277A4: '',  # 𧞤
    # 0x277A5: '',  # 𧞥
    # 0x277A6: '',  # 𧞦
    # 0x277A7: '',  # 𧞧
    # 0x277A8: '',  # 𧞨
    0x277A9: 'jié',  # 𧞩
    0x277AA: 'là,lliè',  # 𧞪
    0x277AB: 'shù',  # 𧞫
    0x277AC: 'jié',  # 𧞬
    0x277AD: 'léi',  # 𧞭
    # 0x277AE: '',  # 𧞮
    # 0x277AF: '',  # 𧞯
    0x277B0: 'zú',  # 𧞰
    # 0x277B1: '',  # 𧞱
    0x277B2: 'shì',  # 𧞲
    # 0x277B3: '',  # 𧞳
    # 0x277B4: '',  # 𧞴
    # 0x277B5: '',  # 𧞵
    # 0x277B6: '',  # 𧞶
    # 0x277B7: '',  # 𧞷
    0x277B8: 'wéi,suì',  # 𧞸
    0x277B9: 'dū',  # 𧞹
    0x277BA: 'sù',  # 𧞺
    0x277BB: 'xiāng',  # 𧞻
    # 0x277BC: '',  # 𧞼
    # 0x277BD: '',  # 𧞽
    # 0x277BE: '',  # 𧞾
    # 0x277BF: '',  # 𧞿
    # 0x277C0: '',  # 𧟀
    # 0x277C1: '',  # 𧟁
    # 0x277C2: '',  # 𧟂
    0x277C3: 'xié',  # 𧟃
    0x277C4: 'ráng',  # 𧟄
    # 0x277C5: '',  # 𧟅
    # 0x277C6: '',  # 𧟆
    # 0x277C7: '',  # 𧟇
    # 0x277C8: '',  # 𧟈
    # 0x277C9: '',  # 𧟉
    # 0x277CA: '',  # 𧟊
    # 0x277CB: '',  # 𧟋
    0x277CC: 'luò',  # 𧟌
    # 0x277CD: '',  # 𧟍
    # 0x277CE: '',  # 𧟎
    # 0x277CF: '',  # 𧟏
    # 0x277D0: '',  # 𧟐
    0x277D1: 'qiān',  # 𧟑
    # 0x277D2: '',  # 𧟒
    # 0x277D3: '',  # 𧟓
    # 0x277D4: '',  # 𧟔
    # 0x277D5: '',  # 𧟕
    # 0x277D6: '',  # 𧟖
    # 0x277D7: '',  # 𧟗
    0x277D8: 'nàng',  # 𧟘
    0x277D9: 'líng',  # 𧟙
    # 0x277DA: '',  # 𧟚
    # 0x277DB: '',  # 𧟛
    0x277DC: 'jì',  # 𧟜
    # 0x277DD: '',  # 𧟝
    # 0x277DE: '',  # 𧟞
    # 0x277DF: '',  # 𧟟
    0x277E0: 'mìng',  # 𧟠
    # 0x277E1: '',  # 𧟡
    # 0x277E2: '',  # 𧟢
    0x277E3: 'gǔ',  # 𧟣
    # 0x277E4: '',  # 𧟤
    # 0x277E5: '',  # 𧟥
    # 0x277E6: '',  # 𧟦
    # 0x277E7: '',  # 𧟧
    0x277E8: 'xuán',  # 𧟨
    # 0x277E9: '',  # 𧟩
    # 0x277EA: '',  # 𧟪
    # 0x277EB: '',  # 𧟫
    0x277EC: 'xū',  # 𧟬
    # 0x277ED: '',  # 𧟭
    # 0x277EE: '',  # 𧟮
    # 0x277EF: '',  # 𧟯
    0x277F0: 'fiào',  # 𧟰
    0x277F1: 'bó',  # 𧟱
    # 0x277F2: '',  # 𧟲
    # 0x277F3: '',  # 𧟳
    # 0x277F4: '',  # 𧟴
    0x277F5: 'bó',  # 𧟵
    # 0x277F6: '',  # 𧟶
    # 0x277F7: '',  # 𧟷
    # 0x277F8: '',  # 𧟸
    # 0x277F9: '',  # 𧟹
    # 0x277FA: '',  # 𧟺
    # 0x277FB: '',  # 𧟻
    0x277FC: 'wēi',  # 𧟼
    # 0x277FD: '',  # 𧟽
    # 0x277FE: '',  # 𧟾
    # 0x277FF: '',  # 𧟿
    # 0x27800: '',  # 𧠀
    # 0x27801: '',  # 𧠁
    0x27802: 'kū',  # 𧠂
    # 0x27803: '',  # 𧠃
    # 0x27804: '',  # 𧠄
    # 0x27805: '',  # 𧠅
    0x27806: 'wǎn',  # 𧠆
    # 0x27807: '',  # 𧠇
    0x27808: 'chà',  # 𧠈
    # 0x27809: '',  # 𧠉
    0x2780A: 'mào',  # 𧠊
    0x2780B: 'kè',  # 𧠋
    # 0x2780C: '',  # 𧠌
    # 0x2780D: '',  # 𧠍
    0x2780E: 'cì',  # 𧠎
    # 0x2780F: '',  # 𧠏
    # 0x27810: '',  # 𧠐
    # 0x27811: '',  # 𧠑
    0x27812: 'xiàn',  # 𧠒
    0x27813: 'mò',  # 𧠓
    # 0x27814: '',  # 𧠔
    # 0x27815: '',  # 𧠕
    # 0x27816: '',  # 𧠖
    # 0x27817: '',  # 𧠗
    # 0x27818: '',  # 𧠘
    # 0x27819: '',  # 𧠙
    0x2781A: 'hūn',  # 𧠚
    0x2781B: 'chàn',  # 𧠛
    0x2781C: 'shī',  # 𧠜
    0x2781D: 'zhěn',  # 𧠝
    0x2781E: 'è',  # 𧠞
    0x2781F: 'mí',  # 𧠟
    # 0x27820: '',  # 𧠠
    0x27821: 'shī',  # 𧠡
    0x27822: 'qū',  # 𧠢
    0x27823: 'shū',  # 𧠣
    # 0x27824: '',  # 𧠤
    0x27825: 'cī',  # 𧠥
    0x27826: 'yǎn',  # 𧠦
    # 0x27827: '',  # 𧠧
    # 0x27828: '',  # 𧠨
    0x27829: 'hū',  # 𧠩
    0x2782A: 'qī',  # 𧠪
    0x2782B: 'zhì,dí,chì',  # 𧠫
    0x2782C: 'huāng',  # 𧠬
    # 0x2782D: '',  # 𧠭
    # 0x2782E: '',  # 𧠮
    # 0x2782F: '',  # 𧠯
    # 0x27830: '',  # 𧠰
    # 0x27831: '',  # 𧠱
    # 0x27832: '',  # 𧠲
    # 0x27833: '',  # 𧠳
    0x27834: 'zhǐ',  # 𧠴
    # 0x27835: '',  # 𧠵
    0x27836: 'yǒu',  # 𧠶
    # 0x27837: '',  # 𧠷
    # 0x27838: '',  # 𧠸
    # 0x27839: '',  # 𧠹
    # 0x2783A: '',  # 𧠺
    # 0x2783B: '',  # 𧠻
    0x2783C: 'gào',  # 𧠼
    0x2783D: 'yǎo',  # 𧠽
    0x2783E: 'pōu',  # 𧠾
    # 0x2783F: '',  # 𧠿
    # 0x27840: '',  # 𧡀
    # 0x27841: '',  # 𧡁
    # 0x27842: '',  # 𧡂
    # 0x27843: '',  # 𧡃
    # 0x27844: '',  # 𧡄
    # 0x27845: '',  # 𧡅
    # 0x27846: '',  # 𧡆
    0x27847: 'yí',  # 𧡇
    0x27848: 'chèng',  # 𧡈
    0x27849: 'jì',  # 𧡉
    # 0x2784A: '',  # 𧡊
    0x2784B: 'ǎi,yá',  # 𧡋
    # 0x2784C: '',  # 𧡌
    0x2784D: 'dòng',  # 𧡍
    0x2784E: 'nì',  # 𧡎
    0x2784F: 'suì',  # 𧡏
    # 0x27850: '',  # 𧡐
    0x27851: 'jiù',  # 𧡑
    # 0x27852: '',  # 𧡒
    # 0x27853: '',  # 𧡓
    # 0x27854: '',  # 𧡔
    # 0x27855: '',  # 𧡕
    # 0x27856: '',  # 𧡖
    # 0x27857: '',  # 𧡗
    0x27858: 'qì,qīn',  # 𧡘
    0x27859: 'lián',  # 𧡙
    0x2785A: 'xuǎn',  # 𧡚
    # 0x2785B: '',  # 𧡛
    0x2785C: 'liǎo',  # 𧡜
    # 0x2785D: '',  # 𧡝
    # 0x2785E: '',  # 𧡞
    # 0x2785F: '',  # 𧡟
    # 0x27860: '',  # 𧡠
    0x27861: 'yùn',  # 𧡡
    0x27862: 'xuǎn',  # 𧡢
    0x27863: 'cóu',  # 𧡣
    0x27864: 'piān',  # 𧡤
    # 0x27865: '',  # 𧡥
    0x27866: 'kuí',  # 𧡦
    # 0x27867: '',  # 𧡧
    0x27868: 'tí',  # 𧡨
    0x27869: 'huǎn',  # 𧡩
    0x2786A: 'dān,dàn',  # 𧡪
    0x2786B: 'guì,kuì',  # 𧡫
    0x2786C: 'chēn',  # 𧡬
    # 0x2786D: '',  # 𧡭
    0x2786E: 'shǎng',  # 𧡮
    0x2786F: 'jì',  # 𧡯
    # 0x27870: '',  # 𧡰
    # 0x27871: '',  # 𧡱
    # 0x27872: '',  # 𧡲
    # 0x27873: '',  # 𧡳
    0x27874: 'liàn',  # 𧡴
    0x27875: 'kān',  # 𧡵
    0x27876: 'shèng',  # 𧡶
    # 0x27877: '',  # 𧡷
    0x27878: 'dōu',  # 𧡸
    0x27879: 'yóu',  # 𧡹
    0x2787A: 'qí',  # 𧡺
    # 0x2787B: '',  # 𧡻
    0x2787C: 'xiǎo',  # 𧡼
    # 0x2787D: '',  # 𧡽
    # 0x2787E: '',  # 𧡾
    # 0x2787F: '',  # 𧡿
    # 0x27880: '',  # 𧢀
    # 0x27881: '',  # 𧢁
    0x27882: 'yì',  # 𧢂
    0x27883: 'lóu',  # 𧢃
    0x27884: 'piǎo',  # 𧢄
    # 0x27885: '',  # 𧢅
    0x27886: 'chuāng',  # 𧢆
    # 0x27887: '',  # 𧢇
    # 0x27888: '',  # 𧢈
    # 0x27889: '',  # 𧢉
    # 0x2788A: '',  # 𧢊
    0x2788B: 'lào',  # 𧢋
    0x2788C: 'gāo',  # 𧢌
    # 0x2788D: '',  # 𧢍
    # 0x2788E: '',  # 𧢎
    # 0x2788F: '',  # 𧢏
    0x27890: 'zēng',  # 𧢐
    # 0x27891: '',  # 𧢑
    0x27892: 'wéi,wěi',  # 𧢒
    # 0x27893: '',  # 𧢓
    # 0x27894: '',  # 𧢔
    # 0x27895: '',  # 𧢕
    0x27896: 'jiān',  # 𧢖
    # 0x27897: '',  # 𧢗
    # 0x27898: '',  # 𧢘
    # 0x27899: '',  # 𧢙
    # 0x2789A: '',  # 𧢚
    0x2789B: 'yīng',  # 𧢛
    0x2789C: 'fán',  # 𧢜
    0x2789D: 'lì',  # 𧢝
    0x2789E: 'qiān',  # 𧢞
    # 0x2789F: '',  # 𧢟
    # 0x278A0: '',  # 𧢠
    # 0x278A1: '',  # 𧢡
    0x278A2: 'yào',  # 𧢢
    # 0x278A3: '',  # 𧢣
    # 0x278A4: '',  # 𧢤
    # 0x278A5: '',  # 𧢥
    0x278A6: 'kuī,kuí,guì',  # 𧢦
    0x278A7: 'wéi',  # 𧢧
    # 0x278A8: '',  # 𧢨
    0x278A9: 'què',  # 𧢩
    # 0x278AA: '',  # 𧢪
    # 0x278AB: '',  # 𧢫
    0x278AC: 'xiǎo',  # 𧢬
    0x278AD: 'què',  # 𧢭
    # 0x278AE: '',  # 𧢮
    # 0x278AF: '',  # 𧢯
    0x278B0: 'hū',  # 𧢰
    # 0x278B1: '',  # 𧢱
    # 0x278B2: '',  # 𧢲
    # 0x278B3: '',  # 𧢳
    # 0x278B4: '',  # 𧢴
    0x278B5: 'duō',  # 𧢵
    0x278B6: 'chù',  # 𧢶
    # 0x278B7: '',  # 𧢷
    # 0x278B8: '',  # 𧢸
    0x278B9: 'shēn,jīn',  # 𧢹
    # 0x278BA: '',  # 𧢺
    0x278BB: 'chù',  # 𧢻
    0x278BC: 'zhuó',  # 𧢼
    0x278BD: 'é',  # 𧢽
    0x278BE: 'jì',  # 𧢾
    # 0x278BF: '',  # 𧢿
    # 0x278C0: '',  # 𧣀
    0x278C1: 'tán',  # 𧣁
    # 0x278C2: '',  # 𧣂
    0x278C3: 'pā',  # 𧣃
    # 0x278C4: '',  # 𧣄
    # 0x278C5: '',  # 𧣅
    # 0x278C6: '',  # 𧣆
    # 0x278C7: '',  # 𧣇
    0x278C8: 'chù',  # 𧣈
    # 0x278C9: '',  # 𧣉
    # 0x278CA: '',  # 𧣊
    0x278CB: 'jiè',  # 𧣋
    0x278CC: 'qiào',  # 𧣌
    # 0x278CD: '',  # 𧣍
    # 0x278CE: '',  # 𧣎
    # 0x278CF: '',  # 𧣏
    # 0x278D0: '',  # 𧣐
    0x278D1: 'qián',  # 𧣑
    0x278D2: 'jù',  # 𧣒
    # 0x278D3: '',  # 𧣓
    # 0x278D4: '',  # 𧣔
    0x278D5: 'qiú',  # 𧣕
    0x278D6: 'tuó',  # 𧣖
    # 0x278D7: '',  # 𧣗
    # 0x278D8: '',  # 𧣘
    # 0x278D9: '',  # 𧣙
    0x278DA: 'nuò',  # 𧣚
    0x278DB: 'sì',  # 𧣛
    # 0x278DC: '',  # 𧣜
    # 0x278DD: '',  # 𧣝
    # 0x278DE: '',  # 𧣞
    0x278DF: 'yí',  # 𧣟
    # 0x278E0: '',  # 𧣠
    0x278E1: 'gǔ',  # 𧣡
    0x278E2: 'hùn',  # 𧣢
    0x278E3: 'pá',  # 𧣣
    0x278E4: 'zī',  # 𧣤
    # 0x278E5: '',  # 𧣥
    0x278E6: 'jiāo',  # 𧣦
    # 0x278E7: '',  # 𧣧
    # 0x278E8: '',  # 𧣨
    0x278E9: 'xǐ',  # 𧣩
    0x278EA: 'shǎo,shào',  # 𧣪
    # 0x278EB: '',  # 𧣫
    0x278EC: 'yí',  # 𧣬
    0x278ED: 'zhì',  # 𧣭
    # 0x278EE: '',  # 𧣮
    # 0x278EF: '',  # 𧣯
    # 0x278F0: '',  # 𧣰
    # 0x278F1: '',  # 𧣱
    # 0x278F2: '',  # 𧣲
    # 0x278F3: '',  # 𧣳
    # 0x278F4: '',  # 𧣴
    0x278F5: 'lùn',  # 𧣵
    # 0x278F6: '',  # 𧣶
    0x278F7: 'zhōu',  # 𧣷
    0x278F8: 'jué',  # 𧣸
    0x278F9: 'tán',  # 𧣹
    0x278FA: 'nuò,chuò',  # 𧣺
    0x278FB: 'jù',  # 𧣻
    0x278FC: 'hú',  # 𧣼
    # 0x278FD: '',  # 𧣽
    0x278FE: 'zhì',  # 𧣾
    # 0x278FF: '',  # 𧣿
    # 0x27900: '',  # 𧤀
    # 0x27901: '',  # 𧤁
    # 0x27902: '',  # 𧤂
    0x27903: 'bī',  # 𧤃
    # 0x27904: '',  # 𧤄
    # 0x27905: '',  # 𧤅
    # 0x27906: '',  # 𧤆
    # 0x27907: '',  # 𧤇
    # 0x27908: '',  # 𧤈
    # 0x27909: '',  # 𧤉
    # 0x2790A: '',  # 𧤊
    # 0x2790B: '',  # 𧤋
    # 0x2790C: '',  # 𧤌
    0x2790D: 'chì,tì',  # 𧤍
    0x2790E: 'xuān',  # 𧤎
    0x2790F: 'jí',  # 𧤏
    0x27910: 'guǎ',  # 𧤐
    0x27911: 'jú',  # 𧤑
    0x27912: 'wò',  # 𧤒
    0x27913: 'tuó',  # 𧤓
    # 0x27914: '',  # 𧤔
    0x27915: 'qiú',  # 𧤕
    0x27916: 'wēi',  # 𧤖
    0x27917: 'duān',  # 𧤗
    # 0x27918: '',  # 𧤘
    0x27919: 'shòu',  # 𧤙
    # 0x2791A: '',  # 𧤚
    0x2791B: 'zhěn',  # 𧤛
    0x2791C: 'nè,lì',  # 𧤜
    # 0x2791D: '',  # 𧤝
    # 0x2791E: '',  # 𧤞
    0x2791F: 'xì',  # 𧤟
    0x27920: 'zhé',  # 𧤠
    0x27921: 'zhì',  # 𧤡
    # 0x27922: '',  # 𧤢
    0x27923: 'ná',  # 𧤣
    # 0x27924: '',  # 𧤤
    # 0x27925: '',  # 𧤥
    # 0x27926: '',  # 𧤦
    # 0x27927: '',  # 𧤧
    0x27928: 'jiān',  # 𧤨
    # 0x27929: '',  # 𧤩
    # 0x2792A: '',  # 𧤪
    # 0x2792B: '',  # 𧤫
    # 0x2792C: '',  # 𧤬
    # 0x2792D: '',  # 𧤭
    0x2792E: 'yáo',  # 𧤮
    0x2792F: 'guó,yuè',  # 𧤯
    # 0x27930: '',  # 𧤰
    # 0x27931: '',  # 𧤱
    0x27932: 'dǐ',  # 𧤲
    # 0x27933: '',  # 𧤳
    0x27934: 'huò',  # 𧤴
    0x27935: 'jīng',  # 𧤵
    # 0x27936: '',  # 𧤶
    # 0x27937: '',  # 𧤷
    # 0x27938: '',  # 𧤸
    # 0x27939: '',  # 𧤹
    # 0x2793A: '',  # 𧤺
    # 0x2793B: '',  # 𧤻
    0x2793C: 'jué',  # 𧤼
    0x2793D: 'yuè,jiàn',  # 𧤽
    # 0x2793E: '',  # 𧤾
    # 0x2793F: '',  # 𧤿
    # 0x27940: '',  # 𧥀
    # 0x27941: '',  # 𧥁
    # 0x27942: '',  # 𧥂
    # 0x27943: '',  # 𧥃
    0x27944: 'jí',  # 𧥄
    # 0x27945: '',  # 𧥅
    0x27946: 'sù',  # 𧥆
    # 0x27947: '',  # 𧥇
    0x27948: 'jiān',  # 𧥈
    # 0x27949: '',  # 𧥉
    0x2794A: 'kūn',  # 𧥊
    0x2794B: 'wò',  # 𧥋
    0x2794C: 'kuàng',  # 𧥌
    0x2794D: 'biāo',  # 𧥍
    0x2794E: 'jué',  # 𧥎
    # 0x2794F: '',  # 𧥏
    # 0x27950: '',  # 𧥐
    0x27951: 'bì',  # 𧥑
    # 0x27952: '',  # 𧥒
    0x27953: 'chán',  # 𧥓
    # 0x27954: '',  # 𧥔
    0x27955: 'zī',  # 𧥕
    0x27956: 'lì,shǐ',  # 𧥖
    # 0x27957: '',  # 𧥗
    # 0x27958: '',  # 𧥘
    # 0x27959: '',  # 𧥙
    0x2795A: 'fó',  # 𧥚
    0x2795B: 'qiǎn',  # 𧥛
    0x2795C: 'yǎn',  # 𧥜
    # 0x2795D: '',  # 𧥝
    0x2795E: 'tàn',  # 𧥞
    0x2795F: 'mò',  # 𧥟
    # 0x27960: '',  # 𧥠
    # 0x27961: '',  # 𧥡
    # 0x27962: '',  # 𧥢
    0x27963: 'kòu',  # 𧥣
    0x27964: 'xī,xiē',  # 𧥤
    # 0x27965: '',  # 𧥥
    # 0x27966: '',  # 𧥦
    # 0x27967: '',  # 𧥧
    # 0x27968: '',  # 𧥨
    # 0x27969: '',  # 𧥩
    # 0x2796A: '',  # 𧥪
    # 0x2796B: '',  # 𧥫
    # 0x2796C: '',  # 𧥬
    # 0x2796D: '',  # 𧥭
    0x2796E: 'hù,dǐ',  # 𧥮
    0x2796F: 'hù',  # 𧥯
    # 0x27970: '',  # 𧥰
    0x27971: 'fú',  # 𧥱
    # 0x27972: '',  # 𧥲
    # 0x27973: '',  # 𧥳
    0x27974: 'yàng',  # 𧥴
    0x27975: 'guò',  # 𧥵
    # 0x27976: '',  # 𧥶
    0x27977: 'rén',  # 𧥷
    0x27978: 'yìn',  # 𧥸
    0x27979: 'fēng',  # 𧥹
    0x2797A: 'jùn,yùn',  # 𧥺
    # 0x2797B: '',  # 𧥻
    0x2797C: 'yún',  # 𧥼
    # 0x2797D: '',  # 𧥽
    # 0x2797E: '',  # 𧥾
    0x2797F: 'xùn',  # 𧥿
    # 0x27980: '',  # 𧦀
    0x27981: 'xì',  # 𧦁
    # 0x27982: '',  # 𧦂
    # 0x27983: '',  # 𧦃
    # 0x27984: '',  # 𧦄
    # 0x27985: '',  # 𧦅
    # 0x27986: '',  # 𧦆
    # 0x27987: '',  # 𧦇
    # 0x27988: '',  # 𧦈
    # 0x27989: '',  # 𧦉
    # 0x2798A: '',  # 𧦊
    # 0x2798B: '',  # 𧦋
    # 0x2798C: '',  # 𧦌
    # 0x2798D: '',  # 𧦍
    0x2798E: 'xiā',  # 𧦎
    # 0x2798F: '',  # 𧦏
    # 0x27990: '',  # 𧦐
    0x27991: 'háng',  # 𧦑
    # 0x27992: '',  # 𧦒
    # 0x27993: '',  # 𧦓
    # 0x27994: '',  # 𧦔
    # 0x27995: '',  # 𧦕
    # 0x27996: '',  # 𧦖
    # 0x27997: '',  # 𧦗
    # 0x27998: '',  # 𧦘
    # 0x27999: '',  # 𧦙
    0x2799A: 'hù,dǐ',  # 𧦚
    # 0x2799B: '',  # 𧦛
    # 0x2799C: '',  # 𧦜
    0x2799D: 'hū,hào',  # 𧦝
    0x2799E: 'pù',  # 𧦞
    0x2799F: 'fān',  # 𧦟
    # 0x279A0: '',  # 𧦠
    # 0x279A1: '',  # 𧦡
    # 0x279A2: '',  # 𧦢
    # 0x279A3: '',  # 𧦣
    0x279A4: 'jiā',  # 𧦤
    # 0x279A5: '',  # 𧦥
    # 0x279A6: '',  # 𧦦
    0x279A7: 'yí,tuō',  # 𧦧
    # 0x279A8: '',  # 𧦨
    # 0x279A9: '',  # 𧦩
    # 0x279AA: '',  # 𧦪
    # 0x279AB: '',  # 𧦫
    # 0x279AC: '',  # 𧦬
    0x279AD: 'tuō,xī',  # 𧦭
    0x279AE: 'ná',  # 𧦮
    # 0x279AF: '',  # 𧦯
    # 0x279B0: '',  # 𧦰
    # 0x279B1: '',  # 𧦱
    # 0x279B2: '',  # 𧦲
    # 0x279B3: '',  # 𧦳
    0x279B4: 'chá',  # 𧦴
    # 0x279B5: '',  # 𧦵
    # 0x279B6: '',  # 𧦶
    # 0x279B7: '',  # 𧦷
    0x279B8: 'yín',  # 𧦸
    0x279B9: 'yìn',  # 𧦹
    # 0x279BA: '',  # 𧦺
    # 0x279BB: '',  # 𧦻
    # 0x279BC: '',  # 𧦼
    # 0x279BD: '',  # 𧦽
    # 0x279BE: '',  # 𧦾
    # 0x279BF: '',  # 𧦿
    # 0x279C0: '',  # 𧧀
    0x279C1: 'yuǎn',  # 𧧁
    # 0x279C2: '',  # 𧧂
    0x279C3: 'jì',  # 𧧃
    0x279C4: 'wàng',  # 𧧄
    0x279C5: 'shì,jiàn',  # 𧧅
    0x279C6: 'duī',  # 𧧆
    0x279C7: 'duò',  # 𧧇
    # 0x279C8: '',  # 𧧈
    0x279C9: 'tuó',  # 𧧉
    0x279CA: 'wā',  # 𧧊
    0x279CB: 'lì',  # 𧧋
    # 0x279CC: '',  # 𧧌
    # 0x279CD: '',  # 𧧍
    # 0x279CE: '',  # 𧧎
    0x279CF: 'rè,rě',  # 𧧏
    # 0x279D0: '',  # 𧧐
    # 0x279D1: '',  # 𧧑
    0x279D2: 'cì',  # 𧧒
    0x279D3: 'xù',  # 𧧓
    0x279D4: 'zhōu',  # 𧧔
    0x279D5: 'zì',  # 𧧕
    # 0x279D6: '',  # 𧧖
    # 0x279D7: '',  # 𧧗
    # 0x279D8: '',  # 𧧘
    # 0x279D9: '',  # 𧧙
    # 0x279DA: '',  # 𧧚
    0x279DB: 'nán',  # 𧧛
    0x279DC: 'wǎng',  # 𧧜
    0x279DD: 'yǎ',  # 𧧝
    # 0x279DE: '',  # 𧧞
    0x279DF: 'jì',  # 𧧟
    0x279E0: 'chǎo',  # 𧧠
    # 0x279E1: '',  # 𧧡
    # 0x279E2: '',  # 𧧢
    # 0x279E3: '',  # 𧧣
    # 0x279E4: '',  # 𧧤
    # 0x279E5: '',  # 𧧥
    # 0x279E6: '',  # 𧧦
    # 0x279E7: '',  # 𧧧
    # 0x279E8: '',  # 𧧨
    0x279E9: 'jí',  # 𧧩
    # 0x279EA: '',  # 𧧪
    # 0x279EB: '',  # 𧧫
    0x279EC: 'zhí,xiè',  # 𧧬
    0x279ED: 'gàng',  # 𧧭
    # 0x279EE: '',  # 𧧮
    # 0x279EF: '',  # 𧧯
    0x279F0: 'zhǐ',  # 𧧰
    # 0x279F1: '',  # 𧧱
    # 0x279F2: '',  # 𧧲
    # 0x279F3: '',  # 𧧳
    # 0x279F4: '',  # 𧧴
    0x279F5: 'shǎn',  # 𧧵
    0x279F6: 'tú',  # 𧧶
    # 0x279F7: '',  # 𧧷
    0x279F8: 'bié',  # 𧧸
    0x279F9: 'xì',  # 𧧹
    0x279FA: 'pī',  # 𧧺
    0x279FB: 'zhà',  # 𧧻
    # 0x279FC: '',  # 𧧼
    # 0x279FD: '',  # 𧧽
    0x279FE: 'huì',  # 𧧾
    # 0x279FF: '',  # 𧧿
    0x27A00: 'suō,zuò',  # 𧨀
    # 0x27A01: '',  # 𧨁
    0x27A02: 'hè',  # 𧨂
    # 0x27A03: '',  # 𧨃
    0x27A04: 'yuē',  # 𧨄
    # 0x27A05: '',  # 𧨅
    0x27A06: 'wū,huǎng',  # 𧨆
    # 0x27A07: '',  # 𧨇
    0x27A08: 'líng,wū',  # 𧨈
    # 0x27A09: '',  # 𧨉
    0x27A0A: 'zhà',  # 𧨊
    0x27A0B: 'huá',  # 𧨋
    # 0x27A0C: '',  # 𧨌
    # 0x27A0D: '',  # 𧨍
    # 0x27A0E: '',  # 𧨎
    # 0x27A0F: '',  # 𧨏
    # 0x27A10: '',  # 𧨐
    # 0x27A11: '',  # 𧨑
    # 0x27A12: '',  # 𧨒
    # 0x27A13: '',  # 𧨓
    # 0x27A14: '',  # 𧨔
    # 0x27A15: '',  # 𧨕
    # 0x27A16: '',  # 𧨖
    0x27A17: 'chán',  # 𧨗
    # 0x27A18: '',  # 𧨘
    # 0x27A19: '',  # 𧨙
    # 0x27A1A: '',  # 𧨚
    # 0x27A1B: '',  # 𧨛
    # 0x27A1C: '',  # 𧨜
    # 0x27A1D: '',  # 𧨝
    # 0x27A1E: '',  # 𧨞
    0x27A1F: 'è',  # 𧨟
    # 0x27A20: '',  # 𧨠
    0x27A21: 'chén',  # 𧨡
    0x27A22: 'xiáng',  # 𧨢
    # 0x27A23: '',  # 𧨣
    # 0x27A24: '',  # 𧨤
    # 0x27A25: '',  # 𧨥
    # 0x27A26: '',  # 𧨦
    0x27A27: 'suì',  # 𧨧
    # 0x27A28: '',  # 𧨨
    0x27A29: 'tiǎn',  # 𧨩
    # 0x27A2A: '',  # 𧨪
    # 0x27A2B: '',  # 𧨫
    # 0x27A2C: '',  # 𧨬
    # 0x27A2D: '',  # 𧨭
    # 0x27A2E: '',  # 𧨮
    # 0x27A2F: '',  # 𧨯
    0x27A30: 'zhì',  # 𧨰
    0x27A31: 'tì',  # 𧨱
    0x27A32: 'āo',  # 𧨲
    0x27A33: 'zhuó',  # 𧨳
    0x27A34: 'zì',  # 𧨴
    0x27A35: 'kē',  # 𧨵
    # 0x27A36: '',  # 𧨶
    0x27A37: 'sè',  # 𧨷
    0x27A38: 'tián',  # 𧨸
    0x27A39: 'lù',  # 𧨹
    # 0x27A3A: '',  # 𧨺
    # 0x27A3B: '',  # 𧨻
    # 0x27A3C: '',  # 𧨼
    # 0x27A3D: '',  # 𧨽
    0x27A3E: 'shán',  # 𧨾
    0x27A3F: 'zhǎ',  # 𧨿
    # 0x27A40: '',  # 𧩀
    # 0x27A41: '',  # 𧩁
    # 0x27A42: '',  # 𧩂
    0x27A43: 'chōng',  # 𧩃
    # 0x27A44: '',  # 𧩄
    0x27A45: 'yàn',  # 𧩅
    # 0x27A46: '',  # 𧩆
    # 0x27A47: '',  # 𧩇
    # 0x27A48: '',  # 𧩈
    # 0x27A49: '',  # 𧩉
    # 0x27A4A: '',  # 𧩊
    # 0x27A4B: '',  # 𧩋
    # 0x27A4C: '',  # 𧩌
    # 0x27A4D: '',  # 𧩍
    # 0x27A4E: '',  # 𧩎
    # 0x27A4F: '',  # 𧩏
    # 0x27A50: '',  # 𧩐
    # 0x27A51: '',  # 𧩑
    0x27A52: 'mǔ',  # 𧩒
    0x27A53: 'hū',  # 𧩓
    # 0x27A54: '',  # 𧩔
    # 0x27A55: '',  # 𧩕
    # 0x27A56: '',  # 𧩖
    # 0x27A57: '',  # 𧩗
    # 0x27A58: '',  # 𧩘
    # 0x27A59: '',  # 𧩙
    0x27A5A: 'chī',  # 𧩚
    # 0x27A5B: '',  # 𧩛
    # 0x27A5C: '',  # 𧩜
    0x27A5D: 'sù',  # 𧩝
    # 0x27A5E: '',  # 𧩞
    # 0x27A5F: '',  # 𧩟
    # 0x27A60: '',  # 𧩠
    # 0x27A61: '',  # 𧩡
    # 0x27A62: '',  # 𧩢
    0x27A63: 'nǎo',  # 𧩣
    # 0x27A64: '',  # 𧩤
    # 0x27A65: '',  # 𧩥
    0x27A66: 'jí',  # 𧩦
    0x27A67: 'duó',  # 𧩧
    0x27A68: 'hòu',  # 𧩨
    # 0x27A69: '',  # 𧩩
    0x27A6A: 'còng',  # 𧩪
    0x27A6B: 'zhā,chà',  # 𧩫
    0x27A6C: 'yín',  # 𧩬
    # 0x27A6D: '',  # 𧩭
    0x27A6E: 'xiǎo,sǒu,sòu',  # 𧩮
    # 0x27A6F: '',  # 𧩯
    0x27A70: 'biàn',  # 𧩰
    0x27A71: 'bèng',  # 𧩱
    0x27A72: 'là',  # 𧩲
    # 0x27A73: '',  # 𧩳
    0x27A74: 'chī,chì',  # 𧩴
    # 0x27A75: '',  # 𧩵
    0x27A76: 'qià',  # 𧩶
    # 0x27A77: '',  # 𧩷
    0x27A78: 'ān',  # 𧩸
    0x27A79: 'shī,yǐ',  # 𧩹
    # 0x27A7A: '',  # 𧩺
    # 0x27A7B: '',  # 𧩻
    0x27A7C: 'chì,zhǐ',  # 𧩼
    # 0x27A7D: '',  # 𧩽
    # 0x27A7E: '',  # 𧩾
    # 0x27A7F: '',  # 𧩿
    # 0x27A80: '',  # 𧪀
    # 0x27A81: '',  # 𧪁
    # 0x27A82: '',  # 𧪂
    # 0x27A83: '',  # 𧪃
    # 0x27A84: '',  # 𧪄
    0x27A85: 'nù',  # 𧪅
    # 0x27A86: '',  # 𧪆
    0x27A87: 'jì',  # 𧪇
    # 0x27A88: '',  # 𧪈
    # 0x27A89: '',  # 𧪉
    # 0x27A8A: '',  # 𧪊
    # 0x27A8B: '',  # 𧪋
    # 0x27A8C: '',  # 𧪌
    # 0x27A8D: '',  # 𧪍
    # 0x27A8E: '',  # 𧪎
    # 0x27A8F: '',  # 𧪏
    # 0x27A90: '',  # 𧪐
    # 0x27A91: '',  # 𧪑
    # 0x27A92: '',  # 𧪒
    0x27A93: 'ǒu',  # 𧪓
    # 0x27A94: '',  # 𧪔
    0x27A95: 'xiā',  # 𧪕
    # 0x27A96: '',  # 𧪖
    # 0x27A97: '',  # 𧪗
    0x27A98: 'chài,cuǒ,jiē',  # 𧪘
    # 0x27A99: '',  # 𧪙
    0x27A9A: 'ái',  # 𧪚
    # 0x27A9B: '',  # 𧪛
    # 0x27A9C: '',  # 𧪜
    0x27A9D: 'shèng',  # 𧪝
    0x27A9E: 'hé,gé',  # 𧪞
    # 0x27A9F: '',  # 𧪟
    0x27AA0: 'jí',  # 𧪠
    0x27AA1: 'chī',  # 𧪡
    0x27AA2: 'xì',  # 𧪢
    0x27AA3: 'zhēng',  # 𧪣
    # 0x27AA4: '',  # 𧪤
    # 0x27AA5: '',  # 𧪥
    0x27AA6: 'tā',  # 𧪦
    # 0x27AA7: '',  # 𧪧
    0x27AA8: 'mà',  # 𧪨
    # 0x27AA9: '',  # 𧪩
    # 0x27AAA: '',  # 𧪪
    0x27AAB: 'pī',  # 𧪫
    # 0x27AAC: '',  # 𧪬
    # 0x27AAD: '',  # 𧪭
    0x27AAE: 'xū,huá',  # 𧪮
    0x27AAF: 'qiǎn',  # 𧪯
    # 0x27AB0: '',  # 𧪰
    # 0x27AB1: '',  # 𧪱
    # 0x27AB2: '',  # 𧪲
    # 0x27AB3: '',  # 𧪳
    # 0x27AB4: '',  # 𧪴
    # 0x27AB5: '',  # 𧪵
    # 0x27AB6: '',  # 𧪶
    0x27AB7: 'xī',  # 𧪷
    # 0x27AB8: '',  # 𧪸
    0x27AB9: 'xià',  # 𧪹
    # 0x27ABA: '',  # 𧪺
    # 0x27ABB: '',  # 𧪻
    # 0x27ABC: '',  # 𧪼
    # 0x27ABD: '',  # 𧪽
    # 0x27ABE: '',  # 𧪾
    # 0x27ABF: '',  # 𧪿
    # 0x27AC0: '',  # 𧫀
    # 0x27AC1: '',  # 𧫁
    # 0x27AC2: '',  # 𧫂
    # 0x27AC3: '',  # 𧫃
    # 0x27AC4: '',  # 𧫄
    # 0x27AC5: '',  # 𧫅
    # 0x27AC6: '',  # 𧫆
    # 0x27AC7: '',  # 𧫇
    # 0x27AC8: '',  # 𧫈
    # 0x27AC9: '',  # 𧫉
    0x27ACA: 'yù',  # 𧫊
    # 0x27ACB: '',  # 𧫋
    # 0x27ACC: '',  # 𧫌
    # 0x27ACD: '',  # 𧫍
    # 0x27ACE: '',  # 𧫎
    # 0x27ACF: '',  # 𧫏
    # 0x27AD0: '',  # 𧫐
    0x27AD1: 'jié',  # 𧫑
    0x27AD2: 'xià',  # 𧫒
    0x27AD3: 'lǔ',  # 𧫓
    # 0x27AD4: '',  # 𧫔
    0x27AD5: 'qiè',  # 𧫕
    # 0x27AD6: '',  # 𧫖
    0x27AD7: 'chà',  # 𧫗
    # 0x27AD8: '',  # 𧫘
    # 0x27AD9: '',  # 𧫙
    # 0x27ADA: '',  # 𧫚
    0x27ADB: 'yàng',  # 𧫛
    0x27ADC: 'jì',  # 𧫜
    0x27ADD: 'shǎ',  # 𧫝
    0x27ADE: 'lòu',  # 𧫞
    # 0x27ADF: '',  # 𧫟
    0x27AE0: 'jī',  # 𧫠
    0x27AE1: 'zhì',  # 𧫡
    0x27AE2: 'wàng',  # 𧫢
    # 0x27AE3: '',  # 𧫣
    0x27AE4: 'bì',  # 𧫤
    0x27AE5: 'ān',  # 𧫥
    0x27AE6: 'yī',  # 𧫦
    0x27AE7: 'ān,àn',  # 𧫧
    # 0x27AE8: '',  # 𧫨
    # 0x27AE9: '',  # 𧫩
    # 0x27AEA: '',  # 𧫪
    # 0x27AEB: '',  # 𧫫
    0x27AEC: 'lí',  # 𧫬
    # 0x27AED: '',  # 𧫭
    # 0x27AEE: '',  # 𧫮
    # 0x27AEF: '',  # 𧫯
    # 0x27AF0: '',  # 𧫰
    # 0x27AF1: '',  # 𧫱
    # 0x27AF2: '',  # 𧫲
    # 0x27AF3: '',  # 𧫳
    # 0x27AF4: '',  # 𧫴
    # 0x27AF5: '',  # 𧫵
    # 0x27AF6: '',  # 𧫶
    # 0x27AF7: '',  # 𧫷
    # 0x27AF8: '',  # 𧫸
    0x27AF9: 'xiān',  # 𧫹
    # 0x27AFA: '',  # 𧫺
    # 0x27AFB: '',  # 𧫻
    # 0x27AFC: '',  # 𧫼
    # 0x27AFD: '',  # 𧫽
    0x27AFE: 'jiù',  # 𧫾
    0x27AFF: 'tǎn',  # 𧫿
    # 0x27B00: '',  # 𧬀
    0x27B01: 'hào',  # 𧬁
    0x27B02: 'hè',  # 𧬂
    # 0x27B03: '',  # 𧬃
    # 0x27B04: '',  # 𧬄
    0x27B05: 'zhā',  # 𧬅
    0x27B06: 'zhǎn',  # 𧬆
    0x27B07: 'yì',  # 𧬇
    0x27B08: 'xì',  # 𧬈
    # 0x27B09: '',  # 𧬉
    0x27B0A: 'xì,sí',  # 𧬊
    0x27B0B: 'fà',  # 𧬋
    0x27B0C: 'yán',  # 𧬌
    # 0x27B0D: '',  # 𧬍
    # 0x27B0E: '',  # 𧬎
    0x27B0F: 'mǔ',  # 𧬏
    # 0x27B10: '',  # 𧬐
    # 0x27B11: '',  # 𧬑
    # 0x27B12: '',  # 𧬒
    # 0x27B13: '',  # 𧬓
    # 0x27B14: '',  # 𧬔
    0x27B15: 'gū',  # 𧬕
    # 0x27B16: '',  # 𧬖
    # 0x27B17: '',  # 𧬗
    # 0x27B18: '',  # 𧬘
    # 0x27B19: '',  # 𧬙
    # 0x27B1A: '',  # 𧬚
    # 0x27B1B: '',  # 𧬛
    # 0x27B1C: '',  # 𧬜
    # 0x27B1D: '',  # 𧬝
    0x27B1E: 'yún',  # 𧬞
    # 0x27B1F: '',  # 𧬟
    # 0x27B20: '',  # 𧬠
    # 0x27B21: '',  # 𧬡
    # 0x27B22: '',  # 𧬢
    # 0x27B23: '',  # 𧬣
    0x27B24: 'zhòng',  # 𧬤
    # 0x27B25: '',  # 𧬥
    0x27B26: 'chǎn',  # 𧬦
    0x27B27: 'chuáng',  # 𧬧
    0x27B28: 'huì',  # 𧬨
    0x27B29: 'zá',  # 𧬩
    0x27B2A: 'gùn',  # 𧬪
    0x27B2B: 'jiǎn',  # 𧬫
    0x27B2C: 'yá',  # 𧬬
    # 0x27B2D: '',  # 𧬭
    0x27B2E: 'guà',  # 𧬮
    # 0x27B2F: '',  # 𧬯
    0x27B30: 'xiàng,xiǎng',  # 𧬰
    0x27B31: 'hè',  # 𧬱
    # 0x27B32: '',  # 𧬲
    # 0x27B33: '',  # 𧬳
    # 0x27B34: '',  # 𧬴
    # 0x27B35: '',  # 𧬵
    # 0x27B36: '',  # 𧬶
    # 0x27B37: '',  # 𧬷
    # 0x27B38: '',  # 𧬸
    # 0x27B39: '',  # 𧬹
    # 0x27B3A: '',  # 𧬺
    0x27B3B: 'tà',  # 𧬻
    # 0x27B3C: '',  # 𧬼
    # 0x27B3D: '',  # 𧬽
    # 0x27B3E: '',  # 𧬾
    # 0x27B3F: '',  # 𧬿
    # 0x27B40: '',  # 𧭀
    # 0x27B41: '',  # 𧭁
    # 0x27B42: '',  # 𧭂
    0x27B43: 'dàn',  # 𧭃
    # 0x27B44: '',  # 𧭄
    # 0x27B45: '',  # 𧭅
    # 0x27B46: '',  # 𧭆
    0x27B47: 'mián',  # 𧭇
    0x27B48: 'níng,nìng',  # 𧭈
    # 0x27B49: '',  # 𧭉
    0x27B4A: 'méng',  # 𧭊
    # 0x27B4B: '',  # 𧭋
    0x27B4C: 'liè',  # 𧭌
    0x27B4D: 'zhòu',  # 𧭍
    0x27B4E: 'pū',  # 𧭎
    0x27B4F: 'tāi',  # 𧭏
    # 0x27B50: '',  # 𧭐
    # 0x27B51: '',  # 𧭑
    # 0x27B52: '',  # 𧭒
    0x27B53: 'yíng',  # 𧭓
    0x27B54: 'téng',  # 𧭔
    0x27B55: 'guó',  # 𧭕
    # 0x27B56: '',  # 𧭖
    # 0x27B57: '',  # 𧭗
    # 0x27B58: '',  # 𧭘
    # 0x27B59: '',  # 𧭙
    0x27B5A: 'qiáng',  # 𧭚
    # 0x27B5B: '',  # 𧭛
    0x27B5C: 'lǜ',  # 𧭜
    0x27B5D: 'sà',  # 𧭝
    0x27B5E: 'liè',  # 𧭞
    0x27B5F: 'chí',  # 𧭟
    0x27B60: 'xiě',  # 𧭠
    # 0x27B61: '',  # 𧭡
    # 0x27B62: '',  # 𧭢
    0x27B63: 'guó',  # 𧭣
    0x27B64: 'bào,báo',  # 𧭤
    0x27B65: 'luò',  # 𧭥
    0x27B66: 'juàn,xuān',  # 𧭦
    # 0x27B67: '',  # 𧭧
    # 0x27B68: '',  # 𧭨
    # 0x27B69: '',  # 𧭩
    0x27B6A: 'è',  # 𧭪
    # 0x27B6B: '',  # 𧭫
    # 0x27B6C: '',  # 𧭬
    0x27B6D: 'yìng',  # 𧭭
    # 0x27B6E: '',  # 𧭮
    # 0x27B6F: '',  # 𧭯
    # 0x27B70: '',  # 𧭰
    # 0x27B71: '',  # 𧭱
    # 0x27B72: '',  # 𧭲
    0x27B73: 'hé',  # 𧭳
    # 0x27B74: '',  # 𧭴
    0x27B75: 'mèi',  # 𧭵
    # 0x27B76: '',  # 𧭶
    # 0x27B77: '',  # 𧭷
    0x27B78: 'xiè',  # 𧭸
    0x27B79: 'pín',  # 𧭹
    # 0x27B7A: '',  # 𧭺
    0x27B7B: 'hān',  # 𧭻
    0x27B7C: 'chèn',  # 𧭼
    0x27B7D: 'shàn',  # 𧭽
    0x27B7E: 'huì',  # 𧭾
    # 0x27B7F: '',  # 𧭿
    # 0x27B80: '',  # 𧮀
    # 0x27B81: '',  # 𧮁
    # 0x27B82: '',  # 𧮂
    # 0x27B83: '',  # 𧮃
    # 0x27B84: '',  # 𧮄
    # 0x27B85: '',  # 𧮅
    0x27B86: 'yīng',  # 𧮆
    0x27B87: 'mài',  # 𧮇
    0x27B88: 'jiǎn',  # 𧮈
    # 0x27B89: '',  # 𧮉
    # 0x27B8A: '',  # 𧮊
    # 0x27B8B: '',  # 𧮋
    # 0x27B8C: '',  # 𧮌
    0x27B8D: 'ān',  # 𧮍
    # 0x27B8E: '',  # 𧮎
    # 0x27B8F: '',  # 𧮏
    # 0x27B90: '',  # 𧮐
    0x27B91: 'tà',  # 𧮑
    0x27B92: 'yī',  # 𧮒
    0x27B93: 'tuí',  # 𧮓
    # 0x27B94: '',  # 𧮔
    # 0x27B95: '',  # 𧮕
    # 0x27B96: '',  # 𧮖
    0x27B97: 'liú',  # 𧮗
    # 0x27B98: '',  # 𧮘
    0x27B99: 'zuó',  # 𧮙
    0x27B9A: 'mài',  # 𧮚
    0x27B9B: 'lí',  # 𧮛
    # 0x27B9C: '',  # 𧮜
    0x27B9D: 'pín',  # 𧮝
    0x27B9E: 'xuè',  # 𧮞
    # 0x27B9F: '',  # 𧮟
    0x27BA0: 'nèn',  # 𧮠
    0x27BA1: 'dòu',  # 𧮡
    # 0x27BA2: '',  # 𧮢
    # 0x27BA3: '',  # 𧮣
    0x27BA4: 'lǎn',  # 𧮤
    # 0x27BA5: '',  # 𧮥
    # 0x27BA6: '',  # 𧮦
    # 0x27BA7: '',  # 𧮧
    # 0x27BA8: '',  # 𧮨
    # 0x27BA9: '',  # 𧮩
    0x27BAA: 'zhān',  # 𧮪
    0x27BAB: 'jué',  # 𧮫
    0x27BAC: 'zhēn,jué',  # 𧮬
    0x27BAD: 'jí',  # 𧮭
    0x27BAE: 'qiān',  # 𧮮
    0x27BAF: 'hóng',  # 𧮯
    0x27BB0: 'hān',  # 𧮰
    0x27BB1: 'fén',  # 𧮱
    # 0x27BB2: '',  # 𧮲
    0x27BB3: 'hān',  # 𧮳
    0x27BB4: 'hóng',  # 𧮴
    0x27BB5: 'hé',  # 𧮵
    0x27BB6: 'hóu',  # 𧮶
    # 0x27BB7: '',  # 𧮷
    # 0x27BB8: '',  # 𧮸
    # 0x27BB9: '',  # 𧮹
    0x27BBA: 'zhàn',  # 𧮺
    0x27BBB: 'chóu,xiāo',  # 𧮻
    0x27BBC: 'tài',  # 𧮼
    0x27BBD: 'qiàn',  # 𧮽
    # 0x27BBE: '',  # 𧮾
    0x27BBF: 'shè',  # 𧮿
    0x27BC0: 'yīng',  # 𧯀
    # 0x27BC1: '',  # 𧯁
    # 0x27BC2: '',  # 𧯂
    0x27BC3: 'qīn',  # 𧯃
    # 0x27BC4: '',  # 𧯄
    # 0x27BC5: '',  # 𧯅
    0x27BC6: 'huò',  # 𧯆
    # 0x27BC7: '',  # 𧯇
    0x27BC8: 'xì',  # 𧯈
    0x27BC9: 'hè',  # 𧯉
    0x27BCA: 'xì',  # 𧯊
    0x27BCB: 'xiā',  # 𧯋
    0x27BCC: 'hāo',  # 𧯌
    0x27BCD: 'lào',  # 𧯍
    # 0x27BCE: '',  # 𧯎
    0x27BCF: 'lì',  # 𧯏
    # 0x27BD0: '',  # 𧯐
    # 0x27BD1: '',  # 𧯑
    0x27BD2: 'chēng',  # 𧯒
    # 0x27BD3: '',  # 𧯓
    # 0x27BD4: '',  # 𧯔
    # 0x27BD5: '',  # 𧯕
    0x27BD6: 'jùn',  # 𧯖
    0x27BD7: 'xī',  # 𧯗
    0x27BD8: 'hǎn',  # 𧯘
    # 0x27BD9: '',  # 𧯙
    # 0x27BDA: '',  # 𧯚
    # 0x27BDB: '',  # 𧯛
    # 0x27BDC: '',  # 𧯜
    # 0x27BDD: '',  # 𧯝
    0x27BDE: 'dòu,dōu',  # 𧯞
    # 0x27BDF: '',  # 𧯟
    0x27BE0: 'dōu',  # 𧯠
    0x27BE1: 'wān,yuè',  # 𧯡
    # 0x27BE2: '',  # 𧯢
    # 0x27BE3: '',  # 𧯣
    0x27BE4: 'dōu',  # 𧯤
    0x27BE5: 'zài',  # 𧯥
    0x27BE6: 'juàn',  # 𧯦
    # 0x27BE7: '',  # 𧯧
    0x27BE8: 'lǒu',  # 𧯨
    0x27BE9: 'chù',  # 𧯩
    # 0x27BEA: '',  # 𧯪
    0x27BEB: 'zhēng',  # 𧯫
    # 0x27BEC: '',  # 𧯬
    # 0x27BED: '',  # 𧯭
    # 0x27BEE: '',  # 𧯮
    0x27BEF: 'qí',  # 𧯯
    0x27BF0: 'kàn',  # 𧯰
    0x27BF1: 'huò,yù',  # 𧯱
    0x27BF2: 'lái',  # 𧯲
    # 0x27BF3: '',  # 𧯳
    # 0x27BF4: '',  # 𧯴
    # 0x27BF5: '',  # 𧯵
    # 0x27BF6: '',  # 𧯶
    0x27BF7: 'jǐn',  # 𧯷
    # 0x27BF8: '',  # 𧯸
    # 0x27BF9: '',  # 𧯹
    0x27BFA: 'gāi',  # 𧯺
    # 0x27BFB: '',  # 𧯻
    0x27BFC: 'shòu',  # 𧯼
    # 0x27BFD: '',  # 𧯽
    0x27BFE: 'dōng',  # 𧯾
    # 0x27BFF: '',  # 𧯿
    # 0x27C00: '',  # 𧰀
    # 0x27C01: '',  # 𧰁
    0x27C02: 'tā',  # 𧰂
    0x27C03: 'lóu',  # 𧰃
    0x27C04: 'tuān',  # 𧰄
    # 0x27C05: '',  # 𧰅
    # 0x27C06: '',  # 𧰆
    0x27C07: 'yú',  # 𧰇
    0x27C08: 'wù',  # 𧰈
    # 0x27C09: '',  # 𧰉
    0x27C0A: 'tián',  # 𧰊
    # 0x27C0B: '',  # 𧰋
    # 0x27C0C: '',  # 𧰌
    # 0x27C0D: '',  # 𧰍
    # 0x27C0E: '',  # 𧰎
    # 0x27C0F: '',  # 𧰏
    # 0x27C10: '',  # 𧰐
    # 0x27C11: '',  # 𧰑
    0x27C12: 'guó',  # 𧰒
    # 0x27C13: '',  # 𧰓
    # 0x27C14: '',  # 𧰔
    # 0x27C15: '',  # 𧰕
    # 0x27C16: '',  # 𧰖
    # 0x27C17: '',  # 𧰗
    0x27C18: 'tán',  # 𧰘
    0x27C19: 'qí',  # 𧰙
    # 0x27C1A: '',  # 𧰚
    # 0x27C1B: '',  # 𧰛
    # 0x27C1C: '',  # 𧰜
    # 0x27C1D: '',  # 𧰝
    # 0x27C1E: '',  # 𧰞
    # 0x27C1F: '',  # 𧰟
    0x27C20: 'liè',  # 𧰠
    0x27C21: 'lì',  # 𧰡
    # 0x27C22: '',  # 𧰢
    0x27C23: 'xūn',  # 𧰣
    # 0x27C24: '',  # 𧰤
    # 0x27C25: '',  # 𧰥
    # 0x27C26: '',  # 𧰦
    # 0x27C27: '',  # 𧰧
    0x27C28: 'gèng',  # 𧰨
    0x27C29: 'tīng',  # 𧰩
    0x27C2A: 'hàn',  # 𧰪
    0x27C2B: 'chù',  # 𧰫
    # 0x27C2C: '',  # 𧰬
    0x27C2D: 'tún',  # 𧰭
    # 0x27C2E: '',  # 𧰮
    0x27C2F: 'xióng',  # 𧰯
    0x27C30: 'yóu',  # 𧰰
    0x27C31: 'mò',  # 𧰱
    0x27C32: 'chǐ',  # 𧰲
    # 0x27C33: '',  # 𧰳
    0x27C34: 'hǔ',  # 𧰴
    0x27C35: 'dú,zhuó',  # 𧰵
    # 0x27C36: '',  # 𧰶
    0x27C37: 'mǔ',  # 𧰷
    0x27C38: 'ài',  # 𧰸
    0x27C39: 'nà',  # 𧰹
    # 0x27C3A: '',  # 𧰺
    0x27C3B: 'líng',  # 𧰻
    # 0x27C3C: '',  # 𧰼
    # 0x27C3D: '',  # 𧰽
    # 0x27C3E: '',  # 𧰾
    0x27C3F: 'ài',  # 𧰿
    0x27C40: 'xiān',  # 𧱀
    # 0x27C41: '',  # 𧱁
    # 0x27C42: '',  # 𧱂
    # 0x27C43: '',  # 𧱃
    0x27C44: 'kǎn',  # 𧱄
    0x27C45: 'sì',  # 𧱅
    0x27C46: 'sān',  # 𧱆
    # 0x27C47: '',  # 𧱇
    # 0x27C48: '',  # 𧱈
    # 0x27C49: '',  # 𧱉
    0x27C4A: 'yì',  # 𧱊
    # 0x27C4B: '',  # 𧱋
    # 0x27C4C: '',  # 𧱌
    # 0x27C4D: '',  # 𧱍
    # 0x27C4E: '',  # 𧱎
    0x27C4F: 'yì',  # 𧱏
    0x27C50: 'xiào,xiāo',  # 𧱐
    # 0x27C51: '',  # 𧱑
    0x27C52: 'zhī,zhuō',  # 𧱒
    0x27C53: 'dòu',  # 𧱓
    # 0x27C54: '',  # 𧱔
    # 0x27C55: '',  # 𧱕
    # 0x27C56: '',  # 𧱖
    # 0x27C57: '',  # 𧱗
    0x27C58: 'mài',  # 𧱘
    # 0x27C59: '',  # 𧱙
    # 0x27C5A: '',  # 𧱚
    # 0x27C5B: '',  # 𧱛
    0x27C5C: 'lún',  # 𧱜
    0x27C5D: 'jué,jùn',  # 𧱝
    # 0x27C5E: '',  # 𧱞
    # 0x27C5F: '',  # 𧱟
    # 0x27C60: '',  # 𧱠
    0x27C61: 'qiāng',  # 𧱡
    0x27C62: 'líng',  # 𧱢
    # 0x27C63: '',  # 𧱣
    # 0x27C64: '',  # 𧱤
    # 0x27C65: '',  # 𧱥
    # 0x27C66: '',  # 𧱦
    # 0x27C67: '',  # 𧱧
    # 0x27C68: '',  # 𧱨
    0x27C69: 'pián',  # 𧱩
    0x27C6A: 'còu',  # 𧱪
    0x27C6B: 'duò',  # 𧱫
    0x27C6C: 'yǔ',  # 𧱬
    # 0x27C6D: '',  # 𧱭
    # 0x27C6E: '',  # 𧱮
    # 0x27C6F: '',  # 𧱯
    0x27C70: 'zhuō',  # 𧱰
    # 0x27C71: '',  # 𧱱
    0x27C72: 'xì',  # 𧱲
    0x27C73: 'huài',  # 𧱳
    0x27C74: 'míng',  # 𧱴
    0x27C75: 'táng',  # 𧱵
    # 0x27C76: '',  # 𧱶
    # 0x27C77: '',  # 𧱷
    # 0x27C78: '',  # 𧱸
    0x27C79: 'pū',  # 𧱹
    # 0x27C7A: '',  # 𧱺
    0x27C7B: 'mì',  # 𧱻
    0x27C7C: 'mán',  # 𧱼
    # 0x27C7D: '',  # 𧱽
    0x27C7E: 'guāi',  # 𧱾
    # 0x27C7F: '',  # 𧱿
    0x27C80: 'qiān',  # 𧲀
    # 0x27C81: '',  # 𧲁
    0x27C82: 'lín',  # 𧲂
    0x27C83: 'mǐn',  # 𧲃
    0x27C84: 'wěi',  # 𧲄
    0x27C85: 'céng',  # 𧲅
    # 0x27C86: '',  # 𧲆
    0x27C87: 'hù',  # 𧲇
    0x27C88: 'suí',  # 𧲈
    # 0x27C89: '',  # 𧲉
    # 0x27C8A: '',  # 𧲊
    0x27C8B: 'jù',  # 𧲋
    0x27C8C: 'shà',  # 𧲌
    0x27C8D: 'méng',  # 𧲍
    # 0x27C8E: '',  # 𧲎
    # 0x27C8F: '',  # 𧲏
    # 0x27C90: '',  # 𧲐
    # 0x27C91: '',  # 𧲑
    # 0x27C92: '',  # 𧲒
    # 0x27C93: '',  # 𧲓
    # 0x27C94: '',  # 𧲔
    0x27C95: 'lóu',  # 𧲕
    # 0x27C96: '',  # 𧲖
    0x27C97: 'wéi',  # 𧲗
    0x27C98: 'xī',  # 𧲘
    0x27C99: 'lìng',  # 𧲙
    # 0x27C9A: '',  # 𧲚
    # 0x27C9B: '',  # 𧲛
    0x27C9C: 'bì',  # 𧲜
    0x27C9D: 'wèi',  # 𧲝
    # 0x27C9E: '',  # 𧲞
    # 0x27C9F: '',  # 𧲟
    # 0x27CA0: '',  # 𧲠
    0x27CA1: 'lì',  # 𧲡
    0x27CA2: 'zhé',  # 𧲢
    # 0x27CA3: '',  # 𧲣
    0x27CA4: 'yóng',  # 𧲤
    0x27CA5: 'hú',  # 𧲥
    0x27CA6: 'wán,hé',  # 𧲦
    0x27CA7: 'bā',  # 𧲧
    0x27CA8: 'jiān',  # 𧲨
    # 0x27CA9: '',  # 𧲩
    # 0x27CAA: '',  # 𧲪
    # 0x27CAB: '',  # 𧲫
    # 0x27CAC: '',  # 𧲬
    0x27CAD: 'zuǒ',  # 𧲭
    0x27CAE: 'zhǎn',  # 𧲮
    0x27CAF: 'bō',  # 𧲯
    0x27CB0: 'qiū,chū',  # 𧲰
    0x27CB1: 'yāng',  # 𧲱
    # 0x27CB2: '',  # 𧲲
    # 0x27CB3: '',  # 𧲳
    0x27CB4: 'dōng',  # 𧲴
    0x27CB5: 'qú',  # 𧲵
    # 0x27CB6: '',  # 𧲶
    # 0x27CB7: '',  # 𧲷
    # 0x27CB8: '',  # 𧲸
    # 0x27CB9: '',  # 𧲹
    0x27CBA: 'pí',  # 𧲺
    0x27CBB: 'zhǎi',  # 𧲻
    # 0x27CBC: '',  # 𧲼
    # 0x27CBD: '',  # 𧲽
    0x27CBE: 'shān',  # 𧲾
    0x27CBF: 'gòu',  # 𧲿
    0x27CC0: 'biào,nǎo',  # 𧳀
    0x27CC1: 'yí',  # 𧳁
    0x27CC2: 'fú',  # 𧳂
    # 0x27CC3: '',  # 𧳃
    0x27CC4: 'xìn',  # 𧳄
    0x27CC5: 'shì,shǐ',  # 𧳅
    0x27CC6: 'tōng,tóng',  # 𧳆
    # 0x27CC7: '',  # 𧳇
    # 0x27CC8: '',  # 𧳈
    0x27CC9: 'dīng',  # 𧳉
    # 0x27CCA: '',  # 𧳊
    # 0x27CCB: '',  # 𧳋
    0x27CCC: 'tū',  # 𧳌
    0x27CCD: 'xiāo',  # 𧳍
    0x27CCE: 'wú',  # 𧳎
    0x27CCF: 'péi',  # 𧳏
    0x27CD0: 'huī,xī',  # 𧳐
    # 0x27CD1: '',  # 𧳑
    0x27CD2: 'mào',  # 𧳒
    # 0x27CD3: '',  # 𧳓
    # 0x27CD4: '',  # 𧳔
    0x27CD5: 'lái',  # 𧳕
    # 0x27CD6: '',  # 𧳖
    # 0x27CD7: '',  # 𧳗
    # 0x27CD8: '',  # 𧳘
    0x27CD9: 'sì',  # 𧳙
    0x27CDA: 'cuǐ',  # 𧳚
    0x27CDB: 'shà',  # 𧳛
    0x27CDC: 'zhǒu',  # 𧳜
    0x27CDD: 'zhào',  # 𧳝
    0x27CDE: 'wéi',  # 𧳞
    0x27CDF: 'lái',  # 𧳟
    0x27CE0: 'bì,bǐ',  # 𧳠
    # 0x27CE1: '',  # 𧳡
    # 0x27CE2: '',  # 𧳢
    0x27CE3: 'dǒng',  # 𧳣
    # 0x27CE4: '',  # 𧳤
    # 0x27CE5: '',  # 𧳥
    0x27CE6: 'nǎo',  # 𧳦
    0x27CE7: 'xiē',  # 𧳧
    0x27CE8: 'rǎo',  # 𧳨
    0x27CE9: 'tuàn',  # 𧳩
    0x27CEA: 'wèi',  # 𧳪
    0x27CEB: 'yóu,jiū,qiú,yòu',  # 𧳫
    0x27CEC: 'méi',  # 𧳬
    0x27CED: 'yuán',  # 𧳭
    0x27CEE: 'zhòng',  # 𧳮
    # 0x27CEF: '',  # 𧳯
    # 0x27CF0: '',  # 𧳰
    # 0x27CF1: '',  # 𧳱
    # 0x27CF2: '',  # 𧳲
    # 0x27CF3: '',  # 𧳳
    # 0x27CF4: '',  # 𧳴
    # 0x27CF5: '',  # 𧳵
    0x27CF6: 'sōu',  # 𧳶
    # 0x27CF7: '',  # 𧳷
    0x27CF8: 'gú',  # 𧳸
    0x27CF9: 'shào',  # 𧳹
    0x27CFA: 'nǎo',  # 𧳺
    0x27CFB: 'zhǎo',  # 𧳻
    0x27CFC: 'pí',  # 𧳼
    # 0x27CFD: '',  # 𧳽
    # 0x27CFE: '',  # 𧳾
    0x27CFF: 'tōng',  # 𧳿
    # 0x27D00: '',  # 𧴀
    0x27D01: 'chī',  # 𧴁
    0x27D02: 'péng',  # 𧴂
    0x27D03: 'chán',  # 𧴃
    0x27D04: 'yōng',  # 𧴄
    0x27D05: 'shuǎng',  # 𧴅
    # 0x27D06: '',  # 𧴆
    0x27D07: 'wǔ',  # 𧴇
    # 0x27D08: '',  # 𧴈
    0x27D09: 'pí',  # 𧴉
    0x27D0A: 'huàn',  # 𧴊
    # 0x27D0B: '',  # 𧴋
    0x27D0C: 'fú',  # 𧴌
    # 0x27D0D: '',  # 𧴍
    0x27D0E: 'biào',  # 𧴎
    # 0x27D0F: '',  # 𧴏
    # 0x27D10: '',  # 𧴐
    # 0x27D11: '',  # 𧴑
    # 0x27D12: '',  # 𧴒
    0x27D13: 'náo',  # 𧴓
    # 0x27D14: '',  # 𧴔
    0x27D15: 'biào',  # 𧴕
    0x27D16: 'wèi',  # 𧴖
    0x27D17: 'yōng',  # 𧴗
    # 0x27D18: '',  # 𧴘
    0x27D19: 'nǎo',  # 𧴙
    0x27D1A: 'guài',  # 𧴚
    # 0x27D1B: '',  # 𧴛
    # 0x27D1C: '',  # 𧴜
    # 0x27D1D: '',  # 𧴝
    # 0x27D1E: '',  # 𧴞
    # 0x27D1F: '',  # 𧴟
    0x27D20: 'lì',  # 𧴠
    # 0x27D21: '',  # 𧴡
    0x27D22: 'xìn',  # 𧴢
    0x27D23: 'yán',  # 𧴣
    0x27D24: 'pò',  # 𧴤
    0x27D25: 'péi',  # 𧴥
    # 0x27D26: '',  # 𧴦
    # 0x27D27: '',  # 𧴧
    # 0x27D28: '',  # 𧴨
    # 0x27D29: '',  # 𧴩
    0x27D2A: 'suǒ',  # 𧴪
    # 0x27D2B: '',  # 𧴫
    0x27D2C: 'rèn',  # 𧴬
    0x27D2D: 'shǎn',  # 𧴭
    # 0x27D2E: '',  # 𧴮
    # 0x27D2F: '',  # 𧴯
    # 0x27D30: '',  # 𧴰
    # 0x27D31: '',  # 𧴱
    0x27D32: 'suǒ',  # 𧴲
    # 0x27D33: '',  # 𧴳
    # 0x27D34: '',  # 𧴴
    # 0x27D35: '',  # 𧴵
    # 0x27D36: '',  # 𧴶
    # 0x27D37: '',  # 𧴷
    0x27D38: 'dān',  # 𧴸
    # 0x27D39: '',  # 𧴹
    0x27D3A: 'mèn',  # 𧴺
    # 0x27D3B: '',  # 𧴻
    # 0x27D3C: '',  # 𧴼
    # 0x27D3D: '',  # 𧴽
    # 0x27D3E: '',  # 𧴾
    # 0x27D3F: '',  # 𧴿
    # 0x27D40: '',  # 𧵀
    # 0x27D41: '',  # 𧵁
    # 0x27D42: '',  # 𧵂
    0x27D43: 'shǒu',  # 𧵃
    # 0x27D44: '',  # 𧵄
    # 0x27D45: '',  # 𧵅
    # 0x27D46: '',  # 𧵆
    # 0x27D47: '',  # 𧵇
    0x27D48: 'gòu',  # 𧵈
    # 0x27D49: '',  # 𧵉
    0x27D4A: 'hān,hàn,tàn',  # 𧵊
    0x27D4B: 'shì',  # 𧵋
    0x27D4C: 'yǎng',  # 𧵌
    # 0x27D4D: '',  # 𧵍
    0x27D4E: 'gǔ',  # 𧵎
    # 0x27D4F: '',  # 𧵏
    # 0x27D50: '',  # 𧵐
    0x27D51: 'gǔ',  # 𧵑
    # 0x27D52: '',  # 𧵒
    # 0x27D53: '',  # 𧵓
    # 0x27D54: '',  # 𧵔
    # 0x27D55: '',  # 𧵕
    # 0x27D56: '',  # 𧵖
    # 0x27D57: '',  # 𧵗
    # 0x27D58: '',  # 𧵘
    # 0x27D59: '',  # 𧵙
    # 0x27D5A: '',  # 𧵚
    0x27D5B: 'kē',  # 𧵛
    # 0x27D5C: '',  # 𧵜
    # 0x27D5D: '',  # 𧵝
    0x27D5E: 'jū',  # 𧵞
    # 0x27D5F: '',  # 𧵟
    0x27D60: 'pài',  # 𧵠
    0x27D61: 'cè',  # 𧵡
    0x27D62: 'bāo',  # 𧵢
    0x27D63: 'xiōng,mín',  # 𧵣
    0x27D64: 'cái,zhù',  # 𧵤
    # 0x27D65: '',  # 𧵥
    # 0x27D66: '',  # 𧵦
    0x27D67: 'lǐn',  # 𧵧
    0x27D68: 'ài',  # 𧵨
    # 0x27D69: '',  # 𧵩
    # 0x27D6A: '',  # 𧵪
    # 0x27D6B: '',  # 𧵫
    0x27D6C: 'mì,shèn',  # 𧵬
    0x27D6D: 'lǎi',  # 𧵭
    # 0x27D6E: '',  # 𧵮
    # 0x27D6F: '',  # 𧵯
    # 0x27D70: '',  # 𧵰
    0x27D71: 'xiāo',  # 𧵱
    # 0x27D72: '',  # 𧵲
    0x27D73: 'shé',  # 𧵳
    0x27D74: 'zhù',  # 𧵴
    # 0x27D75: '',  # 𧵵
    # 0x27D76: '',  # 𧵶
    # 0x27D77: '',  # 𧵷
    # 0x27D78: '',  # 𧵸
    # 0x27D79: '',  # 𧵹
    # 0x27D7A: '',  # 𧵺
    0x27D7B: 'huó',  # 𧵻
    0x27D7C: 'nì',  # 𧵼
    # 0x27D7D: '',  # 𧵽
    # 0x27D7E: '',  # 𧵾
    # 0x27D7F: '',  # 𧵿
    # 0x27D80: '',  # 𧶀
    # 0x27D81: '',  # 𧶁
    # 0x27D82: '',  # 𧶂
    # 0x27D83: '',  # 𧶃
    0x27D84: 'zhèng',  # 𧶄
    # 0x27D85: '',  # 𧶅
    0x27D86: 'lìn',  # 𧶆
    0x27D87: 'zhá',  # 𧶇
    # 0x27D88: '',  # 𧶈
    # 0x27D89: '',  # 𧶉
    0x27D8A: 'yún',  # 𧶊
    # 0x27D8B: '',  # 𧶋
    # 0x27D8C: '',  # 𧶌
    0x27D8D: 'xù',  # 𧶍
    # 0x27D8E: '',  # 𧶎
    # 0x27D8F: '',  # 𧶏
    # 0x27D90: '',  # 𧶐
    # 0x27D91: '',  # 𧶑
    # 0x27D92: '',  # 𧶒
    # 0x27D93: '',  # 𧶓
    0x27D94: 'chéng',  # 𧶔
    0x27D95: 'wǒ',  # 𧶕
    0x27D96: 'xī',  # 𧶖
    # 0x27D97: '',  # 𧶗
    # 0x27D98: '',  # 𧶘
    0x27D99: 'bèi',  # 𧶙
    # 0x27D9A: '',  # 𧶚
    # 0x27D9B: '',  # 𧶛
    0x27D9C: 'shāng,shǎng',  # 𧶜
    # 0x27D9D: '',  # 𧶝
    # 0x27D9E: '',  # 𧶞
    # 0x27D9F: '',  # 𧶟
    0x27DA0: 'yù',  # 𧶠
    0x27DA1: 'mì',  # 𧶡
    # 0x27DA2: '',  # 𧶢
    # 0x27DA3: '',  # 𧶣
    # 0x27DA4: '',  # 𧶤
    # 0x27DA5: '',  # 𧶥
    # 0x27DA6: '',  # 𧶦
    # 0x27DA7: '',  # 𧶧
    # 0x27DA8: '',  # 𧶨
    # 0x27DA9: '',  # 𧶩
    # 0x27DAA: '',  # 𧶪
    # 0x27DAB: '',  # 𧶫
    # 0x27DAC: '',  # 𧶬
    # 0x27DAD: '',  # 𧶭
    # 0x27DAE: '',  # 𧶮
    # 0x27DAF: '',  # 𧶯
    # 0x27DB0: '',  # 𧶰
    # 0x27DB1: '',  # 𧶱
    0x27DB2: 'duǎn,zhuàn',  # 𧶲
    # 0x27DB3: '',  # 𧶳
    # 0x27DB4: '',  # 𧶴
    0x27DB5: 'chà',  # 𧶵
    # 0x27DB6: '',  # 𧶶
    0x27DB7: 'zé',  # 𧶷
    0x27DB8: 'chèng',  # 𧶸
    # 0x27DB9: '',  # 𧶹
    0x27DBA: 'tíng',  # 𧶺
    # 0x27DBB: '',  # 𧶻
    # 0x27DBC: '',  # 𧶼
    # 0x27DBD: '',  # 𧶽
    # 0x27DBE: '',  # 𧶾
    # 0x27DBF: '',  # 𧶿
    # 0x27DC0: '',  # 𧷀
    # 0x27DC1: '',  # 𧷁
    # 0x27DC2: '',  # 𧷂
    # 0x27DC3: '',  # 𧷃
    # 0x27DC4: '',  # 𧷄
    0x27DC5: 'yí',  # 𧷅
    # 0x27DC6: '',  # 𧷆
    # 0x27DC7: '',  # 𧷇
    # 0x27DC8: '',  # 𧷈
    # 0x27DC9: '',  # 𧷉
    # 0x27DCA: '',  # 𧷊
    0x27DCB: 'yāo',  # 𧷋
    # 0x27DCC: '',  # 𧷌
    # 0x27DCD: '',  # 𧷍
    0x27DCE: 'kū',  # 𧷎
    # 0x27DCF: '',  # 𧷏
    0x27DD0: 'fén',  # 𧷐
    0x27DD1: 'xié',  # 𧷑
    0x27DD2: 'chèng',  # 𧷒
    # 0x27DD3: '',  # 𧷓
    # 0x27DD4: '',  # 𧷔
    # 0x27DD5: '',  # 𧷕
    # 0x27DD6: '',  # 𧷖
    # 0x27DD7: '',  # 𧷗
    # 0x27DD8: '',  # 𧷘
    # 0x27DD9: '',  # 𧷙
    # 0x27DDA: '',  # 𧷚
    0x27DDB: 'kuì',  # 𧷛
    # 0x27DDC: '',  # 𧷜
    # 0x27DDD: '',  # 𧷝
    # 0x27DDE: '',  # 𧷞
    0x27DDF: 'bīn',  # 𧷟
    # 0x27DE0: '',  # 𧷠
    0x27DE1: 'lóu,lòu',  # 𧷡
    # 0x27DE2: '',  # 𧷢
    # 0x27DE3: '',  # 𧷣
    # 0x27DE4: '',  # 𧷤
    0x27DE5: 'yì',  # 𧷥
    0x27DE6: 'mì',  # 𧷦
    0x27DE7: 'xiè',  # 𧷧
    # 0x27DE8: '',  # 𧷨
    # 0x27DE9: '',  # 𧷩
    # 0x27DEA: '',  # 𧷪
    # 0x27DEB: '',  # 𧷫
    # 0x27DEC: '',  # 𧷬
    # 0x27DED: '',  # 𧷭
    # 0x27DEE: '',  # 𧷮
    # 0x27DEF: '',  # 𧷯
    # 0x27DF0: '',  # 𧷰
    0x27DF1: 'guī',  # 𧷱
    # 0x27DF2: '',  # 𧷲
    0x27DF3: 'luó',  # 𧷳
    0x27DF4: 'huò',  # 𧷴
    # 0x27DF5: '',  # 𧷵
    0x27DF6: 'shàn',  # 𧷶
    # 0x27DF7: '',  # 𧷷
    # 0x27DF8: '',  # 𧷸
    # 0x27DF9: '',  # 𧷹
    # 0x27DFA: '',  # 𧷺
    # 0x27DFB: '',  # 𧷻
    # 0x27DFC: '',  # 𧷼
    # 0x27DFD: '',  # 𧷽
    0x27DFE: 'jú',  # 𧷾
    0x27DFF: 'dū',  # 𧷿
    # 0x27E00: '',  # 𧸀
    # 0x27E01: '',  # 𧸁
    0x27E02: 'xiān',  # 𧸂
    # 0x27E03: '',  # 𧸃
    # 0x27E04: '',  # 𧸄
    0x27E05: 'zhǐ',  # 𧸅
    # 0x27E06: '',  # 𧸆
    # 0x27E07: '',  # 𧸇
    0x27E08: 'bìn',  # 𧸈
    # 0x27E09: '',  # 𧸉
    # 0x27E0A: '',  # 𧸊
    # 0x27E0B: '',  # 𧸋
    # 0x27E0C: '',  # 𧸌
    # 0x27E0D: '',  # 𧸍
    # 0x27E0E: '',  # 𧸎
    # 0x27E0F: '',  # 𧸏
    # 0x27E10: '',  # 𧸐
    # 0x27E11: '',  # 𧸑
    # 0x27E12: '',  # 𧸒
    # 0x27E13: '',  # 𧸓
    # 0x27E14: '',  # 𧸔
    0x27E15: 'zhǐ',  # 𧸕
    0x27E16: 'zhuàn,lián',  # 𧸖
    0x27E17: 'xué',  # 𧸗
    0x27E18: 'liàn,biǎn,jiǎn',  # 𧸘
    0x27E19: 'suì',  # 𧸙
    # 0x27E1A: '',  # 𧸚
    # 0x27E1B: '',  # 𧸛
    # 0x27E1C: '',  # 𧸜
    # 0x27E1D: '',  # 𧸝
    # 0x27E1E: '',  # 𧸞
    # 0x27E1F: '',  # 𧸟
    # 0x27E20: '',  # 𧸠
    # 0x27E21: '',  # 𧸡
    # 0x27E22: '',  # 𧸢
    # 0x27E23: '',  # 𧸣
    # 0x27E24: '',  # 𧸤
    # 0x27E25: '',  # 𧸥
    0x27E26: 'làn',  # 𧸦
    0x27E27: 'jù',  # 𧸧
    0x27E28: 'mián',  # 𧸨
    0x27E29: 'xùn',  # 𧸩
    0x27E2A: 'zhàn',  # 𧸪
    0x27E2B: 'gùn',  # 𧸫
    # 0x27E2C: '',  # 𧸬
    # 0x27E2D: '',  # 𧸭
    0x27E2E: 'wéi',  # 𧸮
    # 0x27E2F: '',  # 𧸯
    # 0x27E30: '',  # 𧸰
    # 0x27E31: '',  # 𧸱
    0x27E32: 'zhì',  # 𧸲
    # 0x27E33: '',  # 𧸳
    # 0x27E34: '',  # 𧸴
    # 0x27E35: '',  # 𧸵
    # 0x27E36: '',  # 𧸶
    # 0x27E37: '',  # 𧸷
    # 0x27E38: '',  # 𧸸
    # 0x27E39: '',  # 𧸹
    # 0x27E3A: '',  # 𧸺
    # 0x27E3B: '',  # 𧸻
    # 0x27E3C: '',  # 𧸼
    0x27E3D: 'wèi',  # 𧸽
    0x27E3E: 'quǎn,xuàn',  # 𧸾
    0x27E3F: 'chài',  # 𧸿
    # 0x27E40: '',  # 𧹀
    # 0x27E41: '',  # 𧹁
    # 0x27E42: '',  # 𧹂
    # 0x27E43: '',  # 𧹃
    # 0x27E44: '',  # 𧹄
    # 0x27E45: '',  # 𧹅
    # 0x27E46: '',  # 𧹆
    # 0x27E47: '',  # 𧹇
    0x27E48: 'réng',  # 𧹈
    # 0x27E49: '',  # 𧹉
    0x27E4A: 'yuè',  # 𧹊
    # 0x27E4B: '',  # 𧹋
    0x27E4C: 'zī',  # 𧹌
    # 0x27E4D: '',  # 𧹍
    # 0x27E4E: '',  # 𧹎
    # 0x27E4F: '',  # 𧹏
    0x27E50: 'luò',  # 𧹐
    # 0x27E51: '',  # 𧹑
    # 0x27E52: '',  # 𧹒
    # 0x27E53: '',  # 𧹓
    # 0x27E54: '',  # 𧹔
    # 0x27E55: '',  # 𧹕
    # 0x27E56: '',  # 𧹖
    # 0x27E57: '',  # 𧹗
    # 0x27E58: '',  # 𧹘
    # 0x27E59: '',  # 𧹙
    # 0x27E5A: '',  # 𧹚
    0x27E5B: 'zhī',  # 𧹛
    # 0x27E5C: '',  # 𧹜
    # 0x27E5D: '',  # 𧹝
    0x27E5E: 'nǎn,niǎn',  # 𧹞
    # 0x27E5F: '',  # 𧹟
    # 0x27E60: '',  # 𧹠
    # 0x27E61: '',  # 𧹡
    # 0x27E62: '',  # 𧹢
    0x27E63: 'hān',  # 𧹣
    # 0x27E64: '',  # 𧹤
    # 0x27E65: '',  # 𧹥
    # 0x27E66: '',  # 𧹦
    # 0x27E67: '',  # 𧹧
    0x27E68: 'xī',  # 𧹨
    0x27E69: 'lín',  # 𧹩
    # 0x27E6A: '',  # 𧹪
    # 0x27E6B: '',  # 𧹫
    0x27E6C: 'yān',  # 𧹬
    0x27E6D: 'xù',  # 𧹭
    # 0x27E6E: '',  # 𧹮
    # 0x27E6F: '',  # 𧹯
    # 0x27E70: '',  # 𧹰
    # 0x27E71: '',  # 𧹱
    0x27E72: 'hù',  # 𧹲
    0x27E73: 'gàn',  # 𧹳
    0x27E74: 'xù,huò',  # 𧹴
    # 0x27E75: '',  # 𧹵
    0x27E76: 'xì',  # 𧹶
    # 0x27E77: '',  # 𧹷
    # 0x27E78: '',  # 𧹸
    # 0x27E79: '',  # 𧹹
    0x27E7A: 'cuì',  # 𧹺
    # 0x27E7B: '',  # 𧹻
    # 0x27E7C: '',  # 𧹼
    0x27E7D: 'xì',  # 𧹽
    0x27E7E: 'hú',  # 𧹾
    # 0x27E7F: '',  # 𧹿
    # 0x27E80: '',  # 𧺀
    # 0x27E81: '',  # 𧺁
    # 0x27E82: '',  # 𧺂
    # 0x27E83: '',  # 𧺃
    # 0x27E84: '',  # 𧺄
    0x27E85: 'yān',  # 𧺅
    0x27E86: 'zǒu',  # 𧺆
    # 0x27E87: '',  # 𧺇
    # 0x27E88: '',  # 𧺈
    # 0x27E89: '',  # 𧺉
    # 0x27E8A: '',  # 𧺊
    # 0x27E8B: '',  # 𧺋
    # 0x27E8C: '',  # 𧺌
    0x27E8D: 'péi',  # 𧺍
    0x27E8E: 'yì',  # 𧺎
    0x27E8F: 'chí',  # 𧺏
    0x27E90: 'jué',  # 𧺐
    # 0x27E91: '',  # 𧺑
    0x27E92: 'zú',  # 𧺒
    # 0x27E93: '',  # 𧺓
    # 0x27E94: '',  # 𧺔
    # 0x27E95: '',  # 𧺕
    # 0x27E96: '',  # 𧺖
    # 0x27E97: '',  # 𧺗
    # 0x27E98: '',  # 𧺘
    # 0x27E99: '',  # 𧺙
    # 0x27E9A: '',  # 𧺚
    # 0x27E9B: '',  # 𧺛
    0x27E9C: 'jiào',  # 𧺜
    0x27E9D: 'yì',  # 𧺝
    # 0x27E9E: '',  # 𧺞
    0x27E9F: 'tǎn',  # 𧺟
    0x27EA0: 'chì',  # 𧺠
    0x27EA1: 'bá',  # 𧺡
    0x27EA2: 'tòu,yì',  # 𧺢
    0x27EA3: 'zōng',  # 𧺣
    0x27EA4: 'qiú,jū',  # 𧺤
    # 0x27EA5: '',  # 𧺥
    # 0x27EA6: '',  # 𧺦
    0x27EA7: 'chì',  # 𧺧
    0x27EA8: 'xǐ',  # 𧺨
    # 0x27EA9: '',  # 𧺩
    # 0x27EAA: '',  # 𧺪
    0x27EAB: 'qǐ',  # 𧺫
    # 0x27EAC: '',  # 𧺬
    # 0x27EAD: '',  # 𧺭
    # 0x27EAE: '',  # 𧺮
    # 0x27EAF: '',  # 𧺯
    0x27EB0: 'nì',  # 𧺰
    # 0x27EB1: '',  # 𧺱
    0x27EB2: 'cū',  # 𧺲
    # 0x27EB3: '',  # 𧺳
    0x27EB4: 'wǔ',  # 𧺴
    # 0x27EB5: '',  # 𧺵
    0x27EB6: 'chù',  # 𧺶
    0x27EB7: 'sū',  # 𧺷
    0x27EB8: 'yóng',  # 𧺸
    0x27EB9: 'jǔ',  # 𧺹
    0x27EBA: 'bá',  # 𧺺
    # 0x27EBB: '',  # 𧺻
    0x27EBC: 'cǐ',  # 𧺼
    0x27EBD: 'dì',  # 𧺽
    0x27EBE: 'pǎn',  # 𧺾
    0x27EBF: 'chì,yì',  # 𧺿
    # 0x27EC0: '',  # 𧻀
    0x27EC1: 'qiǔ',  # 𧻁
    # 0x27EC2: '',  # 𧻂
    0x27EC3: 'yán,qù',  # 𧻃
    # 0x27EC4: '',  # 𧻄
    # 0x27EC5: '',  # 𧻅
    # 0x27EC6: '',  # 𧻆
    # 0x27EC7: '',  # 𧻇
    # 0x27EC8: '',  # 𧻈
    # 0x27EC9: '',  # 𧻉
    # 0x27ECA: '',  # 𧻊
    # 0x27ECB: '',  # 𧻋
    # 0x27ECC: '',  # 𧻌
    0x27ECD: 'zhǎi',  # 𧻍
    # 0x27ECE: '',  # 𧻎
    # 0x27ECF: '',  # 𧻏
    # 0x27ED0: '',  # 𧻐
    # 0x27ED1: '',  # 𧻑
    0x27ED2: 'xiàn',  # 𧻒
    0x27ED3: 'bèng',  # 𧻓
    0x27ED4: 'kuāng',  # 𧻔
    0x27ED5: 'qì',  # 𧻕
    0x27ED6: 'zhōu',  # 𧻖
    0x27ED7: 'jú',  # 𧻗
    0x27ED8: 'qiè',  # 𧻘
    0x27ED9: 'mò,pò',  # 𧻙
    0x27EDA: 'yuán',  # 𧻚
    # 0x27EDB: '',  # 𧻛
    0x27EDC: 'guì,kuǐ',  # 𧻜
    0x27EDD: 'zuī',  # 𧻝
    # 0x27EDE: '',  # 𧻞
    # 0x27EDF: '',  # 𧻟
    # 0x27EE0: '',  # 𧻠
    # 0x27EE1: '',  # 𧻡
    # 0x27EE2: '',  # 𧻢
    # 0x27EE3: '',  # 𧻣
    # 0x27EE4: '',  # 𧻤
    # 0x27EE5: '',  # 𧻥
    # 0x27EE6: '',  # 𧻦
    0x27EE7: 'qiè',  # 𧻧
    # 0x27EE8: '',  # 𧻨
    # 0x27EE9: '',  # 𧻩
    # 0x27EEA: '',  # 𧻪
    # 0x27EEB: '',  # 𧻫
    # 0x27EEC: '',  # 𧻬
    # 0x27EED: '',  # 𧻭
    # 0x27EEE: '',  # 𧻮
    # 0x27EEF: '',  # 𧻯
    0x27EF0: 'hú,zào',  # 𧻰
    0x27EF1: 'qiú',  # 𧻱
    0x27EF2: 'hái,kuī',  # 𧻲
    0x27EF3: 'fù',  # 𧻳
    0x27EF4: 'làng',  # 𧻴
    0x27EF5: 'shà',  # 𧻵
    0x27EF6: 'xī',  # 𧻶
    0x27EF7: 'bū',  # 𧻷
    0x27EF8: 'shì',  # 𧻸
    0x27EF9: 'yǒng',  # 𧻹
    0x27EFA: 'guāng,kuāng',  # 𧻺
    # 0x27EFB: '',  # 𧻻
    0x27EFC: 'niè',  # 𧻼
    # 0x27EFD: '',  # 𧻽
    # 0x27EFE: '',  # 𧻾
    0x27EFF: 'hǒu',  # 𧻿
    # 0x27F00: '',  # 𧼀
    # 0x27F01: '',  # 𧼁
    # 0x27F02: '',  # 𧼂
    # 0x27F03: '',  # 𧼃
    # 0x27F04: '',  # 𧼄
    # 0x27F05: '',  # 𧼅
    # 0x27F06: '',  # 𧼆
    # 0x27F07: '',  # 𧼇
    # 0x27F08: '',  # 𧼈
    # 0x27F09: '',  # 𧼉
    0x27F0A: 'mì',  # 𧼊
    # 0x27F0B: '',  # 𧼋
    # 0x27F0C: '',  # 𧼌
    # 0x27F0D: '',  # 𧼍
    0x27F0E: 'è',  # 𧼎
    0x27F0F: 'xián',  # 𧼏
    0x27F10: 'yǔn,qūn',  # 𧼐
    0x27F11: 'xù',  # 𧼑
    0x27F12: 'qǐn',  # 𧼒
    0x27F13: 'dōng',  # 𧼓
    0x27F14: 'léng',  # 𧼔
    0x27F15: 'qì',  # 𧼕
    0x27F16: 'lán',  # 𧼖
    0x27F17: 'fú',  # 𧼗
    0x27F18: 'qǐ',  # 𧼘
    0x27F19: 'chǒng',  # 𧼙
    # 0x27F1A: '',  # 𧼚
    # 0x27F1B: '',  # 𧼛
    0x27F1C: 'cù',  # 𧼜
    # 0x27F1D: '',  # 𧼝
    # 0x27F1E: '',  # 𧼞
    0x27F1F: 'mò',  # 𧼟
    0x27F20: 'bēi',  # 𧼠
    # 0x27F21: '',  # 𧼡
    # 0x27F22: '',  # 𧼢
    # 0x27F23: '',  # 𧼣
    0x27F24: 'dào',  # 𧼤
    # 0x27F25: '',  # 𧼥
    # 0x27F26: '',  # 𧼦
    # 0x27F27: '',  # 𧼧
    0x27F28: 'jié,jué',  # 𧼨
    0x27F29: 'chòng,dòng',  # 𧼩
    0x27F2A: 'chì',  # 𧼪
    0x27F2B: 'yù',  # 𧼫
    0x27F2C: 'cuī',  # 𧼬
    0x27F2D: 'sù,sōu,sǒu,qiù',  # 𧼭
    0x27F2E: 'tì',  # 𧼮
    0x27F2F: 'shù,yú',  # 𧼯
    0x27F30: 'zhá',  # 𧼰
    0x27F31: 'fú,bí',  # 𧼱
    # 0x27F32: '',  # 𧼲
    0x27F33: 'chè',  # 𧼳
    0x27F34: 'fó,zhì',  # 𧼴
    0x27F35: 'hóu',  # 𧼵
    0x27F36: 'zhá',  # 𧼶
    # 0x27F37: '',  # 𧼷
    # 0x27F38: '',  # 𧼸
    # 0x27F39: '',  # 𧼹
    # 0x27F3A: '',  # 𧼺
    # 0x27F3B: '',  # 𧼻
    # 0x27F3C: '',  # 𧼼
    # 0x27F3D: '',  # 𧼽
    # 0x27F3E: '',  # 𧼾
    # 0x27F3F: '',  # 𧼿
    # 0x27F40: '',  # 𧽀
    # 0x27F41: '',  # 𧽁
    # 0x27F42: '',  # 𧽂
    # 0x27F43: '',  # 𧽃
    0x27F44: 'jié',  # 𧽄
    0x27F45: 'zhá',  # 𧽅
    0x27F46: 'zhān',  # 𧽆
    # 0x27F47: '',  # 𧽇
    # 0x27F48: '',  # 𧽈
    0x27F49: 'yǎn',  # 𧽉
    0x27F4A: 'hái',  # 𧽊
    0x27F4B: 'wǔ',  # 𧽋
    0x27F4C: 'huá',  # 𧽌
    0x27F4D: 'diān,diàn',  # 𧽍
    0x27F4E: 'yáo',  # 𧽎
    0x27F4F: 'sōu',  # 𧽏
    0x27F50: 'qiān',  # 𧽐
    0x27F51: 'jí',  # 𧽑
    0x27F52: 'xiòng',  # 𧽒
    0x27F53: 'qì',  # 𧽓
    0x27F54: 'jūn',  # 𧽔
    # 0x27F55: '',  # 𧽕
    0x27F56: 'hái',  # 𧽖
    # 0x27F57: '',  # 𧽗
    # 0x27F58: '',  # 𧽘
    # 0x27F59: '',  # 𧽙
    # 0x27F5A: '',  # 𧽚
    # 0x27F5B: '',  # 𧽛
    # 0x27F5C: '',  # 𧽜
    # 0x27F5D: '',  # 𧽝
    0x27F5E: 'yǎn',  # 𧽞
    0x27F5F: 'jié',  # 𧽟
    0x27F60: 'cuī',  # 𧽠
    # 0x27F61: '',  # 𧽡
    0x27F62: 'tuán',  # 𧽢
    0x27F63: 'zhāng',  # 𧽣
    0x27F64: 'piāo',  # 𧽤
    0x27F65: 'lù',  # 𧽥
    0x27F66: 'zhī',  # 𧽦
    0x27F67: 'chù',  # 𧽧
    0x27F68: 'mì',  # 𧽨
    0x27F69: 'qiāng',  # 𧽩
    # 0x27F6A: '',  # 𧽪
    0x27F6B: 'liàn',  # 𧽫
    # 0x27F6C: '',  # 𧽬
    # 0x27F6D: '',  # 𧽭
    # 0x27F6E: '',  # 𧽮
    0x27F6F: 'jiàn',  # 𧽯
    # 0x27F70: '',  # 𧽰
    # 0x27F71: '',  # 𧽱
    0x27F72: 'lì',  # 𧽲
    # 0x27F73: '',  # 𧽳
    # 0x27F74: '',  # 𧽴
    # 0x27F75: '',  # 𧽵
    0x27F76: 'é',  # 𧽶
    0x27F77: 'sù',  # 𧽷
    0x27F78: 'jué,guì',  # 𧽸
    # 0x27F79: '',  # 𧽹
    # 0x27F7A: '',  # 𧽺
    0x27F7B: 'jú',  # 𧽻
    0x27F7C: 'tán',  # 𧽼
    0x27F7D: 'liáo',  # 𧽽
    0x27F7E: 'sān,cún',  # 𧽾
    0x27F7F: 'dòng',  # 𧽿
    # 0x27F80: '',  # 𧾀
    0x27F81: 'zá',  # 𧾁
    0x27F82: 'zhí',  # 𧾂
    # 0x27F83: '',  # 𧾃
    # 0x27F84: '',  # 𧾄
    # 0x27F85: '',  # 𧾅
    0x27F86: 'xuàn',  # 𧾆
    0x27F87: 'líng',  # 𧾇
    # 0x27F88: '',  # 𧾈
    # 0x27F89: '',  # 𧾉
    0x27F8A: 'dēng',  # 𧾊
    # 0x27F8B: '',  # 𧾋
    # 0x27F8C: '',  # 𧾌
    0x27F8D: 'zhān,zhàn,chán',  # 𧾍
    0x27F8E: 'xuān',  # 𧾎
    0x27F8F: 'qǐn',  # 𧾏
    0x27F90: 'jiào',  # 𧾐
    0x27F91: 'pì',  # 𧾑
    # 0x27F92: '',  # 𧾒
    # 0x27F93: '',  # 𧾓
    0x27F94: 'hǎn',  # 𧾔
    # 0x27F95: '',  # 𧾕
    # 0x27F96: '',  # 𧾖
    # 0x27F97: '',  # 𧾗
    # 0x27F98: '',  # 𧾘
    # 0x27F99: '',  # 𧾙
    0x27F9A: 'yú',  # 𧾚
    0x27F9B: 'guó',  # 𧾛
    # 0x27F9C: '',  # 𧾜
    0x27F9D: 'xún',  # 𧾝
    # 0x27F9E: '',  # 𧾞
    # 0x27F9F: '',  # 𧾟
    0x27FA0: 'xún',  # 𧾠
    0x27FA1: 'chán',  # 𧾡
    0x27FA2: 'jié,jí',  # 𧾢
    0x27FA3: 'jú',  # 𧾣
    0x27FA4: 'yǎn',  # 𧾤
    0x27FA5: 'dú',  # 𧾥
    # 0x27FA6: '',  # 𧾦
    0x27FA7: 'hòng',  # 𧾧
    0x27FA8: 'xiàn,xiǎn',  # 𧾨
    0x27FA9: 'xún,xuàn',  # 𧾩
    # 0x27FAA: '',  # 𧾪
    0x27FAB: 'biān',  # 𧾫
    # 0x27FAC: '',  # 𧾬
    # 0x27FAD: '',  # 𧾭
    0x27FAE: 'líng',  # 𧾮
    0x27FAF: 'jié',  # 𧾯
    0x27FB0: 'yì',  # 𧾰
    0x27FB1: 'qú',  # 𧾱
    0x27FB2: 'gān',  # 𧾲
    0x27FB3: 'fēng',  # 𧾳
    # 0x27FB4: '',  # 𧾴
    0x27FB5: 'jué',  # 𧾵
    0x27FB6: 'qū',  # 𧾶
    # 0x27FB7: '',  # 𧾷
    # 0x27FB8: '',  # 𧾸
    # 0x27FB9: '',  # 𧾹
    # 0x27FBA: '',  # 𧾺
    0x27FBB: 'jiù',  # 𧾻
    # 0x27FBC: '',  # 𧾼
    0x27FBD: 'jì',  # 𧾽
    0x27FBE: 'jǐ',  # 𧾾
    # 0x27FBF: '',  # 𧾿
    # 0x27FC0: '',  # 𧿀
    # 0x27FC1: '',  # 𧿁
    # 0x27FC2: '',  # 𧿂
    # 0x27FC3: '',  # 𧿃
    # 0x27FC4: '',  # 𧿄
    0x27FC5: 'xí',  # 𧿅
    0x27FC6: 'pāng',  # 𧿆
    # 0x27FC7: '',  # 𧿇
    # 0x27FC8: '',  # 𧿈
    0x27FC9: 'kù,wù',  # 𧿉
    # 0x27FCA: '',  # 𧿊
    0x27FCB: 'kù',  # 𧿋
    0x27FCC: 'zhà',  # 𧿌
    # 0x27FCD: '',  # 𧿍
    # 0x27FCE: '',  # 𧿎
    0x27FCF: 'bà',  # 𧿏
    # 0x27FD0: '',  # 𧿐
    # 0x27FD1: '',  # 𧿑
    0x27FD2: 'chěn',  # 𧿒
    0x27FD3: 'hù',  # 𧿓
    0x27FD4: 'nù',  # 𧿔
    0x27FD5: 'é',  # 𧿕
    0x27FD6: 'xiōng',  # 𧿖
    0x27FD7: 'dǔn',  # 𧿗
    0x27FD8: 'shēng',  # 𧿘
    0x27FD9: 'wán',  # 𧿙
    0x27FDA: 'fēn',  # 𧿚
    # 0x27FDB: '',  # 𧿛
    # 0x27FDC: '',  # 𧿜
    0x27FDD: 'xī',  # 𧿝
    0x27FDE: 'zī',  # 𧿞
    # 0x27FDF: '',  # 𧿟
    0x27FE0: 'hù,dì',  # 𧿠
    # 0x27FE1: '',  # 𧿡
    # 0x27FE2: '',  # 𧿢
    # 0x27FE3: '',  # 𧿣
    # 0x27FE4: '',  # 𧿤
    0x27FE5: 'bié',  # 𧿥
    # 0x27FE6: '',  # 𧿦
    0x27FE7: 'tuò',  # 𧿧
    0x27FE8: 'bǎn',  # 𧿨
    0x27FE9: 'gé',  # 𧿩
    # 0x27FEA: '',  # 𧿪
    0x27FEB: 'kē',  # 𧿫
    # 0x27FEC: '',  # 𧿬
    # 0x27FED: '',  # 𧿭
    # 0x27FEE: '',  # 𧿮
    # 0x27FEF: '',  # 𧿯
    # 0x27FF0: '',  # 𧿰
    # 0x27FF1: '',  # 𧿱
    0x27FF2: 'zhuì,bó',  # 𧿲
    0x27FF3: 'fú,fèi',  # 𧿳
    0x27FF4: 'mò',  # 𧿴
    0x27FF5: 'jiá',  # 𧿵
    0x27FF6: 'tuó',  # 𧿶
    0x27FF7: 'yù',  # 𧿷
    # 0x27FF8: '',  # 𧿸
    0x27FF9: 'mǔ',  # 𧿹
    0x27FFA: 'jué',  # 𧿺
    0x27FFB: 'jú',  # 𧿻
    0x27FFC: 'guā',  # 𧿼
    0x27FFD: 'pǒ',  # 𧿽
    # 0x27FFE: '',  # 𧿾
    # 0x27FFF: '',  # 𧿿
    0x28000: 'nǐ,niǎn',  # 𨀀
    # 0x28001: '',  # 𨀁
    # 0x28002: '',  # 𨀂
    # 0x28003: '',  # 𨀃
    0x28004: 'wǎ',  # 𨀄
    0x28005: 'yǎn',  # 𨀅
    # 0x28006: '',  # 𨀆
    # 0x28007: '',  # 𨀇
    # 0x28008: '',  # 𨀈
    # 0x28009: '',  # 𨀉
    # 0x2800A: '',  # 𨀊
    # 0x2800B: '',  # 𨀋
    # 0x2800C: '',  # 𨀌
    # 0x2800D: '',  # 𨀍
    # 0x2800E: '',  # 𨀎
    # 0x2800F: '',  # 𨀏
    # 0x28010: '',  # 𨀐
    # 0x28011: '',  # 𨀑
    # 0x28012: '',  # 𨀒
    # 0x28013: '',  # 𨀓
    0x28014: 'chǒu',  # 𨀔
    0x28015: 'kuāng',  # 𨀕
    0x28016: 'hài',  # 𨀖
    # 0x28017: '',  # 𨀗
    0x28018: 'xiáng',  # 𨀘
    0x28019: 'xī',  # 𨀙
    # 0x2801A: '',  # 𨀚
    0x2801B: 'cún',  # 𨀛
    0x2801C: 'tōng',  # 𨀜
    0x2801D: 'ruò',  # 𨀝
    # 0x2801E: '',  # 𨀞
    0x2801F: 'duó',  # 𨀟
    0x28020: 'chè',  # 𨀠
    # 0x28021: '',  # 𨀡
    # 0x28022: '',  # 𨀢
    # 0x28023: '',  # 𨀣
    0x28024: 'lèi',  # 𨀤
    0x28025: 'zī',  # 𨀥
    # 0x28026: '',  # 𨀦
    0x28027: 'zhěng',  # 𨀧
    0x28028: 'zuǒ',  # 𨀨
    # 0x28029: '',  # 𨀩
    # 0x2802A: '',  # 𨀪
    0x2802B: 'kāng',  # 𨀫
    0x2802C: 'zài',  # 𨀬
    # 0x2802D: '',  # 𨀭
    0x2802E: 'yuān,xuān',  # 𨀮
    0x2802F: 'qióng',  # 𨀯
    # 0x28030: '',  # 𨀰
    # 0x28031: '',  # 𨀱
    # 0x28032: '',  # 𨀲
    0x28033: 'fá',  # 𨀳
    0x28034: 'xún',  # 𨀴
    0x28035: 'zhuàng',  # 𨀵
    0x28036: 'jì',  # 𨀶
    # 0x28037: '',  # 𨀷
    0x28038: 'chā',  # 𨀸
    # 0x28039: '',  # 𨀹
    # 0x2803A: '',  # 𨀺
    # 0x2803B: '',  # 𨀻
    # 0x2803C: '',  # 𨀼
    # 0x2803D: '',  # 𨀽
    # 0x2803E: '',  # 𨀾
    # 0x2803F: '',  # 𨀿
    0x28040: 'shū,chōu',  # 𨁀
    0x28041: 'xuàn',  # 𨁁
    0x28042: 'xié',  # 𨁂
    0x28043: 'tī',  # 𨁃
    0x28044: 'hàn',  # 𨁄
    0x28045: 'xiān',  # 𨁅
    0x28046: 'shān',  # 𨁆
    0x28047: 'tùn',  # 𨁇
    0x28048: 'háng,gēng',  # 𨁈
    0x28049: 'kǔn',  # 𨁉
    0x2804A: 'cén',  # 𨁊
    0x2804B: 'dōu',  # 𨁋
    0x2804C: 'nuó',  # 𨁌
    0x2804D: 'yàn',  # 𨁍
    0x2804E: 'chéng,jìng',  # 𨁎
    0x2804F: 'pū',  # 𨁏
    0x28050: 'qì',  # 𨁐
    0x28051: 'yuè',  # 𨁑
    0x28052: 'fū',  # 𨁒
    # 0x28053: '',  # 𨁓
    # 0x28054: '',  # 𨁔
    # 0x28055: '',  # 𨁕
    # 0x28056: '',  # 𨁖
    0x28057: 'tǐng',  # 𨁗
    # 0x28058: '',  # 𨁘
    # 0x28059: '',  # 𨁙
    # 0x2805A: '',  # 𨁚
    # 0x2805B: '',  # 𨁛
    # 0x2805C: '',  # 𨁜
    # 0x2805D: '',  # 𨁝
    # 0x2805E: '',  # 𨁞
    0x2805F: 'wǒ',  # 𨁟
    0x28060: 'shēng',  # 𨁠
    0x28061: 'tuǒ',  # 𨁡
    # 0x28062: '',  # 𨁢
    # 0x28063: '',  # 𨁣
    # 0x28064: '',  # 𨁤
    # 0x28065: '',  # 𨁥
    # 0x28066: '',  # 𨁦
    # 0x28067: '',  # 𨁧
    # 0x28068: '',  # 𨁨
    # 0x28069: '',  # 𨁩
    # 0x2806A: '',  # 𨁪
    # 0x2806B: '',  # 𨁫
    # 0x2806C: '',  # 𨁬
    # 0x2806D: '',  # 𨁭
    # 0x2806E: '',  # 𨁮
    # 0x2806F: '',  # 𨁯
    # 0x28070: '',  # 𨁰
    # 0x28071: '',  # 𨁱
    # 0x28072: '',  # 𨁲
    # 0x28073: '',  # 𨁳
    # 0x28074: '',  # 𨁴
    # 0x28075: '',  # 𨁵
    0x28076: 'yǎ,yā',  # 𨁶
    0x28077: 'zhì',  # 𨁷
    0x28078: 'lù,lì',  # 𨁸
    0x28079: 'yǎn',  # 𨁹
    0x2807A: 'jū',  # 𨁺
    # 0x2807B: '',  # 𨁻
    # 0x2807C: '',  # 𨁼
    0x2807D: 'dé',  # 𨁽
    # 0x2807E: '',  # 𨁾
    0x2807F: 'chù,zhuó',  # 𨁿
    0x28080: 'zǔ',  # 𨂀
    0x28081: 'è',  # 𨂁
    0x28082: 'zhí,xuě',  # 𨂂
    0x28083: 'péng',  # 𨂃
    # 0x28084: '',  # 𨂄
    0x28085: 'biē',  # 𨂅
    # 0x28086: '',  # 𨂆
    0x28087: 'dǐ',  # 𨂇
    # 0x28088: '',  # 𨂈
    # 0x28089: '',  # 𨂉
    0x2808A: 'zhōu',  # 𨂊
    0x2808B: 'jī',  # 𨂋
    # 0x2808C: '',  # 𨂌
    # 0x2808D: '',  # 𨂍
    # 0x2808E: '',  # 𨂎
    # 0x2808F: '',  # 𨂏
    0x28090: 'lái',  # 𨂐
    # 0x28091: '',  # 𨂑
    0x28092: 'yè',  # 𨂒
    # 0x28093: '',  # 𨂓
    # 0x28094: '',  # 𨂔
    # 0x28095: '',  # 𨂕
    # 0x28096: '',  # 𨂖
    # 0x28097: '',  # 𨂗
    # 0x28098: '',  # 𨂘
    # 0x28099: '',  # 𨂙
    # 0x2809A: '',  # 𨂚
    # 0x2809B: '',  # 𨂛
    0x2809C: 'háo',  # 𨂜
    0x2809D: 'pán',  # 𨂝
    0x2809E: 'tàn',  # 𨂞
    0x2809F: 'kāng',  # 𨂟
    0x280A0: 'xū,lǚ',  # 𨂠
    0x280A1: 'zòu',  # 𨂡
    0x280A2: 'jì',  # 𨂢
    0x280A3: 'wù',  # 𨂣
    # 0x280A4: '',  # 𨂤
    # 0x280A5: '',  # 𨂥
    0x280A6: 'chuàn',  # 𨂦
    # 0x280A7: '',  # 𨂧
    # 0x280A8: '',  # 𨂨
    0x280A9: 'pò',  # 𨂩
    0x280AA: 'yǎn',  # 𨂪
    0x280AB: 'tuò',  # 𨂫
    # 0x280AC: '',  # 𨂬
    0x280AD: 'dú',  # 𨂭
    # 0x280AE: '',  # 𨂮
    0x280AF: 'pián',  # 𨂯
    0x280B0: 'chì',  # 𨂰
    0x280B1: 'hùn',  # 𨂱
    0x280B2: 'pīng',  # 𨂲
    # 0x280B3: '',  # 𨂳
    0x280B4: 'cōng',  # 𨂴
    0x280B5: 'zhǎ',  # 𨂵
    # 0x280B6: '',  # 𨂶
    # 0x280B7: '',  # 𨂷
    # 0x280B8: '',  # 𨂸
    # 0x280B9: '',  # 𨂹
    # 0x280BA: '',  # 𨂺
    0x280BB: 'dǎo',  # 𨂻
    # 0x280BC: '',  # 𨂼
    0x280BD: 'dàn',  # 𨂽
    0x280BE: 'nàn',  # 𨂾
    # 0x280BF: '',  # 𨂿
    # 0x280C0: '',  # 𨃀
    # 0x280C1: '',  # 𨃁
    # 0x280C2: '',  # 𨃂
    0x280C3: 'è',  # 𨃃
    0x280C4: 'wèi',  # 𨃄
    0x280C5: 'bāi',  # 𨃅
    # 0x280C6: '',  # 𨃆
    0x280C7: 'jiāng',  # 𨃇
    # 0x280C8: '',  # 𨃈
    0x280C9: 'zhì',  # 𨃉
    # 0x280CA: '',  # 𨃊
    # 0x280CB: '',  # 𨃋
    # 0x280CC: '',  # 𨃌
    # 0x280CD: '',  # 𨃍
    # 0x280CE: '',  # 𨃎
    # 0x280CF: '',  # 𨃏
    # 0x280D0: '',  # 𨃐
    # 0x280D1: '',  # 𨃑
    # 0x280D2: '',  # 𨃒
    0x280D3: 'chá',  # 𨃓
    # 0x280D4: '',  # 𨃔
    0x280D5: 'chù',  # 𨃕
    0x280D6: 'kuà',  # 𨃖
    0x280D7: 'téng',  # 𨃗
    0x280D8: 'zōu,qū',  # 𨃘
    0x280D9: 'lì',  # 𨃙
    0x280DA: 'tà',  # 𨃚
    0x280DB: 'sà',  # 𨃛
    # 0x280DC: '',  # 𨃜
    # 0x280DD: '',  # 𨃝
    0x280DE: 'pán',  # 𨃞
    0x280DF: 'pán',  # 𨃟
    # 0x280E0: '',  # 𨃠
    # 0x280E1: '',  # 𨃡
    # 0x280E2: '',  # 𨃢
    0x280E3: 'sào',  # 𨃣
    0x280E4: 'qiāo,kào',  # 𨃤
    # 0x280E5: '',  # 𨃥
    # 0x280E6: '',  # 𨃦
    # 0x280E7: '',  # 𨃧
    # 0x280E8: '',  # 𨃨
    0x280E9: 'xiàn',  # 𨃩
    # 0x280EA: '',  # 𨃪
    # 0x280EB: '',  # 𨃫
    # 0x280EC: '',  # 𨃬
    0x280ED: 'zú',  # 𨃭
    # 0x280EE: '',  # 𨃮
    0x280EF: 'zhì',  # 𨃯
    0x280F0: 'yǎn',  # 𨃰
    # 0x280F1: '',  # 𨃱
    0x280F2: 'jié',  # 𨃲
    0x280F3: 'néng',  # 𨃳
    # 0x280F4: '',  # 𨃴
    # 0x280F5: '',  # 𨃵
    # 0x280F6: '',  # 𨃶
    # 0x280F7: '',  # 𨃷
    # 0x280F8: '',  # 𨃸
    # 0x280F9: '',  # 𨃹
    # 0x280FA: '',  # 𨃺
    # 0x280FB: '',  # 𨃻
    # 0x280FC: '',  # 𨃼
    # 0x280FD: '',  # 𨃽
    # 0x280FE: '',  # 𨃾
    # 0x280FF: '',  # 𨃿
    # 0x28100: '',  # 𨄀
    # 0x28101: '',  # 𨄁
    # 0x28102: '',  # 𨄂
    # 0x28103: '',  # 𨄃
    # 0x28104: '',  # 𨄄
    0x28105: 'qū',  # 𨄅
    # 0x28106: '',  # 𨄆
    0x28107: 'dèng,téng',  # 𨄇
    0x28108: 'liáng',  # 𨄈
    0x28109: 'chǎn',  # 𨄉
    0x2810A: 'qiè',  # 𨄊
    0x2810B: 'lòu',  # 𨄋
    0x2810C: 'dié,xiè',  # 𨄌
    0x2810D: 'cuī',  # 𨄍
    # 0x2810E: '',  # 𨄎
    # 0x2810F: '',  # 𨄏
    0x28110: 'jǐ',  # 𨄐
    # 0x28111: '',  # 𨄑
    # 0x28112: '',  # 𨄒
    0x28113: 'cháo',  # 𨄓
    0x28114: 'shuàn',  # 𨄔
    0x28115: 'zú',  # 𨄕
    # 0x28116: '',  # 𨄖
    0x28117: 'kāng',  # 𨄗
    # 0x28118: '',  # 𨄘
    # 0x28119: '',  # 𨄙
    0x2811A: 'qiāng',  # 𨄚
    0x2811B: 'lí',  # 𨄛
    # 0x2811C: '',  # 𨄜
    # 0x2811D: '',  # 𨄝
    # 0x2811E: '',  # 𨄞
    # 0x2811F: '',  # 𨄟
    # 0x28120: '',  # 𨄠
    # 0x28121: '',  # 𨄡
    # 0x28122: '',  # 𨄢
    # 0x28123: '',  # 𨄣
    # 0x28124: '',  # 𨄤
    # 0x28125: '',  # 𨄥
    # 0x28126: '',  # 𨄦
    # 0x28127: '',  # 𨄧
    # 0x28128: '',  # 𨄨
    # 0x28129: '',  # 𨄩
    # 0x2812A: '',  # 𨄪
    # 0x2812B: '',  # 𨄫
    # 0x2812C: '',  # 𨄬
    # 0x2812D: '',  # 𨄭
    0x2812E: 'shuāi',  # 𨄮
    0x2812F: 'yù',  # 𨄯
    0x28130: 'zhāng',  # 𨄰
    0x28131: 'lěi',  # 𨄱
    # 0x28132: '',  # 𨄲
    # 0x28133: '',  # 𨄳
    # 0x28134: '',  # 𨄴
    # 0x28135: '',  # 𨄵
    # 0x28136: '',  # 𨄶
    # 0x28137: '',  # 𨄷
    # 0x28138: '',  # 𨄸
    # 0x28139: '',  # 𨄹
    # 0x2813A: '',  # 𨄺
    # 0x2813B: '',  # 𨄻
    # 0x2813C: '',  # 𨄼
    # 0x2813D: '',  # 𨄽
    # 0x2813E: '',  # 𨄾
    # 0x2813F: '',  # 𨄿
    # 0x28140: '',  # 𨅀
    # 0x28141: '',  # 𨅁
    # 0x28142: '',  # 𨅂
    # 0x28143: '',  # 𨅃
    # 0x28144: '',  # 𨅄
    0x28145: 'pó',  # 𨅅
    # 0x28146: '',  # 𨅆
    # 0x28147: '',  # 𨅇
    # 0x28148: '',  # 𨅈
    # 0x28149: '',  # 𨅉
    0x2814A: 'zhé,chè',  # 𨅊
    0x2814B: 'xiào',  # 𨅋
    # 0x2814C: '',  # 𨅌
    0x2814D: 'tǎn',  # 𨅍
    0x2814E: 'cuì',  # 𨅎
    0x2814F: 'lán',  # 𨅏
    # 0x28150: '',  # 𨅐
    0x28151: 'xū',  # 𨅑
    0x28152: 'shù,chú',  # 𨅒
    0x28153: 'zhǎ,dá',  # 𨅓
    0x28154: 'cán',  # 𨅔
    # 0x28155: '',  # 𨅕
    # 0x28156: '',  # 𨅖
    0x28157: 'bǐ',  # 𨅗
    0x28158: 'pèng',  # 𨅘
    # 0x28159: '',  # 𨅙
    # 0x2815A: '',  # 𨅚
    # 0x2815B: '',  # 𨅛
    # 0x2815C: '',  # 𨅜
    0x2815D: 'chéng',  # 𨅝
    # 0x2815E: '',  # 𨅞
    # 0x2815F: '',  # 𨅟
    # 0x28160: '',  # 𨅠
    # 0x28161: '',  # 𨅡
    # 0x28162: '',  # 𨅢
    0x28163: 'qiáo',  # 𨅣
    0x28164: 'jī',  # 𨅤
    # 0x28165: '',  # 𨅥
    # 0x28166: '',  # 𨅦
    # 0x28167: '',  # 𨅧
    # 0x28168: '',  # 𨅨
    # 0x28169: '',  # 𨅩
    0x2816A: 'zhāi',  # 𨅪
    # 0x2816B: '',  # 𨅫
    # 0x2816C: '',  # 𨅬
    0x2816D: 'tán',  # 𨅭
    # 0x2816E: '',  # 𨅮
    # 0x2816F: '',  # 𨅯
    # 0x28170: '',  # 𨅰
    # 0x28171: '',  # 𨅱
    # 0x28172: '',  # 𨅲
    # 0x28173: '',  # 𨅳
    # 0x28174: '',  # 𨅴
    # 0x28175: '',  # 𨅵
    # 0x28176: '',  # 𨅶
    # 0x28177: '',  # 𨅷
    # 0x28178: '',  # 𨅸
    # 0x28179: '',  # 𨅹
    # 0x2817A: '',  # 𨅺
    # 0x2817B: '',  # 𨅻
    # 0x2817C: '',  # 𨅼
    # 0x2817D: '',  # 𨅽
    # 0x2817E: '',  # 𨅾
    # 0x2817F: '',  # 𨅿
    # 0x28180: '',  # 𨆀
    0x28181: 'tiǎn,yǎn',  # 𨆁
    0x28182: 'sà',  # 𨆂
    0x28183: 'jīn',  # 𨆃
    0x28184: 'zhù',  # 𨆄
    0x28185: 'duò',  # 𨆅
    # 0x28186: '',  # 𨆆
    0x28187: 'chà',  # 𨆇
    0x28188: 'juàn',  # 𨆈
    0x28189: 'táng',  # 𨆉
    0x2818A: 'bèng',  # 𨆊
    0x2818B: 'zhī',  # 𨆋
    0x2818C: 'fán',  # 𨆌
    0x2818D: 'liè',  # 𨆍
    0x2818E: 'zéi',  # 𨆎
    0x2818F: 'suì',  # 𨆏
    # 0x28190: '',  # 𨆐
    # 0x28191: '',  # 𨆑
    # 0x28192: '',  # 𨆒
    0x28193: 'qín',  # 𨆓
    # 0x28194: '',  # 𨆔
    # 0x28195: '',  # 𨆕
    # 0x28196: '',  # 𨆖
    # 0x28197: '',  # 𨆗
    # 0x28198: '',  # 𨆘
    0x28199: 'sè',  # 𨆙
    # 0x2819A: '',  # 𨆚
    # 0x2819B: '',  # 𨆛
    # 0x2819C: '',  # 𨆜
    # 0x2819D: '',  # 𨆝
    # 0x2819E: '',  # 𨆞
    # 0x2819F: '',  # 𨆟
    # 0x281A0: '',  # 𨆠
    # 0x281A1: '',  # 𨆡
    # 0x281A2: '',  # 𨆢
    # 0x281A3: '',  # 𨆣
    # 0x281A4: '',  # 𨆤
    # 0x281A5: '',  # 𨆥
    # 0x281A6: '',  # 𨆦
    0x281A7: 'zhì',  # 𨆧
    0x281A8: 'tuí',  # 𨆨
    # 0x281A9: '',  # 𨆩
    0x281AA: 'qīng',  # 𨆪
    # 0x281AB: '',  # 𨆫
    0x281AC: 'chuò',  # 𨆬
    # 0x281AD: '',  # 𨆭
    # 0x281AE: '',  # 𨆮
    # 0x281AF: '',  # 𨆯
    0x281B0: 'tà,dà',  # 𨆰
    0x281B1: 'bìng',  # 𨆱
    0x281B2: 'wěn',  # 𨆲
    # 0x281B3: '',  # 𨆳
    # 0x281B4: '',  # 𨆴
    0x281B5: 'pǒ',  # 𨆵
    # 0x281B6: '',  # 𨆶
    # 0x281B7: '',  # 𨆷
    # 0x281B8: '',  # 𨆸
    # 0x281B9: '',  # 𨆹
    # 0x281BA: '',  # 𨆺
    # 0x281BB: '',  # 𨆻
    # 0x281BC: '',  # 𨆼
    0x281BD: 'mó',  # 𨆽
    0x281BE: 'cā',  # 𨆾
    # 0x281BF: '',  # 𨆿
    # 0x281C0: '',  # 𨇀
    0x281C1: 'kuàng',  # 𨇁
    # 0x281C2: '',  # 𨇂
    0x281C3: 'cuó,zuān',  # 𨇃
    0x281C4: 'rǎo',  # 𨇄
    0x281C5: 'bào',  # 𨇅
    0x281C6: 'lài',  # 𨇆
    # 0x281C7: '',  # 𨇇
    # 0x281C8: '',  # 𨇈
    # 0x281C9: '',  # 𨇉
    # 0x281CA: '',  # 𨇊
    # 0x281CB: '',  # 𨇋
    # 0x281CC: '',  # 𨇌
    0x281CD: 'niǎn',  # 𨇍
    0x281CE: 'lí',  # 𨇎
    # 0x281CF: '',  # 𨇏
    # 0x281D0: '',  # 𨇐
    # 0x281D1: '',  # 𨇑
    # 0x281D2: '',  # 𨇒
    # 0x281D3: '',  # 𨇓
    # 0x281D4: '',  # 𨇔
    0x281D5: 'jiǎo',  # 𨇕
    0x281D6: 'lú',  # 𨇖
    0x281D7: 'lì',  # 𨇗
    0x281D8: 'lóng',  # 𨇘
    0x281D9: 'guì',  # 𨇙
    # 0x281DA: '',  # 𨇚
    # 0x281DB: '',  # 𨇛
    # 0x281DC: '',  # 𨇜
    0x281DD: 'chǎn',  # 𨇝
    # 0x281DE: '',  # 𨇞
    # 0x281DF: '',  # 𨇟
    # 0x281E0: '',  # 𨇠
    # 0x281E1: '',  # 𨇡
    # 0x281E2: '',  # 𨇢
    # 0x281E3: '',  # 𨇣
    0x281E4: 'xiān',  # 𨇤
    # 0x281E5: '',  # 𨇥
    0x281E6: 'chàn',  # 𨇦
    # 0x281E7: '',  # 𨇧
    0x281E8: 'xiè',  # 𨇨
    0x281E9: 'zhàn',  # 𨇩
    # 0x281EA: '',  # 𨇪
    # 0x281EB: '',  # 𨇫
    # 0x281EC: '',  # 𨇬
    # 0x281ED: '',  # 𨇭
    # 0x281EE: '',  # 𨇮
    0x281EF: 'shuāng',  # 𨇯
    # 0x281F0: '',  # 𨇰
    # 0x281F1: '',  # 𨇱
    # 0x281F2: '',  # 𨇲
    # 0x281F3: '',  # 𨇳
    # 0x281F4: '',  # 𨇴
    # 0x281F5: '',  # 𨇵
    # 0x281F6: '',  # 𨇶
    # 0x281F7: '',  # 𨇷
    # 0x281F8: '',  # 𨇸
    # 0x281F9: '',  # 𨇹
    # 0x281FA: '',  # 𨇺
    0x281FB: 'mǐ',  # 𨇻
    0x281FC: 'luán',  # 𨇼
    0x281FD: 'luò',  # 𨇽
    # 0x281FE: '',  # 𨇾
    # 0x281FF: '',  # 𨇿
    0x28200: 'diān',  # 𨈀
    # 0x28201: '',  # 𨈁
    # 0x28202: '',  # 𨈂
    # 0x28203: '',  # 𨈃
    # 0x28204: '',  # 𨈄
    # 0x28205: '',  # 𨈅
    0x28206: 'lán',  # 𨈆
    0x28207: 'làn',  # 𨈇
    0x28208: 'dié',  # 𨈈
    # 0x28209: '',  # 𨈉
    0x2820A: 'wān',  # 𨈊
    0x2820B: 'yuè',  # 𨈋
    0x2820C: 'luán',  # 𨈌
    # 0x2820D: '',  # 𨈍
    0x2820E: 'luán',  # 𨈎
    # 0x2820F: '',  # 𨈏
    # 0x28210: '',  # 𨈐
    # 0x28211: '',  # 𨈑
    # 0x28212: '',  # 𨈒
    0x28213: 'léng',  # 𨈓
    # 0x28214: '',  # 𨈔
    0x28215: 'wǎi',  # 𨈕
    0x28216: 'dìn',  # 𨈖
    0x28217: 'nèn',  # 𨈗
    0x28218: 'shǎo',  # 𨈘
    0x28219: 'xiè,zhī',  # 𨈙
    0x2821A: 'pí',  # 𨈚
    # 0x2821B: '',  # 𨈛
    # 0x2821C: '',  # 𨈜
    # 0x2821D: '',  # 𨈝
    # 0x2821E: '',  # 𨈞
    # 0x2821F: '',  # 𨈟
    # 0x28220: '',  # 𨈠
    # 0x28221: '',  # 𨈡
    # 0x28222: '',  # 𨈢
    # 0x28223: '',  # 𨈣
    # 0x28224: '',  # 𨈤
    0x28225: 'máo',  # 𨈥
    # 0x28226: '',  # 𨈦
    0x28227: 'yǐn',  # 𨈧
    # 0x28228: '',  # 𨈨
    0x28229: 'bó',  # 𨈩
    # 0x2822A: '',  # 𨈪
    0x2822B: 'zhù',  # 𨈫
    # 0x2822C: '',  # 𨈬
    # 0x2822D: '',  # 𨈭
    0x2822E: 'chōng',  # 𨈮
    # 0x2822F: '',  # 𨈯
    # 0x28230: '',  # 𨈰
    # 0x28231: '',  # 𨈱
    # 0x28232: '',  # 𨈲
    # 0x28233: '',  # 𨈳
    # 0x28234: '',  # 𨈴
    # 0x28235: '',  # 𨈵
    0x28236: 'mǔ',  # 𨈶
    0x28237: 'tuó',  # 𨈷
    # 0x28238: '',  # 𨈸
    0x28239: 'tǒng',  # 𨈹
    0x2823A: 'yé',  # 𨈺
    # 0x2823B: '',  # 𨈻
    # 0x2823C: '',  # 𨈼
    # 0x2823D: '',  # 𨈽
    # 0x2823E: '',  # 𨈾
    # 0x2823F: '',  # 𨈿
    # 0x28240: '',  # 𨉀
    0x28241: 'huàng',  # 𨉁
    # 0x28242: '',  # 𨉂
    0x28243: 'rèn',  # 𨉃
    # 0x28244: '',  # 𨉄
    0x28245: 'yè',  # 𨉅
    # 0x28246: '',  # 𨉆
    # 0x28247: '',  # 𨉇
    # 0x28248: '',  # 𨉈
    # 0x28249: '',  # 𨉉
    # 0x2824A: '',  # 𨉊
    0x2824B: 'tuó',  # 𨉋
    # 0x2824C: '',  # 𨉌
    # 0x2824D: '',  # 𨉍
    # 0x2824E: '',  # 𨉎
    # 0x2824F: '',  # 𨉏
    # 0x28250: '',  # 𨉐
    # 0x28251: '',  # 𨉑
    # 0x28252: '',  # 𨉒
    # 0x28253: '',  # 𨉓
    # 0x28254: '',  # 𨉔
    # 0x28255: '',  # 𨉕
    0x28256: 'zuān',  # 𨉖
    # 0x28257: '',  # 𨉗
    # 0x28258: '',  # 𨉘
    # 0x28259: '',  # 𨉙
    0x2825A: 'ā',  # 𨉚
    # 0x2825B: '',  # 𨉛
    0x2825C: 'zhōu',  # 𨉜
    0x2825D: 'wān',  # 𨉝
    # 0x2825E: '',  # 𨉞
    # 0x2825F: '',  # 𨉟
    # 0x28260: '',  # 𨉠
    0x28261: 'duǒ',  # 𨉡
    0x28262: 'zhòng',  # 𨉢
    0x28263: 'hā',  # 𨉣
    0x28264: 'huáng',  # 𨉤
    0x28265: 'miàn,tǐ',  # 𨉥
    # 0x28266: '',  # 𨉦
    # 0x28267: '',  # 𨉧
    # 0x28268: '',  # 𨉨
    0x28269: 'chūn',  # 𨉩
    0x2826A: 'qiè',  # 𨉪
    0x2826B: 'gōng,qiōng',  # 𨉫
    0x2826C: 'tíng',  # 𨉬
    0x2826D: 'méi',  # 𨉭
    # 0x2826E: '',  # 𨉮
    # 0x2826F: '',  # 𨉯
    # 0x28270: '',  # 𨉰
    0x28271: 'tàng',  # 𨉱
    # 0x28272: '',  # 𨉲
    # 0x28273: '',  # 𨉳
    0x28274: 'róng',  # 𨉴
    # 0x28275: '',  # 𨉵
    # 0x28276: '',  # 𨉶
    0x28277: 'róng',  # 𨉷
    0x28278: 'qí',  # 𨉸
    0x28279: 'guó',  # 𨉹
    # 0x2827A: '',  # 𨉺
    # 0x2827B: '',  # 𨉻
    # 0x2827C: '',  # 𨉼
    0x2827D: 'xiàng',  # 𨉽
    0x2827E: 'tián',  # 𨉾
    # 0x2827F: '',  # 𨉿
    # 0x28280: '',  # 𨊀
    # 0x28281: '',  # 𨊁
    # 0x28282: '',  # 𨊂
    # 0x28283: '',  # 𨊃
    # 0x28284: '',  # 𨊄
    0x28285: 'xiāo',  # 𨊅
    # 0x28286: '',  # 𨊆
    # 0x28287: '',  # 𨊇
    0x28288: 'zhān',  # 𨊈
    0x28289: 'cuì',  # 𨊉
    # 0x2828A: '',  # 𨊊
    # 0x2828B: '',  # 𨊋
    # 0x2828C: '',  # 𨊌
    # 0x2828D: '',  # 𨊍
    # 0x2828E: '',  # 𨊎
    # 0x2828F: '',  # 𨊏
    # 0x28290: '',  # 𨊐
    # 0x28291: '',  # 𨊑
    # 0x28292: '',  # 𨊒
    # 0x28293: '',  # 𨊓
    0x28294: 'lán',  # 𨊔
    # 0x28295: '',  # 𨊕
    # 0x28296: '',  # 𨊖
    # 0x28297: '',  # 𨊗
    0x28298: 'shēn,qū',  # 𨊘
    # 0x28299: '',  # 𨊙
    0x2829A: 'lěi',  # 𨊚
    0x2829B: 'lì',  # 𨊛
    # 0x2829C: '',  # 𨊜
    0x2829D: 'chān',  # 𨊝
    0x2829E: 'niè',  # 𨊞
    0x2829F: 'luán',  # 𨊟
    # 0x282A0: '',  # 𨊠
    0x282A1: 'tīng',  # 𨊡
    0x282A2: 'huì,sháo',  # 𨊢
    # 0x282A3: '',  # 𨊣
    # 0x282A4: '',  # 𨊤
    # 0x282A5: '',  # 𨊥
    # 0x282A6: '',  # 𨊦
    0x282A7: 'gōng',  # 𨊧
    # 0x282A8: '',  # 𨊨
    # 0x282A9: '',  # 𨊩
    # 0x282AA: '',  # 𨊪
    # 0x282AB: '',  # 𨊫
    # 0x282AC: '',  # 𨊬
    # 0x282AD: '',  # 𨊭
    # 0x282AE: '',  # 𨊮
    # 0x282AF: '',  # 𨊯
    0x282B0: 'qì',  # 𨊰
    0x282B1: 'yú',  # 𨊱
    # 0x282B2: '',  # 𨊲
    0x282B3: 'xīn',  # 𨊳
    # 0x282B4: '',  # 𨊴
    # 0x282B5: '',  # 𨊵
    # 0x282B6: '',  # 𨊶
    # 0x282B7: '',  # 𨊷
    0x282B8: 'yuè',  # 𨊸
    0x282B9: 'bā',  # 𨊹
    0x282BA: 'dài',  # 𨊺
    0x282BB: 'jī',  # 𨊻
    0x282BC: 'xuàn',  # 𨊼
    # 0x282BD: '',  # 𨊽
    # 0x282BE: '',  # 𨊾
    0x282BF: 'jué',  # 𨊿
    0x282C0: 'niǔ',  # 𨋀
    # 0x282C1: '',  # 𨋁
    # 0x282C2: '',  # 𨋂
    # 0x282C3: '',  # 𨋃
    # 0x282C4: '',  # 𨋄
    # 0x282C5: '',  # 𨋅
    # 0x282C6: '',  # 𨋆
    # 0x282C7: '',  # 𨋇
    0x282C8: 'dù',  # 𨋈
    0x282C9: 'jí',  # 𨋉
    # 0x282CA: '',  # 𨋊
    # 0x282CB: '',  # 𨋋
    # 0x282CC: '',  # 𨋌
    # 0x282CD: '',  # 𨋍
    # 0x282CE: '',  # 𨋎
    # 0x282CF: '',  # 𨋏
    0x282D0: 'pā',  # 𨋐
    0x282D1: 'gǒng',  # 𨋑
    0x282D2: 'bèn',  # 𨋒
    # 0x282D3: '',  # 𨋓
    0x282D4: 'kēng,jú',  # 𨋔
    0x282D5: 'yàng,ǎng',  # 𨋕
    0x282D6: 'liǔ',  # 𨋖
    0x282D7: 'ní',  # 𨋗
    0x282D8: 'zhà',  # 𨋘
    0x282D9: 'yìn',  # 𨋙
    0x282DA: 'niǎn,ruǎn',  # 𨋚
    0x282DB: 'pào',  # 𨋛
    # 0x282DC: '',  # 𨋜
    0x282DD: 'gōng',  # 𨋝
    0x282DE: 'bù',  # 𨋞
    0x282DF: 'hé',  # 𨋟
    0x282E0: 'rǒng',  # 𨋠
    0x282E1: 'guì',  # 𨋡
    # 0x282E2: '',  # 𨋢
    # 0x282E3: '',  # 𨋣
    # 0x282E4: '',  # 𨋤
    0x282E5: 'bì',  # 𨋥
    0x282E6: 'xī',  # 𨋦
    0x282E7: 'jú',  # 𨋧
    0x282E8: 'hún',  # 𨋨
    0x282E9: 'bì,fú',  # 𨋩
    # 0x282EA: '',  # 𨋪
    0x282EB: 'tiāo',  # 𨋫
    0x282EC: 'zhěng,chèng',  # 𨋬
    # 0x282ED: '',  # 𨋭
    # 0x282EE: '',  # 𨋮
    0x282EF: 'yì',  # 𨋯
    0x282F0: 'cì',  # 𨋰
    # 0x282F1: '',  # 𨋱
    0x282F2: 'bìng',  # 𨋲
    # 0x282F3: '',  # 𨋳
    # 0x282F4: '',  # 𨋴
    # 0x282F5: '',  # 𨋵
    # 0x282F6: '',  # 𨋶
    0x282F7: 'gōng',  # 𨋷
    # 0x282F8: '',  # 𨋸
    # 0x282F9: '',  # 𨋹
    0x282FA: 'fá',  # 𨋺
    # 0x282FB: '',  # 𨋻
    # 0x282FC: '',  # 𨋼
    0x282FD: 'yáng',  # 𨋽
    0x282FE: 'xǔ',  # 𨋾
    # 0x282FF: '',  # 𨋿
    # 0x28300: '',  # 𨌀
    0x28301: 'hōng,chūn',  # 𨌁
    # 0x28302: '',  # 𨌂
    # 0x28303: '',  # 𨌃
    0x28304: 'zàng',  # 𨌄
    0x28305: 'chái',  # 𨌅
    0x28306: 'hóng',  # 𨌆
    # 0x28307: '',  # 𨌇
    0x28308: 'tián',  # 𨌈
    # 0x28309: '',  # 𨌉
    # 0x2830A: '',  # 𨌊
    # 0x2830B: '',  # 𨌋
    0x2830C: 'zhī',  # 𨌌
    0x2830D: 'xīng',  # 𨌍
    0x2830E: 'xú',  # 𨌎
    # 0x2830F: '',  # 𨌏
    # 0x28310: '',  # 𨌐
    0x28311: 'zhèn',  # 𨌑
    # 0x28312: '',  # 𨌒
    # 0x28313: '',  # 𨌓
    0x28314: 'wǎn,wàn',  # 𨌔
    # 0x28315: '',  # 𨌕
    # 0x28316: '',  # 𨌖
    # 0x28317: '',  # 𨌗
    0x28318: 'jùn',  # 𨌘
    # 0x28319: '',  # 𨌙
    # 0x2831A: '',  # 𨌚
    # 0x2831B: '',  # 𨌛
    # 0x2831C: '',  # 𨌜
    0x2831D: 'wò,huò',  # 𨌝
    # 0x2831E: '',  # 𨌞
    # 0x2831F: '',  # 𨌟
    0x28320: 'lù',  # 𨌠
    # 0x28321: '',  # 𨌡
    0x28322: 'zhēng',  # 𨌢
    0x28323: 'rǒng',  # 𨌣
    0x28324: 'chéng,chèng',  # 𨌤
    0x28325: 'fú',  # 𨌥
    # 0x28326: '',  # 𨌦
    0x28327: 'è',  # 𨌧
    0x28328: 'tāo',  # 𨌨
    0x28329: 'táng',  # 𨌩
    # 0x2832A: '',  # 𨌪
    0x2832B: 'juān',  # 𨌫
    0x2832C: 'chào',  # 𨌬
    0x2832D: 'tà',  # 𨌭
    0x2832E: 'dǐ',  # 𨌮
    # 0x2832F: '',  # 𨌯
    0x28330: 'zōng',  # 𨌰
    # 0x28331: '',  # 𨌱
    0x28332: 'mǐn',  # 𨌲
    0x28333: 'kēng',  # 𨌳
    0x28334: 'tuī',  # 𨌴
    # 0x28335: '',  # 𨌵
    0x28336: 'kēng',  # 𨌶
    # 0x28337: '',  # 𨌷
    # 0x28338: '',  # 𨌸
    # 0x28339: '',  # 𨌹
    # 0x2833A: '',  # 𨌺
    # 0x2833B: '',  # 𨌻
    # 0x2833C: '',  # 𨌼
    # 0x2833D: '',  # 𨌽
    # 0x2833E: '',  # 𨌾
    # 0x2833F: '',  # 𨌿
    # 0x28340: '',  # 𨍀
    # 0x28341: '',  # 𨍁
    # 0x28342: '',  # 𨍂
    # 0x28343: '',  # 𨍃
    # 0x28344: '',  # 𨍄
    0x28345: 'rǒng',  # 𨍅
    0x28346: 'yūn',  # 𨍆
    0x28347: 'hé',  # 𨍇
    0x28348: 'zǒng',  # 𨍈
    0x28349: 'cōng,zǒng',  # 𨍉
    0x2834A: 'qiū',  # 𨍊
    # 0x2834B: '',  # 𨍋
    # 0x2834C: '',  #
    # 0x2834D: '',  #
    0x2834E: 'mù',  # 𨍎
    # 0x2834F: '',  #
    # 0x28350: '',  #
    0x28351: 'kēng',  # 𨍑
    0x28352: 'xiàn,jiàn',  # 𨍒
    # 0x28353: '',  # 𨍓
    # 0x28354: '',  # 𨍔
    # 0x28355: '',  # 𨍕
    # 0x28356: '',  # 𨍖
    # 0x28357: '',  # 𨍗
    # 0x28358: '',  # 𨍘
    # 0x28359: '',  # 𨍙
    # 0x2835A: '',  # 𨍚
    0x2835B: 'dú',  # 𨍛
    0x2835C: 'kǎn',  # 𨍜
    # 0x2835D: '',  # 𨍝
    0x2835E: 'yīng',  # 𨍞
    # 0x2835F: '',  # 𨍟
    # 0x28360: '',  # 𨍠
    # 0x28361: '',  # 𨍡
    0x28362: 'zī',  # 𨍢
    # 0x28363: '',  # 𨍣
    # 0x28364: '',  # 𨍤
    # 0x28365: '',  # 𨍥
    # 0x28366: '',  # 𨍦
    0x28367: 'huáng',  # 𨍧
    # 0x28368: '',  # 𨍨
    0x28369: 'péng',  # 𨍩
    # 0x2836A: '',  # 𨍪
    0x2836B: 'lì',  # 𨍫
    # 0x2836C: '',  # 𨍬
    0x2836D: 'bó,pò',  # 𨍭
    0x2836E: 'gé,lì',  # 𨍮
    0x2836F: 'jú',  # 𨍯
    0x28370: 'kē',  # 𨍰
    # 0x28371: '',  # 𨍱
    0x28372: 'hú,gǔn',  # 𨍲
    0x28373: 'diāo,yáo',  # 𨍳
    0x28374: 'táng',  # 𨍴
    # 0x28375: '',  # 𨍵
    0x28376: 'qióng',  # 𨍶
    0x28377: 'rǒng',  # 𨍷
    0x28378: 'liǔ',  # 𨍸
    0x28379: 'huì',  # 𨍹
    0x2837A: 'jī',  # 𨍺
    # 0x2837B: '',  # 𨍻
    # 0x2837C: '',  # 𨍼
    0x2837D: 'gǔn',  # 𨍽
    # 0x2837E: '',  # 𨍾
    # 0x2837F: '',  # 𨍿
    # 0x28380: '',  # 𨎀
    # 0x28381: '',  # 𨎁
    # 0x28382: '',  # 𨎂
    # 0x28383: '',  # 𨎃
    # 0x28384: '',  # 𨎄
    # 0x28385: '',  # 𨎅
    # 0x28386: '',  # 𨎆
    # 0x28387: '',  # 𨎇
    # 0x28388: '',  # 𨎈
    0x28389: 'zhì',  # 𨎉
    # 0x2838A: '',  # 𨎊
    0x2838B: 'táng,chēng',  # 𨎋
    0x2838C: 'zhǐ',  # 𨎌
    0x2838D: 'kāng,liáng',  # 𨎍
    # 0x2838E: '',  # 𨎎
    # 0x2838F: '',  # 𨎏
    # 0x28390: '',  # 𨎐
    # 0x28391: '',  # 𨎑
    # 0x28392: '',  # 𨎒
    # 0x28393: '',  # 𨎓
    0x28394: 'yàng',  # 𨎔
    # 0x28395: '',  # 𨎕
    0x28396: 'tǎng,chǎng',  # 𨎖
    0x28397: 'hōng',  # 𨎗
    # 0x28398: '',  # 𨎘
    # 0x28399: '',  # 𨎙
    # 0x2839A: '',  # 𨎚
    0x2839B: 'liáng',  # 𨎛
    # 0x2839C: '',  # 𨎜
    0x2839D: 'cáo',  # 𨎝
    # 0x2839E: '',  # 𨎞
    # 0x2839F: '',  # 𨎟
    # 0x283A0: '',  # 𨎠
    0x283A1: 'nǎi',  # 𨎡
    0x283A2: 'zǒng',  # 𨎢
    # 0x283A3: '',  # 𨎣
    0x283A4: 'dèng',  # 𨎤
    # 0x283A5: '',  # 𨎥
    0x283A6: 'jiāo',  # 𨎦
    0x283A7: 'péng',  # 𨎧
    # 0x283A8: '',  # 𨎨
    0x283A9: 'guāng',  # 𨎩
    # 0x283AA: '',  # 𨎪
    0x283AB: 'jiàn',  # 𨎫
    0x283AC: 'jiào',  # 𨎬
    0x283AD: 'nuó',  # 𨎭
    0x283AE: 'zǎo',  # 𨎮
    # 0x283AF: '',  # 𨎯
    # 0x283B0: '',  # 𨎰
    # 0x283B1: '',  # 𨎱
    # 0x283B2: '',  # 𨎲
    0x283B3: 'péng',  # 𨎳
    0x283B4: 'dāng',  # 𨎴
    # 0x283B5: '',  # 𨎵
    0x283B6: 'qú',  # 𨎶
    0x283B7: 'lián',  # 𨎷
    0x283B8: 'mù',  # 𨎸
    0x283B9: 'lǎn',  # 𨎹
    # 0x283BA: '',  # 𨎺
    # 0x283BB: '',  # 𨎻
    # 0x283BC: '',  # 𨎼
    # 0x283BD: '',  # 𨎽
    0x283BE: 'fén',  # 𨎾
    # 0x283BF: '',  # 𨎿
    # 0x283C0: '',  # 𨏀
    # 0x283C1: '',  # 𨏁
    0x283C2: 'hún,xuān',  # 𨏂
    # 0x283C3: '',  # 𨏃
    # 0x283C4: '',  # 𨏄
    # 0x283C5: '',  # 𨏅
    0x283C6: 'kuāng',  # 𨏆
    # 0x283C7: '',  # 𨏇
    0x283C8: 'yǐn',  # 𨏈
    0x283C9: 'shuàn',  # 𨏉
    0x283CA: 'jiàn',  # 𨏊
    # 0x283CB: '',  # 𨏋
    # 0x283CC: '',  # 𨏌
    # 0x283CD: '',  # 𨏍
    # 0x283CE: '',  # 𨏎
    # 0x283CF: '',  # 𨏏
    # 0x283D0: '',  # 𨏐
    # 0x283D1: '',  # 𨏑
    0x283D2: 'luò,léi',  # 𨏒
    # 0x283D3: '',  # 𨏓
    0x283D4: 'lù,dú',  # 𨏔
    # 0x283D5: '',  # 𨏕
    # 0x283D6: '',  # 𨏖
    # 0x283D7: '',  # 𨏗
    # 0x283D8: '',  # 𨏘
    # 0x283D9: '',  # 𨏙
    0x283DA: 'gé',  # 𨏚
    0x283DB: 'rǎng,niǎn',  # 𨏛
    # 0x283DC: '',  # 𨏜
    # 0x283DD: '',  # 𨏝
    0x283DE: 'pín',  # 𨏞
    # 0x283DF: '',  # 𨏟
    0x283E0: 'lóng',  # 𨏠
    # 0x283E1: '',  # 𨏡
    # 0x283E2: '',  # 𨏢
    # 0x283E3: '',  # 𨏣
    0x283E4: 'zhěn',  # 𨏤
    0x283E5: 'xiàn',  # 𨏥
    # 0x283E6: '',  # 𨏦
    # 0x283E7: '',  # 𨏧
    0x283E8: 'lìn',  # 𨏨
    0x283E9: 'lián',  # 𨏩
    0x283EA: 'shān',  # 𨏪
    0x283EB: 'bó',  # 𨏫
    0x283EC: 'lì',  # 𨏬
    # 0x283ED: '',  # 𨏭
    # 0x283EE: '',  # 𨏮
    # 0x283EF: '',  # 𨏯
    # 0x283F0: '',  # 𨏰
    # 0x283F1: '',  # 𨏱
    # 0x283F2: '',  # 𨏲
    0x283F3: 'xié',  # 𨏳
    0x283F4: 'gé',  # 𨏴
    0x283F5: 'mǐn',  # 𨏵
    0x283F6: 'lián',  # 𨏶
    # 0x283F7: '',  # 𨏷
    # 0x283F8: '',  # 𨏸
    0x283F9: 'jué',  # 𨏹
    0x283FA: 'zhōu',  # 𨏺
    # 0x283FB: '',  # 𨏻
    # 0x283FC: '',  # 𨏼
    # 0x283FD: '',  # 𨏽
    # 0x283FE: '',  # 𨏾
    0x283FF: 'kē',  # 𨏿
    # 0x28400: '',  # 𨐀
    0x28401: 'dié',  # 𨐁
    # 0x28402: '',  # 𨐂
    0x28403: 'zhé',  # 𨐃
    # 0x28404: '',  # 𨐄
    # 0x28405: '',  # 𨐅
    0x28406: 'jī',  # 𨐆
    # 0x28407: '',  # 𨐇
    # 0x28408: '',  # 𨐈
    # 0x28409: '',  # 𨐉
    # 0x2840A: '',  # 𨐊
    0x2840B: 'qiān',  # 𨐋
    # 0x2840C: '',  # 𨐌
    0x2840D: 'shēn',  # 𨐍
    # 0x2840E: '',  # 𨐎
    # 0x2840F: '',  # 𨐏
    0x28410: 'yǐn',  # 𨐐
    0x28411: 'jiè',  # 𨐑
    # 0x28412: '',  # 𨐒
    # 0x28413: '',  # 𨐓
    0x28414: 'shēn',  # 𨐔
    0x28415: 'shēn,cí',  # 𨐕
    0x28416: 'sǎ',  # 𨐖
    # 0x28417: '',  # 𨐗
    # 0x28418: '',  # 𨐘
    # 0x28419: '',  # 𨐙
    # 0x2841A: '',  # 𨐚
    0x2841B: 'xì',  # 𨐛
    # 0x2841C: '',  # 𨐜
    # 0x2841D: '',  # 𨐝
    # 0x2841E: '',  # 𨐞
    # 0x2841F: '',  # 𨐟
    # 0x28420: '',  # 𨐠
    0x28421: 'kù',  # 𨐡
    # 0x28422: '',  # 𨐢
    0x28423: 'qú',  # 𨐣
    # 0x28424: '',  # 𨐤
    0x28425: 'gé',  # 𨐥
    0x28426: 'bàn',  # 𨐦
    # 0x28427: '',  # 𨐧
    0x28428: 'bì',  # 𨐨
    0x28429: 'qiān',  # 𨐩
    # 0x2842A: '',  # 𨐪
    # 0x2842B: '',  # 𨐫
    # 0x2842C: '',  # 𨐬
    # 0x2842D: '',  # 𨐭
    # 0x2842E: '',  # 𨐮
    # 0x2842F: '',  # 𨐯
    0x28430: 'bīn',  # 𨐰
    0x28431: 'bàn',  # 𨐱
    # 0x28432: '',  # 𨐲
    0x28433: 'zuò',  # 𨐳
    0x28434: 'pì',  # 𨐴
    # 0x28435: '',  # 𨐵
    0x28436: 'huò',  # 𨐶
    # 0x28437: '',  # 𨐷
    # 0x28438: '',  # 𨐸
    # 0x28439: '',  # 𨐹
    # 0x2843A: '',  # 𨐺
    # 0x2843B: '',  # 𨐻
    # 0x2843C: '',  # 𨐼
    # 0x2843D: '',  # 𨐽
    0x2843E: 'bàn,biàn',  # 𨐾
    # 0x2843F: '',  # 𨐿
    # 0x28440: '',  # 𨑀
    # 0x28441: '',  # 𨑁
    # 0x28442: '',  # 𨑂
    # 0x28443: '',  # 𨑃
    # 0x28444: '',  # 𨑄
    # 0x28445: '',  # 𨑅
    # 0x28446: '',  # 𨑆
    # 0x28447: '',  # 𨑇
    # 0x28448: '',  # 𨑈
    # 0x28449: '',  # 𨑉
    0x2844A: 'nóng',  # 𨑊
    # 0x2844B: '',  # 𨑋
    0x2844C: 'chén',  # 𨑌
    # 0x2844D: '',  # 𨑍
    0x2844E: 'pēng',  # 𨑎
    # 0x2844F: '',  # 𨑏
    # 0x28450: '',  # 𨑐
    0x28451: 'fǔ',  # 𨑑
    0x28452: 'tú',  # 𨑒
    # 0x28453: '',  # 𨑓
    # 0x28454: '',  # 𨑔
    # 0x28455: '',  # 𨑕
    # 0x28456: '',  # 𨑖
    # 0x28457: '',  # 𨑗
    # 0x28458: '',  # 𨑘
    # 0x28459: '',  # 𨑙
    # 0x2845A: '',  # 𨑚
    # 0x2845B: '',  # 𨑛
    0x2845C: 'pǐ',  # 𨑜
    0x2845D: 'pò',  # 𨑝
    # 0x2845E: '',  # 𨑞
    # 0x2845F: '',  # 𨑟
    0x28460: 'chǐ',  # 𨑠
    # 0x28461: '',  # 𨑡
    # 0x28462: '',  # 𨑢
    0x28463: 'xuè',  # 𨑣
    0x28464: 'qì',  # 𨑤
    0x28465: 'wù',  # 𨑥
    # 0x28466: '',  # 𨑦
    # 0x28467: '',  # 𨑧
    0x28468: 'zhì',  # 𨑨
    0x28469: 'dì',  # 𨑩
    0x2846A: 'cōng',  # 𨑪
    0x2846B: 'yóu',  # 𨑫
    # 0x2846C: '',  # 𨑬
    0x2846D: 'xǐ',  # 𨑭
    # 0x2846E: '',  # 𨑮
    # 0x2846F: '',  # 𨑯
    # 0x28470: '',  # 𨑰
    # 0x28471: '',  # 𨑱
    # 0x28472: '',  # 𨑲
    # 0x28473: '',  # 𨑳
    # 0x28474: '',  # 𨑴
    # 0x28475: '',  # 𨑵
    # 0x28476: '',  # 𨑶
    # 0x28477: '',  # 𨑷
    0x28478: 'ěr',  # 𨑸
    # 0x28479: '',  # 𨑹
    # 0x2847A: '',  # 𨑺
    # 0x2847B: '',  # 𨑻
    0x2847C: 'dì',  # 𨑼
    0x2847D: 'zhuó',  # 𨑽
    # 0x2847E: '',  # 𨑾
    0x2847F: 'zǒu',  # 𨑿
    0x28480: 'cóng',  # 𨒀
    # 0x28481: '',  # 𨒁
    # 0x28482: '',  # 𨒂
    0x28483: 'pàn',  # 𨒃
    0x28484: 'yǎn',  # 𨒄
    0x28485: 'qì',  # 𨒅
    0x28486: 'rǒng',  # 𨒆
    0x28487: 'jiǎ',  # 𨒇
    0x28488: 'chí',  # 𨒈
    0x28489: 'zhì,zhuì,suì',  # 𨒉
    0x2848A: 'qiú',  # 𨒊
    0x2848B: 'yuè',  # 𨒋
    0x2848C: 'zhēng',  # 𨒌
    0x2848D: 'shì',  # 𨒍
    # 0x2848E: '',  # 𨒎
    # 0x2848F: '',  # 𨒏
    # 0x28490: '',  # 𨒐
    0x28491: 'háo',  # 𨒑
    # 0x28492: '',  # 𨒒
    # 0x28493: '',  # 𨒓
    # 0x28494: '',  # 𨒔
    # 0x28495: '',  # 𨒕
    # 0x28496: '',  # 𨒖
    # 0x28497: '',  # 𨒗
    # 0x28498: '',  # 𨒘
    0x28499: 'tuō,hòu',  # 𨒙
    # 0x2849A: '',  # 𨒚
    # 0x2849B: '',  # 𨒛
    0x2849C: 'bié',  # 𨒜
    # 0x2849D: '',  # 𨒝
    0x2849E: 'kàn',  # 𨒞
    # 0x2849F: '',  # 𨒟
    # 0x284A0: '',  # 𨒠
    # 0x284A1: '',  # 𨒡
    0x284A2: 'chuò',  # 𨒢
    # 0x284A3: '',  # 𨒣
    0x284A4: 'cǐ',  # 𨒤
    0x284A5: 'hòu',  # 𨒥
    0x284A6: 'yǐn',  # 𨒦
    0x284A7: 'shì',  # 𨒧
    0x284A8: 'nài',  # 𨒨
    0x284A9: 'ruǎn',  # 𨒩
    # 0x284AA: '',  # 𨒪
    0x284AB: 'yáng,nì',  # 𨒫
    0x284AC: 'chī',  # 𨒬
    # 0x284AD: '',  # 𨒭
    0x284AE: 'cī',  # 𨒮
    # 0x284AF: '',  # 𨒯
    # 0x284B0: '',  # 𨒰
    0x284B1: 'gōng',  # 𨒱
    0x284B2: 'mí,xuè',  # 𨒲
    # 0x284B3: '',  # 𨒳
    0x284B4: 'jǐ',  # 𨒴
    # 0x284B5: '',  # 𨒵
    # 0x284B6: '',  # 𨒶
    # 0x284B7: '',  # 𨒷
    # 0x284B8: '',  # 𨒸
    # 0x284B9: '',  # 𨒹
    # 0x284BA: '',  # 𨒺
    # 0x284BB: '',  # 𨒻
    0x284BC: 'gèn',  # 𨒼
    0x284BD: 'zào,suō',  # 𨒽
    # 0x284BE: '',  # 𨒾
    # 0x284BF: '',  # 𨒿
    # 0x284C0: '',  # 𨓀
    0x284C1: 'běng',  # 𨓁
    # 0x284C2: '',  # 𨓂
    # 0x284C3: '',  # 𨓃
    # 0x284C4: '',  # 𨓄
    # 0x284C5: '',  # 𨓅
    # 0x284C6: '',  # 𨓆
    0x284C7: 'xǐn',  # 𨓇
    0x284C8: 'kuò',  # 𨓈
    # 0x284C9: '',  # 𨓉
    0x284CA: 'dié',  # 𨓊
    # 0x284CB: '',  # 𨓋
    # 0x284CC: '',  # 𨓌
    0x284CD: 'tíng',  # 𨓍
    # 0x284CE: '',  # 𨓎
    # 0x284CF: '',  # 𨓏
    # 0x284D0: '',  # 𨓐
    # 0x284D1: '',  # 𨓑
    # 0x284D2: '',  # 𨓒
    # 0x284D3: '',  # 𨓓
    # 0x284D4: '',  # 𨓔
    # 0x284D5: '',  # 𨓕
    # 0x284D6: '',  # 𨓖
    # 0x284D7: '',  # 𨓗
    # 0x284D8: '',  # 𨓘
    # 0x284D9: '',  # 𨓙
    0x284DA: 'shuì',  # 𨓚
    # 0x284DB: '',  # 𨓛
    # 0x284DC: '',  # 𨓜
    # 0x284DD: '',  # 𨓝
    0x284DE: 'dài',  # 𨓞
    # 0x284DF: '',  # 𨓟
    0x284E0: 'dì',  # 𨓠
    # 0x284E1: '',  # 𨓡
    # 0x284E2: '',  # 𨓢
    # 0x284E3: '',  # 𨓣
    # 0x284E4: '',  # 𨓤
    # 0x284E5: '',  # 𨓥
    0x284E6: 'lǐ',  # 𨓦
    # 0x284E7: '',  # 𨓧
    0x284E8: 'yǒng',  # 𨓨
    0x284E9: 'jiāo',  # 𨓩
    # 0x284EA: '',  # 𨓪
    # 0x284EB: '',  # 𨓫
    0x284EC: 'tá',  # 𨓬
    0x284ED: 'qǔ,còu',  # 𨓭
    0x284EE: 'yín',  # 𨓮
    0x284EF: 'yuān',  # 𨓯
    0x284F0: 'jié',  # 𨓰
    # 0x284F1: '',  # 𨓱
    0x284F2: 'qiān',  # 𨓲
    0x284F3: 'yāo',  # 𨓳
    0x284F4: 'yà',  # 𨓴
    # 0x284F5: '',  # 𨓵
    # 0x284F6: '',  # 𨓶
    0x284F7: 'qīng',  # 𨓷
    # 0x284F8: '',  # 𨓸
    # 0x284F9: '',  # 𨓹
    # 0x284FA: '',  # 𨓺
    # 0x284FB: '',  # 𨓻
    # 0x284FC: '',  # 𨓼
    # 0x284FD: '',  # 𨓽
    # 0x284FE: '',  # 𨓾
    0x284FF: 'péi',  # 𨓿
    # 0x28500: '',  # 𨔀
    # 0x28501: '',  # 𨔁
    # 0x28502: '',  # 𨔂
    # 0x28503: '',  # 𨔃
    # 0x28504: '',  # 𨔄
    # 0x28505: '',  # 𨔅
    # 0x28506: '',  # 𨔆
    # 0x28507: '',  # 𨔇
    # 0x28508: '',  # 𨔈
    # 0x28509: '',  # 𨔉
    # 0x2850A: '',  # 𨔊
    # 0x2850B: '',  # 𨔋
    # 0x2850C: '',  # 𨔌
    # 0x2850D: '',  # 𨔍
    # 0x2850E: '',  # 𨔎
    # 0x2850F: '',  # 𨔏
    # 0x28510: '',  # 𨔐
    # 0x28511: '',  # 𨔑
    # 0x28512: '',  # 𨔒
    # 0x28513: '',  # 𨔓
    # 0x28514: '',  # 𨔔
    # 0x28515: '',  # 𨔕
    # 0x28516: '',  # 𨔖
    0x28517: 'jiā',  # 𨔗
    # 0x28518: '',  # 𨔘
    0x28519: 'tòu',  # 𨔙
    # 0x2851A: '',  # 𨔚
    0x2851B: 'tī',  # 𨔛
    # 0x2851C: '',  # 𨔜
    # 0x2851D: '',  # 𨔝
    # 0x2851E: '',  # 𨔞
    # 0x2851F: '',  # 𨔟
    # 0x28520: '',  # 𨔠
    0x28521: 'dùn,tún,chuàn,chuán',  # 𨔡
    0x28522: 'chǎn',  # 𨔢
    0x28523: 'jiā,jià',  # 𨔣
    0x28524: 'chì',  # 𨔤
    0x28525: 'jiān,jīn',  # 𨔥
    0x28526: 'shù',  # 𨔦
    # 0x28527: '',  # 𨔧
    # 0x28528: '',  # 𨔨
    # 0x28529: '',  # 𨔩
    # 0x2852A: '',  # 𨔪
    # 0x2852B: '',  # 𨔫
    # 0x2852C: '',  # 𨔬
    # 0x2852D: '',  # 𨔭
    # 0x2852E: '',  # 𨔮
    0x2852F: 'tà',  # 𨔯
    # 0x28530: '',  # 𨔰
    # 0x28531: '',  # 𨔱
    # 0x28532: '',  # 𨔲
    # 0x28533: '',  # 𨔳
    # 0x28534: '',  # 𨔴
    0x28535: 'dùn',  # 𨔵
    # 0x28536: '',  # 𨔶
    # 0x28537: '',  # 𨔷
    # 0x28538: '',  # 𨔸
    # 0x28539: '',  # 𨔹
    # 0x2853A: '',  # 𨔺
    # 0x2853B: '',  # 𨔻
    # 0x2853C: '',  # 𨔼
    # 0x2853D: '',  # 𨔽
    # 0x2853E: '',  # 𨔾
    # 0x2853F: '',  # 𨔿
    # 0x28540: '',  # 𨕀
    # 0x28541: '',  # 𨕁
    # 0x28542: '',  # 𨕂
    # 0x28543: '',  # 𨕃
    # 0x28544: '',  # 𨕄
    # 0x28545: '',  # 𨕅
    # 0x28546: '',  # 𨕆
    # 0x28547: '',  # 𨕇
    # 0x28548: '',  # 𨕈
    # 0x28549: '',  # 𨕉
    # 0x2854A: '',  # 𨕊
    # 0x2854B: '',  # 𨕋
    # 0x2854C: '',  # 𨕌
    # 0x2854D: '',  # 𨕍
    # 0x2854E: '',  # 𨕎
    # 0x2854F: '',  # 𨕏
    # 0x28550: '',  # 𨕐
    # 0x28551: '',  # 𨕑
    # 0x28552: '',  # 𨕒
    # 0x28553: '',  # 𨕓
    # 0x28554: '',  # 𨕔
    0x28555: 'zhī',  # 𨕕
    # 0x28556: '',  # 𨕖
    0x28557: 'yuán',  # 𨕗
    # 0x28558: '',  # 𨕘
    # 0x28559: '',  # 𨕙
    0x2855A: 'hū',  # 𨕚
    # 0x2855B: '',  # 𨕛
    0x2855C: 'liè',  # 𨕜
    # 0x2855D: '',  # 𨕝
    # 0x2855E: '',  # 𨕞
    # 0x2855F: '',  # 𨕟
    0x28560: 'zé',  # 𨕠
    # 0x28561: '',  # 𨕡
    0x28562: 'chù',  # 𨕢
    # 0x28563: '',  # 𨕣
    # 0x28564: '',  # 𨕤
    # 0x28565: '',  # 𨕥
    0x28566: 'qiù',  # 𨕦
    0x28567: 'bēng',  # 𨕧
    # 0x28568: '',  # 𨕨
    # 0x28569: '',  # 𨕩
    # 0x2856A: '',  # 𨕪
    # 0x2856B: '',  # 𨕫
    # 0x2856C: '',  # 𨕬
    # 0x2856D: '',  # 𨕭
    # 0x2856E: '',  # 𨕮
    # 0x2856F: '',  # 𨕯
    # 0x28570: '',  # 𨕰
    # 0x28571: '',  # 𨕱
    # 0x28572: '',  # 𨕲
    # 0x28573: '',  # 𨕳
    # 0x28574: '',  # 𨕴
    # 0x28575: '',  # 𨕵
    # 0x28576: '',  # 𨕶
    # 0x28577: '',  # 𨕷
    # 0x28578: '',  # 𨕸
    0x28579: 'huán',  # 𨕹
    0x2857A: 'kuā',  # 𨕺
    0x2857B: 'shēng',  # 𨕻
    # 0x2857C: '',  # 𨕼
    0x2857D: 'jié',  # 𨕽
    # 0x2857E: '',  # 𨕾
    0x2857F: 'wǎng',  # 𨕿
    # 0x28580: '',  # 𨖀
    # 0x28581: '',  # 𨖁
    # 0x28582: '',  # 𨖂
    0x28583: 'hū',  # 𨖃
    # 0x28584: '',  # 𨖄
    # 0x28585: '',  # 𨖅
    # 0x28586: '',  # 𨖆
    # 0x28587: '',  # 𨖇
    # 0x28588: '',  # 𨖈
    # 0x28589: '',  # 𨖉
    0x2858A: 'zé,jī',  # 𨖊
    0x2858B: 'zǎn,zhì',  # 𨖋
    0x2858C: 'yàng',  # 𨖌
    # 0x2858D: '',  # 𨖍
    0x2858E: 'chǐ',  # 𨖎
    0x2858F: 'jiù',  # 𨖏
    # 0x28590: '',  # 𨖐
    # 0x28591: '',  # 𨖑
    # 0x28592: '',  # 𨖒
    # 0x28593: '',  # 𨖓
    # 0x28594: '',  # 𨖔
    # 0x28595: '',  # 𨖕
    # 0x28596: '',  # 𨖖
    # 0x28597: '',  # 𨖗
    # 0x28598: '',  # 𨖘
    # 0x28599: '',  # 𨖙
    0x2859A: 'liáo',  # 𨖚
    0x2859B: 'yū',  # 𨖛
    # 0x2859C: '',  # 𨖜
    # 0x2859D: '',  # 𨖝
    # 0x2859E: '',  # 𨖞
    # 0x2859F: '',  # 𨖟
    0x285A0: 'biǎn,biàn',  # 𨖠
    # 0x285A1: '',  # 𨖡
    0x285A2: 'kuáng',  # 𨖢
    # 0x285A3: '',  # 𨖣
    # 0x285A4: '',  # 𨖤
    # 0x285A5: '',  # 𨖥
    # 0x285A6: '',  # 𨖦
    # 0x285A7: '',  # 𨖧
    # 0x285A8: '',  # 𨖨
    # 0x285A9: '',  # 𨖩
    # 0x285AA: '',  # 𨖪
    # 0x285AB: '',  # 𨖫
    0x285AC: 'chòu',  # 𨖬
    0x285AD: 'yá',  # 𨖭
    0x285AE: 'zhuó',  # 𨖮
    # 0x285AF: '',  # 𨖯
    0x285B0: 'qiè',  # 𨖰
    0x285B1: 'xiàn',  # 𨖱
    # 0x285B2: '',  # 𨖲
    0x285B3: 'yuān',  # 𨖳
    0x285B4: 'wǔ',  # 𨖴
    0x285B5: 'jiǎo',  # 𨖵
    0x285B6: 'xiàng',  # 𨖶
    0x285B7: 'shà',  # 𨖷
    # 0x285B8: '',  # 𨖸
    0x285B9: 'zhì',  # 𨖹
    # 0x285BA: '',  # 𨖺
    # 0x285BB: '',  # 𨖻
    0x285BC: 'chòng',  # 𨖼
    # 0x285BD: '',  # 𨖽
    0x285BE: 'biān',  # 𨖾
    0x285BF: 'wēi',  # 𨖿
    # 0x285C0: '',  # 𨗀
    # 0x285C1: '',  # 𨗁
    # 0x285C2: '',  # 𨗂
    # 0x285C3: '',  # 𨗃
    # 0x285C4: '',  # 𨗄
    # 0x285C5: '',  # 𨗅
    # 0x285C6: '',  # 𨗆
    # 0x285C7: '',  # 𨗇
    # 0x285C8: '',  # 𨗈
    # 0x285C9: '',  # 𨗉
    # 0x285CA: '',  # 𨗊
    # 0x285CB: '',  # 𨗋
    # 0x285CC: '',  # 𨗌
    # 0x285CD: '',  # 𨗍
    # 0x285CE: '',  # 𨗎
    # 0x285CF: '',  # 𨗏
    # 0x285D0: '',  # 𨗐
    # 0x285D1: '',  # 𨗑
    # 0x285D2: '',  # 𨗒
    0x285D3: 'dào',  # 𨗓
    # 0x285D4: '',  # 𨗔
    # 0x285D5: '',  # 𨗕
    # 0x285D6: '',  # 𨗖
    # 0x285D7: '',  # 𨗗
    # 0x285D8: '',  # 𨗘
    # 0x285D9: '',  # 𨗙
    # 0x285DA: '',  # 𨗚
    # 0x285DB: '',  # 𨗛
    # 0x285DC: '',  # 𨗜
    0x285DD: 'yù,jú',  # 𨗝
    0x285DE: 'tuí',  # 𨗞
    # 0x285DF: '',  # 𨗟
    # 0x285E0: '',  # 𨗠
    0x285E1: 'chào',  # 𨗡
    # 0x285E2: '',  # 𨗢
    # 0x285E3: '',  # 𨗣
    # 0x285E4: '',  # 𨗤
    0x285E5: 'huì',  # 𨗥
    0x285E6: 'qiǎn',  # 𨗦
    # 0x285E7: '',  # 𨗧
    0x285E8: 'wěi',  # 𨗨
    # 0x285E9: '',  # 𨗩
    # 0x285EA: '',  # 𨗪
    # 0x285EB: '',  # 𨗫
    # 0x285EC: '',  # 𨗬
    # 0x285ED: '',  # 𨗭
    # 0x285EE: '',  # 𨗮
    # 0x285EF: '',  # 𨗯
    0x285F0: 'yóu',  # 𨗰
    # 0x285F1: '',  # 𨗱
    # 0x285F2: '',  # 𨗲
    # 0x285F3: '',  # 𨗳
    # 0x285F4: '',  # 𨗴
    # 0x285F5: '',  # 𨗵
    # 0x285F6: '',  # 𨗶
    # 0x285F7: '',  # 𨗷
    # 0x285F8: '',  # 𨗸
    # 0x285F9: '',  # 𨗹
    # 0x285FA: '',  # 𨗺
    # 0x285FB: '',  # 𨗻
    0x285FC: 'dì,dài',  # 𨗼
    # 0x285FD: '',  # 𨗽
    0x285FE: 'dà',  # 𨗾
    # 0x285FF: '',  # 𨗿
    # 0x28600: '',  # 𨘀
    0x28601: 'yóu',  # 𨘁
    0x28602: 'jiù',  # 𨘂
    0x28603: 'tuí',  # 𨘃
    0x28604: 'zǎn',  # 𨘄
    # 0x28605: '',  # 𨘅
    # 0x28606: '',  # 𨘆
    0x28607: 'huì',  # 𨘇
    # 0x28608: '',  # 𨘈
    0x28609: 'shà',  # 𨘉
    # 0x2860A: '',  # 𨘊
    # 0x2860B: '',  # 𨘋
    0x2860C: 'huò',  # 𨘌
    # 0x2860D: '',  # 𨘍
    # 0x2860E: '',  # 𨘎
    # 0x2860F: '',  # 𨘏
    # 0x28610: '',  # 𨘐
    # 0x28611: '',  # 𨘑
    # 0x28612: '',  # 𨘒
    # 0x28613: '',  # 𨘓
    0x28614: 'yáo',  # 𨘔
    0x28615: 'yǔ',  # 𨘕
    # 0x28616: '',  # 𨘖
    # 0x28617: '',  # 𨘗
    # 0x28618: '',  # 𨘘
    0x28619: 'xiàn',  # 𨘙
    # 0x2861A: '',  # 𨘚
    # 0x2861B: '',  # 𨘛
    # 0x2861C: '',  # 𨘜
    # 0x2861D: '',  # 𨘝
    0x2861E: 'xiàn',  # 𨘞
    # 0x2861F: '',  # 𨘟
    # 0x28620: '',  # 𨘠
    # 0x28621: '',  # 𨘡
    0x28622: 'biān',  # 𨘢
    # 0x28623: '',  # 𨘣
    # 0x28624: '',  # 𨘤
    # 0x28625: '',  # 𨘥
    # 0x28626: '',  # 𨘦
    # 0x28627: '',  # 𨘧
    # 0x28628: '',  # 𨘨
    # 0x28629: '',  # 𨘩
    # 0x2862A: '',  # 𨘪
    # 0x2862B: '',  # 𨘫
    0x2862C: 'dì',  # 𨘬
    # 0x2862D: '',  # 𨘭
    0x2862E: 'jiù',  # 𨘮
    # 0x2862F: '',  # 𨘯
    # 0x28630: '',  # 𨘰
    # 0x28631: '',  # 𨘱
    0x28632: 'huì',  # 𨘲
    # 0x28633: '',  # 𨘳
    0x28634: 'kào',  # 𨘴
    0x28635: 'yóu',  # 𨘵
    # 0x28636: '',  # 𨘶
    0x28637: 'miǎo',  # 𨘷
    0x28638: 'lì',  # 𨘸
    # 0x28639: '',  # 𨘹
    # 0x2863A: '',  # 𨘺
    # 0x2863B: '',  # 𨘻
    0x2863C: 'chuán',  # 𨘼
    # 0x2863D: '',  # 𨘽
    0x2863E: 'chí',  # 𨘾
    # 0x2863F: '',  # 𨘿
    0x28640: 'huò',  # 𨙀
    # 0x28641: '',  # 𨙁
    0x28642: 'yóu',  # 𨙂
    # 0x28643: '',  # 𨙃
    0x28644: 'yuè',  # 𨙄
    # 0x28645: '',  # 𨙅
    # 0x28646: '',  # 𨙆
    # 0x28647: '',  # 𨙇
    # 0x28648: '',  # 𨙈
    # 0x28649: '',  # 𨙉
    # 0x2864A: '',  # 𨙊
    # 0x2864B: '',  # 𨙋
    # 0x2864C: '',  # 𨙌
    # 0x2864D: '',  # 𨙍
    0x2864E: 'tà',  # 𨙎
    0x2864F: 'zàn',  # 𨙏
    # 0x28650: '',  # 𨙐
    # 0x28651: '',  # 𨙑
    # 0x28652: '',  # 𨙒
    0x28653: 'niè',  # 𨙓
    0x28654: 'zhù',  # 𨙔
    # 0x28655: '',  # 𨙕
    # 0x28656: '',  # 𨙖
    # 0x28657: '',  # 𨙗
    # 0x28658: '',  # 𨙘
    # 0x28659: '',  # 𨙙
    # 0x2865A: '',  # 𨙚
    # 0x2865B: '',  # 𨙛
    # 0x2865C: '',  # 𨙜
    # 0x2865D: '',  # 𨙝
    # 0x2865E: '',  # 𨙞
    # 0x2865F: '',  # 𨙟
    # 0x28660: '',  # 𨙠
    0x28661: 'xiǎn',  # 𨙡
    # 0x28662: '',  # 𨙢
    # 0x28663: '',  # 𨙣
    # 0x28664: '',  # 𨙤
    # 0x28665: '',  # 𨙥
    # 0x28666: '',  # 𨙦
    # 0x28667: '',  # 𨙧
    0x28668: 'yì',  # 𨙨
    0x28669: 'shí',  # 𨙩
    # 0x2866A: '',  # 𨙪
    0x2866B: 'kǒu',  # 𨙫
    0x2866C: 'qǐ',  # 𨙬
    0x2866D: 'tǔ',  # 𨙭
    0x2866E: 'fán',  # 𨙮
    0x2866F: 'cūn',  # 𨙯
    # 0x28670: '',  # 𨙰
    # 0x28671: '',  # 𨙱
    0x28672: 'tún,cūn',  # 𨙲
    0x28673: 'chā',  # 𨙳
    0x28674: 'cái,zài',  # 𨙴
    0x28675: 'xiàng',  # 𨙵
    0x28676: 'pèi',  # 𨙶
    0x28677: 'jǐng',  # 𨙷
    0x28678: 'qí,zhī',  # 𨙸
    0x28679: 'shǎo',  # 𨙹
    0x2867A: 'niǔ',  # 𨙺
    0x2867B: 'nuó',  # 𨙻
    # 0x2867C: '',  # 𨙼
    0x2867D: 'qín',  # 𨙽
    # 0x2867E: '',  # 𨙾
    # 0x2867F: '',  # 𨙿
    # 0x28680: '',  # 𨚀
    # 0x28681: '',  # 𨚁
    # 0x28682: '',  # 𨚂
    # 0x28683: '',  # 𨚃
    # 0x28684: '',  # 𨚄
    # 0x28685: '',  # 𨚅
    # 0x28686: '',  # 𨚆
    # 0x28687: '',  # 𨚇
    # 0x28688: '',  # 𨚈
    # 0x28689: '',  # 𨚉
    # 0x2868A: '',  # 𨚊
    # 0x2868B: '',  # 𨚋
    # 0x2868C: '',  # 𨚌
    0x2868D: 'bì,bèi',  # 𨚍
    # 0x2868E: '',  # 𨚎
    # 0x2868F: '',  # 𨚏
    # 0x28690: '',  # 𨚐
    # 0x28691: '',  # 𨚑
    # 0x28692: '',  # 𨚒
    0x28693: 'bì,fèi,fú',  # 𨚓
    0x28694: 'bāo',  # 𨚔
    0x28695: 'biàn',  # 𨚕
    0x28696: 'zī',  # 𨚖
    # 0x28697: '',  # 𨚗
    0x28698: 'wèi',  # 𨚘
    0x28699: 'háo',  # 𨚙
    # 0x2869A: '',  # 𨚚
    # 0x2869B: '',  # 𨚛
    # 0x2869C: '',  # 𨚜
    # 0x2869D: '',  # 𨚝
    # 0x2869E: '',  # 𨚞
    # 0x2869F: '',  # 𨚟
    # 0x286A0: '',  # 𨚠
    0x286A1: 'jǐn',  # 𨚡
    # 0x286A2: '',  # 𨚢
    0x286A3: 'zhèng',  # 𨚣
    # 0x286A4: '',  # 𨚤
    # 0x286A5: '',  # 𨚥
    # 0x286A6: '',  # 𨚦
    0x286A7: 'qié',  # 𨚧
    # 0x286A8: '',  # 𨚨
    # 0x286A9: '',  # 𨚩
    # 0x286AA: '',  # 𨚪
    # 0x286AB: '',  # 𨚫
    # 0x286AC: '',  # 𨚬
    # 0x286AD: '',  # 𨚭
    0x286AE: 'hào',  # 𨚮
    0x286AF: 'tóng',  # 𨚯
    0x286B0: 'zǎo',  # 𨚰
    0x286B1: 'shèng',  # 𨚱
    0x286B2: 'cún',  # 𨚲
    0x286B3: 'huāng',  # 𨚳
    0x286B4: 'rú',  # 𨚴
    0x286B5: 'zài',  # 𨚵
    0x286B6: 'nián',  # 𨚶
    # 0x286B7: '',  # 𨚷
    # 0x286B8: '',  # 𨚸
    # 0x286B9: '',  # 𨚹
    # 0x286BA: '',  # 𨚺
    # 0x286BB: '',  # 𨚻
    # 0x286BC: '',  # 𨚼
    # 0x286BD: '',  # 𨚽
    0x286BE: 'xiān',  # 𨚾
    # 0x286BF: '',  # 𨚿
    # 0x286C0: '',  # 𨛀
    # 0x286C1: '',  # 𨛁
    # 0x286C2: '',  # 𨛂
    # 0x286C3: '',  # 𨛃
    # 0x286C4: '',  # 𨛄
    # 0x286C5: '',  # 𨛅
    # 0x286C6: '',  # 𨛆
    # 0x286C7: '',  # 𨛇
    0x286C8: 'quán',  # 𨛈
    0x286C9: 'jì',  # 𨛉
    0x286CA: 'yín',  # 𨛊
    0x286CB: 'lǐ',  # 𨛋
    0x286CC: 'máng',  # 𨛌
    0x286CD: 'shào',  # 𨛍
    0x286CE: 'hàn',  # 𨛎
    0x286CF: 'cuò',  # 𨛏
    0x286D0: 'jùn',  # 𨛐
    0x286D1: 'jì',  # 𨛑
    0x286D2: 'bù',  # 𨛒
    0x286D3: 'lòng',  # 𨛓
    0x286D4: 'fǒu',  # 𨛔
    0x286D5: 'yóu',  # 𨛕
    0x286D6: 'kuài',  # 𨛖
    # 0x286D7: '',  # 𨛗
    # 0x286D8: '',  # 𨛘
    # 0x286D9: '',  # 𨛙
    # 0x286DA: '',  # 𨛚
    # 0x286DB: '',  # 𨛛
    0x286DC: 'xiàng',  # 𨛜
    # 0x286DD: '',  # 𨛝
    # 0x286DE: '',  # 𨛞
    # 0x286DF: '',  # 𨛟
    # 0x286E0: '',  # 𨛠
    0x286E1: 'yún',  # 𨛡
    # 0x286E2: '',  # 𨛢
    0x286E3: 'qín',  # 𨛣
    0x286E4: 'huí',  # 𨛤
    0x286E5: 'pú',  # 𨛥
    # 0x286E6: '',  # 𨛦
    # 0x286E7: '',  # 𨛧
    # 0x286E8: '',  # 𨛨
    # 0x286E9: '',  # 𨛩
    # 0x286EA: '',  # 𨛪
    0x286EB: 'lí',  # 𨛫
    0x286EC: 'péi',  # 𨛬
    0x286ED: 'shū,shè',  # 𨛭
    0x286EE: 'jū',  # 𨛮
    0x286EF: 'yí',  # 𨛯
    0x286F0: 'zhēng',  # 𨛰
    0x286F1: 'chóng',  # 𨛱
    0x286F2: 'nián',  # 𨛲
    0x286F3: 'xí,jí',  # 𨛳
    # 0x286F4: '',  # 𨛴
    0x286F5: 'hǔ',  # 𨛵
    0x286F6: 'róu,shòu',  # 𨛶
    # 0x286F7: '',  # 𨛷
    # 0x286F8: '',  # 𨛸
    # 0x286F9: '',  # 𨛹
    # 0x286FA: '',  # 𨛺
    # 0x286FB: '',  # 𨛻
    # 0x286FC: '',  # 𨛼
    # 0x286FD: '',  # 𨛽
    # 0x286FE: '',  # 𨛾
    # 0x286FF: '',  # 𨛿
    # 0x28700: '',  # 𨜀
    # 0x28701: '',  # 𨜁
    0x28702: 'dǎng',  # 𨜂
    # 0x28703: '',  # 𨜃
    # 0x28704: '',  # 𨜄
    # 0x28705: '',  # 𨜅
    # 0x28706: '',  # 𨜆
    # 0x28707: '',  # 𨜇
    # 0x28708: '',  # 𨜈
    # 0x28709: '',  # 𨜉
    # 0x2870A: '',  # 𨜊
    # 0x2870B: '',  # 𨜋
    0x2870C: 'huàn',  # 𨜌
    0x2870D: 'qiào',  # 𨜍
    0x2870E: 'zhī',  # 𨜎
    0x2870F: 'yíng',  # 𨜏
    0x28710: 'xǐ',  # 𨜐
    0x28711: 'qiāo',  # 𨜑
    0x28712: 'jì',  # 𨜒
    0x28713: 'zhēng',  # 𨜓
    0x28714: 'huáng',  # 𨜔
    # 0x28715: '',  # 𨜕
    0x28716: 'yú',  # 𨜖
    0x28717: 'zōu',  # 𨜗
    0x28718: 'méi',  # 𨜘
    # 0x28719: '',  # 𨜙
    # 0x2871A: '',  # 𨜚
    0x2871B: 'sōu',  # 𨜛
    0x2871C: 'shěng',  # 𨜜
    # 0x2871D: '',  # 𨜝
    # 0x2871E: '',  # 𨜞
    # 0x2871F: '',  # 𨜟
    # 0x28720: '',  # 𨜠
    # 0x28721: '',  # 𨜡
    # 0x28722: '',  # 𨜢
    # 0x28723: '',  # 𨜣
    # 0x28724: '',  # 𨜤
    # 0x28725: '',  # 𨜥
    # 0x28726: '',  # 𨜦
    # 0x28727: '',  # 𨜧
    # 0x28728: '',  # 𨜨
    0x28729: 'quán',  # 𨜩
    # 0x2872A: '',  # 𨜪
    0x2872B: 'hòu',  # 𨜫
    # 0x2872C: '',  # 𨜬
    # 0x2872D: '',  # 𨜭
    # 0x2872E: '',  # 𨜮
    # 0x2872F: '',  # 𨜯
    0x28730: 'jiāng',  # 𨜰
    0x28731: 'hé',  # 𨜱
    # 0x28732: '',  # 𨜲
    0x28733: 'tóng',  # 𨜳
    0x28734: 'hé',  # 𨜴
    0x28735: 'wēn',  # 𨜵
    0x28736: 'yì',  # 𨜶
    0x28737: 'páng',  # 𨜷
    # 0x28738: '',  # 𨜸
    # 0x28739: '',  # 𨜹
    0x2873A: 'wēng',  # 𨜺
    0x2873B: 'qián',  # 𨜻
    0x2873C: 'lì',  # 𨜼
    0x2873D: 'yí',  # 𨜽
    0x2873E: 'chuàng',  # 𨜾
    0x2873F: 'xù',  # 𨜿
    0x28740: 'wěi',  # 𨝀
    # 0x28741: '',  # 𨝁
    # 0x28742: '',  # 𨝂
    # 0x28743: '',  # 𨝃
    # 0x28744: '',  # 𨝄
    # 0x28745: '',  # 𨝅
    0x28746: 'gē',  # 𨝆
    # 0x28747: '',  # 𨝇
    0x28748: 'yǔ',  # 𨝈
    # 0x28749: '',  # 𨝉
    # 0x2874A: '',  # 𨝊
    0x2874B: 'zhài',  # 𨝋
    0x2874C: 'gān',  # 𨝌
    0x2874D: 'qiān',  # 𨝍
    0x2874E: 'kāng',  # 𨝎
    0x2874F: 'lí',  # 𨝏
    0x28750: 'shēn',  # 𨝐
    0x28751: 'guàn',  # 𨝑
    # 0x28752: '',  # 𨝒
    0x28753: 'piáo',  # 𨝓
    # 0x28754: '',  # 𨝔
    # 0x28755: '',  # 𨝕
    0x28756: 'lí',  # 𨝖
    # 0x28757: '',  # 𨝗
    0x28758: 'hǔ',  # 𨝘
    # 0x28759: '',  # 𨝙
    # 0x2875A: '',  # 𨝚
    0x2875B: 'tú',  # 𨝛
    0x2875C: 'shùn',  # 𨝜
    # 0x2875D: '',  # 𨝝
    0x2875E: 'hù',  # 𨝞
    0x2875F: 'lí',  # 𨝟
    # 0x28760: '',  # 𨝠
    # 0x28761: '',  # 𨝡
    0x28762: 'lòu',  # 𨝢
    # 0x28763: '',  # 𨝣
    # 0x28764: '',  # 𨝤
    # 0x28765: '',  # 𨝥
    0x28766: 'dàng',  # 𨝦
    # 0x28767: '',  # 𨝧
    0x28768: 'zuò',  # 𨝨
    0x28769: 'shān',  # 𨝩
    # 0x2876A: '',  # 𨝪
    0x2876B: 'shè,xì',  # 𨝫
    # 0x2876C: '',  # 𨝬
    0x2876D: 'féng',  # 𨝭
    0x2876E: 'jù,zōu',  # 𨝮
    0x2876F: 'tóng',  # 𨝯
    0x28770: 'jiǎo',  # 𨝰
    0x28771: 'qiáo',  # 𨝱
    0x28772: 'gāo,hào',  # 𨝲
    0x28773: 'zī',  # 𨝳
    0x28774: 'huáng',  # 𨝴
    0x28775: 'shān',  # 𨝵
    # 0x28776: '',  # 𨝶
    # 0x28777: '',  # 𨝷
    0x28778: 'tán',  # 𨝸
    # 0x28779: '',  # 𨝹
    # 0x2877A: '',  # 𨝺
    # 0x2877B: '',  # 𨝻
    # 0x2877C: '',  # 𨝼
    # 0x2877D: '',  # 𨝽
    # 0x2877E: '',  # 𨝾
    # 0x2877F: '',  # 𨝿
    # 0x28780: '',  # 𨞀
    # 0x28781: '',  # 𨞁
    # 0x28782: '',  # 𨞂
    # 0x28783: '',  # 𨞃
    # 0x28784: '',  # 𨞄
    # 0x28785: '',  # 𨞅
    # 0x28786: '',  # 𨞆
    # 0x28787: '',  # 𨞇
    # 0x28788: '',  # 𨞈
    # 0x28789: '',  # 𨞉
    # 0x2878A: '',  # 𨞊
    # 0x2878B: '',  # 𨞋
    0x2878C: 'tuō',  # 𨞌
    # 0x2878D: '',  # 𨞍
    0x2878E: 'lìng',  # 𨞎
    # 0x2878F: '',  # 𨞏
    0x28790: 'chéng',  # 𨞐
    0x28791: 'wèng',  # 𨞑
    0x28792: 'zuó',  # 𨞒
    0x28793: 'yù',  # 𨞓
    # 0x28794: '',  # 𨞔
    0x28795: 'zhú,chù',  # 𨞕
    # 0x28796: '',  # 𨞖
    0x28797: 'qún',  # 𨞗
    0x28798: 'xǐ',  # 𨞘
    0x28799: 'qú',  # 𨞙
    # 0x2879A: '',  # 𨞚
    0x2879B: 'gé',  # 𨞛
    # 0x2879C: '',  # 𨞜
    # 0x2879D: '',  # 𨞝
    # 0x2879E: '',  # 𨞞
    # 0x2879F: '',  # 𨞟
    0x287A0: 'xiàng',  # 𨞠
    # 0x287A1: '',  # 𨞡
    0x287A2: 'qī',  # 𨞢
    0x287A3: 'xū',  # 𨞣
    # 0x287A4: '',  # 𨞤
    # 0x287A5: '',  # 𨞥
    # 0x287A6: '',  # 𨞦
    # 0x287A7: '',  # 𨞧
    0x287A8: 'gài',  # 𨞨
    0x287A9: 'què',  # 𨞩
    0x287AA: 'chóu,shòu',  # 𨞪
    0x287AB: 'méng',  # 𨞫
    # 0x287AC: '',  # 𨞬
    # 0x287AD: '',  # 𨞭
    # 0x287AE: '',  # 𨞮
    # 0x287AF: '',  # 𨞯
    0x287B0: 'xiāng',  # 𨞰
    # 0x287B1: '',  # 𨞱
    0x287B2: 'shēn',  # 𨞲
    0x287B3: 'qú',  # 𨞳
    # 0x287B4: '',  # 𨞴
    # 0x287B5: '',  # 𨞵
    0x287B6: 'qiāo',  # 𨞶
    0x287B7: 'cán',  # 𨞷
    # 0x287B8: '',  # 𨞸
    # 0x287B9: '',  # 𨞹
    0x287BA: 'lì',  # 𨞺
    0x287BB: 'fū',  # 𨞻
    0x287BC: 'wàn',  # 𨞼
    0x287BD: 'léi',  # 𨞽
    0x287BE: 'xīng',  # 𨞾
    0x287BF: 'láng',  # 𨞿
    # 0x287C0: '',  # 𨟀
    # 0x287C1: '',  # 𨟁
    0x287C2: 'shì',  # 𨟂
    0x287C3: 'zhēng',  # 𨟃
    0x287C4: 'fán',  # 𨟄
    # 0x287C5: '',  # 𨟅
    # 0x287C6: '',  # 𨟆
    # 0x287C7: '',  # 𨟇
    # 0x287C8: '',  # 𨟈
    # 0x287C9: '',  # 𨟉
    0x287CA: 'zhì',  # 𨟊
    # 0x287CB: '',  # 𨟋
    # 0x287CC: '',  # 𨟌
    # 0x287CD: '',  # 𨟍
    # 0x287CE: '',  # 𨟎
    0x287CF: 'yín',  # 𨟏
    0x287D0: 'táng',  # 𨟐
    0x287D1: 'lì',  # 𨟑
    # 0x287D2: '',  # 𨟒
    # 0x287D3: '',  # 𨟓
    # 0x287D4: '',  # 𨟔
    # 0x287D5: '',  # 𨟕
    0x287D6: 'mó',  # 𨟖
    0x287D7: 'wěi',  # 𨟗
    # 0x287D8: '',  # 𨟘
    0x287D9: 'yīng',  # 𨟙
    0x287DA: 'ráng',  # 𨟚
    # 0x287DB: '',  # 𨟛
    # 0x287DC: '',  # 𨟜
    # 0x287DD: '',  # 𨟝
    # 0x287DE: '',  # 𨟞
    # 0x287DF: '',  # 𨟟
    0x287E0: 'què,jué,quān',  # 𨟠
    # 0x287E1: '',  # 𨟡
    # 0x287E2: '',  # 𨟢
    # 0x287E3: '',  # 𨟣
    # 0x287E4: '',  # 𨟤
    0x287E5: 'luǒ',  # 𨟥
    0x287E6: 'qiān',  # 𨟦
    # 0x287E7: '',  # 𨟧
    # 0x287E8: '',  # 𨟨
    # 0x287E9: '',  # 𨟩
    # 0x287EA: '',  # 𨟪
    # 0x287EB: '',  # 𨟫
    # 0x287EC: '',  # 𨟬
    # 0x287ED: '',  # 𨟭
    # 0x287EE: '',  # 𨟮
    # 0x287EF: '',  # 𨟯
    # 0x287F0: '',  # 𨟰
    # 0x287F1: '',  # 𨟱
    0x287F2: 'dài',  # 𨟲
    # 0x287F3: '',  # 𨟳
    0x287F4: 'yìn',  # 𨟴
    0x287F5: 'bǐ',  # 𨟵
    0x287F6: 'gē',  # 𨟶
    # 0x287F7: '',  # 𨟷
    0x287F8: 'wèn',  # 𨟸
    0x287F9: 'yǎn',  # 𨟹
    0x287FA: 'miǎn',  # 𨟺
    # 0x287FB: '',  # 𨟻
    0x287FC: 'gǎng',  # 𨟼
    0x287FD: 'qiú',  # 𨟽
    0x287FE: 'zhī',  # 𨟾
    # 0x287FF: '',  # 𨟿
    # 0x28800: '',  # 𨠀
    # 0x28801: '',  # 𨠁
    # 0x28802: '',  # 𨠂
    # 0x28803: '',  # 𨠃
    # 0x28804: '',  # 𨠄
    # 0x28805: '',  # 𨠅
    # 0x28806: '',  # 𨠆
    # 0x28807: '',  # 𨠇
    # 0x28808: '',  # 𨠈
    # 0x28809: '',  # 𨠉
    # 0x2880A: '',  # 𨠊
    0x2880B: 'gū',  # 𨠋
    0x2880C: 'tóng',  # 𨠌
    # 0x2880D: '',  # 𨠍
    0x2880E: 'líng',  # 𨠎
    0x2880F: 'tí',  # 𨠏
    0x28810: 'cí',  # 𨠐
    0x28811: 'yí,tuó',  # 𨠑
    0x28812: 'fàn',  # 𨠒
    0x28813: 'pō',  # 𨠓
    0x28814: 'bì',  # 𨠔
    # 0x28815: '',  # 𨠕
    0x28816: 'bào',  # 𨠖
    # 0x28817: '',  # 𨠗
    # 0x28818: '',  # 𨠘
    # 0x28819: '',  # 𨠙
    # 0x2881A: '',  # 𨠚
    # 0x2881B: '',  # 𨠛
    # 0x2881C: '',  # 𨠜
    # 0x2881D: '',  # 𨠝
    # 0x2881E: '',  # 𨠞
    0x2881F: 'pēng',  # 𨠟
    # 0x28820: '',  # 𨠠
    0x28821: 'suān',  # 𨠡
    # 0x28822: '',  # 𨠢
    # 0x28823: '',  # 𨠣
    0x28824: 'sōng,nóng',  # 𨠤
    0x28825: 'wéi',  # 𨠥
    0x28826: 'xiáo',  # 𨠦
    # 0x28827: '',  # 𨠧
    # 0x28828: '',  # 𨠨
    # 0x28829: '',  # 𨠩
    # 0x2882A: '',  # 𨠪
    # 0x2882B: '',  # 𨠫
    0x2882C: 'hào',  # 𨠬
    0x2882D: 'yǎn',  # 𨠭
    # 0x2882E: '',  # 𨠮
    # 0x2882F: '',  # 𨠯
    # 0x28830: '',  # 𨠰
    # 0x28831: '',  # 𨠱
    # 0x28832: '',  # 𨠲
    # 0x28833: '',  # 𨠳
    # 0x28834: '',  # 𨠴
    # 0x28835: '',  # 𨠵
    0x28836: 'yí',  # 𨠶
    0x28837: 'zāo',  # 𨠷
    0x28838: 'yǐng',  # 𨠸
    0x28839: 'nǎn',  # 𨠹
    # 0x2883A: '',  # 𨠺
    # 0x2883B: '',  # 𨠻
    # 0x2883C: '',  # 𨠼
    # 0x2883D: '',  # 𨠽
    # 0x2883E: '',  # 𨠾
    0x2883F: 'zā',  # 𨠿
    # 0x28840: '',  # 𨡀
    0x28841: 'tiǎn',  # 𨡁
    0x28842: 'xī',  # 𨡂
    0x28843: 'jiào',  # 𨡃
    0x28844: 'yán',  # 𨡄
    # 0x28845: '',  # 𨡅
    # 0x28846: '',  # 𨡆
    # 0x28847: '',  # 𨡇
    # 0x28848: '',  # 𨡈
    # 0x28849: '',  # 𨡉
    # 0x2884A: '',  # 𨡊
    # 0x2884B: '',  # 𨡋
    0x2884C: 'néi',  # 𨡌
    0x2884D: 'tǎn',  # 𨡍
    0x2884E: 'yàn',  # 𨡎
    0x2884F: 'tiǎn',  # 𨡏
    0x28850: 'zhì',  # 𨡐
    0x28851: 'chōu,chóu',  # 𨡑
    0x28852: 'táo',  # 𨡒
    0x28853: 'jiàng',  # 𨡓
    # 0x28854: '',  # 𨡔
    # 0x28855: '',  # 𨡕
    # 0x28856: '',  # 𨡖
    0x28857: 'zhà',  # 𨡗
    # 0x28858: '',  # 𨡘
    # 0x28859: '',  # 𨡙
    # 0x2885A: '',  # 𨡚
    # 0x2885B: '',  # 𨡛
    # 0x2885C: '',  # 𨡜
    # 0x2885D: '',  # 𨡝
    0x2885E: 'miǎn',  # 𨡞
    # 0x2885F: '',  # 𨡟
    # 0x28860: '',  # 𨡠
    0x28861: 'wǔ',  # 𨡡
    0x28862: 'yǐn',  # 𨡢
    0x28863: 'yàn',  # 𨡣
    0x28864: 'lǎo',  # 𨡤
    # 0x28865: '',  # 𨡥
    # 0x28866: '',  # 𨡦
    # 0x28867: '',  # 𨡧
    # 0x28868: '',  # 𨡨
    0x28869: 'pō',  # 𨡩
    # 0x2886A: '',  # 𨡪
    0x2886B: 'hùn',  # 𨡫
    0x2886C: 'hǎi',  # 𨡬
    0x2886D: 'mú',  # 𨡭
    0x2886E: 'cōng',  # 𨡮
    # 0x2886F: '',  # 𨡯
    # 0x28870: '',  # 𨡰
    0x28871: 'kù,dǐng',  # 𨡱
    0x28872: 'chōu',  # 𨡲
    # 0x28873: '',  # 𨡳
    0x28874: 'yǒu',  # 𨡴
    # 0x28875: '',  # 𨡵
    # 0x28876: '',  # 𨡶
    # 0x28877: '',  # 𨡷
    0x28878: 'zhuó',  # 𨡸
    # 0x28879: '',  # 𨡹
    # 0x2887A: '',  # 𨡺
    0x2887B: 'sōu',  # 𨡻
    # 0x2887C: '',  # 𨡼
    # 0x2887D: '',  # 𨡽
    # 0x2887E: '',  # 𨡾
    # 0x2887F: '',  # 𨡿
    # 0x28880: '',  # 𨢀
    # 0x28881: '',  # 𨢁
    0x28882: 'yìn',  # 𨢂
    # 0x28883: '',  # 𨢃
    # 0x28884: '',  # 𨢄
    0x28885: 'zuì',  # 𨢅
    0x28886: 'sāng',  # 𨢆
    0x28887: 'liù',  # 𨢇
    0x28888: 'hàn',  # 𨢈
    0x28889: 'wèi',  # 𨢉
    0x2888A: 'méng',  # 𨢊
    0x2888B: 'hú',  # 𨢋
    0x2888C: 'lì',  # 𨢌
    # 0x2888D: '',  # 𨢍
    0x2888E: 'mì,yīn',  # 𨢎
    # 0x2888F: '',  # 𨢏
    0x28890: 'bāng',  # 𨢐
    0x28891: 'jiǎn',  # 𨢑
    # 0x28892: '',  # 𨢒
    # 0x28893: '',  # 𨢓
    # 0x28894: '',  # 𨢔
    # 0x28895: '',  # 𨢕
    # 0x28896: '',  # 𨢖
    # 0x28897: '',  # 𨢗
    # 0x28898: '',  #
    # 0x28899: '',  #
    # 0x2889A: '',  # 𨢚
    # 0x2889B: '',  # 𨢛
    0x2889C: 'què',  # 𨢜
    # 0x2889D: '',  # 𨢝
    # 0x2889E: '',  # 𨢞
    # 0x2889F: '',  # 𨢟
    0x288A0: 'méng',  # 𨢠
    0x288A1: 'bì',  # 𨢡
    0x288A2: 'mú',  # 𨢢
    0x288A3: 'hǒng',  # 𨢣
    0x288A4: 'hù',  # 𨢤
    0x288A5: 'mí',  # 𨢥
    0x288A6: 'shài,zhà',  # 𨢦
    # 0x288A7: '',  # 𨢧
    # 0x288A8: '',  # 𨢨
    0x288A9: 'shāng',  # 𨢩
    0x288AA: 'chào',  # 𨢪
    # 0x288AB: '',  # 𨢫
    0x288AC: 'zhuó,tú',  # 𨢬
    # 0x288AD: '',  # 𨢭
    0x288AE: 'zhī',  # 𨢮
    0x288AF: 'niàn',  # 𨢯
    # 0x288B0: '',  # 𨢰
    # 0x288B1: '',  # 𨢱
    # 0x288B2: '',  # 𨢲
    # 0x288B3: '',  # 𨢳
    # 0x288B4: '',  # 𨢴
    0x288B5: 'jì',  # 𨢵
    # 0x288B6: '',  # 𨢶
    # 0x288B7: '',  # 𨢷
    0x288B8: 'kē',  # 𨢸
    0x288B9: 'zhēng',  # 𨢹
    # 0x288BA: '',  # 𨢺
    # 0x288BB: '',  # 𨢻
    # 0x288BC: '',  # 𨢼
    # 0x288BD: '',  # 𨢽
    # 0x288BE: '',  # 𨢾
    0x288BF: 'dān',  # 𨢿
    0x288C0: 'liǎo',  # 𨣀
    0x288C1: 'zhǎn',  # 𨣁
    0x288C2: 'gǒng',  # 𨣂
    0x288C3: 'láo',  # 𨣃
    0x288C4: 'huā',  # 𨣄
    0x288C5: 'chuài',  # 𨣅
    # 0x288C6: '',  # 𨣆
    0x288C7: 'jiǎn',  # 𨣇
    0x288C8: 'kuì',  # 𨣈
    0x288C9: 'gàn',  # 𨣉
    # 0x288CA: '',  # 𨣊
    # 0x288CB: '',  # 𨣋
    # 0x288CC: '',  # 𨣌
    0x288CD: 'shē',  # 𨣍
    # 0x288CE: '',  # 𨣎
    # 0x288CF: '',  # 𨣏
    # 0x288D0: '',  # 𨣐
    # 0x288D1: '',  # 𨣑
    # 0x288D2: '',  # 𨣒
    # 0x288D3: '',  # 𨣓
    0x288D4: 'chěn',  # 𨣔
    0x288D5: 'tǎn',  # 𨣕
    # 0x288D6: '',  # 𨣖
    0x288D7: 'hú',  # 𨣗
    0x288D8: 'méng',  # 𨣘
    0x288D9: 'pào',  # 𨣙
    0x288DA: 'zhǎn',  # 𨣚
    0x288DB: 'cháng',  # 𨣛
    # 0x288DC: '',  # 𨣜
    0x288DD: 'gǎn,jiǎn',  # 𨣝
    # 0x288DE: '',  # 𨣞
    # 0x288DF: '',  # 𨣟
    0x288E0: 'yì',  # 𨣠
    # 0x288E1: '',  # 𨣡
    0x288E2: 'suì',  # 𨣢
    # 0x288E3: '',  # 𨣣
    # 0x288E4: '',  # 𨣤
    # 0x288E5: '',  # 𨣥
    0x288E6: 'xù',  # 𨣦
    0x288E7: 'jì',  # 𨣧
    0x288E8: 'làn',  # 𨣨
    # 0x288E9: '',  # 𨣩
    # 0x288EA: '',  # 𨣪
    # 0x288EB: '',  # 𨣫
    0x288EC: 'yí',  # 𨣬
    # 0x288ED: '',  # 𨣭
    # 0x288EE: '',  # 𨣮
    0x288EF: 'mì',  # 𨣯
    # 0x288F0: '',  # 𨣰
    0x288F1: 'miè',  # 𨣱
    # 0x288F2: '',  # 𨣲
    # 0x288F3: '',  # 𨣳
    # 0x288F4: '',  # 𨣴
    0x288F5: 'cuán',  # 𨣵
    # 0x288F6: '',  # 𨣶
    # 0x288F7: '',  # 𨣷
    0x288F8: 'lǎn',  # 𨣸
    # 0x288F9: '',  # 𨣹
    # 0x288FA: '',  # 𨣺
    0x288FB: 'yān,yǎn',  # 𨣻
    # 0x288FC: '',  # 𨣼
    # 0x288FD: '',  # 𨣽
    0x288FE: 'mí',  # 𨣾
    # 0x288FF: '',  # 𨣿
    # 0x28900: '',  # 𨤀
    # 0x28901: '',  # 𨤁
    0x28902: 'yǒng',  # 𨤂
    0x28903: 'cáng,zā',  # 𨤃
    0x28904: 'jiǎn',  # 𨤄
    # 0x28905: '',  # 𨤅
    # 0x28906: '',  # 𨤆
    0x28907: 'sōu,zāo',  # 𨤇
    # 0x28908: '',  # 𨤈
    # 0x28909: '',  # 𨤉
    # 0x2890A: '',  # 𨤊
    0x2890B: 'lǎn',  # 𨤋
    # 0x2890C: '',  # 𨤌
    # 0x2890D: '',  # 𨤍
    0x2890E: 'yán',  # 𨤎
    # 0x2890F: '',  # 𨤏
    # 0x28910: '',  # 𨤐
    0x28911: 'juàn',  # 𨤑
    # 0x28912: '',  # 𨤒
    # 0x28913: '',  # 𨤓
    # 0x28914: '',  # 𨤔
    0x28915: 'è',  # 𨤕
    # 0x28916: '',  # 𨤖
    # 0x28917: '',  # 𨤗
    0x28918: 'fèn',  # 𨤘
    # 0x28919: '',  # 𨤙
    0x2891A: 'fèn',  # 𨤚
    # 0x2891B: '',  # 𨤛
    # 0x2891C: '',  # 𨤜
    0x2891D: 'fèn',  # 𨤝
    # 0x2891E: '',  # 𨤞
    # 0x2891F: '',  # 𨤟
    # 0x28920: '',  # 𨤠
    0x28921: 'guàng',  # 𨤡
    0x28922: 'mái',  # 𨤢
    # 0x28923: '',  # 𨤣
    0x28924: 'liě',  # 𨤤
    # 0x28925: '',  # 𨤥
    # 0x28926: '',  # 𨤦
    # 0x28927: '',  # 𨤧
    # 0x28928: '',  # 𨤨
    0x28929: 'chōng',  # 𨤩
    # 0x2892A: '',  # 𨤪
    0x2892B: 'lí',  # 𨤫
    # 0x2892C: '',  # 𨤬
    # 0x2892D: '',  # 𨤭
    # 0x2892E: '',  # 𨤮
    # 0x2892F: '',  # 𨤯
    # 0x28930: '',  # 𨤰
    0x28931: 'zhí',  # 𨤱
    0x28932: 'lí',  # 𨤲
    # 0x28933: '',  # 𨤳
    0x28934: 'xiè',  # 𨤴
    # 0x28935: '',  # 𨤵
    # 0x28936: '',  # 𨤶
    0x28937: 'chóu',  # 𨤷
    # 0x28938: '',  # 𨤸
    0x28939: 'jí',  # 𨤹
    # 0x2893A: '',  # 𨤺
    # 0x2893B: '',  # 𨤻
    # 0x2893C: '',  # 𨤼
    0x2893D: 'pī',  # 𨤽
    # 0x2893E: '',  # 𨤾
    # 0x2893F: '',  # 𨤿
    # 0x28940: '',  # 𨥀
    # 0x28941: '',  # 𨥁
    0x28942: 'jié',  # 𨥂
    # 0x28943: '',  # 𨥃
    # 0x28944: '',  # 𨥄
    # 0x28945: '',  # 𨥅
    # 0x28946: '',  # 𨥆
    0x28947: 'zhǒu,zhù',  # 𨥇
    # 0x28948: '',  # 𨥈
    # 0x28949: '',  # 𨥉
    # 0x2894A: '',  # 𨥊
    # 0x2894B: '',  # 𨥋
    # 0x2894C: '',  # 𨥌
    0x2894D: 'xiōng',  # 𨥍
    # 0x2894E: '',  # 𨥎
    # 0x2894F: '',  # 𨥏
    # 0x28950: '',  # 𨥐
    0x28951: 'kuàng,gǒng',  # 𨥑
    # 0x28952: '',  # 𨥒
    # 0x28953: '',  # 𨥓
    # 0x28954: '',  # 𨥔
    # 0x28955: '',  # 𨥕
    # 0x28956: '',  # 𨥖
    # 0x28957: '',  # 𨥗
    # 0x28958: '',  # 𨥘
    0x28959: 'jǐng',  # 𨥙
    # 0x2895A: '',  # 𨥚
    0x2895B: 'hù',  # 𨥛
    # 0x2895C: '',  # 𨥜
    # 0x2895D: '',  # 𨥝
    0x2895E: 'qián',  # 𨥞
    # 0x2895F: '',  # 𨥟
    # 0x28960: '',  # 𨥠
    # 0x28961: '',  # 𨥡
    # 0x28962: '',  # 𨥢
    0x28963: 'cén',  # 𨥣
    # 0x28964: '',  # 𨥤
    # 0x28965: '',  # 𨥥
    0x28966: 'qí',  # 𨥦
    0x28967: 'wǎn,fàn,biān',  # 𨥧
    0x28968: 'máo',  # 𨥨
    # 0x28969: '',  # 𨥩
    0x2896A: 'dǒu',  # 𨥪
    # 0x2896B: '',  # 𨥫
    # 0x2896C: '',  # 𨥬
    # 0x2896D: '',  # 𨥭
    # 0x2896E: '',  # 𨥮
    # 0x2896F: '',  # 𨥯
    # 0x28970: '',  # 𨥰
    # 0x28971: '',  # 𨥱
    # 0x28972: '',  # 𨥲
    # 0x28973: '',  # 𨥳
    0x28974: 'kǒu',  # 𨥴
    # 0x28975: '',  # 𨥵
    0x28976: 'dài',  # 𨥶
    # 0x28977: '',  # 𨥷
    0x28978: 'náo',  # 𨥸
    # 0x28979: '',  # 𨥹
    0x2897A: 'hóng',  # 𨥺
    # 0x2897B: '',  # 𨥻
    # 0x2897C: '',  # 𨥼
    # 0x2897D: '',  # 𨥽
    # 0x2897E: '',  # 𨥾
    # 0x2897F: '',  # 𨥿
    # 0x28980: '',  # 𨦀
    # 0x28981: '',  # 𨦁
    0x28982: 'lǎi',  # 𨦂
    0x28983: 'duǒ,duò',  # 𨦃
    0x28984: 'qiān',  # 𨦄
    # 0x28985: '',  # 𨦅
    0x28986: 'yín',  # 𨦆
    # 0x28987: '',  # 𨦇
    # 0x28988: '',  # 𨦈
    # 0x28989: '',  # 𨦉
    # 0x2898A: '',  # 𨦊
    # 0x2898B: '',  # 𨦋
    # 0x2898C: '',  # 𨦌
    # 0x2898D: '',  # 𨦍
    # 0x2898E: '',  # 𨦎
    # 0x2898F: '',  # 𨦏
    # 0x28990: '',  # 𨦐
    # 0x28991: '',  # 𨦑
    # 0x28992: '',  # 𨦒
    # 0x28993: '',  # 𨦓
    # 0x28994: '',  # 𨦔
    0x28995: 'xíng',  # 𨦕
    0x28996: 'lòu',  # 𨦖
    0x28997: 'huī',  # 𨦗
    # 0x28998: '',  # 𨦘
    # 0x28999: '',  # 𨦙
    # 0x2899A: '',  # 𨦚
    0x2899B: 'fù',  # 𨦛
    0x2899C: 'máo',  # 𨦜
    # 0x2899D: '',  # 𨦝
    0x2899E: 'zhōu',  # 𨦞
    # 0x2899F: '',  # 𨦟
    # 0x289A0: '',  # 𨦠
    0x289A1: 'yóng,yáng',  # 𨦡
    # 0x289A2: '',  # 𨦢
    # 0x289A3: '',  # 𨦣
    # 0x289A4: '',  # 𨦤
    # 0x289A5: '',  # 𨦥
    # 0x289A6: '',  # 𨦦
    # 0x289A7: '',  # 𨦧
    # 0x289A8: '',  # 𨦨
    # 0x289A9: '',  # 𨦩
    # 0x289AA: '',  # 𨦪
    # 0x289AB: '',  # 𨦫
    # 0x289AC: '',  # 𨦬
    0x289AD: 'láo',  # 𨦭
    0x289AE: 'jí',  # 𨦮
    0x289AF: 'yì',  # 𨦯
    0x289B0: 'liú',  # 𨦰
    0x289B1: 'cōng',  # 𨦱
    # 0x289B2: '',  # 𨦲
    0x289B3: 'nǎn',  # 𨦳
    # 0x289B4: '',  # 𨦴
    # 0x289B5: '',  # 𨦵
    # 0x289B6: '',  # 𨦶
    # 0x289B7: '',  # 𨦷
    # 0x289B8: '',  # 𨦸
    # 0x289B9: '',  # 𨦹
    # 0x289BA: '',  # 𨦺
    # 0x289BB: '',  # 𨦻
    # 0x289BC: '',  # 𨦼
    # 0x289BD: '',  # 𨦽
    # 0x289BE: '',  # 𨦾
    # 0x289BF: '',  # 𨦿
    # 0x289C0: '',  # 𨧀
    # 0x289C1: '',  # 𨧁
    # 0x289C2: '',  # 𨧂
    # 0x289C3: '',  # 𨧃
    # 0x289C4: '',  # 𨧄
    # 0x289C5: '',  # 𨧅
    # 0x289C6: '',  # 𨧆
    # 0x289C7: '',  # 𨧇
    # 0x289C8: '',  # 𨧈
    # 0x289C9: '',  # 𨧉
    # 0x289CA: '',  # 𨧊
    # 0x289CB: '',  # 𨧋
    # 0x289CC: '',  # 𨧌
    # 0x289CD: '',  # 𨧍
    # 0x289CE: '',  # 𨧎
    # 0x289CF: '',  # 𨧏
    0x289D0: 'tūn',  # 𨧐
    0x289D1: 'xiàng',  # 𨧑
    # 0x289D2: '',  # 𨧒
    # 0x289D3: '',  # 𨧓
    # 0x289D4: '',  # 𨧔
    0x289D5: 'biàn',  # 𨧕
    0x289D6: 'chuáng',  # 𨧖
    0x289D7: 'wù',  # 𨧗
    # 0x289D8: '',  # 𨧘
    0x289D9: 'jū',  # 𨧙
    # 0x289DA: '',  # 𨧚
    # 0x289DB: '',  # 𨧛
    # 0x289DC: '',  # 𨧜
    # 0x289DD: '',  # 𨧝
    # 0x289DE: '',  # 𨧞
    # 0x289DF: '',  # 𨧟
    # 0x289E0: '',  # 𨧠
    # 0x289E1: '',  # 𨧡
    # 0x289E2: '',  # 𨧢
    # 0x289E3: '',  # 𨧣
    # 0x289E4: '',  # 𨧤
    0x289E5: 'xiē',  # 𨧥
    0x289E6: 'pī',  # 𨧦
    0x289E7: 'zhuó',  # 𨧧
    0x289E8: 'ruì,zhuì',  # 𨧨
    # 0x289E9: '',  # 𨧩
    0x289EA: 'sào',  # 𨧪
    0x289EB: 'zì',  # 𨧫
    # 0x289EC: '',  # 𨧬
    0x289ED: 'zhèng',  # 𨧭
    # 0x289EE: '',  # 𨧮
    # 0x289EF: '',  # 𨧯
    0x289F0: 'zú',  # 𨧰
    0x289F1: 'qū',  # 𨧱
    # 0x289F2: '',  # 𨧲
    0x289F3: 'chì',  # 𨧳
    # 0x289F4: '',  # 𨧴
    0x289F5: 'zhì',  # 𨧵
    # 0x289F6: '',  # 𨧶
    # 0x289F7: '',  # 𨧷
    # 0x289F8: '',  # 𨧸
    # 0x289F9: '',  # 𨧹
    # 0x289FA: '',  # 𨧺
    # 0x289FB: '',  # 𨧻
    # 0x289FC: '',  # 𨧼
    # 0x289FD: '',  # 𨧽
    # 0x289FE: '',  # 𨧾
    # 0x289FF: '',  # 𨧿
    # 0x28A00: '',  # 𨨀
    # 0x28A01: '',  # 𨨁
    # 0x28A02: '',  # 𨨂
    # 0x28A03: '',  # 𨨃
    # 0x28A04: '',  # 𨨄
    # 0x28A05: '',  # 𨨅
    # 0x28A06: '',  # 𨨆
    # 0x28A07: '',  # 𨨇
    # 0x28A08: '',  # 𨨈
    # 0x28A09: '',  # 𨨉
    # 0x28A0A: '',  # 𨨊
    # 0x28A0B: '',  # 𨨋
    # 0x28A0C: '',  # 𨨌
    # 0x28A0D: '',  # 𨨍
    # 0x28A0E: '',  # 𨨎
    0x28A0F: 'bō',  # 𨨏
    # 0x28A10: '',  # 𨨐
    # 0x28A11: '',  # 𨨑
    # 0x28A12: '',  # 𨨒
    # 0x28A13: '',  # 𨨓
    # 0x28A14: '',  # 𨨔
    0x28A15: 'sǎn',  # 𨨕
    # 0x28A16: '',  # 𨨖
    0x28A17: 'quàn',  # 𨨗
    0x28A18: 'qiān',  # 𨨘
    0x28A19: 'yā',  # 𨨙
    0x28A1A: 'chào',  # 𨨚
    0x28A1B: 'hé',  # 𨨛
    0x28A1C: 'rǔ',  # 𨨜
    # 0x28A1D: '',  # 𨨝
    # 0x28A1E: '',  # 𨨞
    # 0x28A1F: '',  # 𨨟
    0x28A20: 'jū',  # 𨨠
    0x28A21: 'wù',  # 𨨡
    0x28A22: 'chuī',  # 𨨢
    # 0x28A23: '',  # 𨨣
    # 0x28A24: '',  # 𨨤
    # 0x28A25: '',  # 𨨥
    # 0x28A26: '',  # 𨨦
    # 0x28A27: '',  # 𨨧
    # 0x28A28: '',  # 𨨨
    # 0x28A29: '',  # 𨨩
    # 0x28A2A: '',  # 𨨪
    # 0x28A2B: '',  # 𨨫
    0x28A2C: 'chì',  # 𨨬
    0x28A2D: 'kuàng,gǒng',  # 𨨭
    # 0x28A2E: '',  # 𨨮
    0x28A2F: 'còu,zhòu',  # 𨨯
    0x28A30: 'ruàn',  # 𨨰
    0x28A31: 'kuò',  # 𨨱
    0x28A32: 'chí',  # 𨨲
    0x28A33: 'zú',  # 𨨳
    0x28A34: 'jiāo',  # 𨨴
    # 0x28A35: '',  # 𨨵
    0x28A36: 'yú',  # 𨨶
    0x28A37: 'tú',  # 𨨷
    0x28A38: 'méng',  # 𨨸
    0x28A39: 'dā',  # 𨨹
    0x28A3A: 'shuò,xuē',  # 𨨺
    # 0x28A3B: '',  # 𨨻
    # 0x28A3C: '',  # 𨨼
    # 0x28A3D: '',  # 𨨽
    # 0x28A3E: '',  # 𨨾
    # 0x28A3F: '',  # 𨨿
    0x28A40: 'hóu',  # 𨩀
    # 0x28A41: '',  # 𨩁
    # 0x28A42: '',  # 𨩂
    # 0x28A43: '',  # 𨩃
    # 0x28A44: '',  # 𨩄
    # 0x28A45: '',  # 𨩅
    # 0x28A46: '',  # 𨩆
    # 0x28A47: '',  # 𨩇
    # 0x28A48: '',  # 𨩈
    # 0x28A49: '',  # 𨩉
    # 0x28A4A: '',  # 𨩊
    # 0x28A4B: '',  # 𨩋
    # 0x28A4C: '',  # 𨩌
    # 0x28A4D: '',  # 𨩍
    # 0x28A4E: '',  # 𨩎
    # 0x28A4F: '',  # 𨩏
    # 0x28A50: '',  # 𨩐
    # 0x28A51: '',  # 𨩑
    # 0x28A52: '',  # 𨩒
    # 0x28A53: '',  # 𨩓
    # 0x28A54: '',  # 𨩔
    # 0x28A55: '',  # 𨩕
    # 0x28A56: '',  # 𨩖
    # 0x28A57: '',  # 𨩗
    # 0x28A58: '',  # 𨩘
    # 0x28A59: '',  # 𨩙
    # 0x28A5A: '',  # 𨩚
    # 0x28A5B: '',  # 𨩛
    # 0x28A5C: '',  # 𨩜
    # 0x28A5D: '',  # 𨩝
    # 0x28A5E: '',  # 𨩞
    # 0x28A5F: '',  # 𨩟
    # 0x28A60: '',  # 𨩠
    # 0x28A61: '',  # 𨩡
    # 0x28A62: '',  # 𨩢
    # 0x28A63: '',  # 𨩣
    # 0x28A64: '',  # 𨩤
    0x28A65: 'fēng',  # 𨩥
    0x28A66: 'gǒu',  # 𨩦
    0x28A67: 'dōng',  # 𨩧
    0x28A68: 'chǎ',  # 𨩨
    0x28A69: 'mào',  # 𨩩
    0x28A6A: 'chǎn',  # 𨩪
    0x28A6B: 'biān',  # 𨩫
    0x28A6C: 'yù',  # 𨩬
    # 0x28A6D: '',  # 𨩭
    # 0x28A6E: '',  # 𨩮
    0x28A6F: 'wán',  # 𨩯
    0x28A70: 'zú',  # 𨩰
    # 0x28A71: '',  # 𨩱
    0x28A72: 'zī',  # 𨩲
    # 0x28A73: '',  # 𨩳
    0x28A74: 'chuān',  # 𨩴
    0x28A75: 'wǎn',  # 𨩵
    0x28A76: 'wā',  # 𨩶
    # 0x28A77: '',  # 𨩷
    0x28A78: 'quān,juān',  # 𨩸
    # 0x28A79: '',  # 𨩹
    # 0x28A7A: '',  # 𨩺
    0x28A7B: 'wǎn',  # 𨩻
    # 0x28A7C: '',  # 𨩼
    0x28A7D: 'xià',  # 𨩽
    # 0x28A7E: '',  # 𨩾
    # 0x28A7F: '',  # 𨩿
    # 0x28A80: '',  # 𨪀
    # 0x28A81: '',  # 𨪁
    # 0x28A82: '',  # 𨪂
    # 0x28A83: '',  # 𨪃
    0x28A84: 'yìng',  # 𨪄
    0x28A85: 'jiàn',  # 𨪅
    # 0x28A86: '',  # 𨪆
    # 0x28A87: '',  # 𨪇
    0x28A88: 'wěi',  # 𨪈
    0x28A89: 'tí',  # 𨪉
    0x28A8A: 'sāo',  # 𨪊
    # 0x28A8B: '',  # 𨪋
    0x28A8C: 'qí',  # 𨪌
    0x28A8D: 'shā',  # 𨪍
    0x28A8E: 'yù',  # 𨪎
    0x28A8F: 'jí',  # 𨪏
    0x28A90: 'dòu,tōu',  # 𨪐
    0x28A91: 'chǎn',  # 𨪑
    0x28A92: 'tuán',  # 𨪒
    # 0x28A93: '',  # 𨪓
    # 0x28A94: '',  # 𨪔
    0x28A95: 'liú',  # 𨪕
    # 0x28A96: '',  # 𨪖
    0x28A97: 'zhuì',  # 𨪗
    # 0x28A98: '',  # 𨪘
    # 0x28A99: '',  # 𨪙
    # 0x28A9A: '',  # 𨪚
    # 0x28A9B: '',  # 𨪛
    # 0x28A9C: '',  # 𨪜
    # 0x28A9D: '',  # 𨪝
    # 0x28A9E: '',  # 𨪞
    # 0x28A9F: '',  # 𨪟
    # 0x28AA0: '',  # 𨪠
    # 0x28AA1: '',  # 𨪡
    # 0x28AA2: '',  # 𨪢
    # 0x28AA3: '',  # 𨪣
    # 0x28AA4: '',  # 𨪤
    # 0x28AA5: '',  # 𨪥
    # 0x28AA6: '',  # 𨪦
    # 0x28AA7: '',  # 𨪧
    # 0x28AA8: '',  # 𨪨
    # 0x28AA9: '',  # 𨪩
    # 0x28AAA: '',  # 𨪪
    # 0x28AAB: '',  # 𨪫
    # 0x28AAC: '',  # 𨪬
    # 0x28AAD: '',  # 𨪭
    # 0x28AAE: '',  # 𨪮
    # 0x28AAF: '',  # 𨪯
    # 0x28AB0: '',  # 𨪰
    # 0x28AB1: '',  # 𨪱
    # 0x28AB2: '',  # 𨪲
    0x28AB3: 'ruàn',  # 𨪳
    # 0x28AB4: '',  # 𨪴
    # 0x28AB5: '',  # 𨪵
    0x28AB6: 'yàn',  # 𨪶
    0x28AB7: 'gǔ',  # 𨪷
    # 0x28AB8: '',  # 𨪸
    0x28AB9: 'lì',  # 𨪹
    0x28ABA: 'chā',  # 𨪺
    # 0x28ABB: '',  # 𨪻
    # 0x28ABC: '',  # 𨪼
    # 0x28ABD: '',  # 𨪽
    0x28ABE: 'dì',  # 𨪾
    # 0x28ABF: '',  # 𨪿
    0x28AC0: 'zhǎn',  # 𨫀
    0x28AC1: 'pō',  # 𨫁
    # 0x28AC2: '',  # 𨫂
    # 0x28AC3: '',  # 𨫃
    # 0x28AC4: '',  # 𨫄
    # 0x28AC5: '',  # 𨫅
    # 0x28AC6: '',  # 𨫆
    # 0x28AC7: '',  # 𨫇
    # 0x28AC8: '',  # 𨫈
    # 0x28AC9: '',  # 𨫉
    # 0x28ACA: '',  # 𨫊
    # 0x28ACB: '',  # 𨫋
    # 0x28ACC: '',  # 𨫌
    # 0x28ACD: '',  # 𨫍
    # 0x28ACE: '',  # 𨫎
    # 0x28ACF: '',  # 𨫏
    # 0x28AD0: '',  # 𨫐
    # 0x28AD1: '',  # 𨫑
    0x28AD2: 'lòu',  # 𨫒
    # 0x28AD3: '',  # 𨫓
    0x28AD4: 'zhì,xiè',  # 𨫔
    # 0x28AD5: '',  # 𨫕
    # 0x28AD6: '',  # 𨫖
    # 0x28AD7: '',  # 𨫗
    # 0x28AD8: '',  # 𨫘
    # 0x28AD9: '',  # 𨫙
    # 0x28ADA: '',  # 𨫚
    # 0x28ADB: '',  # 𨫛
    # 0x28ADC: '',  # 𨫜
    # 0x28ADD: '',  # 𨫝
    # 0x28ADE: '',  # 𨫞
    # 0x28ADF: '',  # 𨫟
    # 0x28AE0: '',  # 𨫠
    # 0x28AE1: '',  # 𨫡
    # 0x28AE2: '',  # 𨫢
    # 0x28AE3: '',  # 𨫣
    # 0x28AE4: '',  # 𨫤
    # 0x28AE5: '',  # 𨫥
    # 0x28AE6: '',  # 𨫦
    # 0x28AE7: '',  # 𨫧
    # 0x28AE8: '',  # 𨫨
    # 0x28AE9: '',  # 𨫩
    # 0x28AEA: '',  # 𨫪
    # 0x28AEB: '',  # 𨫫
    # 0x28AEC: '',  # 𨫬
    # 0x28AED: '',  # 𨫭
    # 0x28AEE: '',  # 𨫮
    # 0x28AEF: '',  # 𨫯
    # 0x28AF0: '',  # 𨫰
    # 0x28AF1: '',  # 𨫱
    # 0x28AF2: '',  # 𨫲
    # 0x28AF3: '',  # 𨫳
    # 0x28AF4: '',  # 𨫴
    # 0x28AF5: '',  # 𨫵
    # 0x28AF6: '',  # 𨫶
    # 0x28AF7: '',  # 𨫷
    # 0x28AF8: '',  # 𨫸
    # 0x28AF9: '',  # 𨫹
    # 0x28AFA: '',  # 𨫺
    # 0x28AFB: '',  # 𨫻
    # 0x28AFC: '',  # 𨫼
    # 0x28AFD: '',  # 𨫽
    # 0x28AFE: '',  # 𨫾
    # 0x28AFF: '',  # 𨫿
    # 0x28B00: '',  # 𨬀
    0x28B01: 'lián',  # 𨬁
    # 0x28B02: '',  # 𨬂
    # 0x28B03: '',  # 𨬃
    # 0x28B04: '',  # 𨬄
    0x28B05: 'luǒ',  # 𨬅
    # 0x28B06: '',  # 𨬆
    # 0x28B07: '',  # 𨬇
    # 0x28B08: '',  # 𨬈
    # 0x28B09: '',  # 𨬉
    # 0x28B0A: '',  # 𨬊
    # 0x28B0B: '',  # 𨬋
    # 0x28B0C: '',  # 𨬌
    0x28B0D: 'duò,duì',  # 𨬍
    # 0x28B0E: '',  # 𨬎
    # 0x28B0F: '',  # 𨬏
    0x28B10: 'jué',  # 𨬐
    0x28B11: 'lì',  # 𨬑
    0x28B12: 'lán',  # 𨬒
    # 0x28B13: '',  # 𨬓
    0x28B14: 'ruàn',  # 𨬔
    0x28B15: 'gū',  # 𨬕
    0x28B16: 'chán',  # 𨬖
    0x28B17: 'xū',  # 𨬗
    # 0x28B18: '',  # 𨬘
    # 0x28B19: '',  # 𨬙
    0x28B1A: 'zhǐ',  # 𨬚
    # 0x28B1B: '',  # 𨬛
    # 0x28B1C: '',  # 𨬜
    0x28B1D: 'zhì,xiè',  # 𨬝
    # 0x28B1E: '',  # 𨬞
    # 0x28B1F: '',  # 𨬟
    # 0x28B20: '',  # 𨬠
    # 0x28B21: '',  # 𨬡
    # 0x28B22: '',  # 𨬢
    # 0x28B23: '',  # 𨬣
    # 0x28B24: '',  # 𨬤
    # 0x28B25: '',  # 𨬥
    # 0x28B26: '',  # 𨬦
    # 0x28B27: '',  # 𨬧
    # 0x28B28: '',  # 𨬨
    # 0x28B29: '',  # 𨬩
    # 0x28B2A: '',  # 𨬪
    # 0x28B2B: '',  # 𨬫
    # 0x28B2C: '',  # 𨬬
    # 0x28B2D: '',  # 𨬭
    # 0x28B2E: '',  # 𨬮
    # 0x28B2F: '',  # 𨬯
    # 0x28B30: '',  # 𨬰
    # 0x28B31: '',  # 𨬱
    # 0x28B32: '',  # 𨬲
    # 0x28B33: '',  # 𨬳
    # 0x28B34: '',  # 𨬴
    # 0x28B35: '',  # 𨬵
    # 0x28B36: '',  # 𨬶
    # 0x28B37: '',  # 𨬷
    # 0x28B38: '',  # 𨬸
    # 0x28B39: '',  # 𨬹
    # 0x28B3A: '',  # 𨬺
    # 0x28B3B: '',  # 𨬻
    # 0x28B3C: '',  # 𨬼
    # 0x28B3D: '',  # 𨬽
    # 0x28B3E: '',  # 𨬾
    # 0x28B3F: '',  # 𨬿
    # 0x28B40: '',  # 𨭀
    0x28B41: 'xuè',  # 𨭁
    0x28B42: 'bō',  # 𨭂
    0x28B43: 'chēng',  # 𨭃
    # 0x28B44: '',  # 𨭄
    0x28B45: 'zhù',  # 𨭅
    0x28B46: 'hēi',  # 𨭆
    # 0x28B47: '',  # 𨭇
    # 0x28B48: '',  # 𨭈
    0x28B49: 'bān',  # 𨭉
    # 0x28B4A: '',  # 𨭊
    # 0x28B4B: '',  # 𨭋
    0x28B4C: 'péng',  # 𨭌
    # 0x28B4D: '',  # 𨭍
    # 0x28B4E: '',  # 𨭎
    # 0x28B4F: '',  # 𨭏
    # 0x28B50: '',  # 𨭐
    # 0x28B51: '',  # 𨭑
    # 0x28B52: '',  # 𨭒
    0x28B53: 'dié',  # 𨭓
    # 0x28B54: '',  # 𨭔
    # 0x28B55: '',  # 𨭕
    0x28B56: 'zhǎn',  # 𨭖
    0x28B57: 'guó',  # 𨭗
    # 0x28B58: '',  # 𨭘
    # 0x28B59: '',  # 𨭙
    0x28B5A: 'biāo',  # 𨭚
    0x28B5B: 'là,gě',  # 𨭛
    # 0x28B5C: '',  # 𨭜
    # 0x28B5D: '',  # 𨭝
    # 0x28B5E: '',  # 𨭞
    # 0x28B5F: '',  # 𨭟
    # 0x28B60: '',  # 𨭠
    # 0x28B61: '',  # 𨭡
    # 0x28B62: '',  # 𨭢
    # 0x28B63: '',  # 𨭣
    # 0x28B64: '',  # 𨭤
    # 0x28B65: '',  # 𨭥
    # 0x28B66: '',  # 𨭦
    # 0x28B67: '',  # 𨭧
    # 0x28B68: '',  # 𨭨
    # 0x28B69: '',  # 𨭩
    # 0x28B6A: '',  # 𨭪
    # 0x28B6B: '',  # 𨭫
    # 0x28B6C: '',  # 𨭬
    # 0x28B6D: '',  # 𨭭
    # 0x28B6E: '',  # 𨭮
    # 0x28B6F: '',  # 𨭯
    # 0x28B70: '',  # 𨭰
    # 0x28B71: '',  # 𨭱
    # 0x28B72: '',  # 𨭲
    # 0x28B73: '',  # 𨭳
    # 0x28B74: '',  # 𨭴
    # 0x28B75: '',  # 𨭵
    # 0x28B76: '',  # 𨭶
    # 0x28B77: '',  # 𨭷
    # 0x28B78: '',  # 𨭸
    # 0x28B79: '',  # 𨭹
    0x28B7A: 'jīn',  # 𨭺
    # 0x28B7B: '',  # 𨭻
    # 0x28B7C: '',  # 𨭼
    # 0x28B7D: '',  # 𨭽
    # 0x28B7E: '',  # 𨭾
    # 0x28B7F: '',  # 𨭿
    # 0x28B80: '',  # 𨮀
    0x28B81: 'yuè',  # 𨮁
    0x28B82: 'gǎi',  # 𨮂
    # 0x28B83: '',  # 𨮃
    # 0x28B84: '',  # 𨮄
    # 0x28B85: '',  # 𨮅
    # 0x28B86: '',  # 𨮆
    # 0x28B87: '',  # 𨮇
    # 0x28B88: '',  # 𨮈
    # 0x28B89: '',  # 𨮉
    # 0x28B8A: '',  # 𨮊
    # 0x28B8B: '',  # 𨮋
    # 0x28B8C: '',  # 𨮌
    # 0x28B8D: '',  # 𨮍
    # 0x28B8E: '',  # 𨮎
    # 0x28B8F: '',  # 𨮏
    # 0x28B90: '',  # 𨮐
    # 0x28B91: '',  # 𨮑
    0x28B92: 'mèng',  # 𨮒
    # 0x28B93: '',  # 𨮓
    0x28B94: 'yù',  # 𨮔
    # 0x28B95: '',  # 𨮕
    # 0x28B96: '',  # 𨮖
    # 0x28B97: '',  # 𨮗
    # 0x28B98: '',  # 𨮘
    # 0x28B99: '',  # 𨮙
    # 0x28B9A: '',  # 𨮚
    # 0x28B9B: '',  # 𨮛
    # 0x28B9C: '',  # 𨮜
    # 0x28B9D: '',  # 𨮝
    # 0x28B9E: '',  # 𨮞
    # 0x28B9F: '',  # 𨮟
    # 0x28BA0: '',  # 𨮠
    # 0x28BA1: '',  # 𨮡
    # 0x28BA2: '',  # 𨮢
    # 0x28BA3: '',  # 𨮣
    # 0x28BA4: '',  # 𨮤
    # 0x28BA5: '',  # 𨮥
    # 0x28BA6: '',  # 𨮦
    # 0x28BA7: '',  # 𨮧
    # 0x28BA8: '',  # 𨮨
    # 0x28BA9: '',  # 𨮩
    0x28BAA: 'xǐ',  # 𨮪
    # 0x28BAB: '',  # 𨮫
    0x28BAC: 'piāo',  # 𨮬
    0x28BAD: 'sī',  # 𨮭
    # 0x28BAE: '',  # 𨮮
    0x28BAF: 'tiě',  # 𨮯
    # 0x28BB0: '',  # 𨮰
    # 0x28BB1: '',  # 𨮱
    # 0x28BB2: '',  # 𨮲
    # 0x28BB3: '',  # 𨮳
    0x28BB4: 'dèng',  # 𨮴
    # 0x28BB5: '',  # 𨮵
    # 0x28BB6: '',  # 𨮶
    # 0x28BB7: '',  # 𨮷
    0x28BB8: 'chuō',  # 𨮸
    0x28BB9: 'dí',  # 𨮹
    0x28BBA: 'jī',  # 𨮺
    0x28BBB: 'chán',  # 𨮻
    # 0x28BBC: '',  # 𨮼
    # 0x28BBD: '',  # 𨮽
    # 0x28BBE: '',  # 𨮾
    0x28BBF: 'zhuó',  # 𨮿
    0x28BC0: 'jī',  # 𨯀
    # 0x28BC1: '',  # 𨯁
    # 0x28BC2: '',  # 𨯂
    # 0x28BC3: '',  # 𨯃
    # 0x28BC4: '',  # 𨯄
    # 0x28BC5: '',  # 𨯅
    # 0x28BC6: '',  # 𨯆
    # 0x28BC7: '',  # 𨯇
    # 0x28BC8: '',  # 𨯈
    # 0x28BC9: '',  # 𨯉
    # 0x28BCA: '',  # 𨯊
    # 0x28BCB: '',  # 𨯋
    # 0x28BCC: '',  # 𨯌
    # 0x28BCD: '',  # 𨯍
    # 0x28BCE: '',  # 𨯎
    # 0x28BCF: '',  # 𨯏
    # 0x28BD0: '',  # 𨯐
    # 0x28BD1: '',  # 𨯑
    # 0x28BD2: '',  # 𨯒
    0x28BD3: 'cài',  # 𨯓
    # 0x28BD4: '',  # 𨯔
    # 0x28BD5: '',  # 𨯕
    # 0x28BD6: '',  # 𨯖
    # 0x28BD7: '',  # 𨯗
    # 0x28BD8: '',  # 𨯘
    # 0x28BD9: '',  # 𨯙
    # 0x28BDA: '',  # 𨯚
    # 0x28BDB: '',  # 𨯛
    # 0x28BDC: '',  # 𨯜
    # 0x28BDD: '',  # 𨯝
    0x28BDE: 'jiàng',  # 𨯞
    0x28BDF: 'huò',  # 𨯟
    # 0x28BE0: '',  # 𨯠
    # 0x28BE1: '',  # 𨯡
    # 0x28BE2: '',  # 𨯢
    # 0x28BE3: '',  # 𨯣
    # 0x28BE4: '',  # 𨯤
    # 0x28BE5: '',  # 𨯥
    # 0x28BE6: '',  # 𨯦
    # 0x28BE7: '',  # 𨯧
    # 0x28BE8: '',  # 𨯨
    # 0x28BE9: '',  # 𨯩
    # 0x28BEA: '',  # 𨯪
    # 0x28BEB: '',  # 𨯫
    # 0x28BEC: '',  # 𨯬
    # 0x28BED: '',  # 𨯭
    # 0x28BEE: '',  # 𨯮
    # 0x28BEF: '',  # 𨯯
    # 0x28BF0: '',  # 𨯰
    # 0x28BF1: '',  # 𨯱
    0x28BF2: 'tóu',  # 𨯲
    # 0x28BF3: '',  # 𨯳
    # 0x28BF4: '',  # 𨯴
    # 0x28BF5: '',  # 𨯵
    # 0x28BF6: '',  # 𨯶
    # 0x28BF7: '',  # 𨯷
    # 0x28BF8: '',  # 𨯸
    # 0x28BF9: '',  # 𨯹
    # 0x28BFA: '',  # 𨯺
    # 0x28BFB: '',  # 𨯻
    # 0x28BFC: '',  # 𨯼
    0x28BFD: 'lí',  # 𨯽
    # 0x28BFE: '',  # 𨯾
    # 0x28BFF: '',  # 𨯿
    # 0x28C00: '',  # 𨰀
    # 0x28C01: '',  # 𨰁
    0x28C02: 'qiàn',  # 𨰂
    # 0x28C03: '',  # 𨰃
    # 0x28C04: '',  # 𨰄
    # 0x28C05: '',  # 𨰅
    0x28C06: 'chuō',  # 𨰆
    # 0x28C07: '',  # 𨰇
    # 0x28C08: '',  # 𨰈
    # 0x28C09: '',  # 𨰉
    # 0x28C0A: '',  # 𨰊
    0x28C0B: 'lǎi',  # 𨰋
    # 0x28C0C: '',  # 𨰌
    # 0x28C0D: '',  # 𨰍
    # 0x28C0E: '',  # 𨰎
    0x28C0F: 'tà',  # 𨰏
    # 0x28C10: '',  # 𨰐
    0x28C11: 'diào',  # 𨰑
    # 0x28C12: '',  # 𨰒
    0x28C13: 'jiǎn',  # 𨰓
    # 0x28C14: '',  # 𨰔
    # 0x28C15: '',  # 𨰕
    # 0x28C16: '',  # 𨰖
    # 0x28C17: '',  # 𨰗
    # 0x28C18: '',  # 𨰘
    # 0x28C19: '',  # 𨰙
    # 0x28C1A: '',  # 𨰚
    0x28C1B: 'zhǐ',  # 𨰛
    0x28C1C: 'jué',  # 𨰜
    # 0x28C1D: '',  # 𨰝
    0x28C1E: 'mó',  # 𨰞
    # 0x28C1F: '',  # 𨰟
    0x28C20: 'luó',  # 𨰠
    # 0x28C21: '',  # 𨰡
    # 0x28C22: '',  # 𨰢
    # 0x28C23: '',  # 𨰣
    # 0x28C24: '',  # 𨰤
    # 0x28C25: '',  # 𨰥
    0x28C26: 'bǎo',  # 𨰦
    # 0x28C27: '',  # 𨰧
    # 0x28C28: '',  # 𨰨
    # 0x28C29: '',  # 𨰩
    # 0x28C2A: '',  # 𨰪
    # 0x28C2B: '',  # 𨰫
    # 0x28C2C: '',  # 𨰬
    0x28C2D: 'zuǎn',  # 𨰭
    # 0x28C2E: '',  # 𨰮
    # 0x28C2F: '',  # 𨰯
    # 0x28C30: '',  # 𨰰
    # 0x28C31: '',  # 𨰱
    # 0x28C32: '',  # 𨰲
    # 0x28C33: '',  # 𨰳
    # 0x28C34: '',  # 𨰴
    0x28C35: 'zhē',  # 𨰵
    # 0x28C36: '',  # 𨰶
    # 0x28C37: '',  # 𨰷
    0x28C38: 'yú',  # 𨰸
    # 0x28C39: '',  # 𨰹
    # 0x28C3A: '',  # 𨰺
    0x28C3B: 'bǎo',  # 𨰻
    # 0x28C3C: '',  # 𨰼
    # 0x28C3D: '',  # 𨰽
    0x28C3E: 'mǎ',  # 𨰾
    # 0x28C3F: '',  # 𨰿
    # 0x28C40: '',  # 𨱀
    # 0x28C41: '',  # 𨱁
    # 0x28C42: '',  # 𨱂
    # 0x28C43: '',  # 𨱃
    # 0x28C44: '',  # 𨱄
    # 0x28C45: '',  # 𨱅
    # 0x28C46: '',  # 𨱆
    # 0x28C47: '',  # 𨱇
    # 0x28C48: '',  # 𨱈
    # 0x28C49: '',  # 𨱉
    # 0x28C4A: '',  # 𨱊
    # 0x28C4B: '',  # 𨱋
    # 0x28C4C: '',  # 𨱌
    # 0x28C4D: '',  # 𨱍
    0x28C4E: 'tōu',  # 𨱎
    # 0x28C4F: '',  # 𨱏
    0x28C50: 'lòu',  # 𨱐
    # 0x28C51: '',  # 𨱑
    # 0x28C52: '',  # 𨱒
    # 0x28C53: '',  # 𨱓
    # 0x28C54: '',  # 𨱔
    0x28C55: 'gǎi',  # 𨱕
    # 0x28C56: '',  # 𨱖
    # 0x28C57: '',  # 𨱗
    # 0x28C58: '',  # 𨱘
    0x28C59: 'kūn',  # 𨱙
    0x28C5A: 'duàn',  # 𨱚
    0x28C5B: 'sōng',  # 𨱛
    0x28C5C: 'qí',  # 𨱜
    0x28C5D: 'yǎng',  # 𨱝
    # 0x28C5E: '',  # 𨱞
    # 0x28C5F: '',  # 𨱟
    # 0x28C60: '',  # 𨱠
    0x28C61: 'shì',  # 𨱡
    # 0x28C62: '',  # 𨱢
    0x28C63: 'gǎi',  # 𨱣
    0x28C64: 'kūn',  # 𨱤
    # 0x28C65: '',  # 𨱥
    0x28C66: 'dào',  # 𨱦
    0x28C67: 'yǎo,ǎo',  # 𨱧
    # 0x28C68: '',  # 𨱨
    # 0x28C69: '',  # 𨱩
    # 0x28C6A: '',  # 𨱪
    0x28C6B: 'qián',  # 𨱫
    # 0x28C6C: '',  # 𨱬
    0x28C6D: 'shāo',  # 𨱭
    0x28C6E: 'cháng',  # 𨱮
    0x28C6F: 'miǔ',  # 𨱯
    # 0x28C70: '',  # 𨱰
    0x28C71: 'mó',  # 𨱱
    # 0x28C72: '',  # 𨱲
    # 0x28C73: '',  # 𨱳
    # 0x28C74: '',  # 𨱴
    0x28C75: 'nǎo',  # 𨱵
    # 0x28C76: '',  # 𨱶
    # 0x28C77: '',  # 𨱷
    0x28C78: 'cōng',  # 𨱸
    # 0x28C79: '',  # 𨱹
    0x28C7A: 'niè',  # 𨱺
    0x28C7B: 'zhāo',  # 𨱻
    0x28C7C: 'cén',  # 𨱼
    # 0x28C7D: '',  # 𨱽
    # 0x28C7E: '',  # 𨱾
    0x28C7F: 'sōng',  # 𨱿
    0x28C80: 'niè',  # 𨲀
    0x28C81: 'cì',  # 𨲁
    # 0x28C82: '',  # 𨲂
    # 0x28C83: '',  # 𨲃
    0x28C84: 'jùn',  # 𨲄
    # 0x28C85: '',  # 𨲅
    0x28C86: 'shāo',  # 𨲆
    # 0x28C87: '',  # 𨲇
    0x28C88: 'zhú',  # 𨲈
    0x28C89: 'duǒ,tuǒ,shèng',  # 𨲉
    0x28C8A: 'àn',  # 𨲊
    0x28C8B: 'bī',  # 𨲋
    # 0x28C8C: '',  # 𨲌
    # 0x28C8D: '',  # 𨲍
    0x28C8E: 'tì',  # 𨲎
    # 0x28C8F: '',  # 𨲏
    0x28C90: 'pǐ',  # 𨲐
    0x28C91: 'xiá',  # 𨲑
    0x28C92: 'qiú',  # 𨲒
    0x28C93: 'shěng',  # 𨲓
    # 0x28C94: '',  # 𨲔
    # 0x28C95: '',  # 𨲕
    # 0x28C96: '',  # 𨲖
    0x28C97: 'tāng',  # 𨲗
    # 0x28C98: '',  # 𨲘
    # 0x28C99: '',  # 𨲙
    # 0x28C9A: '',  # 𨲚
    0x28C9B: 'mán,mián',  # 𨲛
    0x28C9C: 'piān',  # 𨲜
    # 0x28C9D: '',  # 𨲝
    0x28C9E: 'tì',  # 𨲞
    0x28C9F: 'róng',  # 𨲟
    # 0x28CA0: '',  # 𨲠
    # 0x28CA1: '',  # 𨲡
    # 0x28CA2: '',  # 𨲢
    # 0x28CA3: '',  # 𨲣
    # 0x28CA4: '',  # 𨲤
    # 0x28CA5: '',  # 𨲥
    # 0x28CA6: '',  # 𨲦
    0x28CA7: 'cōng',  # 𨲧
    # 0x28CA8: '',  # 𨲨
    # 0x28CA9: '',  # 𨲩
    0x28CAA: 'jī',  # 𨲪
    0x28CAB: 'féng',  # 𨲫
    0x28CAC: 'wù',  # 𨲬
    0x28CAD: 'jiào',  # 𨲭
    0x28CAE: 'láo',  # 𨲮
    0x28CAF: 'zēng',  # 𨲯
    0x28CB0: 'péng',  # 𨲰
    0x28CB1: 'cǎn',  # 𨲱
    # 0x28CB2: '',  # 𨲲
    0x28CB3: 'nóng',  # 𨲳
    # 0x28CB4: '',  # 𨲴
    0x28CB5: 'chǎn',  # 𨲵
    # 0x28CB6: '',  # 𨲶
    # 0x28CB7: '',  # 𨲷
    # 0x28CB8: '',  # 𨲸
    # 0x28CB9: '',  # 𨲹
    # 0x28CBA: '',  # 𨲺
    # 0x28CBB: '',  # 𨲻
    # 0x28CBC: '',  # 𨲼
    # 0x28CBD: '',  # 𨲽
    0x28CBE: 'mán,mián',  # 𨲾
    0x28CBF: 'guì',  # 𨲿
    0x28CC0: 'niào',  # 𨳀
    0x28CC1: 'chōng',  # 𨳁
    0x28CC2: 'chàn',  # 𨳂
    # 0x28CC3: '',  # 𨳃
    # 0x28CC4: '',  # 𨳄
    # 0x28CC5: '',  # 𨳅
    0x28CC6: 'nàng',  # 𨳆
    # 0x28CC7: '',  # 𨳇
    # 0x28CC8: '',  # 𨳈
    0x28CC9: 'xiā',  # 𨳉
    0x28CCA: 'jiū',  # 𨳊
    0x28CCB: 'jǐ',  # 𨳋
    0x28CCC: 'zhèn',  # 𨳌
    # 0x28CCD: '',  # 𨳍
    # 0x28CCE: '',  # 𨳎
    # 0x28CCF: '',  # 𨳏
    # 0x28CD0: '',  # 𨳐
    0x28CD1: 'tǐng',  # 𨳑
    # 0x28CD2: '',  # 𨳒
    # 0x28CD3: '',  # 𨳓
    0x28CD4: 'mén',  # 𨳔
    0x28CD5: 'yuè',  # 𨳕
    # 0x28CD6: '',  # 𨳖
    0x28CD7: 'zhōng',  # 𨳗
    0x28CD8: 'tún',  # 𨳘
    0x28CD9: 'ruì',  # 𨳙
    0x28CDA: 'xiè,fēn',  # 𨳚
    0x28CDB: 'xī',  # 𨳛
    # 0x28CDC: '',  # 𨳜
    0x28CDD: 'tǐng,rùn',  # 𨳝
    0x28CDE: 'niǔ',  # 𨳞
    # 0x28CDF: '',  # 𨳟
    0x28CE0: 'wǎng',  # 𨳠
    0x28CE1: 'jiān,guān',  # 𨳡
    # 0x28CE2: '',  # 𨳢
    0x28CE3: 'fēn',  # 𨳣
    # 0x28CE4: '',  # 𨳤
    # 0x28CE5: '',  # 𨳥
    # 0x28CE6: '',  # 𨳦
    # 0x28CE7: '',  # 𨳧
    # 0x28CE8: '',  # 𨳨
    # 0x28CE9: '',  # 𨳩
    # 0x28CEA: '',  # 𨳪
    # 0x28CEB: '',  # 𨳫
    # 0x28CEC: '',  # 𨳬
    # 0x28CED: '',  # 𨳭
    # 0x28CEE: '',  # 𨳮
    # 0x28CEF: '',  # 𨳯
    # 0x28CF0: '',  # 𨳰
    # 0x28CF1: '',  # 𨳱
    0x28CF2: 'biàn,bì',  # 𨳲
    # 0x28CF3: '',  # 𨳳
    # 0x28CF4: '',  # 𨳴
    # 0x28CF5: '',  # 𨳵
    # 0x28CF6: '',  # 𨳶
    0x28CF7: 'yí',  # 𨳷
    # 0x28CF8: '',  # 𨳸
    # 0x28CF9: '',  # 𨳹
    0x28CFA: 'dié',  # 𨳺
    0x28CFB: 'jī',  # 𨳻
    0x28CFC: 'gǎn',  # 𨳼
    # 0x28CFD: '',  # 𨳽
    # 0x28CFE: '',  # 𨳾
    0x28CFF: 'jiān,xì,mǎ',  # 𨳿
    0x28D00: 'jiōng',  # 𨴀
    # 0x28D01: '',  # 𨴁
    # 0x28D02: '',  # 𨴂
    # 0x28D03: '',  # 𨴃
    # 0x28D04: '',  # 𨴄
    # 0x28D05: '',  # 𨴅
    0x28D06: 'kāi',  # 𨴆
    # 0x28D07: '',  # 𨴇
    # 0x28D08: '',  # 𨴈
    # 0x28D09: '',  # 𨴉
    0x28D0A: 'què,guān',  # 𨴊
    # 0x28D0B: '',  # 𨴋
    0x28D0C: 'nán',  # 𨴌
    0x28D0D: 'móu',  # 𨴍
    0x28D0E: 'xù',  # 𨴎
    0x28D0F: 'sǒng',  # 𨴏
    0x28D10: 'shèn',  # 𨴐
    0x28D11: 'kuāng',  # 𨴑
    0x28D12: 'què',  # 𨴒
    0x28D13: 'wéi',  # 𨴓
    # 0x28D14: '',  # 𨴔
    # 0x28D15: '',  # 𨴕
    # 0x28D16: '',  # 𨴖
    0x28D17: 'dié',  # 𨴗
    0x28D18: 'nán',  # 𨴘
    # 0x28D19: '',  # 𨴙
    0x28D1A: 'ruò',  # 𨴚
    0x28D1B: 'gōng',  # 𨴛
    0x28D1C: 'dòu,yòu',  # 𨴜
    # 0x28D1D: '',  # 𨴝
    0x28D1E: 'niǎn',  # 𨴞
    # 0x28D1F: '',  # 𨴟
    # 0x28D20: '',  # 𨴠
    0x28D21: 'chāo',  # 𨴡
    0x28D22: 'hé',  # 𨴢
    0x28D23: 'yàn',  # 𨴣
    # 0x28D24: '',  # 𨴤
    # 0x28D25: '',  # 𨴥
    # 0x28D26: '',  # 𨴦
    # 0x28D27: '',  # 𨴧
    # 0x28D28: '',  # 𨴨
    0x28D29: 'tú',  # 𨴩
    0x28D2A: 'bǔ',  # 𨴪
    # 0x28D2B: '',  # 𨴫
    0x28D2C: 'hú',  # 𨴬
    0x28D2D: 'yǒng',  # 𨴭
    # 0x28D2E: '',  # 𨴮
    0x28D2F: 'shǐ',  # 𨴯
    0x28D30: 'chù',  # 𨴰
    # 0x28D31: '',  # 𨴱
    # 0x28D32: '',  # 𨴲
    # 0x28D33: '',  # 𨴳
    # 0x28D34: '',  # 𨴴
    # 0x28D35: '',  # 𨴵
    # 0x28D36: '',  # 𨴶
    # 0x28D37: '',  # 𨴷
    # 0x28D38: '',  # 𨴸
    0x28D39: 'xiāo',  # 𨴹
    0x28D3A: 'mén',  # 𨴺
    0x28D3B: 'lǐ',  # 𨴻
    0x28D3C: 'tí',  # 𨴼
    # 0x28D3D: '',  # 𨴽
    0x28D3E: 'jiān',  # 𨴾
    # 0x28D3F: '',  # 𨴿
    # 0x28D40: '',  # 𨵀
    # 0x28D41: '',  # 𨵁
    0x28D42: 'zhǐ',  # 𨵂
    0x28D43: 'guā,yuè',  # 𨵃
    0x28D44: 'guǎn',  # 𨵄
    # 0x28D45: '',  # 𨵅
    0x28D46: 'qì',  # 𨵆
    # 0x28D47: '',  # 𨵇
    0x28D48: 'fēi',  # 𨵈
    0x28D49: 'yǔ',  # 𨵉
    0x28D4A: 'zhé',  # 𨵊
    0x28D4B: 'wěi',  # 𨵋
    0x28D4C: 'ě',  # 𨵌
    0x28D4D: 'chān',  # 𨵍
    0x28D4E: 'xī,qí',  # 𨵎
    # 0x28D4F: '',  # 𨵏
    0x28D50: 'gǔ',  # 𨵐
    # 0x28D51: '',  # 𨵑
    # 0x28D52: '',  # 𨵒
    # 0x28D53: '',  # 𨵓
    # 0x28D54: '',  # 𨵔
    # 0x28D55: '',  # 𨵕
    # 0x28D56: '',  # 𨵖
    0x28D57: 'què',  # 𨵗
    0x28D58: 'huì',  # 𨵘
    # 0x28D59: '',  # 𨵙
    0x28D5A: 'xié',  # 𨵚
    0x28D5B: 'yīng',  # 𨵛
    # 0x28D5C: '',  # 𨵜
    0x28D5D: 'tà',  # 𨵝
    0x28D5E: 'wāi',  # 𨵞
    0x28D5F: 'fú',  # 𨵟
    0x28D60: 'jiè',  # 𨵠
    0x28D61: 'pì',  # 𨵡
    # 0x28D62: '',  # 𨵢
    # 0x28D63: '',  # 𨵣
    0x28D64: 'xī',  # 𨵤
    0x28D65: 'shěng',  # 𨵥
    0x28D66: 'yú',  # 𨵦
    0x28D67: 'kuā',  # 𨵧
    # 0x28D68: '',  # 𨵨
    0x28D69: 'pì',  # 𨵩
    0x28D6A: 'xié',  # 𨵪
    0x28D6B: 'nüè',  # 𨵫
    0x28D6C: 'xiàn',  # 𨵬
    0x28D6D: 'jiàn',  # 𨵭
    0x28D6E: 'xù',  # 𨵮
    # 0x28D6F: '',  # 𨵯
    0x28D70: 'bì',  # 𨵰
    # 0x28D71: '',  # 𨵱
    # 0x28D72: '',  # 𨵲
    # 0x28D73: '',  # 𨵳
    0x28D74: 'nán',  # 𨵴
    # 0x28D75: '',  # 𨵵
    0x28D76: 'liáng',  # 𨵶
    # 0x28D77: '',  # 𨵷
    0x28D78: 'pián',  # 𨵸
    # 0x28D79: '',  # 𨵹
    # 0x28D7A: '',  # 𨵺
    # 0x28D7B: '',  # 𨵻
    0x28D7C: 'jìng',  # 𨵼
    # 0x28D7D: '',  # 𨵽
    # 0x28D7E: '',  # 𨵾
    # 0x28D7F: '',  # 𨵿
    0x28D80: 'tǎ',  # 𨶀
    0x28D81: 'yàn',  # 𨶁
    0x28D82: 'ài',  # 𨶂
    # 0x28D83: '',  # 𨶃
    # 0x28D84: '',  # 𨶄
    0x28D85: 'xiāo',  # 𨶅
    0x28D86: 'qiāng',  # 𨶆
    0x28D87: 'wǔ',  # 𨶇
    0x28D88: 'táng',  # 𨶈
    # 0x28D89: '',  # 𨶉
    0x28D8A: 'jùn',  # 𨶊
    # 0x28D8B: '',  # 𨶋
    # 0x28D8C: '',  # 𨶌
    # 0x28D8D: '',  # 𨶍
    # 0x28D8E: '',  # 𨶎
    # 0x28D8F: '',  # 𨶏
    0x28D90: 'kuò',  # 𨶐
    # 0x28D91: '',  # 𨶑
    # 0x28D92: '',  # 𨶒
    # 0x28D93: '',  # 𨶓
    0x28D94: 'quē,què',  # 𨶔
    # 0x28D95: '',  # 𨶕
    # 0x28D96: '',  # 𨶖
    0x28D97: 'làng',  # 𨶗
    # 0x28D98: '',  # 𨶘
    0x28D99: 'něng',  # 𨶙
    # 0x28D9A: '',  # 𨶚
    # 0x28D9B: '',  # 𨶛
    0x28D9C: 'dòu,dǒu',  # 𨶜
    0x28D9D: 'shú',  # 𨶝
    # 0x28D9E: '',  # 𨶞
    0x28D9F: 'jiǎo',  # 𨶟
    0x28DA0: 'niè',  # 𨶠
    # 0x28DA1: '',  # 𨶡
    0x28DA2: 'yú',  # 𨶢
    # 0x28DA3: '',  # 𨶣
    # 0x28DA4: '',  # 𨶤
    # 0x28DA5: '',  # 𨶥
    # 0x28DA6: '',  # 𨶦
    # 0x28DA7: '',  # 𨶧
    0x28DA8: 'cè',  # 𨶨
    # 0x28DA9: '',  # 𨶩
    0x28DAA: 'jiǎo,liú',  # 𨶪
    # 0x28DAB: '',  # 𨶫
    0x28DAC: 'huà',  # 𨶬
    0x28DAD: 'wén',  # 𨶭
    0x28DAE: 'yē',  # 𨶮
    0x28DAF: 'é',  # 𨶯
    0x28DB0: 'guāng',  # 𨶰
    0x28DB1: 'huā',  # 𨶱
    0x28DB2: 'jiāo',  # 𨶲
    # 0x28DB3: '',  # 𨶳
    # 0x28DB4: '',  # 𨶴
    # 0x28DB5: '',  # 𨶵
    # 0x28DB6: '',  # 𨶶
    # 0x28DB7: '',  # 𨶷
    # 0x28DB8: '',  # 𨶸
    # 0x28DB9: '',  # 𨶹
    0x28DBA: 'lèi',  # 𨶺
    # 0x28DBB: '',  # 𨶻
    0x28DBC: 'shāng',  # 𨶼
    0x28DBD: 'yòng',  # 𨶽
    # 0x28DBE: '',  # 𨶾
    0x28DBF: 'dēng',  # 𨶿
    0x28DC0: 'guān',  # 𨷀
    0x28DC1: 'niú',  # 𨷁
    # 0x28DC2: '',  # 𨷂
    0x28DC3: 'suì',  # 𨷃
    0x28DC4: 'xiàng',  # 𨷄
    # 0x28DC5: '',  # 𨷅
    0x28DC6: 'sà',  # 𨷆
    0x28DC7: 'chāng',  # 𨷇
    # 0x28DC8: '',  # 𨷈
    # 0x28DC9: '',  # 𨷉
    # 0x28DCA: '',  # 𨷊
    # 0x28DCB: '',  # 𨷋
    # 0x28DCC: '',  # 𨷌
    # 0x28DCD: '',  # 𨷍
    0x28DCE: 'rùn',  # 𨷎
    # 0x28DCF: '',  # 𨷏
    0x28DD0: 'yūn',  # 𨷐
    # 0x28DD1: '',  # 𨷑
    0x28DD2: 'fēn',  # 𨷒
    0x28DD3: 'jiàn',  # 𨷓
    0x28DD4: 'xù',  # 𨷔
    # 0x28DD5: '',  # 𨷕
    # 0x28DD6: '',  # 𨷖
    # 0x28DD7: '',  # 𨷗
    0x28DD8: 'xì',  # 𨷘
    0x28DD9: 'shú',  # 𨷙
    # 0x28DDA: '',  # 𨷚
    # 0x28DDB: '',  # 𨷛
    # 0x28DDC: '',  # 𨷜
    # 0x28DDD: '',  # 𨷝
    # 0x28DDE: '',  # 𨷞
    # 0x28DDF: '',  # 𨷟
    # 0x28DE0: '',  # 𨷠
    # 0x28DE1: '',  # 𨷡
    # 0x28DE2: '',  # 𨷢
    # 0x28DE3: '',  # 𨷣
    # 0x28DE4: '',  # 𨷤
    0x28DE5: 'xié',  # 𨷥
    0x28DE6: 'lì',  # 𨷦
    # 0x28DE7: '',  # 𨷧
    # 0x28DE8: '',  # 𨷨
    0x28DE9: 'tóu',  # 𨷩
    # 0x28DEA: '',  # 𨷪
    # 0x28DEB: '',  # 𨷫
    0x28DEC: 'mǐ',  # 𨷬
    0x28DED: 'chǎn',  # 𨷭
    0x28DEE: 'huō',  # 𨷮
    # 0x28DEF: '',  # 𨷯
    # 0x28DF0: '',  # 𨷰
    0x28DF1: 'zhuǎn',  # 𨷱
    0x28DF2: 'yuè',  # 𨷲
    # 0x28DF3: '',  # 𨷳
    # 0x28DF4: '',  # 𨷴
    # 0x28DF5: '',  # 𨷵
    # 0x28DF6: '',  # 𨷶
    # 0x28DF7: '',  # 𨷷
    # 0x28DF8: '',  # 𨷸
    # 0x28DF9: '',  # 𨷹
    # 0x28DFA: '',  # 𨷺
    0x28DFB: 'lán',  # 𨷻
    # 0x28DFC: '',  # 𨷼
    0x28DFD: 'yán',  # 𨷽
    0x28DFE: 'dàng',  # 𨷾
    # 0x28DFF: '',  # 𨷿
    # 0x28E00: '',  # 𨸀
    # 0x28E01: '',  # 𨸁
    # 0x28E02: '',  # 𨸂
    # 0x28E03: '',  # 𨸃
    # 0x28E04: '',  # 𨸄
    # 0x28E05: '',  # 𨸅
    # 0x28E06: '',  # 𨸆
    # 0x28E07: '',  # 𨸇
    # 0x28E08: '',  # 𨸈
    # 0x28E09: '',  # 𨸉
    # 0x28E0A: '',  # 𨸊
    # 0x28E0B: '',  # 𨸋
    # 0x28E0C: '',  # 𨸌
    # 0x28E0D: '',  # 𨸍
    # 0x28E0E: '',  # 𨸎
    0x28E0F: 'fù',  # 𨸏
    0x28E10: 'réng',  # 𨸐
    0x28E11: 'qiǎo',  # 𨸑
    0x28E12: 'qí',  # 𨸒
    0x28E13: 'diāo',  # 𨸓
    0x28E14: 'qí,wéi',  # 𨸔
    # 0x28E15: '',  # 𨸕
    # 0x28E16: '',  # 𨸖
    0x28E17: 'hàn',  # 𨸗
    0x28E18: 'yuán',  # 𨸘
    0x28E19: 'yóu',  # 𨸙
    0x28E1A: 'jí',  # 𨸚
    0x28E1B: 'gài',  # 𨸛
    0x28E1C: 'hāi',  # 𨸜
    0x28E1D: 'shì',  # 𨸝
    # 0x28E1E: '',  # 𨸞
    # 0x28E1F: '',  # 𨸟
    # 0x28E20: '',  # 𨸠
    # 0x28E21: '',  # 𨸡
    # 0x28E22: '',  # 𨸢
    # 0x28E23: '',  # 𨸣
    # 0x28E24: '',  # 𨸤
    # 0x28E25: '',  # 𨸥
    # 0x28E26: '',  # 𨸦
    # 0x28E27: '',  # 𨸧
    # 0x28E28: '',  # 𨸨
    0x28E29: 'wèn',  # 𨸩
    # 0x28E2A: '',  # 𨸪
    # 0x28E2B: '',  # 𨸫
    0x28E2C: 'zhèn',  # 𨸬
    0x28E2D: 'pō',  # 𨸭
    0x28E2E: 'yán,yǔn',  # 𨸮
    0x28E2F: 'gū',  # 𨸯
    0x28E30: 'jù',  # 𨸰
    0x28E31: 'tiàn,niǎn',  # 𨸱
    # 0x28E32: '',  # 𨸲
    # 0x28E33: '',  # 𨸳
    # 0x28E34: '',  # 𨸴
    # 0x28E35: '',  # 𨸵
    # 0x28E36: '',  # 𨸶
    0x28E37: 'è',  # 𨸷
    # 0x28E38: '',  # 𨸸
    # 0x28E39: '',  # 𨸹
    0x28E3A: 'yā',  # 𨸺
    0x28E3B: 'lìn',  # 𨸻
    0x28E3C: 'bì',  # 𨸼
    # 0x28E3D: '',  # 𨸽
    # 0x28E3E: '',  # 𨸾
    # 0x28E3F: '',  # 𨸿
    0x28E40: 'zǐ',  # 𨹀
    0x28E41: 'hóng',  # 𨹁
    # 0x28E42: '',  # 𨹂
    0x28E43: 'duǒ,duò',  # 𨹃
    # 0x28E44: '',  # 𨹄
    0x28E45: 'duì',  # 𨹅
    0x28E46: 'xuàn',  # 𨹆
    # 0x28E47: '',  # 𨹇
    0x28E48: 'shǎn,yáng',  # 𨹈
    # 0x28E49: '',  # 𨹉
    0x28E4A: 'shǎn',  # 𨹊
    0x28E4B: 'yáo',  # 𨹋
    0x28E4C: 'rǎn',  # 𨹌
    # 0x28E4D: '',  # 𨹍
    # 0x28E4E: '',  # 𨹎
    # 0x28E4F: '',  # 𨹏
    # 0x28E50: '',  # 𨹐
    # 0x28E51: '',  # 𨹑
    # 0x28E52: '',  # 𨹒
    # 0x28E53: '',  # 𨹓
    0x28E54: 'tuó',  # 𨹔
    # 0x28E55: '',  # 𨹕
    # 0x28E56: '',  # 𨹖
    0x28E57: 'bīng',  # 𨹗
    0x28E58: 'xù',  # 𨹘
    0x28E59: 'tūn',  # 𨹙
    0x28E5A: 'chéng',  # 𨹚
    # 0x28E5B: '',  # 𨹛
    0x28E5C: 'dòu',  # 𨹜
    0x28E5D: 'yì,yà',  # 𨹝
    # 0x28E5E: '',  # 𨹞
    0x28E5F: 'lòu',  # 𨹟
    # 0x28E60: '',  # 𨹠
    0x28E61: 'chè',  # 𨹡
    # 0x28E62: '',  # 𨹢
    # 0x28E63: '',  # 𨹣
    # 0x28E64: '',  # 𨹤
    # 0x28E65: '',  # 𨹥
    # 0x28E66: '',  # 𨹦
    # 0x28E67: '',  # 𨹧
    # 0x28E68: '',  # 𨹨
    # 0x28E69: '',  # 𨹩
    # 0x28E6A: '',  # 𨹪
    # 0x28E6B: '',  # 𨹫
    # 0x28E6C: '',  # 𨹬
    # 0x28E6D: '',  # 𨹭
    # 0x28E6E: '',  # 𨹮
    # 0x28E6F: '',  # 𨹯
    # 0x28E70: '',  # 𨹰
    # 0x28E71: '',  # 𨹱
    # 0x28E72: '',  # 𨹲
    # 0x28E73: '',  # 𨹳
    # 0x28E74: '',  # 𨹴
    0x28E75: 'juǎn',  # 𨹵
    0x28E76: 'jī',  # 𨹶
    # 0x28E77: '',  # 𨹷
    0x28E78: 'zhào',  # 𨹸
    0x28E79: 'bēng,bèng',  # 𨹹
    # 0x28E7A: '',  # 𨹺
    0x28E7B: 'tiǎn',  # 𨹻
    # 0x28E7C: '',  # 𨹼
    # 0x28E7D: '',  # 𨹽
    # 0x28E7E: '',  # 𨹾
    # 0x28E7F: '',  # 𨹿
    0x28E80: 'pēng',  # 𨺀
    # 0x28E81: '',  # 𨺁
    # 0x28E82: '',  # 𨺂
    # 0x28E83: '',  # 𨺃
    # 0x28E84: '',  # 𨺄
    0x28E85: 'fù',  # 𨺅
    # 0x28E86: '',  # 𨺆
    # 0x28E87: '',  # 𨺇
    # 0x28E88: '',  # 𨺈
    # 0x28E89: '',  # 𨺉
    # 0x28E8A: '',  # 𨺊
    # 0x28E8B: '',  # 𨺋
    # 0x28E8C: '',  # 𨺌
    # 0x28E8D: '',  # 𨺍
    # 0x28E8E: '',  # 𨺎
    # 0x28E8F: '',  # 𨺏
    # 0x28E90: '',  # 𨺐
    # 0x28E91: '',  # 𨺑
    # 0x28E92: '',  # 𨺒
    # 0x28E93: '',  # 𨺓
    # 0x28E94: '',  # 𨺔
    # 0x28E95: '',  # 𨺕
    0x28E96: 'tuǒ',  # 𨺖
    # 0x28E97: '',  # 𨺗
    0x28E98: 'xián',  # 𨺘
    0x28E99: 'nì',  # 𨺙
    0x28E9A: 'lóng',  # 𨺚
    # 0x28E9B: '',  # 𨺛
    # 0x28E9C: '',  # 𨺜
    0x28E9D: 'zhuó',  # 𨺝
    # 0x28E9E: '',  # 𨺞
    0x28E9F: 'zhēng',  # 𨺟
    0x28EA0: 'shǔn',  # 𨺠
    0x28EA1: 'zōng',  # 𨺡
    0x28EA2: 'fēng',  # 𨺢
    0x28EA3: 'duàn',  # 𨺣
    0x28EA4: 'pì',  # 𨺤
    0x28EA5: 'yǎn',  # 𨺥
    0x28EA6: 'sǒu',  # 𨺦
    0x28EA7: 'qiú',  # 𨺧
    0x28EA8: 'è',  # 𨺨
    0x28EA9: 'qián',  # 𨺩
    # 0x28EAA: '',  # 𨺪
    0x28EAB: 'qiǎn',  # 𨺫
    # 0x28EAC: '',  # 𨺬
    0x28EAD: 'cā',  # 𨺭
    0x28EAE: 'xùn',  # 𨺮
    # 0x28EAF: '',  # 𨺯
    # 0x28EB0: '',  # 𨺰
    # 0x28EB1: '',  # 𨺱
    # 0x28EB2: '',  # 𨺲
    # 0x28EB3: '',  # 𨺳
    # 0x28EB4: '',  # 𨺴
    0x28EB5: 'zhuì',  # 𨺵
    # 0x28EB6: '',  # 𨺶
    # 0x28EB7: '',  # 𨺷
    0x28EB8: 'mǎo',  # 𨺸
    0x28EB9: 'jiǎo',  # 𨺹
    # 0x28EBA: '',  # 𨺺
    # 0x28EBB: '',  # 𨺻
    # 0x28EBC: '',  # 𨺼
    # 0x28EBD: '',  # 𨺽
    # 0x28EBE: '',  # 𨺾
    0x28EBF: 'zhǎn',  # 𨺿
    0x28EC0: 'pí,bī',  # 𨻀
    0x28EC1: 'xī',  # 𨻁
    0x28EC2: 'yàn',  # 𨻂
    0x28EC3: 'fèi',  # 𨻃
    0x28EC4: 'niè',  # 𨻄
    # 0x28EC5: '',  # 𨻅
    0x28EC6: 'zhì',  # 𨻆
    # 0x28EC7: '',  # 𨻇
    0x28EC8: 'suǒ',  # 𨻈
    # 0x28EC9: '',  # 𨻉
    0x28ECA: 'yì',  # 𨻊
    # 0x28ECB: '',  # 𨻋
    0x28ECC: 'lěi',  # 𨻌
    0x28ECD: 'xù',  # 𨻍
    # 0x28ECE: '',  # 𨻎
    0x28ECF: 'yì',  # 𨻏
    # 0x28ED0: '',  # 𨻐
    # 0x28ED1: '',  # 𨻑
    0x28ED2: 'wēi',  # 𨻒
    # 0x28ED3: '',  # 𨻓
    # 0x28ED4: '',  # 𨻔
    0x28ED5: 'jī',  # 𨻕
    0x28ED6: 'chēn',  # 𨻖
    0x28ED7: 'dié',  # 𨻗
    # 0x28ED8: '',  # 𨻘
    # 0x28ED9: '',  # 𨻙
    # 0x28EDA: '',  # 𨻚
    # 0x28EDB: '',  # 𨻛
    # 0x28EDC: '',  # 𨻜
    # 0x28EDD: '',  # 𨻝
    # 0x28EDE: '',  # 𨻞
    # 0x28EDF: '',  # 𨻟
    # 0x28EE0: '',  # 𨻠
    # 0x28EE1: '',  # 𨻡
    # 0x28EE2: '',  # 𨻢
    0x28EE3: 'yuán',  # 𨻣
    0x28EE4: 'shǎn',  # 𨻤
    0x28EE5: 'xí',  # 𨻥
    # 0x28EE6: '',  # 𨻦
    0x28EE7: 'liú',  # 𨻧
    0x28EE8: 'suǒ',  # 𨻨
    0x28EE9: 'qīng',  # 𨻩
    # 0x28EEA: '',  # 𨻪
    # 0x28EEB: '',  # 𨻫
    # 0x28EEC: '',  # 𨻬
    # 0x28EED: '',  # 𨻭
    # 0x28EEE: '',  # 𨻮
    # 0x28EEF: '',  # 𨻯
    # 0x28EF0: '',  # 𨻰
    0x28EF1: 'bēng',  # 𨻱
    0x28EF2: 'xià',  # 𨻲
    0x28EF3: 'yàn,yān',  # 𨻳
    # 0x28EF4: '',  # 𨻴
    0x28EF5: 'cuī,zuī,duì',  # 𨻵
    0x28EF6: 'qīng',  # 𨻶
    0x28EF7: 'kāng',  # 𨻷
    # 0x28EF8: '',  # 𨻸
    # 0x28EF9: '',  # 𨻹
    0x28EFA: 'qīng',  # 𨻺
    0x28EFB: 'lóu',  # 𨻻
    0x28EFC: 'bī',  # 𨻼
    # 0x28EFD: '',  # 𨻽
    # 0x28EFE: '',  # 𨻾
    # 0x28EFF: '',  # 𨻿
    # 0x28F00: '',  # 𨼀
    # 0x28F01: '',  # 𨼁
    # 0x28F02: '',  # 𨼂
    # 0x28F03: '',  # 𨼃
    # 0x28F04: '',  # 𨼄
    # 0x28F05: '',  # 𨼅
    # 0x28F06: '',  # 𨼆
    0x28F07: 'lóng',  # 𨼇
    0x28F08: 'zhàn',  # 𨼈
    0x28F09: 'cuàn',  # 𨼉
    0x28F0A: 'wú',  # 𨼊
    0x28F0B: 'xū',  # 𨼋
    0x28F0C: 'chēn',  # 𨼌
    0x28F0D: 'háo',  # 𨼍
    0x28F0E: 'jué',  # 𨼎
    # 0x28F0F: '',  # 𨼏
    0x28F10: 'chèn',  # 𨼐
    0x28F11: 'chá',  # 𨼑
    0x28F12: 'chǎn',  # 𨼒
    0x28F13: 'zhí',  # 𨼓
    0x28F14: 'xún',  # 𨼔
    # 0x28F15: '',  # 𨼕
    # 0x28F16: '',  # 𨼖
    # 0x28F17: '',  # 𨼗
    # 0x28F18: '',  # 𨼘
    # 0x28F19: '',  # 𨼙
    # 0x28F1A: '',  # 𨼚
    # 0x28F1B: '',  # 𨼛
    # 0x28F1C: '',  # 𨼜
    # 0x28F1D: '',  # 𨼝
    # 0x28F1E: '',  # 𨼞
    # 0x28F1F: '',  # 𨼟
    # 0x28F20: '',  # 𨼠
    # 0x28F21: '',  # 𨼡
    # 0x28F22: '',  # 𨼢
    # 0x28F23: '',  # 𨼣
    0x28F24: 'chén',  # 𨼤
    0x28F25: 'yè,gé',  # 𨼥
    # 0x28F26: '',  # 𨼦
    # 0x28F27: '',  # 𨼧
    # 0x28F28: '',  # 𨼨
    # 0x28F29: '',  # 𨼩
    0x28F2A: 'chǔ',  # 𨼪
    0x28F2B: 'qú',  # 𨼫
    0x28F2C: 'xiè',  # 𨼬
    # 0x28F2D: '',  # 𨼭
    0x28F2E: 'zhàn',  # 𨼮
    0x28F2F: 'kěn',  # 𨼯
    # 0x28F30: '',  # 𨼰
    0x28F31: 'jué',  # 𨼱
    # 0x28F32: '',  # 𨼲
    # 0x28F33: '',  # 𨼳
    # 0x28F34: '',  # 𨼴
    # 0x28F35: '',  # 𨼵
    # 0x28F36: '',  # 𨼶
    # 0x28F37: '',  # 𨼷
    # 0x28F38: '',  # 𨼸
    # 0x28F39: '',  # 𨼹
    # 0x28F3A: '',  # 𨼺
    # 0x28F3B: '',  # 𨼻
    # 0x28F3C: '',  # 𨼼
    0x28F3D: 'qú',  # 𨼽
    # 0x28F3E: '',  # 𨼾
    0x28F3F: 'méng',  # 𨼿
    0x28F40: 'yè',  # 𨽀
    0x28F41: 'zōu,cóng',  # 𨽁
    0x28F42: 'pú',  # 𨽂
    # 0x28F43: '',  # 𨽃
    0x28F44: 'shì',  # 𨽄
    # 0x28F45: '',  # 𨽅
    # 0x28F46: '',  # 𨽆
    # 0x28F47: '',  # 𨽇
    # 0x28F48: '',  # 𨽈
    0x28F49: 'shǔ',  # 𨽉
    0x28F4A: 'chán',  # 𨽊
    # 0x28F4B: '',  # 𨽋
    0x28F4C: 'yǐn',  # 𨽌
    0x28F4D: 'dú',  # 𨽍
    # 0x28F4E: '',  # 𨽎
    0x28F4F: 'guō',  # 𨽏
    0x28F50: 'lù,yáng',  # 𨽐
    0x28F51: 'yān',  # 𨽑
    # 0x28F52: '',  # 𨽒
    # 0x28F53: '',  # 𨽓
    # 0x28F54: '',  # 𨽔
    # 0x28F55: '',  # 𨽕
    0x28F56: 'niǎo',  # 𨽖
    0x28F57: 'bīn,pín',  # 𨽗
    # 0x28F58: '',  # 𨽘
    # 0x28F59: '',  # 𨽙
    # 0x28F5A: '',  # 𨽚
    # 0x28F5B: '',  # 𨽛
    # 0x28F5C: '',  # 𨽜
    0x28F5D: 'ài',  # 𨽝
    # 0x28F5E: '',  # 𨽞
    0x28F5F: 'tuí',  # 𨽟
    # 0x28F60: '',  # 𨽠
    # 0x28F61: '',  # 𨽡
    # 0x28F62: '',  # 𨽢
    # 0x28F63: '',  # 𨽣
    # 0x28F64: '',  # 𨽤
    0x28F65: 'zhì',  # 𨽥
    0x28F66: 'nì',  # 𨽦
    0x28F67: 'huān',  # 𨽧
    0x28F68: 'qián',  # 𨽨
    # 0x28F69: '',  # 𨽩
    # 0x28F6A: '',  # 𨽪
    # 0x28F6B: '',  # 𨽫
    # 0x28F6C: '',  # 𨽬
    # 0x28F6D: '',  # 𨽭
    # 0x28F6E: '',  # 𨽮
    0x28F6F: 'xià',  # 𨽯
    # 0x28F70: '',  # 𨽰
    # 0x28F71: '',  # 𨽱
    0x28F72: 'líng',  # 𨽲
    # 0x28F73: '',  # 𨽳
    # 0x28F74: '',  # 𨽴
    0x28F75: 'suì',  # 𨽵
    # 0x28F76: '',  # 𨽶
    0x28F77: 'lián',  # 𨽷
    0x28F78: 'sì',  # 𨽸
    0x28F79: 'yì,lì',  # 𨽹
    # 0x28F7A: '',  # 𨽺
    0x28F7B: 'lì',  # 𨽻
    0x28F7C: 'sì',  # 𨽼
    # 0x28F7D: '',  # 𨽽
    # 0x28F7E: '',  # 𨽾
    0x28F7F: 'dài',  # 𨽿
    # 0x28F80: '',  # 𨾀
    # 0x28F81: '',  # 𨾁
    0x28F82: 'wèi',  # 𨾂
    # 0x28F83: '',  # 𨾃
    # 0x28F84: '',  # 𨾄
    0x28F85: 'cì',  # 𨾅
    # 0x28F86: '',  # 𨾆
    # 0x28F87: '',  # 𨾇
    # 0x28F88: '',  # 𨾈
    0x28F89: 'jiǔ',  # 𨾉
    0x28F8A: 'hóng',  # 𨾊
    # 0x28F8B: '',  # 𨾋
    0x28F8C: 'yú',  # 𨾌
    # 0x28F8D: '',  # 𨾍
    0x28F8E: 'kuí',  # 𨾎
    # 0x28F8F: '',  # 𨾏
    # 0x28F90: '',  # 𨾐
    # 0x28F91: '',  # 𨾑
    0x28F92: 'háng',  # 𨾒
    0x28F93: 'gē,yì',  # 𨾓
    0x28F94: 'fàng',  # 𨾔
    # 0x28F95: '',  # 𨾕
    # 0x28F96: '',  # 𨾖
    0x28F97: 'kuí,xié',  # 𨾗
    # 0x28F98: '',  # 𨾘
    # 0x28F99: '',  # 𨾙
    0x28F9A: 'guī,fū',  # 𨾚
    0x28F9B: 'chǐ,qí',  # 𨾛
    # 0x28F9C: '',  # 𨾜
    # 0x28F9D: '',  # 𨾝
    0x28F9E: 'jiǔ',  # 𨾞
    # 0x28F9F: '',  # 𨾟
    # 0x28FA0: '',  # 𨾠
    0x28FA1: 'suī,huǎng',  # 𨾡
    # 0x28FA2: '',  # 𨾢
    # 0x28FA3: '',  # 𨾣
    0x28FA4: 'dié',  # 𨾤
    # 0x28FA5: '',  # 𨾥
    0x28FA6: 'chī',  # 𨾦
    # 0x28FA7: '',  # 𨾧
    # 0x28FA8: '',  # 𨾨
    # 0x28FA9: '',  # 𨾩
    # 0x28FAA: '',  # 𨾪
    # 0x28FAB: '',  # 𨾫
    0x28FAC: 'suǐ',  # 𨾬
    # 0x28FAD: '',  # 𨾭
    # 0x28FAE: '',  # 𨾮
    0x28FAF: 'rú',  # 𨾯
    0x28FB0: 'qín',  # 𨾰
    # 0x28FB1: '',  # 𨾱
    # 0x28FB2: '',  # 𨾲
    # 0x28FB3: '',  # 𨾳
    0x28FB4: 'guī',  # 𨾴
    # 0x28FB5: '',  # 𨾵
    # 0x28FB6: '',  # 𨾶
    # 0x28FB7: '',  # 𨾷
    # 0x28FB8: '',  # 𨾸
    # 0x28FB9: '',  # 𨾹
    # 0x28FBA: '',  # 𨾺
    0x28FBB: 'zhuī',  # 𨾻
    # 0x28FBC: '',  # 𨾼
    # 0x28FBD: '',  # 𨾽
    0x28FBE: 'tiào',  # 𨾾
    # 0x28FBF: '',  # 𨾿
    # 0x28FC0: '',  # 𨿀
    0x28FC1: 'yuè',  # 𨿁
    # 0x28FC2: '',  # 𨿂
    # 0x28FC3: '',  # 𨿃
    # 0x28FC4: '',  # 𨿄
    # 0x28FC5: '',  # 𨿅
    # 0x28FC6: '',  # 𨿆
    0x28FC7: 'zuǐ',  # 𨿇
    # 0x28FC8: '',  # 𨿈
    # 0x28FC9: '',  # 𨿉
    # 0x28FCA: '',  # 𨿊
    # 0x28FCB: '',  # 𨿋
    # 0x28FCC: '',  # 𨿌
    # 0x28FCD: '',  # 𨿍
    # 0x28FCE: '',  # 𨿎
    0x28FCF: 'wú',  # 𨿏
    0x28FD0: 'cuǐ',  # 𨿐
    # 0x28FD1: '',  # 𨿑
    # 0x28FD2: '',  # 𨿒
    # 0x28FD3: '',  # 𨿓
    # 0x28FD4: '',  # 𨿔
    # 0x28FD5: '',  # 𨿕
    # 0x28FD6: '',  # 𨿖
    # 0x28FD7: '',  # 𨿗
    # 0x28FD8: '',  # 𨿘
    # 0x28FD9: '',  # 𨿙
    # 0x28FDA: '',  # 𨿚
    0x28FDB: 'zhì,xī',  # 𨿛
    # 0x28FDC: '',  # 𨿜
    # 0x28FDD: '',  # 𨿝
    # 0x28FDE: '',  # 𨿞
    # 0x28FDF: '',  # 𨿟
    0x28FE0: 'shuì',  # 𨿠
    0x28FE1: 'chún',  # 𨿡
    0x28FE2: 'dōng',  # 𨿢
    # 0x28FE3: '',  # 𨿣
    # 0x28FE4: '',  # 𨿤
    # 0x28FE5: '',  # 𨿥
    # 0x28FE6: '',  # 𨿦
    # 0x28FE7: '',  # 𨿧
    # 0x28FE8: '',  # 𨿨
    # 0x28FE9: '',  # 𨿩
    # 0x28FEA: '',  # 𨿪
    # 0x28FEB: '',  # 𨿫
    # 0x28FEC: '',  # 𨿬
    0x28FED: 'wéi',  # 𨿭
    # 0x28FEE: '',  # 𨿮
    # 0x28FEF: '',  # 𨿯
    # 0x28FF0: '',  # 𨿰
    # 0x28FF1: '',  # 𨿱
    # 0x28FF2: '',  # 𨿲
    0x28FF3: 'yīng',  # 𨿳
    # 0x28FF4: '',  # 𨿴
    # 0x28FF5: '',  # 𨿵
    # 0x28FF6: '',  # 𨿶
    # 0x28FF7: '',  # 𨿷
    # 0x28FF8: '',  # 𨿸
    # 0x28FF9: '',  # 𨿹
    # 0x28FFA: '',  # 𨿺
    # 0x28FFB: '',  # 𨿻
    # 0x28FFC: '',  # 𨿼
    # 0x28FFD: '',  # 𨿽
    # 0x28FFE: '',  # 𨿾
    0x28FFF: 'chǒng',  # 𨿿
    # 0x29000: '',  # 𩀀
    # 0x29001: '',  # 𩀁
    # 0x29002: '',  # 𩀂
    # 0x29003: '',  # 𩀃
    # 0x29004: '',  # 𩀄
    # 0x29005: '',  # 𩀅
    # 0x29006: '',  # 𩀆
    # 0x29007: '',  # 𩀇
    # 0x29008: '',  # 𩀈
    # 0x29009: '',  # 𩀉
    # 0x2900A: '',  # 𩀊
    0x2900B: 'rún',  # 𩀋
    # 0x2900C: '',  # 𩀌
    # 0x2900D: '',  # 𩀍
    # 0x2900E: '',  # 𩀎
    # 0x2900F: '',  # 𩀏
    # 0x29010: '',  # 𩀐
    # 0x29011: '',  # 𩀑
    # 0x29012: '',  # 𩀒
    # 0x29013: '',  # 𩀓
    # 0x29014: '',  # 𩀔
    # 0x29015: '',  # 𩀕
    0x29016: 'jí',  # 𩀖
    # 0x29017: '',  # 𩀗
    # 0x29018: '',  # 𩀘
    # 0x29019: '',  # 𩀙
    # 0x2901A: '',  # 𩀚
    # 0x2901B: '',  # 𩀛
    0x2901C: 'diāo',  # 𩀜
    # 0x2901D: '',  # 𩀝
    0x2901E: 'cāng',  # 𩀞
    # 0x2901F: '',  # 𩀟
    0x29020: 'kòu,gǔ',  # 𩀠
    # 0x29021: '',  # 𩀡
    # 0x29022: '',  # 𩀢
    0x29023: 'wéi',  # 𩀣
    # 0x29024: '',  # 𩀤
    # 0x29025: '',  # 𩀥
    # 0x29026: '',  # 𩀦
    0x29027: 'cán',  # 𩀧
    # 0x29028: '',  # 𩀨
    # 0x29029: '',  # 𩀩
    0x2902A: 'má',  # 𩀪
    0x2902B: 'òu',  # 𩀫
    # 0x2902C: '',  # 𩀬
    # 0x2902D: '',  # 𩀭
    # 0x2902E: '',  # 𩀮
    # 0x2902F: '',  # 𩀯
    # 0x29030: '',  # 𩀰
    # 0x29031: '',  # 𩀱
    0x29032: 'sǎn',  # 𩀲
    # 0x29033: '',  # 𩀳
    # 0x29034: '',  # 𩀴
    # 0x29035: '',  # 𩀵
    0x29036: 'wéi,huī,mí',  # 𩀶
    # 0x29037: '',  # 𩀷
    # 0x29038: '',  # 𩀸
    # 0x29039: '',  # 𩀹
    # 0x2903A: '',  # 𩀺
    # 0x2903B: '',  # 𩀻
    0x2903C: 'sǎn',  # 𩀼
    # 0x2903D: '',  # 𩀽
    # 0x2903E: '',  # 𩀾
    0x2903F: 'jīn',  # 𩀿
    # 0x29040: '',  # 𩁀
    # 0x29041: '',  # 𩁁
    # 0x29042: '',  # 𩁂
    # 0x29043: '',  # 𩁃
    # 0x29044: '',  # 𩁄
    # 0x29045: '',  # 𩁅
    # 0x29046: '',  # 𩁆
    # 0x29047: '',  # 𩁇
    # 0x29048: '',  # 𩁈
    # 0x29049: '',  # 𩁉
    # 0x2904A: '',  # 𩁊
    # 0x2904B: '',  # 𩁋
    0x2904C: 'wéi',  # 𩁌
    # 0x2904D: '',  # 𩁍
    # 0x2904E: '',  # 𩁎
    # 0x2904F: '',  # 𩁏
    # 0x29050: '',  # 𩁐
    # 0x29051: '',  # 𩁑
    # 0x29052: '',  # 𩁒
    # 0x29053: '',  # 𩁓
    # 0x29054: '',  # 𩁔
    # 0x29055: '',  # 𩁕
    # 0x29056: '',  # 𩁖
    # 0x29057: '',  # 𩁗
    # 0x29058: '',  # 𩁘
    # 0x29059: '',  # 𩁙
    # 0x2905A: '',  # 𩁚
    # 0x2905B: '',  # 𩁛
    # 0x2905C: '',  # 𩁜
    # 0x2905D: '',  # 𩁝
    0x2905E: 'cài',  # 𩁞
    0x2905F: 'lí',  # 𩁟
    # 0x29060: '',  # 𩁠
    # 0x29061: '',  # 𩁡
    # 0x29062: '',  # 𩁢
    # 0x29063: '',  # 𩁣
    # 0x29064: '',  # 𩁤
    # 0x29065: '',  # 𩁥
    # 0x29066: '',  # 𩁦
    # 0x29067: '',  # 𩁧
    # 0x29068: '',  # 𩁨
    # 0x29069: '',  # 𩁩
    # 0x2906A: '',  # 𩁪
    # 0x2906B: '',  # 𩁫
    # 0x2906C: '',  # 𩁬
    # 0x2906D: '',  # 𩁭
    # 0x2906E: '',  # 𩁮
    0x2906F: 'yuè',  # 𩁯
    # 0x29070: '',  # 𩁰
    # 0x29071: '',  # 𩁱
    # 0x29072: '',  # 𩁲
    # 0x29073: '',  # 𩁳
    0x29074: 'yūn',  # 𩁴
    # 0x29075: '',  # 𩁵
    # 0x29076: '',  # 𩁶
    0x29077: 'chēng',  # 𩁷
    # 0x29078: '',  # 𩁸
    0x29079: 'yú',  # 𩁹
    0x2907A: 'shān',  # 𩁺
    # 0x2907B: '',  # 𩁻
    # 0x2907C: '',  # 𩁼
    # 0x2907D: '',  # 𩁽
    # 0x2907E: '',  # 𩁾
    0x2907F: 'nüè',  # 𩁿
    # 0x29080: '',  # 𩂀
    # 0x29081: '',  # 𩂁
    0x29082: 'hū',  # 𩂂
    0x29083: 'shài',  # 𩂃
    0x29084: 'tún',  # 𩂄
    # 0x29085: '',  # 𩂅
    0x29086: 'fǒu,fù',  # 𩂆
    # 0x29087: '',  # 𩂇
    0x29088: 'qìn',  # 𩂈
    0x29089: 'xū,chēn',  # 𩂉
    # 0x2908A: '',  # 𩂊
    # 0x2908B: '',  # 𩂋
    # 0x2908C: '',  # 𩂌
    0x2908D: 'chuān',  # 𩂍
    0x2908E: 'fù',  # 𩂎
    # 0x2908F: '',  # 𩂏
    # 0x29090: '',  # 𩂐
    # 0x29091: '',  # 𩂑
    0x29092: 'yì,ài',  # 𩂒
    0x29093: 'dōng',  # 𩂓
    0x29094: 'fú',  # 𩂔
    0x29095: 'fú',  # 𩂕
    0x29096: 'zé',  # 𩂖
    0x29097: 'pù',  # 𩂗
    # 0x29098: '',  # 𩂘
    0x29099: 'líng',  # 𩂙
    # 0x2909A: '',  # 𩂚
    # 0x2909B: '',  # 𩂛
    # 0x2909C: '',  # 𩂜
    0x2909D: 'shài,yīng',  # 𩂝
    0x2909E: 'pào',  # 𩂞
    # 0x2909F: '',  # 𩂟
    # 0x290A0: '',  # 𩂠
    # 0x290A1: '',  # 𩂡
    0x290A2: 'yín,ái',  # 𩂢
    0x290A3: 'luò',  # 𩂣
    0x290A4: 'huà',  # 𩂤
    0x290A5: 'yìn',  # 𩂥
    0x290A6: 'bèng',  # 𩂦
    0x290A7: 'yū',  # 𩂧
    0x290A8: 'shè',  # 𩂨
    # 0x290A9: '',  # 𩂩
    0x290AA: 'xiè',  # 𩂪
    0x290AB: 'chǔ',  # 𩂫
    # 0x290AC: '',  # 𩂬
    # 0x290AD: '',  # 𩂭
    # 0x290AE: '',  # 𩂮
    # 0x290AF: '',  # 𩂯
    # 0x290B0: '',  # 𩂰
    # 0x290B1: '',  # 𩂱
    # 0x290B2: '',  # 𩂲
    # 0x290B3: '',  # 𩂳
    0x290B4: 'shè',  # 𩂴
    0x290B5: 'diàn',  # 𩂵
    # 0x290B6: '',  # 𩂶
    # 0x290B7: '',  # 𩂷
    # 0x290B8: '',  # 𩂸
    0x290B9: 'yì',  # 𩂹
    # 0x290BA: '',  # 𩂺
    0x290BB: 'chè',  # 𩂻
    0x290BC: 'gěng',  # 𩂼
    0x290BD: 'lóng',  # 𩂽
    0x290BE: 'píng',  # 𩂾
    0x290BF: 'yǔn',  # 𩂿
    0x290C0: 'yàn',  # 𩃀
    0x290C1: 'mò',  # 𩃁
    # 0x290C2: '',  # 𩃂
    0x290C3: 'suī',  # 𩃃
    # 0x290C4: '',  # 𩃄
    # 0x290C5: '',  # 𩃅
    # 0x290C6: '',  # 𩃆
    # 0x290C7: '',  # 𩃇
    # 0x290C8: '',  # 𩃈
    # 0x290C9: '',  # 𩃉
    # 0x290CA: '',  # 𩃊
    0x290CB: 'jìng',  # 𩃋
    # 0x290CC: '',  # 𩃌
    0x290CD: 'sòng',  # 𩃍
    0x290CE: 'páng',  # 𩃎
    # 0x290CF: '',  # 𩃏
    0x290D0: 'yá',  # 𩃐
    0x290D1: 'sè',  # 𩃑
    0x290D2: 'duǒ',  # 𩃒
    # 0x290D3: '',  # 𩃓
    0x290D4: 'jiān',  # 𩃔
    0x290D5: 'chuáng',  # 𩃕
    0x290D6: 'xiè',  # 𩃖
    # 0x290D7: '',  # 𩃗
    0x290D8: 'tuán',  # 𩃘
    0x290D9: 'gōng',  # 𩃙
    0x290DA: 'xuàn',  # 𩃚
    # 0x290DB: '',  # 𩃛
    0x290DC: 'lā',  # 𩃜
    # 0x290DD: '',  # 𩃝
    0x290DE: 'líng',  # 𩃞
    # 0x290DF: '',  # 𩃟
    0x290E0: 'dài',  # 𩃠
    0x290E1: 'zhá',  # 𩃡
    # 0x290E2: '',  # 𩃢
    # 0x290E3: '',  # 𩃣
    # 0x290E4: '',  # 𩃤
    # 0x290E5: '',  # 𩃥
    # 0x290E6: '',  # 𩃦
    # 0x290E7: '',  # 𩃧
    # 0x290E8: '',  # 𩃨
    # 0x290E9: '',  # 𩃩
    # 0x290EA: '',  # 𩃪
    # 0x290EB: '',  # 𩃫
    0x290EC: 'yīn',  # 𩃬
    0x290ED: 'sōng',  # 𩃭
    # 0x290EE: '',  # 𩃮
    0x290EF: 'yǔ',  # 𩃯
    0x290F0: 'tuó',  # 𩃰
    0x290F1: 'tuó',  # 𩃱
    # 0x290F2: '',  # 𩃲
    # 0x290F3: '',  # 𩃳
    0x290F4: 'bà',  # 𩃴
    0x290F5: 'rǎn',  # 𩃵
    0x290F6: 'bó',  # 𩃶
    0x290F7: 'dài',  # 𩃷
    # 0x290F8: '',  # 𩃸
    0x290F9: 'zhá,zhǎ',  # 𩃹
    0x290FA: 'hóu',  # 𩃺
    # 0x290FB: '',  # 𩃻
    # 0x290FC: '',  # 𩃼
    # 0x290FD: '',  # 𩃽
    0x290FE: 'huǐ',  # 𩃾
    # 0x290FF: '',  # 𩃿
    # 0x29100: '',  # 𩄀
    # 0x29101: '',  # 𩄁
    # 0x29102: '',  # 𩄂
    # 0x29103: '',  # 𩄃
    # 0x29104: '',  # 𩄄
    0x29105: 'lú',  # 𩄅
    # 0x29106: '',  # 𩄆
    # 0x29107: '',  # 𩄇
    # 0x29108: '',  # 𩄈
    # 0x29109: '',  # 𩄉
    0x2910A: 'lìng',  # 𩄊
    0x2910B: 'rú',  # 𩄋
    # 0x2910C: '',  # 𩄌
    # 0x2910D: '',  # 𩄍
    # 0x2910E: '',  # 𩄎
    # 0x2910F: '',  # 𩄏
    # 0x29110: '',  # 𩄐
    # 0x29111: '',  # 𩄑
    # 0x29112: '',  # 𩄒
    # 0x29113: '',  # 𩄓
    # 0x29114: '',  # 𩄔
    0x29115: 'dàn',  # 𩄕
    0x29116: 'méng',  # 𩄖
    0x29117: 'xià',  # 𩄗
    0x29118: 'wěng',  # 𩄘
    0x29119: 'hán',  # 𩄙
    0x2911A: 'zī',  # 𩄚
    0x2911B: 'zhèn',  # 𩄛
    0x2911C: 'sè',  # 𩄜
    0x2911D: 'cuó',  # 𩄝
    0x2911E: 'lì',  # 𩄞
    # 0x2911F: '',  # 𩄟
    0x29120: 'diān',  # 𩄠
    0x29121: 'lián',  # 𩄡
    0x29122: 'gòu',  # 𩄢
    # 0x29123: '',  # 𩄣
    # 0x29124: '',  # 𩄤
    # 0x29125: '',  # 𩄥
    0x29126: 'péng',  # 𩄦
    # 0x29127: '',  # 𩄧
    # 0x29128: '',  # 𩄨
    # 0x29129: '',  # 𩄩
    0x2912A: 'yīng',  # 𩄪
    # 0x2912B: '',  # 𩄫
    0x2912C: 'hòu',  # 𩄬
    # 0x2912D: '',  # 𩄭
    0x2912E: 'duì',  # 𩄮
    0x2912F: 'wù',  # 𩄯
    # 0x29130: '',  # 𩄰
    # 0x29131: '',  # 𩄱
    # 0x29132: '',  # 𩄲
    # 0x29133: '',  # 𩄳
    # 0x29134: '',  # 𩄴
    # 0x29135: '',  # 𩄵
    # 0x29136: '',  # 𩄶
    0x29137: 'piào',  # 𩄷
    0x29138: 'hè',  # 𩄸
    # 0x29139: '',  # 𩄹
    0x2913A: 'lóng',  # 𩄺
    0x2913B: 'mò',  # 𩄻
    0x2913C: 'fěi',  # 𩄼
    0x2913D: 'lǚ',  # 𩄽
    0x2913E: 'zé',  # 𩄾
    0x2913F: 'bó',  # 𩄿
    0x29140: 'diàn,zhí',  # 𩅀
    0x29141: 'mǎng',  # 𩅁
    # 0x29142: '',  # 𩅂
    0x29143: 'zhuàng,chóng',  # 𩅃
    0x29144: 'lù',  # 𩅄
    0x29145: 'pāng',  # 𩅅
    0x29146: 'duì',  # 𩅆
    0x29147: 'bù',  # 𩅇
    # 0x29148: '',  # 𩅈
    0x29149: 'zhōng',  # 𩅉
    # 0x2914A: '',  # 𩅊
    # 0x2914B: '',  # 𩅋
    0x2914C: 'chēn',  # 𩅌
    0x2914D: 'màn',  # 𩅍
    # 0x2914E: '',  # 𩅎
    # 0x2914F: '',  # 𩅏
    # 0x29150: '',  # 𩅐
    # 0x29151: '',  # 𩅑
    # 0x29152: '',  # 𩅒
    # 0x29153: '',  # 𩅓
    # 0x29154: '',  # 𩅔
    # 0x29155: '',  # 𩅕
    0x29156: 'xī',  # 𩅖
    # 0x29157: '',  # 𩅗
    # 0x29158: '',  # 𩅘
    # 0x29159: '',  # 𩅙
    # 0x2915A: '',  # 𩅚
    # 0x2915B: '',  # 𩅛
    # 0x2915C: '',  # 𩅜
    0x2915D: 'ǎn',  # 𩅝
    0x2915E: 'zhōng,chòng',  # 𩅞
    # 0x2915F: '',  # 𩅟
    0x29160: 'nàn',  # 𩅠
    0x29161: 'tuò',  # 𩅡
    0x29162: 'hé',  # 𩅢
    0x29163: 'duì',  # 𩅣
    # 0x29164: '',  # 𩅤
    0x29165: 'duì',  # 𩅥
    0x29166: 'wān,dān',  # 𩅦
    0x29167: 'zhōng',  # 𩅧
    0x29168: 'cén,shèn',  # 𩅨
    0x29169: 'lì',  # 𩅩
    0x2916A: 'shuāng',  # 𩅪
    # 0x2916B: '',  # 𩅫
    # 0x2916C: '',  # 𩅬
    # 0x2916D: '',  # 𩅭
    0x2916E: 'cén',  # 𩅮
    # 0x2916F: '',  # 𩅯
    0x29170: 'sī',  # 𩅰
    # 0x29171: '',  # 𩅱
    0x29172: 'duì',  # 𩅲
    # 0x29173: '',  # 𩅳
    0x29174: 'hūn',  # 𩅴
    # 0x29175: '',  # 𩅵
    # 0x29176: '',  # 𩅶
    # 0x29177: '',  # 𩅷
    0x29178: 'liù',  # 𩅸
    # 0x29179: '',  # 𩅹
    # 0x2917A: '',  # 𩅺
    # 0x2917B: '',  # 𩅻
    0x2917C: 'jiān,jiàn',  # 𩅼
    0x2917D: 'nóng',  # 𩅽
    0x2917E: 'dàn',  # 𩅾
    0x2917F: 'fù',  # 𩅿
    0x29180: 'huò',  # 𩆀
    0x29181: 'huì,wèi',  # 𩆁
    0x29182: 'cí',  # 𩆂
    # 0x29183: '',  # 𩆃
    0x29184: 'yǒng',  # 𩆄
    0x29185: 'sà',  # 𩆅
    0x29186: 'tíng',  # 𩆆
    # 0x29187: '',  # 𩆇
    # 0x29188: '',  # 𩆈
    # 0x29189: '',  # 𩆉
    # 0x2918A: '',  # 𩆊
    # 0x2918B: '',  # 𩆋
    # 0x2918C: '',  # 𩆌
    # 0x2918D: '',  # 𩆍
    0x2918E: 'liù',  # 𩆎
    # 0x2918F: '',  # 𩆏
    # 0x29190: '',  # 𩆐
    0x29191: 'suān',  # 𩆑
    0x29192: 'líng',  # 𩆒
    0x29193: 'mán,màn',  # 𩆓
    0x29194: 'diàn',  # 𩆔
    # 0x29195: '',  # 𩆕
    # 0x29196: '',  # 𩆖
    # 0x29197: '',  # 𩆗
    0x29198: 'pāo',  # 𩆘
    # 0x29199: '',  # 𩆙
    0x2919A: 'líng',  # 𩆚
    # 0x2919B: '',  # 𩆛
    0x2919C: 'líng',  # 𩆜
    0x2919D: 'lì',  # 𩆝
    # 0x2919E: '',  # 𩆞
    0x2919F: 'nóu',  # 𩆟
    # 0x291A0: '',  # 𩆠
    # 0x291A1: '',  # 𩆡
    # 0x291A2: '',  # 𩆢
    0x291A3: 'liè',  # 𩆣
    0x291A4: 'shǎn',  # 𩆤
    # 0x291A5: '',  # 𩆥
    0x291A6: 'fèi',  # 𩆦
    # 0x291A7: '',  # 𩆧
    # 0x291A8: '',  # 𩆨
    0x291A9: 'shù',  # 𩆩
    # 0x291AA: '',  # 𩆪
    0x291AB: 'shǎn',  # 𩆫
    # 0x291AC: '',  # 𩆬
    # 0x291AD: '',  # 𩆭
    0x291AE: 'líng',  # 𩆮
    0x291AF: 'zhàn,jiān',  # 𩆯
    # 0x291B0: '',  # 𩆰
    0x291B1: 'bīn',  # 𩆱
    0x291B2: 'lí',  # 𩆲
    # 0x291B3: '',  # 𩆳
    # 0x291B4: '',  # 𩆴
    0x291B5: 'sī,xiàn',  # 𩆵
    0x291B6: 'ráng',  # 𩆶
    0x291B7: 'jiān',  # 𩆷
    0x291B8: 'zhuó',  # 𩆸
    # 0x291B9: '',  # 𩆹
    # 0x291BA: '',  # 𩆺
    0x291BB: 'líng',  # 𩆻
    0x291BC: 'líng',  # 𩆼
    0x291BD: 'mèng',  # 𩆽
    # 0x291BE: '',  # 𩆾
    0x291BF: 'shuāng',  # 𩆿
    # 0x291C0: '',  # 𩇀
    # 0x291C1: '',  # 𩇁
    # 0x291C2: '',  # 𩇂
    # 0x291C3: '',  # 𩇃
    0x291C4: 'líng',  # 𩇄
    # 0x291C5: '',  # 𩇅
    # 0x291C6: '',  # 𩇆
    0x291C7: 'hùn',  # 𩇇
    # 0x291C8: '',  # 𩇈
    # 0x291C9: '',  # 𩇉
    # 0x291CA: '',  # 𩇊
    # 0x291CB: '',  # 𩇋
    # 0x291CC: '',  # 𩇌
    # 0x291CD: '',  # 𩇍
    0x291CE: 'líng',  # 𩇎
    0x291CF: 'jiān',  # 𩇏
    0x291D0: 'qú',  # 𩇐
    # 0x291D1: '',  # 𩇑
    # 0x291D2: '',  # 𩇒
    # 0x291D3: '',  # 𩇓
    0x291D4: 'nóng',  # 𩇔
    0x291D5: 'jìng',  # 𩇕
    0x291D6: 'chēn',  # 𩇖
    # 0x291D7: '',  # 𩇗
    # 0x291D8: '',  # 𩇘
    # 0x291D9: '',  # 𩇙
    # 0x291DA: '',  # 𩇚
    # 0x291DB: '',  # 𩇛
    0x291DC: 'zhēn,chēng',  # 𩇜
    0x291DD: 'qìng',  # 𩇝
    # 0x291DE: '',  # 𩇞
    0x291DF: 'qìng',  # 𩇟
    0x291E0: 'è,yǎn',  # 𩇠
    # 0x291E1: '',  # 𩇡
    # 0x291E2: '',  # 𩇢
    0x291E3: 'sè',  # 𩇣
    # 0x291E4: '',  # 𩇤
    # 0x291E5: '',  # 𩇥
    # 0x291E6: '',  # 𩇦
    # 0x291E7: '',  # 𩇧
    # 0x291E8: '',  # 𩇨
    0x291E9: 'bèi',  # 𩇩
    # 0x291EA: '',  # 𩇪
    0x291EB: 'fēi',  # 𩇫
    # 0x291EC: '',  # 𩇬
    # 0x291ED: '',  # 𩇭
    0x291EE: 'fèi',  # 𩇮
    0x291EF: 'féi',  # 𩇯
    # 0x291F0: '',  # 𩇰
    # 0x291F1: '',  # 𩇱
    # 0x291F2: '',  # 𩇲
    # 0x291F3: '',  # 𩇳
    0x291F4: 'fāng',  # 𩇴
    0x291F5: 'kǔ',  # 𩇵
    # 0x291F6: '',  # 𩇶
    # 0x291F7: '',  # 𩇷
    # 0x291F8: '',  # 𩇸
    # 0x291F9: '',  # 𩇹
    0x291FA: 'zá',  # 𩇺
    0x291FB: 'huì',  # 𩇻
    # 0x291FC: '',  # 𩇼
    0x291FD: 'féi',  # 𩇽
    # 0x291FE: '',  # 𩇾
    # 0x291FF: '',  # 𩇿
    # 0x29200: '',  # 𩈀
    0x29201: 'duì',  # 𩈁
    # 0x29202: '',  # 𩈂
    # 0x29203: '',  # 𩈃
    # 0x29204: '',  # 𩈄
    # 0x29205: '',  # 𩈅
    0x29206: 'pā',  # 𩈆
    0x29207: 'niǔ',  # 𩈇
    0x29208: 'pàng',  # 𩈈
    0x29209: 'dàn',  # 𩈉
    0x2920A: 'dān,dàn',  # 𩈊
    0x2920B: 'ài',  # 𩈋
    # 0x2920C: '',  # 𩈌
    0x2920D: 'tiǎn',  # 𩈍
    0x2920E: 'chǎo',  # 𩈎
    0x2920F: 'ǎo,yǒu',  # 𩈏
    0x29210: 'mèi',  # 𩈐
    0x29211: 'nǎn',  # 𩈑
    # 0x29212: '',  # 𩈒
    # 0x29213: '',  # 𩈓
    0x29214: 'bò',  # 𩈔
    0x29215: 'yù,chì',  # 𩈕
    0x29216: 'xiān,hān',  # 𩈖
    0x29217: 'mài',  # 𩈗
    # 0x29218: '',  # 𩈘
    # 0x29219: '',  # 𩈙
    0x2921A: 'pīng',  # 𩈚
    # 0x2921B: '',  # 𩈛
    0x2921C: 'duī',  # 𩈜
    # 0x2921D: '',  # 𩈝
    0x2921E: 'dào',  # 𩈞
    # 0x2921F: '',  # 𩈟
    # 0x29220: '',  # 𩈠
    0x29221: 'xìng',  # 𩈡
    0x29222: 'nì,nǜ',  # 𩈢
    0x29223: 'hān',  # 𩈣
    0x29224: 'chù',  # 𩈤
    0x29225: 'shuǎ',  # 𩈥
    0x29226: 'mǎn',  # 𩈦
    # 0x29227: '',  # 𩈧
    # 0x29228: '',  # 𩈨
    # 0x29229: '',  # 𩈩
    # 0x2922A: '',  # 𩈪
    # 0x2922B: '',  # 𩈫
    0x2922C: 'wàn',  # 𩈬
    0x2922D: 'yì',  # 𩈭
    0x2922E: 'diào',  # 𩈮
    0x2922F: 'yān',  # 𩈯
    # 0x29230: '',  # 𩈰
    0x29231: 'wò',  # 𩈱
    0x29232: 'suàn',  # 𩈲
    # 0x29233: '',  # 𩈳
    0x29234: 'ǎn',  # 𩈴
    0x29235: 'lán',  # 𩈵
    0x29236: 'nǎn',  # 𩈶
    # 0x29237: '',  # 𩈷
    0x29238: 'qiǔ',  # 𩈸
    0x29239: 'miàn',  # 𩈹
    0x2923A: 'nuǒ',  # 𩈺
    0x2923B: 'cán',  # 𩈻
    0x2923C: 'cǎn',  # 𩈼
    # 0x2923D: '',  # 𩈽
    # 0x2923E: '',  # 𩈾
    # 0x2923F: '',  # 𩈿
    0x29240: 'làn',  # 𩉀
    0x29241: 'tiǎn',  # 𩉁
    0x29242: 'yè',  # 𩉂
    # 0x29243: '',  # 𩉃
    0x29244: 'niǎn',  # 𩉄
    # 0x29245: '',  # 𩉅
    0x29246: 'shuǎ',  # 𩉆
    # 0x29247: '',  # 𩉇
    # 0x29248: '',  # 𩉈
    # 0x29249: '',  # 𩉉
    # 0x2924A: '',  # 𩉊
    0x2924B: 'cí',  # 𩉋
    # 0x2924C: '',  # 𩉌
    0x2924D: 'jiǎn',  # 𩉍
    # 0x2924E: '',  # 𩉎
    # 0x2924F: '',  # 𩉏
    0x29250: 'gàn',  # 𩉐
    # 0x29251: '',  # 𩉑
    # 0x29252: '',  # 𩉒
    # 0x29253: '',  # 𩉓
    0x29254: 'jiàn',  # 𩉔
    0x29255: 'guó',  # 𩉕
    # 0x29256: '',  # 𩉖
    0x29257: 'zhān',  # 𩉗
    # 0x29258: '',  # 𩉘
    0x29259: 'luǒ',  # 𩉙
    # 0x2925A: '',  # 𩉚
    # 0x2925B: '',  # 𩉛
    0x2925C: 'hàng',  # 𩉜
    0x2925D: 'guì',  # 𩉝
    # 0x2925E: '',  # 𩉞
    # 0x2925F: '',  # 𩉟
    # 0x29260: '',  # 𩉠
    0x29261: 'jiá',  # 𩉡
    0x29262: 'jǐ',  # 𩉢
    # 0x29263: '',  # 𩉣
    # 0x29264: '',  # 𩉤
    0x29265: 'xuàn',  # 𩉥
    # 0x29266: '',  # 𩉦
    0x29267: 'fēng',  # 𩉧
    # 0x29268: '',  # 𩉨
    # 0x29269: '',  # 𩉩
    # 0x2926A: '',  # 𩉪
    0x2926B: 'bì',  # 𩉫
    0x2926C: 'qí,chí',  # 𩉬
    # 0x2926D: '',  # 𩉭
    # 0x2926E: '',  # 𩉮
    0x2926F: 'yuán',  # 𩉯
    0x29270: 'àng',  # 𩉰
    0x29271: 'dī',  # 𩉱
    # 0x29272: '',  # 𩉲
    # 0x29273: '',  # 𩉳
    0x29274: 'è',  # 𩉴
    0x29275: 'fén',  # 𩉵
    # 0x29276: '',  # 𩉶
    # 0x29277: '',  # 𩉷
    0x29278: 'jù',  # 𩉸
    0x29279: 'nǐ',  # 𩉹
    0x2927A: 'tuó',  # 𩉺
    # 0x2927B: '',  # 𩉻
    0x2927C: 'shēn',  # 𩉼
    0x2927D: 'fú',  # 𩉽
    0x2927E: 'xiá',  # 𩉾
    0x2927F: 'qú',  # 𩉿
    0x29280: 'pò',  # 𩊀
    0x29281: 'wǎn',  # 𩊁
    0x29282: 'líng',  # 𩊂
    0x29283: 'mà',  # 𩊃
    0x29284: 'zhòu',  # 𩊄
    0x29285: 'bào',  # 𩊅
    # 0x29286: '',  # 𩊆
    0x29287: 'yù',  # 𩊇
    # 0x29288: '',  # 𩊈
    # 0x29289: '',  # 𩊉
    # 0x2928A: '',  # 𩊊
    # 0x2928B: '',  # 𩊋
    0x2928C: 'běng',  # 𩊌
    0x2928D: 'mài',  # 𩊍
    # 0x2928E: '',  # 𩊎
    0x2928F: 'jiā',  # 𩊏
    # 0x29290: '',  # 𩊐
    0x29291: 'yǎng',  # 𩊑
    # 0x29292: '',  # 𩊒
    0x29293: 'kuǎ,kù',  # 𩊓
    0x29294: 'jiào',  # 𩊔
    # 0x29295: '',  # 𩊕
    0x29296: 'bǐng',  # 𩊖
    # 0x29297: '',  # 𩊗
    # 0x29298: '',  # 𩊘
    # 0x29299: '',  # 𩊙
    0x2929A: 'luò',  # 𩊚
    0x2929B: 'guǐ',  # 𩊛
    0x2929C: 'duò',  # 𩊜
    0x2929D: 'zhì',  # 𩊝
    # 0x2929E: '',  # 𩊞
    # 0x2929F: '',  # 𩊟
    # 0x292A0: '',  # 𩊠
    0x292A1: 'zhèn',  # 𩊡
    0x292A2: 'è',  # 𩊢
    0x292A3: 'zhū',  # 𩊣
    0x292A4: 'bá',  # 𩊤
    # 0x292A5: '',  # 𩊥
    # 0x292A6: '',  # 𩊦
    # 0x292A7: '',  # 𩊧
    0x292A8: 'zhèn',  # 𩊨
    0x292A9: 'fēng,féng',  # 𩊩
    0x292AA: 'dòu',  # 𩊪
    0x292AB: 'niǎn',  # 𩊫
    0x292AC: 'bù',  # 𩊬
    0x292AD: 'duì',  # 𩊭
    0x292AE: 'shā,suō',  # 𩊮
    0x292AF: 'sè',  # 𩊯
    0x292B0: 'bì',  # 𩊰
    # 0x292B1: '',  # 𩊱
    # 0x292B2: '',  # 𩊲
    # 0x292B3: '',  # 𩊳
    0x292B4: 'zhì',  # 𩊴
    0x292B5: 'zhé',  # 𩊵
    0x292B6: 'bù',  # 𩊶
    # 0x292B7: '',  # 𩊷
    # 0x292B8: '',  # 𩊸
    # 0x292B9: '',  # 𩊹
    0x292BA: 'jué',  # 𩊺
    0x292BB: 'xùn',  # 𩊻
    # 0x292BC: '',  # 𩊼
    # 0x292BD: '',  # 𩊽
    # 0x292BE: '',  # 𩊾
    0x292BF: 'xì',  # 𩊿
    # 0x292C0: '',  # 𩋀
    0x292C1: 'zhuó',  # 𩋁
    0x292C2: 'bài',  # 𩋂
    0x292C3: 'yáo,táo',  # 𩋃
    0x292C4: 'chǒu',  # 𩋄
    0x292C5: 'tà',  # 𩋅
    0x292C6: 'qiān',  # 𩋆
    # 0x292C7: '',  # 𩋇
    0x292C8: 'nào',  # 𩋈
    0x292C9: 'yù',  # 𩋉
    0x292CA: 'è',  # 𩋊
    0x292CB: 'jiān',  # 𩋋
    0x292CC: 'yì',  # 𩋌
    0x292CD: 'xiāo',  # 𩋍
    # 0x292CE: '',  # 𩋎
    0x292CF: 'niè',  # 𩋏
    # 0x292D0: '',  # 𩋐
    # 0x292D1: '',  # 𩋑
    0x292D2: 'bīng',  # 𩋒
    # 0x292D3: '',  # 𩋓
    0x292D4: 'xié',  # 𩋔
    # 0x292D5: '',  # 𩋕
    # 0x292D6: '',  # 𩋖
    0x292D7: 'guǒ',  # 𩋗
    0x292D8: 'wā,xié',  # 𩋘
    0x292D9: 'diào',  # 𩋙
    # 0x292DA: '',  # 𩋚
    # 0x292DB: '',  # 𩋛
    0x292DC: 'jū',  # 𩋜
    0x292DD: 'suǒ',  # 𩋝
    0x292DE: 'dié',  # 𩋞
    0x292DF: 'fú,fù',  # 𩋟
    0x292E0: 'miǎn',  # 𩋠
    0x292E1: 'shì',  # 𩋡
    0x292E2: 'xuàn,yùn',  # 𩋢
    0x292E3: 'tí',  # 𩋣
    0x292E4: 'yù',  # 𩋤
    # 0x292E5: '',  # 𩋥
    # 0x292E6: '',  # 𩋦
    0x292E7: 'xié,kài',  # 𩋧
    0x292E8: 'fú',  # 𩋨
    0x292E9: 'zhì',  # 𩋩
    0x292EA: 'nǐ',  # 𩋪
    0x292EB: 'xuàn',  # 𩋫
    0x292EC: 'yáng',  # 𩋬
    # 0x292ED: '',  # 𩋭
    0x292EE: 'fěng,bāng',  # 𩋮
    0x292EF: 'zòng',  # 𩋯
    0x292F0: 'zhòu',  # 𩋰
    0x292F1: 'xuān',  # 𩋱
    # 0x292F2: '',  # 𩋲
    # 0x292F3: '',  # 𩋳
    # 0x292F4: '',  # 𩋴
    0x292F5: 'zhū',  # 𩋵
    # 0x292F6: '',  # 𩋶
    0x292F7: 'la',  # 𩋷
    # 0x292F8: '',  # 𩋸
    0x292F9: 'yìng',  # 𩋹
    0x292FA: 'gào',  # 𩋺
    0x292FB: 'kuò',  # 𩋻
    # 0x292FC: '',  # 𩋼
    0x292FD: 'é',  # 𩋽
    0x292FE: 'wéi,wěi,xuē',  # 𩋾
    0x292FF: 'méi',  # 𩋿
    # 0x29300: '',  # 𩌀
    # 0x29301: '',  # 𩌁
    # 0x29302: '',  # 𩌂
    0x29303: 'huái,guì',  # 𩌃
    0x29304: 'chǒu,zhōu',  # 𩌄
    # 0x29305: '',  # 𩌅
    0x29306: 'suǒ',  # 𩌆
    0x29307: 'tà',  # 𩌇
    0x29308: 'suǒ',  # 𩌈
    0x29309: 'tà',  # 𩌉
    0x2930A: 'xuè',  # 𩌊
    # 0x2930B: '',  # 𩌋
    0x2930C: 'gǒng',  # 𩌌
    0x2930D: 'jiǎ',  # 𩌍
    # 0x2930E: '',  # 𩌎
    0x2930F: 'bó,fú,bù,fù',  # 𩌏
    0x29310: 'tà',  # 𩌐
    0x29311: 'yuǎn',  # 𩌑
    # 0x29312: '',  # 𩌒
    # 0x29313: '',  # 𩌓
    # 0x29314: '',  # 𩌔
    # 0x29315: '',  # 𩌕
    # 0x29316: '',  # 𩌖
    # 0x29317: '',  # 𩌗
    0x29318: 'tà',  # 𩌘
    # 0x29319: '',  # 𩌙
    # 0x2931A: '',  # 𩌚
    # 0x2931B: '',  # 𩌛
    # 0x2931C: '',  # 𩌜
    0x2931D: 'chuí',  # 𩌝
    # 0x2931E: '',  # 𩌞
    # 0x2931F: '',  # 𩌟
    0x29320: 'xiōng',  # 𩌠
    0x29321: 'hé,juē',  # 𩌡
    0x29322: 'suō',  # 𩌢
    # 0x29323: '',  # 𩌣
    # 0x29324: '',  # 𩌤
    # 0x29325: '',  # 𩌥
    0x29326: 'xǐ',  # 𩌦
    0x29327: 'mò',  # 𩌧
    0x29328: 'chóng',  # 𩌨
    0x29329: 'suī',  # 𩌩
    0x2932A: 'zé',  # 𩌪
    0x2932B: 'lù',  # 𩌫
    0x2932C: 'zhāng',  # 𩌬
    0x2932D: 'luò',  # 𩌭
    0x2932E: 'xù',  # 𩌮
    0x2932F: 'jiān',  # 𩌯
    0x29330: 'shān',  # 𩌰
    # 0x29331: '',  # 𩌱
    0x29332: 'xù',  # 𩌲
    # 0x29333: '',  # 𩌳
    # 0x29334: '',  # 𩌴
    # 0x29335: '',  # 𩌵
    # 0x29336: '',  # 𩌶
    # 0x29337: '',  # 𩌷
    # 0x29338: '',  # 𩌸
    # 0x29339: '',  # 𩌹
    # 0x2933A: '',  # 𩌺
    # 0x2933B: '',  # 𩌻
    # 0x2933C: '',  # 𩌼
    # 0x2933D: '',  # 𩌽
    0x2933E: 'jiǎng',  # 𩌾
    # 0x2933F: '',  # 𩌿
    # 0x29340: '',  # 𩍀
    0x29341: 'bèi',  # 𩍁
    0x29342: 'bào',  # 𩍂
    0x29343: 'mái',  # 𩍃
    # 0x29344: '',  # 𩍄
    0x29345: 'tóng',  # 𩍅
    0x29346: 'xì',  # 𩍆
    # 0x29347: '',  # 𩍇
    # 0x29348: '',  # 𩍈
    0x29349: 'róng',  # 𩍉
    # 0x2934A: '',  # 𩍊
    0x2934B: 'shéng',  # 𩍋
    0x2934C: 'zhòu',  # 𩍌
    # 0x2934D: '',  # 𩍍
    0x2934E: 'jiān',  # 𩍎
    0x2934F: 'fù',  # 𩍏
    0x29350: 'dèng',  # 𩍐
    # 0x29351: '',  # 𩍑
    # 0x29352: '',  # 𩍒
    0x29353: 'yōng',  # 𩍓
    0x29354: 'jū,qū',  # 𩍔
    # 0x29355: '',  # 𩍕
    0x29356: 'yì',  # 𩍖
    0x29357: 'bāng',  # 𩍗
    # 0x29358: '',  # 𩍘
    0x29359: 'sè',  # 𩍙
    0x2935A: 'suì',  # 𩍚
    # 0x2935B: '',  # 𩍛
    0x2935C: 'duó',  # 𩍜
    0x2935D: 'xiè',  # 𩍝
    # 0x2935E: '',  # 𩍞
    # 0x2935F: '',  # 𩍟
    # 0x29360: '',  # 𩍠
    0x29361: 'huán',  # 𩍡
    # 0x29362: '',  # 𩍢
    # 0x29363: '',  # 𩍣
    # 0x29364: '',  # 𩍤
    0x29365: 'rǔ',  # 𩍥
    0x29366: 'nǐ',  # 𩍦
    0x29367: 'zhòu',  # 𩍧
    0x29368: 'guì',  # 𩍨
    # 0x29369: '',  # 𩍩
    0x2936A: 'luò',  # 𩍪
    # 0x2936B: '',  # 𩍫
    # 0x2936C: '',  # 𩍬
    # 0x2936D: '',  # 𩍭
    # 0x2936E: '',  # 𩍮
    # 0x2936F: '',  # 𩍯
    # 0x29370: '',  # 𩍰
    # 0x29371: '',  # 𩍱
    0x29372: 'zhī,chàn',  # 𩍲
    0x29373: 'xù',  # 𩍳
    # 0x29374: '',  # 𩍴
    0x29375: 'zhī',  # 𩍵
    # 0x29376: '',  # 𩍶
    0x29377: 'quē',  # 𩍷
    0x29378: 'jū',  # 𩍸
    # 0x29379: '',  # 𩍹
    # 0x2937A: '',  # 𩍺
    0x2937B: 'yuán',  # 𩍻
    0x2937C: 'lú',  # 𩍼
    # 0x2937D: '',  # 𩍽
    # 0x2937E: '',  # 𩍾
    0x2937F: 'bó',  # 𩍿
    # 0x29380: '',  # 𩎀
    # 0x29381: '',  # 𩎁
    0x29382: 'róng',  # 𩎂
    0x29383: 'xiè',  # 𩎃
    # 0x29384: '',  # 𩎄
    # 0x29385: '',  # 𩎅
    # 0x29386: '',  # 𩎆
    # 0x29387: '',  # 𩎇
    # 0x29388: '',  # 𩎈
    0x29389: 'xǐ',  # 𩎉
    0x2938A: 'luó',  # 𩎊
    # 0x2938B: '',  # 𩎋
    # 0x2938C: '',  # 𩎌
    0x2938D: 'xiǎn',  # 𩎍
    0x2938E: 'gé',  # 𩎎
    # 0x2938F: '',  # 𩎏
    # 0x29390: '',  # 𩎐
    0x29391: 'zuān',  # 𩎑
    0x29392: 'hàn,jiān',  # 𩎒
    # 0x29393: '',  # 𩎓
    0x29394: 'jiāo',  # 𩎔
    0x29395: 'sǎ',  # 𩎕
    0x29396: 'qín,qián',  # 𩎖
    0x29397: 'qūn',  # 𩎗
    0x29398: 'páo',  # 𩎘
    0x29399: 'yuè',  # 𩎙
    0x2939A: 'chè',  # 𩎚
    0x2939B: 'fú',  # 𩎛
    0x2939C: 'pēi',  # 𩎜
    # 0x2939D: '',  # 𩎝
    # 0x2939E: '',  # 𩎞
    0x2939F: 'mèi,mò,wà',  # 𩎟
    # 0x293A0: '',  # 𩎠
    # 0x293A1: '',  # 𩎡
    0x293A2: 'tāo',  # 𩎢
    # 0x293A3: '',  # 𩎣
    0x293A4: 'kēn',  # 𩎤
    0x293A5: 'xì',  # 𩎥
    # 0x293A6: '',  # 𩎦
    # 0x293A7: '',  # 𩎧
    # 0x293A8: '',  # 𩎨
    # 0x293A9: '',  # 𩎩
    # 0x293AA: '',  # 𩎪
    0x293AB: 'duò',  # 𩎫
    # 0x293AC: '',  # 𩎬
    0x293AD: 'yì',  # 𩎭
    # 0x293AE: '',  # 𩎮
    # 0x293AF: '',  # 𩎯
    0x293B0: 'suì',  # 𩎰
    # 0x293B1: '',  # 𩎱
    0x293B2: 'xiá',  # 𩎲
    0x293B3: 'juān',  # 𩎳
    # 0x293B4: '',  # 𩎴
    0x293B5: 'wéi',  # 𩎵
    # 0x293B6: '',  # 𩎶
    0x293B7: 'yì',  # 𩎷
    # 0x293B8: '',  # 𩎸
    0x293B9: 'yù',  # 𩎹
    # 0x293BA: '',  # 𩎺
    0x293BB: 'bài',  # 𩎻
    0x293BC: 'tuó',  # 𩎼
    0x293BD: 'tà',  # 𩎽
    0x293BE: 'páo',  # 𩎾
    # 0x293BF: '',  # 𩎿
    # 0x293C0: '',  # 𩏀
    # 0x293C1: '',  # 𩏁
    0x293C2: 'bǐng,bì',  # 𩏂
    # 0x293C3: '',  # 𩏃
    # 0x293C4: '',  # 𩏄
    0x293C5: 'yùn',  # 𩏅
    0x293C6: 'yùn',  # 𩏆
    0x293C7: 'duàn',  # 𩏇
    0x293C8: 'ruǎn',  # 𩏈
    0x293C9: 'wéi',  # 𩏉
    # 0x293CA: '',  # 𩏊
    # 0x293CB: '',  # 𩏋
    # 0x293CC: '',  # 𩏌
    # 0x293CD: '',  # 𩏍
    # 0x293CE: '',  # 𩏎
    0x293CF: 'wěi',  # 𩏏
    0x293D0: 'guì,wěi',  # 𩏐
    0x293D1: 'hán',  # 𩏑
    0x293D2: 'dá',  # 𩏒
    0x293D3: 'xiá',  # 𩏓
    # 0x293D4: '',  # 𩏔
    # 0x293D5: '',  # 𩏕
    0x293D6: 'hùn',  # 𩏖
    0x293D7: 'juǎn',  # 𩏗
    0x293D8: 'suī',  # 𩏘
    # 0x293D9: '',  # 𩏙
    0x293DA: 'suì',  # 𩏚
    # 0x293DB: '',  # 𩏛
    # 0x293DC: '',  # 𩏜
    0x293DD: 'lóu',  # 𩏝
    0x293DE: 'bài',  # 𩏞
    0x293DF: 'yù',  # 𩏟
    0x293E0: 'zhèng',  # 𩏠
    0x293E1: 'guì',  # 𩏡
    # 0x293E2: '',  # 𩏢
    0x293E3: 'kuī',  # 𩏣
    0x293E4: 'gāo',  # 𩏤
    0x293E5: 'dān',  # 𩏥
    # 0x293E6: '',  # 𩏦
    # 0x293E7: '',  # 𩏧
    # 0x293E8: '',  # 𩏨
    0x293E9: 'xiǎn',  # 𩏩
    0x293EA: 'zhái',  # 𩏪
    0x293EB: 'sè',  # 𩏫
    0x293EC: 'wěi',  # 𩏬
    0x293ED: 'kē',  # 𩏭
    0x293EE: 'bǔ',  # 𩏮
    0x293EF: 'bó',  # 𩏯
    # 0x293F0: '',  # 𩏰
    # 0x293F1: '',  # 𩏱
    0x293F2: 'suì',  # 𩏲
    # 0x293F3: '',  # 𩏳
    0x293F4: 'yù',  # 𩏴
    0x293F5: 'bǔ,bù',  # 𩏵
    0x293F6: 'jiū',  # 𩏶
    0x293F7: 'jiū,jiào',  # 𩏷
    # 0x293F8: '',  # 𩏸
    0x293F9: 'juàn',  # 𩏹
    0x293FA: 'jué',  # 𩏺
    # 0x293FB: '',  # 𩏻
    0x293FC: 'nà',  # 𩏼
    # 0x293FD: '',  # 𩏽
    # 0x293FE: '',  # 𩏾
    # 0x293FF: '',  # 𩏿
    # 0x29400: '',  # 𩐀
    0x29401: 'xiè',  # 𩐁
    # 0x29402: '',  # 𩐂
    # 0x29403: '',  # 𩐃
    # 0x29404: '',  # 𩐄
    0x29405: 'sà',  # 𩐅
    0x29406: 'jī',  # 𩐆
    # 0x29407: '',  # 𩐇
    # 0x29408: '',  # 𩐈
    0x29409: 'xiè',  # 𩐉
    # 0x2940A: '',  # 𩐊
    # 0x2940B: '',  # 𩐋
    0x2940C: 'duì',  # 𩐌
    0x2940D: 'zǐ',  # 𩐍
    # 0x2940E: '',  # 𩐎
    # 0x2940F: '',  # 𩐏
    # 0x29410: '',  # 𩐐
    # 0x29411: '',  # 𩐑
    # 0x29412: '',  # 𩐒
    # 0x29413: '',  # 𩐓
    # 0x29414: '',  # 𩐔
    # 0x29415: '',  # 𩐕
    # 0x29416: '',  # 𩐖
    # 0x29417: '',  # 𩐗
    0x29418: 'yuǎn',  # 𩐘
    0x29419: 'qìn',  # 𩐙
    0x2941A: 'fú',  # 𩐚
    0x2941B: 'péng',  # 𩐛
    0x2941C: 'páo',  # 𩐜
    # 0x2941D: '',  # 𩐝
    0x2941E: 'yìn',  # 𩐞
    # 0x2941F: '',  # 𩐟
    0x29420: 'hōng',  # 𩐠
    0x29421: 'zú',  # 𩐡
    # 0x29422: '',  # 𩐢
    0x29423: 'gōng',  # 𩐣
    0x29424: 'dòng',  # 𩐤
    0x29425: 'hē',  # 𩐥
    0x29426: 'wò',  # 𩐦
    # 0x29427: '',  # 𩐧
    0x29428: 'pāng',  # 𩐨
    # 0x29429: '',  # 𩐩
    # 0x2942A: '',  # 𩐪
    0x2942B: 'sù',  # 𩐫
    0x2942C: 'kǎn',  # 𩐬
    0x2942D: 'niè',  # 𩐭
    0x2942E: 'háo',  # 𩐮
    0x2942F: 'fèng',  # 𩐯
    0x29430: 'è',  # 𩐰
    0x29431: 'yè',  # 𩐱
    # 0x29432: '',  # 𩐲
    # 0x29433: '',  # 𩐳
    0x29434: 'tíng',  # 𩐴
    0x29435: 'dòng',  # 𩐵
    0x29436: 'zhé',  # 𩐶
    0x29437: 'sāng',  # 𩐷
    # 0x29438: '',  # 𩐸
    # 0x29439: '',  # 𩐹
    # 0x2943A: '',  # 𩐺
    0x2943B: 'mò',  # 𩐻
    0x2943C: 'sù',  # 𩐼
    # 0x2943D: '',  # 𩐽
    0x2943E: 'lè',  # 𩐾
    # 0x2943F: '',  # 𩐿
    0x29440: 'pǔ',  # 𩑀
    0x29441: 'é',  # 𩑁
    0x29442: 'zhuó',  # 𩑂
    0x29443: 'yè',  # 𩑃
    # 0x29444: '',  # 𩑄
    # 0x29445: '',  # 𩑅
    # 0x29446: '',  # 𩑆
    0x29447: 'xiāng',  # 𩑇
    0x29448: 'guàng',  # 𩑈
    0x29449: 'rěn',  # 𩑉
    0x2944A: 'líng',  # 𩑊
    # 0x2944B: '',  # 𩑋
    # 0x2944C: '',  # 𩑌
    0x2944D: 'ào',  # 𩑍
    0x2944E: 'shùn',  # 𩑎
    # 0x2944F: '',  # 𩑏
    0x29450: 'chāi',  # 𩑐
    # 0x29451: '',  # 𩑑
    0x29452: 'duó',  # 𩑒
    0x29453: 'qióng',  # 𩑓
    0x29454: 'kū,yà',  # 𩑔
    0x29455: 'xū',  # 𩑕
    0x29456: 'huán',  # 𩑖
    0x29457: 'yāo',  # 𩑗
    0x29458: 'zhèn',  # 𩑘
    0x29459: 'tǐng',  # 𩑙
    0x2945A: 'běng,lèi',  # 𩑚
    # 0x2945B: '',  # 𩑛
    # 0x2945C: '',  # 𩑜
    0x2945D: 'áng',  # 𩑝
    # 0x2945E: '',  # 𩑞
    0x2945F: 'kān,qiān',  # 𩑟
    # 0x29460: '',  # 𩑠
    0x29461: 'kū,gěn',  # 𩑡
    0x29462: 'péi,bāi',  # 𩑢
    0x29463: 'yòu',  # 𩑣
    0x29464: 'ǎo',  # 𩑤
    0x29465: 'mén',  # 𩑥
    0x29466: 'mò',  # 𩑦
    # 0x29467: '',  # 𩑧
    # 0x29468: '',  # 𩑨
    # 0x29469: '',  # 𩑩
    # 0x2946A: '',  # 𩑪
    # 0x2946B: '',  # 𩑫
    0x2946C: 'fǔ,guī',  # 𩑬
    0x2946D: 'qīng',  # 𩑭
    0x2946E: 'là',  # 𩑮
    0x2946F: 'dǒu',  # 𩑯
    0x29470: 'tǎn',  # 𩑰
    # 0x29471: '',  # 𩑱
    # 0x29472: '',  # 𩑲
    0x29473: 'qiǎn',  # 𩑳
    0x29474: 'yào',  # 𩑴
    0x29475: 'wèi',  # 𩑵
    0x29476: 'hú,kū',  # 𩑶
    0x29477: 'mò',  # 𩑷
    0x29478: 'hē',  # 𩑸
    0x29479: 'xuàn',  # 𩑹
    # 0x2947A: '',  # 𩑺
    0x2947B: 'bì,pó',  # 𩑻
    0x2947C: 'pō',  # 𩑼
    # 0x2947D: '',  # 𩑽
    0x2947E: 'dī',  # 𩑾
    # 0x2947F: '',  # 𩑿
    0x29480: 'zhěn',  # 𩒀
    # 0x29481: '',  # 𩒁
    0x29482: 'shī',  # 𩒂
    0x29483: 'kǎn',  # 𩒃
    0x29484: 'cè',  # 𩒄
    # 0x29485: '',  # 𩒅
    # 0x29486: '',  # 𩒆
    0x29487: 'xū',  # 𩒇
    0x29488: 'zhěn',  # 𩒈
    # 0x29489: '',  # 𩒉
    0x2948A: 'zhǔ',  # 𩒊
    # 0x2948B: '',  # 𩒋
    # 0x2948C: '',  # 𩒌
    # 0x2948D: '',  # 𩒍
    # 0x2948E: '',  # 𩒎
    0x2948F: 'huì',  # 𩒏
    0x29490: 'chǐ',  # 𩒐
    # 0x29491: '',  # 𩒑
    # 0x29492: '',  # 𩒒
    0x29493: 'hǒng',  # 𩒓
    0x29494: 'nóu',  # 𩒔
    0x29495: 'niè,pò,è',  # 𩒕
    0x29496: 'yàn',  # 𩒖
    # 0x29497: '',  # 𩒗
    0x29498: 'chǒng',  # 𩒘
    0x29499: 'fǔ,guì',  # 𩒙
    0x2949A: 'guāng',  # 𩒚
    0x2949B: 'qī',  # 𩒛
    0x2949C: 'duǒ',  # 𩒜
    0x2949D: 'gěn',  # 𩒝
    0x2949E: 'tǐng',  # 𩒞
    # 0x2949F: '',  # 𩒟
    # 0x294A0: '',  # 𩒠
    # 0x294A1: '',  # 𩒡
    0x294A2: 'tǎn',  # 𩒢
    0x294A3: 'qiǎn',  # 𩒣
    # 0x294A4: '',  # 𩒤
    # 0x294A5: '',  # 𩒥
    0x294A6: 'jiù,xìn',  # 𩒦
    0x294A7: 'xū',  # 𩒧
    0x294A8: 'qǐ',  # 𩒨
    # 0x294A9: '',  # 𩒩
    0x294AA: 'zhèn',  # 𩒪
    # 0x294AB: '',  # 𩒫
    # 0x294AC: '',  # 𩒬
    # 0x294AD: '',  # 𩒭
    0x294AE: 'qiú',  # 𩒮
    # 0x294AF: '',  # 𩒯
    0x294B0: 'ě',  # 𩒰
    # 0x294B1: '',  # 𩒱
    # 0x294B2: '',  # 𩒲
    0x294B3: 'huì',  # 𩒳
    0x294B4: 'hòng',  # 𩒴
    0x294B5: 'qǐng',  # 𩒵
    # 0x294B6: '',  # 𩒶
    0x294B7: 'chē,rǒng',  # 𩒷
    # 0x294B8: '',  # 𩒸
    # 0x294B9: '',  # 𩒹
    0x294BA: 'fù',  # 𩒺
    # 0x294BB: '',  # 𩒻
    0x294BC: 'hōng',  # 𩒼
    0x294BD: 'xī',  # 𩒽
    0x294BE: 'wú',  # 𩒾
    0x294BF: 'máng',  # 𩒿
    # 0x294C0: '',  # 𩓀
    # 0x294C1: '',  # 𩓁
    0x294C2: 'tī',  # 𩓂
    # 0x294C3: '',  # 𩓃
    # 0x294C4: '',  # 𩓄
    0x294C5: 'hōng',  # 𩓅
    # 0x294C6: '',  # 𩓆
    # 0x294C7: '',  # 𩓇
    # 0x294C8: '',  # 𩓈
    # 0x294C9: '',  # 𩓉
    # 0x294CA: '',  # 𩓊
    # 0x294CB: '',  # 𩓋
    # 0x294CC: '',  # 𩓌
    # 0x294CD: '',  # 𩓍
    # 0x294CE: '',  # 𩓎
    # 0x294CF: '',  # 𩓏
    0x294D0: 'bó',  # 𩓐
    # 0x294D1: '',  # 𩓑
    0x294D2: 'qǐn',  # 𩓒
    0x294D3: 'gěn',  # 𩓓
    # 0x294D4: '',  # 𩓔
    # 0x294D5: '',  # 𩓕
    0x294D6: 'fú',  # 𩓖
    0x294D7: 'kuǐ',  # 𩓗
    # 0x294D8: '',  # 𩓘
    # 0x294D9: '',  # 𩓙
    # 0x294DA: '',  # 𩓚
    # 0x294DB: '',  # 𩓛
    # 0x294DC: '',  # 𩓜
    0x294DD: 'bié',  # 𩓝
    0x294DE: 'jìng',  # 𩓞
    0x294DF: 'kǎn',  # 𩓟
    0x294E0: 'guī',  # 𩓠
    # 0x294E1: '',  # 𩓡
    0x294E2: 'gǎo',  # 𩓢
    0x294E3: 'xū',  # 𩓣
    0x294E4: 'àn',  # 𩓤
    0x294E5: 'yuè',  # 𩓥
    0x294E6: 'wù',  # 𩓦
    0x294E7: 'yí',  # 𩓧
    0x294E8: 'jīng',  # 𩓨
    # 0x294E9: '',  # 𩓩
    0x294EA: 'lù',  # 𩓪
    0x294EB: 'quán',  # 𩓫
    0x294EC: 'tuí',  # 𩓬
    # 0x294ED: '',  # 𩓭
    0x294EE: 'jì',  # 𩓮
    # 0x294EF: '',  # 𩓯
    # 0x294F0: '',  # 𩓰
    # 0x294F1: '',  # 𩓱
    # 0x294F2: '',  # 𩓲
    # 0x294F3: '',  # 𩓳
    # 0x294F4: '',  # 𩓴
    # 0x294F5: '',  # 𩓵
    # 0x294F6: '',  # 𩓶
    # 0x294F7: '',  # 𩓷
    0x294F8: 'guī',  # 𩓸
    # 0x294F9: '',  # 𩓹
    0x294FA: 'jiǒng',  # 𩓺
    0x294FB: 'jué',  # 𩓻
    0x294FC: 'piē',  # 𩓼
    0x294FD: 'kūn',  # 𩓽
    # 0x294FE: '',  # 𩓾
    # 0x294FF: '',  # 𩓿
    0x29500: 'wài',  # 𩔀
    0x29501: 'huì',  # 𩔁
    0x29502: 'dùn',  # 𩔂
    0x29503: 'yuǎn',  # 𩔃
    0x29504: 'jié',  # 𩔄
    # 0x29505: '',  # 𩔅
    0x29506: 'guì',  # 𩔆
    0x29507: 'gǎo',  # 𩔇
    0x29508: 'pò',  # 𩔈
    0x29509: 'mén,mín,hūn',  # 𩔉
    0x2950A: 'zhuàn',  # 𩔊
    0x2950B: 'hàng',  # 𩔋
    # 0x2950C: '',  # 𩔌
    # 0x2950D: '',  # 𩔍
    # 0x2950E: '',  # 𩔎
    # 0x2950F: '',  # 𩔏
    # 0x29510: '',  # 𩔐
    # 0x29511: '',  # 𩔑
    # 0x29512: '',  # 𩔒
    # 0x29513: '',  # 𩔓
    0x29514: 'yóng',  # 𩔔
    0x29515: 'qiú',  # 𩔕
    # 0x29516: '',  # 𩔖
    0x29517: 'lèi,lì',  # 𩔗
    0x29518: 'áng',  # 𩔘
    0x29519: 'pǐ,xìn',  # 𩔙
    0x2951A: 'wēng,wěng',  # 𩔚
    # 0x2951B: '',  # 𩔛
    # 0x2951C: '',  # 𩔜
    0x2951D: 'qìn',  # 𩔝
    0x2951E: 'hán',  # 𩔞
    0x2951F: 'qǐn',  # 𩔟
    0x29520: 'miè',  # 𩔠
    0x29521: 'dōu',  # 𩔡
    0x29522: 'mí',  # 𩔢
    0x29523: 'zhān',  # 𩔣
    # 0x29524: '',  # 𩔤
    0x29525: 'qǐng',  # 𩔥
    0x29526: 'yí',  # 𩔦
    # 0x29527: '',  # 𩔧
    # 0x29528: '',  # 𩔨
    # 0x29529: '',  # 𩔩
    # 0x2952A: '',  # 𩔪
    # 0x2952B: '',  # 𩔫
    # 0x2952C: '',  # 𩔬
    # 0x2952D: '',  # 𩔭
    0x2952E: 'bān',  # 𩔮
    # 0x2952F: '',  # 𩔯
    # 0x29530: '',  # 𩔰
    0x29531: 'juān',  # 𩔱
    # 0x29532: '',  # 𩔲
    0x29533: 'zé',  # 𩔳
    0x29534: 'xù',  # 𩔴
    0x29535: 'lán',  # 𩔵
    0x29536: 'má',  # 𩔶
    0x29537: 'má',  # 𩔷
    0x29538: 'ōu',  # 𩔸
    0x29539: 'bēi',  # 𩔹
    # 0x2953A: '',  # 𩔺
    0x2953B: 'póu',  # 𩔻
    0x2953C: 'xù',  # 𩔼
    # 0x2953D: '',  # 𩔽
    # 0x2953E: '',  # 𩔾
    # 0x2953F: '',  # 𩔿
    0x29540: 'ào',  # 𩕀
    # 0x29541: '',  # 𩕁
    # 0x29542: '',  # 𩕂
    # 0x29543: '',  # 𩕃
    0x29544: 'xìn',  # 𩕄
    # 0x29545: '',  # 𩕅
    0x29546: 'hǒng',  # 𩕆
    # 0x29547: '',  # 𩕇
    # 0x29548: '',  # 𩕈
    0x29549: 'hǒng',  # 𩕉
    0x2954A: 'zhǎn',  # 𩕊
    # 0x2954B: '',  # 𩕋
    0x2954C: 'sěn',  # 𩕌
    0x2954D: 'gǎo,háo',  # 𩕍
    # 0x2954E: '',  # 𩕎
    0x2954F: 'pó,fán',  # 𩕏
    0x29550: 'liào',  # 𩕐
    # 0x29551: '',  # 𩕑
    # 0x29552: '',  # 𩕒
    # 0x29553: '',  # 𩕓
    # 0x29554: '',  # 𩕔
    0x29555: 'wài',  # 𩕕
    0x29556: 'xuān',  # 𩕖
    # 0x29557: '',  # 𩕗
    # 0x29558: '',  # 𩕘
    # 0x29559: '',  # 𩕙
    # 0x2955A: '',  # 𩕚
    # 0x2955B: '',  # 𩕛
    0x2955C: 'kuí',  # 𩕜
    # 0x2955D: '',  # 𩕝
    # 0x2955E: '',  # 𩕞
    0x2955F: 'è',  # 𩕟
    0x29560: 'hàn',  # 𩕠
    0x29561: 'sè',  # 𩕡
    # 0x29562: '',  # 𩕢
    # 0x29563: '',  # 𩕣
    0x29564: 'dàn',  # 𩕤
    # 0x29565: '',  # 𩕥
    # 0x29566: '',  # 𩕦
    # 0x29567: '',  # 𩕧
    # 0x29568: '',  # 𩕨
    # 0x29569: '',  # 𩕩
    0x2956A: 'xuān',  # 𩕪
    # 0x2956B: '',  # 𩕫
    0x2956C: 'è',  # 𩕬
    0x2956D: 'gài',  # 𩕭
    # 0x2956E: '',  # 𩕮
    0x2956F: 'dāo',  # 𩕯
    # 0x29570: '',  # 𩕰
    0x29571: 'měng',  # 𩕱
    0x29572: 'yī',  # 𩕲
    0x29573: 'nǐng',  # 𩕳
    # 0x29574: '',  # 𩕴
    0x29575: 'pín',  # 𩕵
    # 0x29576: '',  # 𩕶
    # 0x29577: '',  # 𩕷
    # 0x29578: '',  # 𩕸
    0x29579: 'cāng',  # 𩕹
    0x2957A: 'wài',  # 𩕺
    # 0x2957B: '',  # 𩕻
    # 0x2957C: '',  # 𩕼
    # 0x2957D: '',  # 𩕽
    0x2957E: 'yuàn',  # 𩕾
    # 0x2957F: '',  # 𩕿
    0x29580: 'è',  # 𩖀
    0x29581: 'niè,yá',  # 𩖁
    # 0x29582: '',  # 𩖂
    # 0x29583: '',  # 𩖃
    0x29584: 'yǐn',  # 𩖄
    # 0x29585: '',  # 𩖅
    # 0x29586: '',  # 𩖆
    0x29587: 'qiāo',  # 𩖇
    # 0x29588: '',  # 𩖈
    0x29589: 'hōng',  # 𩖉
    0x2958A: 'líng',  # 𩖊
    # 0x2958B: '',  # 𩖋
    0x2958C: 'chān',  # 𩖌
    0x2958D: 'yǐng',  # 𩖍
    # 0x2958E: '',  # 𩖎
    # 0x2958F: '',  # 𩖏
    # 0x29590: '',  # 𩖐
    # 0x29591: '',  # 𩖑
    0x29592: 'guān',  # 𩖒
    0x29593: 'pín',  # 𩖓
    0x29594: 'niǎo',  # 𩖔
    # 0x29595: '',  # 𩖕
    # 0x29596: '',  # 𩖖
    # 0x29597: '',  # 𩖗
    # 0x29598: '',  # 𩖘
    # 0x29599: '',  # 𩖙
    # 0x2959A: '',  # 𩖚
    0x2959B: 'péng',  # 𩖛
    # 0x2959C: '',  # 𩖜
    0x2959D: 'liáo',  # 𩖝
    # 0x2959E: '',  # 𩖞
    # 0x2959F: '',  # 𩖟
    0x295A0: 'bèi',  # 𩖠
    # 0x295A1: '',  # 𩖡
    # 0x295A2: '',  # 𩖢
    0x295A3: 'xín,bá',  # 𩖣
    0x295A4: 'tún',  # 𩖤
    0x295A5: 'chāo',  # 𩖥
    0x295A6: 'gān',  # 𩖦
    # 0x295A7: '',  # 𩖧
    0x295A8: 'hū',  # 𩖨
    0x295A9: 'wǎng',  # 𩖩
    # 0x295AA: '',  # 𩖪
    # 0x295AB: '',  # 𩖫
    0x295AC: 'fú',  # 𩖬
    0x295AD: 'pèi',  # 𩖭
    # 0x295AE: '',  # 𩖮
    0x295AF: 'náo',  # 𩖯
    0x295B0: 'xún,xín',  # 𩖰
    0x295B1: 'xuè',  # 𩖱
    # 0x295B2: '',  # 𩖲
    # 0x295B3: '',  # 𩖳
    0x295B4: 'liǔ',  # 𩖴
    0x295B5: 'líng',  # 𩖵
    0x295B6: 'xuè',  # 𩖶
    0x295B7: 'qū',  # 𩖷
    0x295B8: 'háo',  # 𩖸
    0x295B9: 'yí',  # 𩖹
    0x295BA: 'hàn',  # 𩖺
    # 0x295BB: '',  # 𩖻
    0x295BC: 'fú',  # 𩖼
    0x295BD: 'bá',  # 𩖽
    0x295BE: 'yí',  # 𩖾
    # 0x295BF: '',  # 𩖿
    0x295C0: 'bó',  # 𩗀
    # 0x295C1: '',  # 𩗁
    # 0x295C2: '',  # 𩗂
    # 0x295C3: '',  # 𩗃
    0x295C4: 'hōng',  # 𩗄
    0x295C5: 'lì',  # 𩗅
    # 0x295C6: '',  # 𩗆
    # 0x295C7: '',  # 𩗇
    # 0x295C8: '',  # 𩗈
    0x295C9: 'sà',  # 𩗉
    0x295CA: 'xī',  # 𩗊
    # 0x295CB: '',  # 𩗋
    # 0x295CC: '',  # 𩗌
    # 0x295CD: '',  # 𩗍
    0x295CE: 'shì',  # 𩗎
    0x295CF: 'piāo',  # 𩗏
    0x295D0: 'huà',  # 𩗐
    0x295D1: 'yí',  # 𩗑
    0x295D2: 'bó',  # 𩗒
    0x295D3: 'bó',  # 𩗓
    0x295D4: 'něi',  # 𩗔
    0x295D5: 'qiú',  # 𩗕
    # 0x295D6: '',  # 𩗖
    # 0x295D7: '',  # 𩗗
    0x295D8: 'wěi',  # 𩗘
    0x295D9: 'chè',  # 𩗙
    0x295DA: 'yóu',  # 𩗚
    # 0x295DB: '',  # 𩗛
    0x295DC: 'wèi',  # 𩗜
    0x295DD: 'huǐ',  # 𩗝
    0x295DE: 'sà',  # 𩗞
    # 0x295DF: '',  # 𩗟
    # 0x295E0: '',  # 𩗠
    # 0x295E1: '',  # 𩗡
    0x295E2: 'hòng',  # 𩗢
    0x295E3: 'sōu',  # 𩗣
    0x295E4: 'hàn',  # 𩗤
    0x295E5: 'páo',  # 𩗥
    # 0x295E6: '',  # 𩗦
    0x295E7: 'fáng',  # 𩗧
    # 0x295E8: '',  # 𩗨
    0x295E9: 'liú',  # 𩗩
    0x295EA: 'zhòu',  # 𩗪
    0x295EB: 'pí',  # 𩗫
    # 0x295EC: '',  # 𩗬
    0x295ED: 'lì',  # 𩗭
    # 0x295EE: '',  # 𩗮
    # 0x295EF: '',  # 𩗯
    0x295F0: 'chuí',  # 𩗰
    0x295F1: 'xī',  # 𩗱
    0x295F2: 'zhēng',  # 𩗲
    # 0x295F3: '',  # 𩗳
    0x295F4: 'bèng',  # 𩗴
    0x295F5: 'zhěng',  # 𩗵
    0x295F6: 'suì',  # 𩗶
    0x295F7: 'yǎn',  # 𩗷
    # 0x295F8: '',  # 𩗸
    # 0x295F9: '',  # 𩗹
    0x295FA: 'yáng',  # 𩗺
    # 0x295FB: '',  # 𩗻
    0x295FC: 'qīng',  # 𩗼
    0x295FD: 'wù',  # 𩗽
    0x295FE: 'liǎng',  # 𩗾
    # 0x295FF: '',  # 𩗿
    0x29600: 'zhào',  # 𩘀
    0x29601: 'liáng',  # 𩘁
    # 0x29602: '',  # 𩘂
    # 0x29603: '',  # 𩘃
    # 0x29604: '',  # 𩘄
    0x29605: 'jiē',  # 𩘅
    # 0x29606: '',  # 𩘆
    0x29607: 'hōng',  # 𩘇
    0x29608: 'yōu',  # 𩘈
    # 0x29609: '',  # 𩘉
    0x2960A: 'là',  # 𩘊
    0x2960B: 'hòu',  # 𩘋
    # 0x2960C: '',  # 𩘌
    0x2960D: 'yuàn',  # 𩘍
    0x2960E: 'hóng',  # 𩘎
    0x2960F: 'yè',  # 𩘏
    # 0x29610: '',  # 𩘐
    0x29611: 'yǐng,yīng',  # 𩘑
    0x29612: 'xuǎn,juān',  # 𩘒
    0x29613: 'yóu',  # 𩘓
    # 0x29614: '',  # 𩘔
    # 0x29615: '',  # 𩘕
    # 0x29616: '',  # 𩘖
    # 0x29617: '',  # 𩘗
    0x29618: 'quán',  # 𩘘
    # 0x29619: '',  # 𩘙
    # 0x2961A: '',  # 𩘚
    # 0x2961B: '',  # 𩘛
    0x2961C: 'táng',  # 𩘜
    0x2961D: 'suǒ',  # 𩘝
    # 0x2961E: '',  # 𩘞
    0x2961F: 'lì',  # 𩘟
    0x29620: 'sōu',  # 𩘠
    0x29621: 'lì',  # 𩘡
    # 0x29622: '',  # 𩘢
    # 0x29623: '',  # 𩘣
    0x29624: 'yù',  # 𩘤
    0x29625: 'kǎi',  # 𩘥
    # 0x29626: '',  # 𩘦
    0x29627: 'yì',  # 𩘧
    # 0x29628: '',  # 𩘨
    # 0x29629: '',  # 𩘩
    # 0x2962A: '',  # 𩘪
    # 0x2962B: '',  # 𩘫
    # 0x2962C: '',  # 𩘬
    0x2962D: 'xiū',  # 𩘭
    0x2962E: 'áo',  # 𩘮
    0x2962F: 'tuán',  # 𩘯
    0x29630: 'sù',  # 𩘰
    0x29631: 'shuài',  # 𩘱
    # 0x29632: '',  # 𩘲
    0x29633: 'yù',  # 𩘳
    # 0x29634: '',  # 𩘴
    0x29635: 'fēng',  # 𩘵
    # 0x29636: '',  # 𩘶
    # 0x29637: '',  # 𩘷
    # 0x29638: '',  # 𩘸
    0x29639: 'sù',  # 𩘹
    0x2963A: 'tuí',  # 𩘺
    0x2963B: 'yù',  # 𩘻
    0x2963C: 'zhēng',  # 𩘼
    0x2963D: 'zhēng',  # 𩘽
    # 0x2963E: '',  # 𩘾
    0x2963F: 'táo',  # 𩘿
    # 0x29640: '',  # 𩙀
    # 0x29641: '',  # 𩙁
    # 0x29642: '',  # 𩙂
    # 0x29643: '',  # 𩙃
    0x29644: 'liú',  # 𩙄
    # 0x29645: '',  # 𩙅
    0x29646: 'chéng',  # 𩙆
    0x29647: 'suí',  # 𩙇
    0x29648: 'sāo',  # 𩙈
    # 0x29649: '',  # 𩙉
    # 0x2964A: '',  # 𩙊
    # 0x2964B: '',  # 𩙋
    # 0x2964C: '',  # 𩙌
    # 0x2964D: '',  # 𩙍
    # 0x2964E: '',  # 𩙎
    0x2964F: 'gǔ',  # 𩙏
    0x29650: 'fēng',  # 𩙐
    0x29651: 'liè',  # 𩙑
    0x29652: 'piāo,piào',  # 𩙒
    # 0x29653: '',  # 𩙓
    # 0x29654: '',  # 𩙔
    # 0x29655: '',  # 𩙕
    0x29656: 'lì',  # 𩙖
    # 0x29657: '',  # 𩙗
    0x29658: 'lóng',  # 𩙘
    0x29659: 'chū',  # 𩙙
    0x2965A: 'xiāo',  # 𩙚
    0x2965B: 'hōng',  # 𩙛
    0x2965C: 'xiè',  # 𩙜
    0x2965D: 'shè',  # 𩙝
    # 0x2965E: '',  # 𩙞
    # 0x2965F: '',  # 𩙟
    0x29660: 'lóng',  # 𩙠
    0x29661: 'hōu',  # 𩙡
    0x29662: 'xuán,shī',  # 𩙢
    0x29663: 'fēng',  # 𩙣
    # 0x29664: '',  # 𩙤
    # 0x29665: '',  # 𩙥
    # 0x29666: '',  # 𩙦
    # 0x29667: '',  # 𩙧
    # 0x29668: '',  # 𩙨
    # 0x29669: '',  # 𩙩
    # 0x2966A: '',  # 𩙪
    # 0x2966B: '',  # 𩙫
    # 0x2966C: '',  # 𩙬
    # 0x2966D: '',  # 𩙭
    # 0x2966E: '',  # 𩙮
    # 0x2966F: '',  # 𩙯
    # 0x29670: '',  # 𩙰
    # 0x29671: '',  # 𩙱
    0x29672: 'fēi',  # 𩙲
    # 0x29673: '',  # 𩙳
    # 0x29674: '',  # 𩙴
    # 0x29675: '',  # 𩙵
    # 0x29676: '',  # 𩙶
    0x29677: 'niù',  # 𩙷
    0x29678: 'mǎng',  # 𩙸
    # 0x29679: '',  # 𩙹
    0x2967A: 'yì',  # 𩙺
    # 0x2967B: '',  # 𩙻
    # 0x2967C: '',  # 𩙼
    0x2967D: 'huán,xuān',  # 𩙽
    0x2967E: 'zhī',  # 𩙾
    # 0x2967F: '',  # 𩙿
    # 0x29680: '',  # 𩚀
    # 0x29681: '',  # 𩚁
    0x29682: 'yì',  # 𩚂
    # 0x29683: '',  # 𩚃
    0x29684: 'yù',  # 𩚄
    # 0x29685: '',  # 𩚅
    # 0x29686: '',  # 𩚆
    0x29687: 'yí',  # 𩚇
    0x29688: 'yuē',  # 𩚈
    0x29689: 'chí',  # 𩚉
    # 0x2968A: '',  # 𩚊
    # 0x2968B: '',  # 𩚋
    # 0x2968C: '',  # 𩚌
    # 0x2968D: '',  # 𩚍
    # 0x2968E: '',  # 𩚎
    0x2968F: 'sūn',  # 𩚏
    # 0x29690: '',  # 𩚐
    # 0x29691: '',  # 𩚑
    # 0x29692: '',  # 𩚒
    # 0x29693: '',  # 𩚓
    # 0x29694: '',  # 𩚔
    0x29695: 'yǐn,qiāng',  # 𩚕
    0x29696: 'niù',  # 𩚖
    0x29697: 'rǒng',  # 𩚗
    # 0x29698: '',  # 𩚘
    # 0x29699: '',  # 𩚙
    # 0x2969A: '',  # 𩚚
    0x2969B: 'nà',  # 𩚛
    # 0x2969C: '',  # 𩚜
    # 0x2969D: '',  # 𩚝
    # 0x2969E: '',  # 𩚞
    # 0x2969F: '',  # 𩚟
    # 0x296A0: '',  # 𩚠
    # 0x296A1: '',  # 𩚡
    # 0x296A2: '',  # 𩚢
    0x296A3: 'tián',  # 𩚣
    # 0x296A4: '',  # 𩚤
    0x296A5: 'bā',  # 𩚥
    # 0x296A6: '',  # 𩚦
    # 0x296A7: '',  # 𩚧
    # 0x296A8: '',  # 𩚨
    0x296A9: 'hú',  # 𩚩
    0x296AA: 'ěr',  # 𩚪
    0x296AB: 'zhēng',  # 𩚫
    0x296AC: 'è',  # 𩚬
    0x296AD: 'póu',  # 𩚭
    0x296AE: 'jī,nì',  # 𩚮
    0x296AF: 'ní',  # 𩚯
    # 0x296B0: '',  # 𩚰
    0x296B1: 'jiǒng',  # 𩚱
    0x296B2: 'jiá',  # 𩚲
    # 0x296B3: '',  # 𩚳
    # 0x296B4: '',  # 𩚴
    0x296B5: 'gān',  # 𩚵
    # 0x296B6: '',  # 𩚶
    # 0x296B7: '',  # 𩚷
    # 0x296B8: '',  # 𩚸
    0x296B9: 'líng',  # 𩚹
    # 0x296BA: '',  # 𩚺
    0x296BB: 'zuì',  # 𩚻
    # 0x296BC: '',  # 𩚼
    # 0x296BD: '',  # 𩚽
    0x296BE: 'bèi',  # 𩚾
    0x296BF: 'yù',  # 𩚿
    # 0x296C0: '',  # 𩛀
    # 0x296C1: '',  # 𩛁
    # 0x296C2: '',  # 𩛂
    # 0x296C3: '',  # 𩛃
    # 0x296C4: '',  # 𩛄
    0x296C5: 'shū',  # 𩛅
    0x296C6: 'yǐ',  # 𩛆
    0x296C7: 'pāi',  # 𩛇
    # 0x296C8: '',  # 𩛈
    # 0x296C9: '',  # 𩛉
    # 0x296CA: '',  # 𩛊
    0x296CB: 'nǎo',  # 𩛋
    0x296CC: 'shì',  # 𩛌
    # 0x296CD: '',  # 𩛍
    0x296CE: 'mǎn',  # 𩛎
    0x296CF: 'shì',  # 𩛏
    # 0x296D0: '',  # 𩛐
    0x296D1: 'tí',  # 𩛑
    # 0x296D2: '',  # 𩛒
    # 0x296D3: '',  # 𩛓
    # 0x296D4: '',  # 𩛔
    # 0x296D5: '',  # 𩛕
    # 0x296D6: '',  # 𩛖
    # 0x296D7: '',  # 𩛗
    0x296D8: 'gōng',  # 𩛘
    # 0x296D9: '',  # 𩛙
    # 0x296DA: '',  # 𩛚
    # 0x296DB: '',  # 𩛛
    # 0x296DC: '',  # 𩛜
    0x296DD: 'lèi',  # 𩛝
    0x296DE: 'bǎo,něi,piǎo',  # 𩛞
    0x296DF: 'yuān,mán',  # 𩛟
    0x296E0: 'zuō',  # 𩛠
    0x296E1: 'láng,náng',  # 𩛡
    0x296E2: 'xiū',  # 𩛢
    # 0x296E3: '',  # 𩛣
    # 0x296E4: '',  # 𩛤
    0x296E5: 'zài',  # 𩛥
    0x296E6: 'chèng',  # 𩛦
    0x296E7: 'jiān',  # 𩛧
    0x296E8: 'mào',  # 𩛨
    0x296E9: 'jiá',  # 𩛩
    0x296EA: 'yù',  # 𩛪
    # 0x296EB: '',  # 𩛫
    # 0x296EC: '',  # 𩛬
    0x296ED: 'yù',  # 𩛭
    0x296EE: 'yí',  # 𩛮
    # 0x296EF: '',  # 𩛯
    # 0x296F0: '',  # 𩛰
    # 0x296F1: '',  # 𩛱
    0x296F2: 'māng',  # 𩛲
    0x296F3: 'zài,cān',  # 𩛳
    # 0x296F4: '',  # 𩛴
    0x296F5: 'zhuì',  # 𩛵
    0x296F6: 'tí',  # 𩛶
    # 0x296F7: '',  # 𩛷
    # 0x296F8: '',  # 𩛸
    0x296F9: 'xì',  # 𩛹
    0x296FA: 'jú',  # 𩛺
    0x296FB: 'zàn,zuǎn,zhān',  # 𩛻
    0x296FC: 'lù',  # 𩛼
    0x296FD: 'táo',  # 𩛽
    # 0x296FE: '',  # 𩛾
    0x296FF: 'xíng',  # 𩛿
    0x29700: 'zhuì,duī',  # 𩜀
    0x29701: 'líng',  # 𩜁
    # 0x29702: '',  # 𩜂
    0x29703: 'jù',  # 𩜃
    # 0x29704: '',  # 𩜄
    # 0x29705: '',  # 𩜅
    0x29706: 'jī',  # 𩜆
    0x29707: 'juàn,juǎn',  # 𩜇
    0x29708: 'yù',  # 𩜈
    # 0x29709: '',  # 𩜉
    0x2970A: 'zī',  # 𩜊
    # 0x2970B: '',  # 𩜋
    0x2970C: 'yuē',  # 𩜌
    0x2970D: 'dōng',  # 𩜍
    # 0x2970E: '',  # 𩜎
    # 0x2970F: '',  # 𩜏
    # 0x29710: '',  # 𩜐
    # 0x29711: '',  # 𩜑
    0x29712: 'nǎng',  # 𩜒
    # 0x29713: '',  # 𩜓
    # 0x29714: '',  # 𩜔
    # 0x29715: '',  # 𩜕
    0x29716: 'chóng',  # 𩜖
    # 0x29717: '',  # 𩜗
    # 0x29718: '',  # 𩜘
    # 0x29719: '',  # 𩜙
    # 0x2971A: '',  # 𩜚
    # 0x2971B: '',  # 𩜛
    # 0x2971C: '',  # 𩜜
    # 0x2971D: '',  # 𩜝
    # 0x2971E: '',  # 𩜞
    0x2971F: 'àng',  # 𩜟
    0x29720: 'mǎn',  # 𩜠
    # 0x29721: '',  # 𩜡
    # 0x29722: '',  # 𩜢
    0x29723: 'gēng',  # 𩜣
    # 0x29724: '',  # 𩜤
    0x29725: 'bō',  # 𩜥
    0x29726: 'dìng',  # 𩜦
    0x29727: 'wěi',  # 𩜧
    # 0x29728: '',  # 𩜨
    # 0x29729: '',  # 𩜩
    # 0x2972A: '',  # 𩜪
    # 0x2972B: '',  # 𩜫
    0x2972C: 'quán',  # 𩜬
    0x2972D: 'kē',  # 𩜭
    # 0x2972E: '',  # 𩜮
    # 0x2972F: '',  # 𩜯
    0x29730: 'pì',  # 𩜰
    0x29731: 'kǎn,sǎn',  # 𩜱
    0x29732: 'fú',  # 𩜲
    0x29733: 'yǒng',  # 𩜳
    # 0x29734: '',  # 𩜴
    0x29735: 'tuán',  # 𩜵
    0x29736: 'tǒu',  # 𩜶
    0x29737: 'yòu,niù',  # 𩜷
    0x29738: 'yāo',  # 𩜸
    # 0x29739: '',  # 𩜹
    0x2973A: 'yē',  # 𩜺
    # 0x2973B: '',  # 𩜻
    # 0x2973C: '',  # 𩜼
    0x2973D: 'yàn',  # 𩜽
    # 0x2973E: '',  # 𩜾
    # 0x2973F: '',  # 𩜿
    # 0x29740: '',  # 𩝀
    # 0x29741: '',  # 𩝁
    # 0x29742: '',  # 𩝂
    # 0x29743: '',  # 𩝃
    # 0x29744: '',  # 𩝄
    # 0x29745: '',  # 𩝅
    # 0x29746: '',  # 𩝆
    # 0x29747: '',  # 𩝇
    0x29748: 'xián',  # 𩝈
    # 0x29749: '',  # 𩝉
    0x2974A: 'tí',  # 𩝊
    # 0x2974B: '',  # 𩝋
    0x2974C: 'suì',  # 𩝌
    0x2974D: 'hóu',  # 𩝍
    # 0x2974E: '',  # 𩝎
    # 0x2974F: '',  # 𩝏
    0x29750: 'cí',  # 𩝐
    0x29751: 'xuān',  # 𩝑
    # 0x29752: '',  # 𩝒
    # 0x29753: '',  # 𩝓
    0x29754: 'xǔ',  # 𩝔
    0x29755: 'wù',  # 𩝕
    0x29756: 'cān',  # 𩝖
    0x29757: 'yù',  # 𩝗
    # 0x29758: '',  # 𩝘
    # 0x29759: '',  # 𩝙
    0x2975A: 'chǎn',  # 𩝚
    0x2975B: 'xiá',  # 𩝛
    # 0x2975C: '',  # 𩝜
    0x2975D: 'kào,gāo',  # 𩝝
    0x2975E: 'cāng',  # 𩝞
    0x2975F: 'chā',  # 𩝟
    0x29760: 'qiǔ',  # 𩝠
    # 0x29761: '',  # 𩝡
    # 0x29762: '',  # 𩝢
    0x29763: 'dā',  # 𩝣
    # 0x29764: '',  # 𩝤
    0x29765: 'sù',  # 𩝥
    0x29766: 'zhāi',  # 𩝦
    # 0x29767: '',  # 𩝧
    0x29768: 'huā',  # 𩝨
    # 0x29769: '',  # 𩝩
    # 0x2976A: '',  # 𩝪
    # 0x2976B: '',  # 𩝫
    # 0x2976C: '',  # 𩝬
    # 0x2976D: '',  # 𩝭
    # 0x2976E: '',  # 𩝮
    # 0x2976F: '',  # 𩝯
    # 0x29770: '',  # 𩝰
    # 0x29771: '',  # 𩝱
    # 0x29772: '',  # 𩝲
    # 0x29773: '',  # 𩝳
    # 0x29774: '',  # 𩝴
    # 0x29775: '',  # 𩝵
    # 0x29776: '',  # 𩝶
    0x29777: 'wū',  # 𩝷
    0x29778: 'yuān',  # 𩝸
    # 0x29779: '',  # 𩝹
    # 0x2977A: '',  # 𩝺
    # 0x2977B: '',  # 𩝻
    # 0x2977C: '',  # 𩝼
    0x2977D: 'jiàng',  # 𩝽
    0x2977E: 'xiǎng',  # 𩝾
    0x2977F: 'zhāi',  # 𩝿
    0x29780: 'sǎn,chěn,càn',  # 𩞀
    0x29781: 'mó,mí',  # 𩞁
    # 0x29782: '',  # 𩞂
    0x29783: 'shǎng,xiǎng',  # 𩞃
    0x29784: 'cáo',  # 𩞄
    0x29785: 'suī',  # 𩞅
    0x29786: 'chuáng',  # 𩞆
    0x29787: 'mí',  # 𩞇
    0x29788: 'zhú',  # 𩞈
    0x29789: 'chóng',  # 𩞉
    0x2978A: 'jì',  # 𩞊
    0x2978B: 'chóng',  # 𩞋
    # 0x2978C: '',  # 𩞌
    # 0x2978D: '',  # 𩞍
    # 0x2978E: '',  # 𩞎
    # 0x2978F: '',  # 𩞏
    # 0x29790: '',  # 𩞐
    0x29791: 'fēn',  # 𩞑
    # 0x29792: '',  # 𩞒
    # 0x29793: '',  # 𩞓
    # 0x29794: '',  # 𩞔
    # 0x29795: '',  # 𩞕
    # 0x29796: '',  # 𩞖
    # 0x29797: '',  # 𩞗
    # 0x29798: '',  # 𩞘
    0x29799: 'lián',  # 𩞙
    # 0x2979A: '',  # 𩞚
    # 0x2979B: '',  # 𩞛
    # 0x2979C: '',  # 𩞜
    # 0x2979D: '',  # 𩞝
    0x2979E: 'hài',  # 𩞞
    # 0x2979F: '',  # 𩞟
    # 0x297A0: '',  # 𩞠
    # 0x297A1: '',  # 𩞡
    # 0x297A2: '',  # 𩞢
    0x297A3: 'tāo',  # 𩞣
    0x297A4: 'dūn',  # 𩞤
    0x297A5: 'xiǎng',  # 𩞥
    0x297A6: 'chēng',  # 𩞦
    0x297A7: 'shǎng',  # 𩞧
    0x297A8: 'lì',  # 𩞨
    0x297A9: 'huáng',  # 𩞩
    # 0x297AA: '',  # 𩞪
    # 0x297AB: '',  # 𩞫
    0x297AC: 'dèng',  # 𩞬
    # 0x297AD: '',  # 𩞭
    # 0x297AE: '',  # 𩞮
    # 0x297AF: '',  # 𩞯
    # 0x297B0: '',  # 𩞰
    # 0x297B1: '',  # 𩞱
    # 0x297B2: '',  # 𩞲
    # 0x297B3: '',  # 𩞳
    # 0x297B4: '',  # 𩞴
    # 0x297B5: '',  # 𩞵
    0x297B6: 'zā',  # 𩞶
    0x297B7: 'liù',  # 𩞷
    # 0x297B8: '',  # 𩞸
    # 0x297B9: '',  # 𩞹
    0x297BA: 'huò',  # 𩞺
    0x297BB: 'lín',  # 𩞻
    # 0x297BC: '',  # 𩞼
    # 0x297BD: '',  # 𩞽
    0x297BE: 'dú,yì',  # 𩞾
    0x297BF: 'hàn',  # 𩞿
    0x297C0: 'yōng,yǒng',  # 𩟀
    0x297C1: 'yuàn,xuàn',  # 𩟁
    0x297C2: 'guò',  # 𩟂
    0x297C3: 'líng',  # 𩟃
    # 0x297C4: '',  # 𩟄
    0x297C5: 'liǎn',  # 𩟅
    # 0x297C6: '',  # 𩟆
    0x297C7: 'ào',  # 𩟇
    0x297C8: 'dāng',  # 𩟈
    0x297C9: 'yì',  # 𩟉
    0x297CA: 'nóng',  # 𩟊
    0x297CB: 'shàn',  # 𩟋
    # 0x297CC: '',  # 𩟌
    0x297CD: 'xìn',  # 𩟍
    # 0x297CE: '',  # 𩟎
    # 0x297CF: '',  # 𩟏
    0x297D0: 'dá',  # 𩟐
    0x297D1: 'yù',  # 𩟑
    0x297D2: 'cān',  # 𩟒
    0x297D3: 'wò',  # 𩟓
    0x297D4: 'chá',  # 𩟔
    0x297D5: 'bó',  # 𩟕
    # 0x297D6: '',  # 𩟖
    0x297D7: 'jiǎn',  # 𩟗
    # 0x297D8: '',  # 𩟘
    # 0x297D9: '',  # 𩟙
    # 0x297DA: '',  # 𩟚
    # 0x297DB: '',  # 𩟛
    # 0x297DC: '',  # 𩟜
    # 0x297DD: '',  # 𩟝
    0x297DE: 'méng',  # 𩟞
    0x297DF: 'wěi',  # 𩟟
    0x297E0: 'mó',  # 𩟠
    # 0x297E1: '',  # 𩟡
    # 0x297E2: '',  # 𩟢
    # 0x297E3: '',  # 𩟣
    # 0x297E4: '',  # 𩟤
    0x297E5: 'shuì,juǎn',  # 𩟥
    0x297E6: 'jié',  # 𩟦
    0x297E7: 'shuò',  # 𩟧
    0x297E8: 'huò',  # 𩟨
    # 0x297E9: '',  # 𩟩
    # 0x297EA: '',  # 𩟪
    0x297EB: 'chuò',  # 𩟫
    # 0x297EC: '',  # 𩟬
    0x297ED: 'lóng',  # 𩟭
    0x297EE: 'huài',  # 𩟮
    # 0x297EF: '',  # 𩟯
    0x297F0: 'tuō',  # 𩟰
    # 0x297F1: '',  # 𩟱
    # 0x297F2: '',  # 𩟲
    0x297F3: 'yú',  # 𩟳
    0x297F4: 'sǎn',  # 𩟴
    # 0x297F5: '',  # 𩟵
    0x297F6: 'chàn,jié',  # 𩟶
    0x297F7: 'yōng',  # 𩟷
    0x297F8: 'huò',  # 𩟸
    # 0x297F9: '',  # 𩟹
    0x297FA: 'lǎn',  # 𩟺
    # 0x297FB: '',  # 𩟻
    # 0x297FC: '',  # 𩟼
    # 0x297FD: '',  # 𩟽
    # 0x297FE: '',  # 𩟾
    # 0x297FF: '',  # 𩟿
    # 0x29800: '',  # 𩠀
    # 0x29801: '',  # 𩠁
    # 0x29802: '',  # 𩠂
    # 0x29803: '',  # 𩠃
    # 0x29804: '',  # 𩠄
    # 0x29805: '',  # 𩠅
    # 0x29806: '',  # 𩠆
    # 0x29807: '',  # 𩠇
    # 0x29808: '',  # 𩠈
    # 0x29809: '',  # 𩠉
    # 0x2980A: '',  # 𩠊
    # 0x2980B: '',  # 𩠋
    # 0x2980C: '',  # 𩠌
    # 0x2980D: '',  # 𩠍
    # 0x2980E: '',  # 𩠎
    # 0x2980F: '',  # 𩠏
    # 0x29810: '',  # 𩠐
    0x29811: 'dǐng',  # 𩠑
    # 0x29812: '',  # 𩠒
    # 0x29813: '',  # 𩠓
    # 0x29814: '',  # 𩠔
    # 0x29815: '',  # 𩠕
    # 0x29816: '',  # 𩠖
    # 0x29817: '',  # 𩠗
    # 0x29818: '',  # 𩠘
    # 0x29819: '',  # 𩠙
    0x2981A: 'hái',  # 𩠚
    # 0x2981B: '',  # 𩠛
    # 0x2981C: '',  # 𩠜
    # 0x2981D: '',  # 𩠝
    # 0x2981E: '',  # 𩠞
    0x2981F: 'wǔ',  # 𩠟
    # 0x29820: '',  # 𩠠
    # 0x29821: '',  # 𩠡
    # 0x29822: '',  # 𩠢
    # 0x29823: '',  # 𩠣
    # 0x29824: '',  # 𩠤
    # 0x29825: '',  # 𩠥
    0x29826: 'qǐ,shǒu',  # 𩠦
    # 0x29827: '',  # 𩠧
    0x29828: 'jī,qǐ',  # 𩠨
    # 0x29829: '',  # 𩠩
    # 0x2982A: '',  # 𩠪
    # 0x2982B: '',  # 𩠫
    # 0x2982C: '',  # 𩠬
    # 0x2982D: '',  # 𩠭
    0x2982E: 'kuí',  # 𩠮
    0x2982F: 'wéi',  # 𩠯
    # 0x29830: '',  # 𩠰
    # 0x29831: '',  # 𩠱
    # 0x29832: '',  # 𩠲
    # 0x29833: '',  # 𩠳
    # 0x29834: '',  # 𩠴
    # 0x29835: '',  # 𩠵
    0x29836: 'shǒu',  # 𩠶
    0x29837: 'fú',  # 𩠷
    # 0x29838: '',  # 𩠸
    0x29839: 'tuán',  # 𩠹
    # 0x2983A: '',  # 𩠺
    0x2983B: 'bié,hān',  # 𩠻
    # 0x2983C: '',  # 𩠼
    0x2983D: 'tán',  # 𩠽
    0x2983E: 'hāng',  # 𩠾
    0x2983F: 'piē',  # 𩠿
    # 0x29840: '',  # 𩡀
    # 0x29841: '',  # 𩡁
    # 0x29842: '',  # 𩡂
    0x29843: 'yú',  # 𩡃
    0x29844: 'tán,xiāng',  # 𩡄
    # 0x29845: '',  # 𩡅
    # 0x29846: '',  # 𩡆
    # 0x29847: '',  # 𩡇
    # 0x29848: '',  # 𩡈
    # 0x29849: '',  # 𩡉
    # 0x2984A: '',  # 𩡊
    # 0x2984B: '',  # 𩡋
    0x2984C: 'xiāng',  # 𩡌
    # 0x2984D: '',  # 𩡍
    0x2984E: 'xiū',  # 𩡎
    # 0x2984F: '',  # 𩡏
    # 0x29850: '',  # 𩡐
    # 0x29851: '',  # 𩡑
    # 0x29852: '',  # 𩡒
    0x29853: 'wěng',  # 𩡓
    0x29854: 'hài',  # 𩡔
    0x29855: 'péng',  # 𩡕
    # 0x29856: '',  # 𩡖
    # 0x29857: '',  # 𩡗
    # 0x29858: '',  # 𩡘
    # 0x29859: '',  # 𩡙
    # 0x2985A: '',  # 𩡚
    # 0x2985B: '',  # 𩡛
    # 0x2985C: '',  # 𩡜
    0x2985D: 'tán',  # 𩡝
    # 0x2985E: '',  # 𩡞
    0x2985F: 'bié',  # 𩡟
    0x29860: 'xiāng',  # 𩡠
    # 0x29861: '',  # 𩡡
    # 0x29862: '',  # 𩡢
    0x29863: 'yǐ',  # 𩡣
    # 0x29864: '',  # 𩡤
    # 0x29865: '',  # 𩡥
    0x29866: 'piáo',  # 𩡦
    0x29867: 'huán',  # 𩡧
    0x29868: 'mǔ',  # 𩡨
    0x29869: 'bā',  # 𩡩
    # 0x2986A: '',  # 𩡪
    0x2986B: 'fàn',  # 𩡫
    # 0x2986C: '',  # 𩡬
    0x2986D: 'bó',  # 𩡭
    # 0x2986E: '',  # 𩡮
    0x2986F: 'dīng',  # 𩡯
    # 0x29870: '',  # 𩡰
    # 0x29871: '',  # 𩡱
    # 0x29872: '',  # 𩡲
    # 0x29873: '',  # 𩡳
    # 0x29874: '',  # 𩡴
    # 0x29875: '',  # 𩡵
    # 0x29876: '',  # 𩡶
    0x29877: 'fēn,fèi',  # 𩡷
    # 0x29878: '',  # 𩡸
    # 0x29879: '',  # 𩡹
    0x2987A: 'jiè',  # 𩡺
    # 0x2987B: '',  # 𩡻
    # 0x2987C: '',  # 𩡼
    # 0x2987D: '',  # 𩡽
    0x2987E: 'suó',  # 𩡾
    # 0x2987F: '',  # 𩡿
    # 0x29880: '',  # 𩢀
    # 0x29881: '',  # 𩢁
    # 0x29882: '',  # 𩢂
    # 0x29883: '',  # 𩢃
    0x29884: 'wàn',  # 𩢄
    0x29885: 'gē',  # 𩢅
    # 0x29886: '',  # 𩢆
    # 0x29887: '',  # 𩢇
    0x29888: 'fēn',  # 𩢈
    # 0x29889: '',  # 𩢉
    0x2988A: 'tuó',  # 𩢊
    # 0x2988B: '',  # 𩢋
    0x2988C: 'wén',  # 𩢌
    0x2988D: 'guā',  # 𩢍
    0x2988E: 'duō',  # 𩢎
    # 0x2988F: '',  # 𩢏
    0x29890: 'zhé',  # 𩢐
    0x29891: 'cǐ',  # 𩢑
    0x29892: 'yǎo',  # 𩢒
    # 0x29893: '',  # 𩢓
    0x29894: 'bàn',  # 𩢔
    0x29895: 'bù',  # 𩢕
    0x29896: 'mò',  # 𩢖
    # 0x29897: '',  # 𩢗
    0x29898: 'pǒ',  # 𩢘
    # 0x29899: '',  # 𩢙
    # 0x2989A: '',  # 𩢚
    0x2989B: 'gé',  # 𩢛
    # 0x2989C: '',  # 𩢜
    # 0x2989D: '',  # 𩢝
    0x2989E: 'liú',  # 𩢞
    # 0x2989F: '',  # 𩢟
    # 0x298A0: '',  # 𩢠
    0x298A1: 'rǎn',  # 𩢡
    # 0x298A2: '',  # 𩢢
    # 0x298A3: '',  # 𩢣
    # 0x298A4: '',  # 𩢤
    # 0x298A5: '',  # 𩢥
    # 0x298A6: '',  # 𩢦
    # 0x298A7: '',  # 𩢧
    0x298A8: 'gān',  # 𩢨
    # 0x298A9: '',  # 𩢩
    0x298AA: 'hú',  # 𩢪
    0x298AB: 'móu',  # 𩢫
    # 0x298AC: '',  # 𩢬
    # 0x298AD: '',  # 𩢭
    0x298AE: 'xiū',  # 𩢮
    0x298AF: 'huāng',  # 𩢯
    0x298B0: 'fú',  # 𩢰
    0x298B1: 'huí',  # 𩢱
    0x298B2: 'shì',  # 𩢲
    0x298B3: 'qú',  # 𩢳
    0x298B4: 'jié,jí',  # 𩢴
    0x298B5: 'tuō',  # 𩢵
    0x298B6: 'yú',  # 𩢶
    0x298B7: 'mò',  # 𩢷
    0x298B8: 'zhōu',  # 𩢸
    0x298B9: 'jiù',  # 𩢹
    # 0x298BA: '',  # 𩢺
    0x298BB: 'shú',  # 𩢻
    0x298BC: 'kuāng',  # 𩢼
    0x298BD: 'qióng',  # 𩢽
    0x298BE: 'liè',  # 𩢾
    0x298BF: 'fù',  # 𩢿
    # 0x298C0: '',  # 𩣀
    # 0x298C1: '',  # 𩣁
    # 0x298C2: '',  # 𩣂
    # 0x298C3: '',  # 𩣃
    # 0x298C4: '',  # 𩣄
    # 0x298C5: '',  # 𩣅
    # 0x298C6: '',  # 𩣆
    # 0x298C7: '',  # 𩣇
    # 0x298C8: '',  # 𩣈
    # 0x298C9: '',  # 𩣉
    0x298CA: 'xù',  # 𩣊
    # 0x298CB: '',  # 𩣋
    # 0x298CC: '',  # 𩣌
    # 0x298CD: '',  # 𩣍
    # 0x298CE: '',  # 𩣎
    # 0x298CF: '',  # 𩣏
    # 0x298D0: '',  # 𩣐
    # 0x298D1: '',  # 𩣑
    # 0x298D2: '',  # 𩣒
    # 0x298D3: '',  # 𩣓
    # 0x298D4: '',  # 𩣔
    # 0x298D5: '',  # 𩣕
    0x298D6: 'lìn',  # 𩣖
    # 0x298D7: '',  # 𩣗
    0x298D8: 'niè',  # 𩣘
    # 0x298D9: '',  # 𩣙
    0x298DA: 'pī,bǐ',  # 𩣚
    # 0x298DB: '',  # 𩣛
    0x298DC: 'fù',  # 𩣜
    0x298DD: 'bù',  # 𩣝
    0x298DE: 'yì,sà',  # 𩣞
    # 0x298DF: '',  # 𩣟
    # 0x298E0: '',  # 𩣠
    0x298E1: 'bó',  # 𩣡
    # 0x298E2: '',  # 𩣢
    0x298E3: 'é,ě',  # 𩣣
    # 0x298E4: '',  # 𩣤
    # 0x298E5: '',  # 𩣥
    # 0x298E6: '',  # 𩣦
    # 0x298E7: '',  # 𩣧
    # 0x298E8: '',  # 𩣨
    0x298E9: 'zhé',  # 𩣩
    # 0x298EA: '',  # 𩣪
    0x298EB: 'lì',  # 𩣫
    # 0x298EC: '',  # 𩣬
    # 0x298ED: '',  # 𩣭
    0x298EE: 'tù',  # 𩣮
    0x298EF: 'dá',  # 𩣯
    # 0x298F0: '',  # 𩣰
    0x298F1: 'lù',  # 𩣱
    0x298F2: 'yān',  # 𩣲
    0x298F3: 'dōng',  # 𩣳
    0x298F4: 'qiè',  # 𩣴
    0x298F5: 'wǎn',  # 𩣵
    0x298F6: 'mǐng',  # 𩣶
    0x298F7: 'zuī,zhù',  # 𩣷
    0x298F8: 'fù',  # 𩣸
    0x298F9: 'qū',  # 𩣹
    0x298FA: 'bēn',  # 𩣺
    0x298FB: 'ǎo',  # 𩣻
    0x298FC: 'qiāng',  # 𩣼
    # 0x298FD: '',  # 𩣽
    # 0x298FE: '',  # 𩣾
    # 0x298FF: '',  # 𩣿
    # 0x29900: '',  # 𩤀
    0x29901: 'qūn',  # 𩤁
    # 0x29902: '',  # 𩤂
    # 0x29903: '',  # 𩤃
    # 0x29904: '',  # 𩤄
    # 0x29905: '',  # 𩤅
    # 0x29906: '',  # 𩤆
    # 0x29907: '',  # 𩤇
    0x29908: 'què',  # 𩤈
    0x29909: 'huá,táo',  # 𩤉
    0x2990A: 'xiàn,jiàn',  # 𩤊
    0x2990B: 'kùn',  # 𩤋
    # 0x2990C: '',  # 𩤌
    # 0x2990D: '',  # 𩤍
    # 0x2990E: '',  # 𩤎
    0x2990F: 'cuì',  # 𩤏
    # 0x29910: '',  # 𩤐
    # 0x29911: '',  # 𩤑
    0x29912: 'yí',  # 𩤒
    # 0x29913: '',  # 𩤓
    # 0x29914: '',  # 𩤔
    # 0x29915: '',  # 𩤕
    0x29916: 'chī,ér',  # 𩤖
    0x29917: 'zòng',  # 𩤗
    0x29918: 'nǎo',  # 𩤘
    0x29919: 'chéng',  # 𩤙
    0x2991A: 'duān',  # 𩤚
    0x2991B: 'yóng',  # 𩤛
    0x2991C: 'zhě',  # 𩤜
    # 0x2991D: '',  # 𩤝
    0x2991E: 'tàn',  # 𩤞
    0x2991F: 'yáng',  # 𩤟
    0x29920: 'xié',  # 𩤠
    0x29921: 'xuān',  # 𩤡
    # 0x29922: '',  # 𩤢
    0x29923: 'duàn',  # 𩤣
    0x29924: 'shuǎ',  # 𩤤
    0x29925: 'xián',  # 𩤥
    0x29926: 'xián',  # 𩤦
    # 0x29927: '',  # 𩤧
    # 0x29928: '',  # 𩤨
    0x29929: 'é',  # 𩤩
    # 0x2992A: '',  # 𩤪
    # 0x2992B: '',  # 𩤫
    # 0x2992C: '',  # 𩤬
    # 0x2992D: '',  # 𩤭
    # 0x2992E: '',  # 𩤮
    # 0x2992F: '',  # 𩤯
    # 0x29930: '',  # 𩤰
    # 0x29931: '',  # 𩤱
    0x29932: 'lā',  # 𩤲
    # 0x29933: '',  # 𩤳
    # 0x29934: '',  # 𩤴
    # 0x29935: '',  # 𩤵
    # 0x29936: '',  # 𩤶
    # 0x29937: '',  # 𩤷
    0x29938: 'wèi',  # 𩤸
    0x29939: 'yōu',  # 𩤹
    0x2993A: 'yú',  # 𩤺
    # 0x2993B: '',  # 𩤻
    # 0x2993C: '',  # 𩤼
    0x2993D: 'tī',  # 𩤽
    # 0x2993E: '',  # 𩤾
    0x2993F: 'jīn',  # 𩤿
    # 0x29940: '',  # 𩥀
    0x29941: 'táng',  # 𩥁
    0x29942: 'qí',  # 𩥂
    0x29943: 'méng',  # 𩥃
    0x29944: 'diān',  # 𩥄
    0x29945: 'tāo',  # 𩥅
    0x29946: 'lǜ',  # 𩥆
    0x29947: 'zhàn',  # 𩥇
    0x29948: 'wēn',  # 𩥈
    0x29949: 'jì',  # 𩥉
    0x2994A: 'āo,jiāo',  # 𩥊
    0x2994B: 'òu,dú',  # 𩥋
    0x2994C: 'qià',  # 𩥌
    0x2994D: 'xīng',  # 𩥍
    # 0x2994E: '',  # 𩥎
    # 0x2994F: '',  # 𩥏
    0x29950: 'shī',  # 𩥐
    0x29951: 'tǎ',  # 𩥑
    # 0x29952: '',  # 𩥒
    # 0x29953: '',  # 𩥓
    0x29954: 'mò',  # 𩥔
    # 0x29955: '',  # 𩥕
    # 0x29956: '',  # 𩥖
    # 0x29957: '',  # 𩥗
    0x29958: 'yóu',  # 𩥘
    # 0x29959: '',  # 𩥙
    # 0x2995A: '',  # 𩥚
    # 0x2995B: '',  # 𩥛
    # 0x2995C: '',  # 𩥜
    # 0x2995D: '',  # 𩥝
    # 0x2995E: '',  # 𩥞
    # 0x2995F: '',  # 𩥟
    0x29960: 'zhá',  # 𩥠
    # 0x29961: '',  # 𩥡
    # 0x29962: '',  # 𩥢
    0x29963: 'yáo',  # 𩥣
    # 0x29964: '',  # 𩥤
    # 0x29965: '',  # 𩥥
    # 0x29966: '',  # 𩥦
    # 0x29967: '',  # 𩥧
    # 0x29968: '',  # 𩥨
    # 0x29969: '',  # 𩥩
    # 0x2996A: '',  # 𩥪
    0x2996B: 'chōng',  # 𩥫
    0x2996C: 'lí',  # 𩥬
    0x2996D: 'yú',  # 𩥭
    0x2996E: 'chǎn',  # 𩥮
    0x2996F: 'yī',  # 𩥯
    # 0x29970: '',  # 𩥰
    # 0x29971: '',  # 𩥱
    0x29972: 'chì',  # 𩥲
    # 0x29973: '',  # 𩥳
    0x29974: 'lí',  # 𩥴
    # 0x29975: '',  # 𩥵
    # 0x29976: '',  # 𩥶
    # 0x29977: '',  # 𩥷
    # 0x29978: '',  # 𩥸
    # 0x29979: '',  # 𩥹
    # 0x2997A: '',  # 𩥺
    # 0x2997B: '',  # 𩥻
    # 0x2997C: '',  # 𩥼
    0x2997D: 'tú',  # 𩥽
    # 0x2997E: '',  # 𩥾
    0x2997F: 'zú',  # 𩥿
    # 0x29980: '',  # 𩦀
    # 0x29981: '',  # 𩦁
    0x29982: 'xián',  # 𩦂
    # 0x29983: '',  # 𩦃
    # 0x29984: '',  # 𩦄
    # 0x29985: '',  # 𩦅
    # 0x29986: '',  # 𩦆
    0x29987: 'xì',  # 𩦇
    # 0x29988: '',  # 𩦈
    0x29989: 'bié',  # 𩦉
    0x2998A: 'hán,qiān',  # 𩦊
    0x2998B: 'qí',  # 𩦋
    0x2998C: 'sāng,shuāng',  # 𩦌
    # 0x2998D: '',  # 𩦍
    0x2998E: 'fēi,fěi',  # 𩦎
    # 0x2998F: '',  # 𩦏
    0x29990: 'shàn,huō',  # 𩦐
    # 0x29991: '',  # 𩦑
    # 0x29992: '',  # 𩦒
    # 0x29993: '',  # 𩦓
    # 0x29994: '',  # 𩦔
    # 0x29995: '',  # 𩦕
    # 0x29996: '',  # 𩦖
    # 0x29997: '',  # 𩦗
    0x29998: 'huān',  # 𩦘
    # 0x29999: '',  # 𩦙
    # 0x2999A: '',  # 𩦚
    # 0x2999B: '',  # 𩦛
    # 0x2999C: '',  # 𩦜
    # 0x2999D: '',  # 𩦝
    # 0x2999E: '',  # 𩦞
    # 0x2999F: '',  # 𩦟
    0x299A0: 'bàng',  # 𩦠
    0x299A1: 'yú',  # 𩦡
    0x299A2: 'yú',  # 𩦢
    # 0x299A3: '',  # 𩦣
    0x299A4: 'jí',  # 𩦤
    # 0x299A5: '',  # 𩦥
    # 0x299A6: '',  # 𩦦
    # 0x299A7: '',  # 𩦧
    # 0x299A8: '',  # 𩦨
    # 0x299A9: '',  # 𩦩
    # 0x299AA: '',  # 𩦪
    # 0x299AB: '',  # 𩦫
    # 0x299AC: '',  # 𩦬
    # 0x299AD: '',  # 𩦭
    # 0x299AE: '',  # 𩦮
    # 0x299AF: '',  # 𩦯
    # 0x299B0: '',  # 𩦰
    0x299B1: 'kuǎi',  # 𩦱
    0x299B2: 'zōng',  # 𩦲
    # 0x299B3: '',  # 𩦳
    # 0x299B4: '',  # 𩦴
    # 0x299B5: '',  # 𩦵
    # 0x299B6: '',  # 𩦶
    0x299B7: 'tiě',  # 𩦷
    # 0x299B8: '',  # 𩦸
    0x299B9: 'xiàn',  # 𩦹
    0x299BA: 'méng',  # 𩦺
    # 0x299BB: '',  # 𩦻
    # 0x299BC: '',  # 𩦼
    # 0x299BD: '',  # 𩦽
    # 0x299BE: '',  # 𩦾
    # 0x299BF: '',  # 𩦿
    0x299C0: 'tiě',  # 𩧀
    0x299C1: 'zhòu',  # 𩧁
    # 0x299C2: '',  # 𩧂
    0x299C3: 'lì',  # 𩧃
    0x299C4: 'zhì',  # 𩧄
    0x299C5: 'fán',  # 𩧅
    0x299C6: 'liè,là',  # 𩧆
    0x299C7: 'cài',  # 𩧇
    0x299C8: 'dú',  # 𩧈
    0x299C9: 'guāng',  # 𩧉
    0x299CA: 'xiòng',  # 𩧊
    0x299CB: 'lí',  # 𩧋
    0x299CC: 'qì',  # 𩧌
    # 0x299CD: '',  # 𩧍
    # 0x299CE: '',  # 𩧎
    0x299CF: 'jué',  # 𩧏
    0x299D0: 'tuō',  # 𩧐
    # 0x299D1: '',  # 𩧑
    0x299D2: 'jù',  # 𩧒
    0x299D3: 'xiāo',  # 𩧓
    # 0x299D4: '',  # 𩧔
    # 0x299D5: '',  # 𩧕
    # 0x299D6: '',  # 𩧖
    # 0x299D7: '',  # 𩧗
    0x299D8: 'qú',  # 𩧘
    # 0x299D9: '',  # 𩧙
    # 0x299DA: '',  # 𩧚
    # 0x299DB: '',  # 𩧛
    0x299DC: 'zhuǎn',  # 𩧜
    # 0x299DD: '',  # 𩧝
    # 0x299DE: '',  # 𩧞
    # 0x299DF: '',  # 𩧟
    # 0x299E0: '',  # 𩧠
    0x299E1: 'jué',  # 𩧡
    # 0x299E2: '',  # 𩧢
    # 0x299E3: '',  # 𩧣
    # 0x299E4: '',  # 𩧤
    # 0x299E5: '',  # 𩧥
    # 0x299E6: '',  # 𩧦
    # 0x299E7: '',  # 𩧧
    # 0x299E8: '',  # 𩧨
    # 0x299E9: '',  # 𩧩
    # 0x299EA: '',  # 𩧪
    # 0x299EB: '',  # 𩧫
    0x299EC: 'rǎn',  # 𩧬
    # 0x299ED: '',  # 𩧭
    # 0x299EE: '',  # 𩧮
    # 0x299EF: '',  # 𩧯
    # 0x299F0: '',  # 𩧰
    # 0x299F1: '',  # 𩧱
    # 0x299F2: '',  # 𩧲
    # 0x299F3: '',  # 𩧳
    # 0x299F4: '',  # 𩧴
    # 0x299F5: '',  # 𩧵
    # 0x299F6: '',  # 𩧶
    # 0x299F7: '',  # 𩧷
    # 0x299F8: '',  # 𩧸
    # 0x299F9: '',  # 𩧹
    # 0x299FA: '',  # 𩧺
    0x299FB: 'wǎn',  # 𩧻
    # 0x299FC: '',  # 𩧼
    # 0x299FD: '',  # 𩧽
    # 0x299FE: '',  # 𩧾
    # 0x299FF: '',  # 𩧿
    # 0x29A00: '',  # 𩨀
    # 0x29A01: '',  # 𩨁
    # 0x29A02: '',  # 𩨂
    # 0x29A03: '',  # 𩨃
    # 0x29A04: '',  # 𩨄
    # 0x29A05: '',  # 𩨅
    # 0x29A06: '',  # 𩨆
    # 0x29A07: '',  # 𩨇
    # 0x29A08: '',  # 𩨈
    # 0x29A09: '',  # 𩨉
    # 0x29A0A: '',  # 𩨊
    # 0x29A0B: '',  # 𩨋
    # 0x29A0C: '',  # 𩨌
    # 0x29A0D: '',  # 𩨍
    # 0x29A0E: '',  # 𩨎
    # 0x29A0F: '',  # 𩨏
    # 0x29A10: '',  # 𩨐
    0x29A11: 'tīng',  # 𩨑
    0x29A12: 'jī',  # 𩨒
    0x29A13: 'qiān',  # 𩨓
    0x29A14: 'hú,huá',  # 𩨔
    # 0x29A15: '',  # 𩨕
    # 0x29A16: '',  # 𩨖
    0x29A17: 'yú',  # 𩨗
    0x29A18: 'qì,gē',  # 𩨘
    0x29A19: 'yú',  # 𩨙
    0x29A1A: 'wā',  # 𩨚
    # 0x29A1B: '',  # 𩨛
    0x29A1C: 'bǎ',  # 𩨜
    0x29A1D: 'qí',  # 𩨝
    0x29A1E: 'sǎ',  # 𩨞
    0x29A1F: 'qiāo',  # 𩨟
    0x29A20: 'yà',  # 𩨠
    0x29A21: 'xiǎn,sǎn',  # 𩨡
    # 0x29A22: '',  # 𩨢
    # 0x29A23: '',  # 𩨣
    # 0x29A24: '',  # 𩨤
    # 0x29A25: '',  # 𩨥
    # 0x29A26: '',  # 𩨦
    # 0x29A27: '',  # 𩨧
    0x29A28: 'cī',  # 𩨨
    0x29A29: 'fàn',  # 𩨩
    # 0x29A2A: '',  # 𩨪
    0x29A2B: 'kǔn',  # 𩨫
    0x29A2C: 'gǔn',  # 𩨬
    0x29A2D: 'quē',  # 𩨭
    0x29A2E: 'è',  # 𩨮
    0x29A2F: 'qióng',  # 𩨯
    # 0x29A30: '',  # 𩨰
    # 0x29A31: '',  # 𩨱
    0x29A32: 'mà',  # 𩨲
    0x29A33: 'kū,dū',  # 𩨳
    0x29A34: 'yǎo',  # 𩨴
    # 0x29A35: '',  # 𩨵
    # 0x29A36: '',  # 𩨶
    0x29A37: 'quē',  # 𩨷
    0x29A38: 'chū',  # 𩨸
    0x29A39: 'jiǎ',  # 𩨹
    # 0x29A3A: '',  # 𩨺
    0x29A3B: 'zhǔ',  # 𩨻
    # 0x29A3C: '',  # 𩨼
    0x29A3D: 'duī',  # 𩨽
    0x29A3E: 'wá',  # 𩨾
    # 0x29A3F: '',  # 𩨿
    0x29A40: 'nǎo',  # 𩩀
    # 0x29A41: '',  # 𩩁
    # 0x29A42: '',  # 𩩂
    # 0x29A43: '',  # 𩩃
    0x29A44: 'yán',  # 𩩄
    0x29A45: 'tóng',  # 𩩅
    # 0x29A46: '',  # 𩩆
    # 0x29A47: '',  # 𩩇
    # 0x29A48: '',  # 𩩈
    # 0x29A49: '',  # 𩩉
    # 0x29A4A: '',  # 𩩊
    0x29A4B: 'xíng,jìng',  # 𩩋
    0x29A4C: 'gǔn',  # 𩩌
    0x29A4D: 'pīng',  # 𩩍
    # 0x29A4E: '',  # 𩩎
    # 0x29A4F: '',  # 𩩏
    # 0x29A50: '',  # 𩩐
    0x29A51: 'yǔ',  # 𩩑
    0x29A52: 'hè',  # 𩩒
    # 0x29A53: '',  # 𩩓
    0x29A54: 'zhuó',  # 𩩔
    # 0x29A55: '',  # 𩩕
    # 0x29A56: '',  # 𩩖
    0x29A57: 'shē',  # 𩩗
    0x29A58: 'yǔ',  # 𩩘
    # 0x29A59: '',  # 𩩙
    # 0x29A5A: '',  # 𩩚
    0x29A5B: 'jì',  # 𩩛
    # 0x29A5C: '',  # 𩩜
    0x29A5D: 'qiāng',  # 𩩝
    0x29A5E: 'shuì',  # 𩩞
    0x29A5F: 'chuò',  # 𩩟
    0x29A60: 'zú',  # 𩩠
    0x29A61: 'léng',  # 𩩡
    0x29A62: 'ní',  # 𩩢
    # 0x29A63: '',  # 𩩣
    0x29A64: 'wā',  # 𩩤
    0x29A65: 'zhá',  # 𩩥
    # 0x29A66: '',  # 𩩦
    0x29A67: 'dàn',  # 𩩧
    # 0x29A68: '',  # 𩩨
    # 0x29A69: '',  # 𩩩
    # 0x29A6A: '',  # 𩩪
    # 0x29A6B: '',  # 𩩫
    # 0x29A6C: '',  # 𩩬
    # 0x29A6D: '',  # 𩩭
    0x29A6E: 'dù',  # 𩩮
    0x29A6F: 'biàn',  # 𩩯
    0x29A70: 'jiē,hái',  # 𩩰
    0x29A71: 'qià',  # 𩩱
    0x29A72: 'hé',  # 𩩲
    0x29A73: 'chòng',  # 𩩳
    0x29A74: 'yán',  # 𩩴
    # 0x29A75: '',  # 𩩵
    0x29A76: 'yàn',  # 𩩶
    # 0x29A77: '',  # 𩩷
    # 0x29A78: '',  # 𩩸
    # 0x29A79: '',  # 𩩹
    0x29A7A: 'sóng',  # 𩩺
    0x29A7B: 'téng',  # 𩩻
    0x29A7C: 'yǎo',  # 𩩼
    # 0x29A7D: '',  # 𩩽
    0x29A7E: 'kāo',  # 𩩾
    # 0x29A7F: '',  # 𩩿
    0x29A80: 'zhuī',  # 𩪀
    0x29A81: 'guì',  # 𩪁
    0x29A82: 'ái',  # 𩪂
    0x29A83: 'hài',  # 𩪃
    # 0x29A84: '',  # 𩪄
    # 0x29A85: '',  # 𩪅
    0x29A86: 'tǐ',  # 𩪆
    # 0x29A87: '',  # 𩪇
    0x29A88: 'suǒ',  # 𩪈
    0x29A89: 'xù',  # 𩪉
    0x29A8A: 'biāo',  # 𩪊
    # 0x29A8B: '',  # 𩪋
    0x29A8C: 'fèng',  # 𩪌
    0x29A8D: 'qū,shū',  # 𩪍
    0x29A8E: 'mǎng',  # 𩪎
    # 0x29A8F: '',  # 𩪏
    0x29A90: 'guó',  # 𩪐
    # 0x29A91: '',  # 𩪑
    # 0x29A92: '',  # 𩪒
    # 0x29A93: '',  # 𩪓
    # 0x29A94: '',  # 𩪔
    # 0x29A95: '',  # 𩪕
    0x29A96: 'bì',  # 𩪖
    0x29A97: 'jué',  # 𩪗
    0x29A98: 'chuáng',  # 𩪘
    # 0x29A99: '',  # 𩪙
    # 0x29A9A: '',  # 𩪚
    0x29A9B: 'pú',  # 𩪛
    # 0x29A9C: '',  # 𩪜
    # 0x29A9D: '',  # 𩪝
    # 0x29A9E: '',  # 𩪞
    0x29A9F: 'yì',  # 𩪟
    # 0x29AA0: '',  # 𩪠
    # 0x29AA1: '',  # 𩪡
    0x29AA2: 'qiān',  # 𩪢
    0x29AA3: 'yì',  # 𩪣
    0x29AA4: 'è',  # 𩪤
    0x29AA5: 'líng',  # 𩪥
    0x29AA6: 'suǐ',  # 𩪦
    0x29AA7: 'bì',  # 𩪧
    # 0x29AA8: '',  # 𩪨
    # 0x29AA9: '',  # 𩪩
    # 0x29AAA: '',  # 𩪪
    # 0x29AAB: '',  # 𩪫
    # 0x29AAC: '',  # 𩪬
    0x29AAD: 'huò',  # 𩪭
    0x29AAE: 'mǒ,mó',  # 𩪮
    # 0x29AAF: '',  # 𩪯
    # 0x29AB0: '',  # 𩪰
    0x29AB1: 'xūn',  # 𩪱
    # 0x29AB2: '',  # 𩪲
    # 0x29AB3: '',  # 𩪳
    0x29AB4: 'yàn',  # 𩪴
    # 0x29AB5: '',  # 𩪵
    # 0x29AB6: '',  # 𩪶
    # 0x29AB7: '',  # 𩪷
    0x29AB8: 'lì',  # 𩪸
    # 0x29AB9: '',  # 𩪹
    0x29ABA: 'tán',  # 𩪺
    # 0x29ABB: '',  # 𩪻
    # 0x29ABC: '',  # 𩪼
    # 0x29ABD: '',  # 𩪽
    0x29ABE: 'luán',  # 𩪾
    # 0x29ABF: '',  # 𩪿
    0x29AC0: 'kài',  # 𩫀
    0x29AC1: 'mào',  # 𩫁
    0x29AC2: 'xiāo',  # 𩫂
    # 0x29AC3: '',  # 𩫃
    # 0x29AC4: '',  # 𩫄
    # 0x29AC5: '',  # 𩫅
    # 0x29AC6: '',  # 𩫆
    0x29AC7: 'ǎi',  # 𩫇
    # 0x29AC8: '',  # 𩫈
    # 0x29AC9: '',  # 𩫉
    0x29ACA: 'tǎ',  # 𩫊
    # 0x29ACB: '',  # 𩫋
    # 0x29ACC: '',  # 𩫌
    0x29ACD: 'mèi',  # 𩫍
    # 0x29ACE: '',  # 𩫎
    0x29ACF: 'guō,yōng',  # 𩫏
    # 0x29AD0: '',  # 𩫐
    # 0x29AD1: '',  # 𩫑
    # 0x29AD2: '',  # 𩫒
    0x29AD3: 'gǎo',  # 𩫓
    0x29AD4: 'náo',  # 𩫔
    0x29AD5: 'háo',  # 𩫕
    0x29AD6: 'guō',  # 𩫖
    # 0x29AD7: '',  # 𩫗
    # 0x29AD8: '',  # 𩫘
    # 0x29AD9: '',  # 𩫙
    0x29ADA: 'háo',  # 𩫚
    # 0x29ADB: '',  # 𩫛
    # 0x29ADC: '',  # 𩫜
    # 0x29ADD: '',  # 𩫝
    # 0x29ADE: '',  # 𩫞
    # 0x29ADF: '',  # 𩫟
    0x29AE0: 'quē',  # 𩫠
    # 0x29AE1: '',  # 𩫡
    # 0x29AE2: '',  # 𩫢
    # 0x29AE3: '',  # 𩫣
    # 0x29AE4: '',  # 𩫤
    0x29AE5: 'cáo',  # 𩫥
    0x29AE6: 'sào',  # 𩫦
    # 0x29AE7: '',  # 𩫧
    # 0x29AE8: '',  # 𩫨
    # 0x29AE9: '',  # 𩫩
    # 0x29AEA: '',  # 𩫪
    0x29AEB: 'pí',  # 𩫫
    # 0x29AEC: '',  # 𩫬
    # 0x29AED: '',  # 𩫭
    # 0x29AEE: '',  # 𩫮
    # 0x29AEF: '',  # 𩫯
    # 0x29AF0: '',  # 𩫰
    # 0x29AF1: '',  # 𩫱
    0x29AF2: 'xiē',  # 𩫲
    0x29AF3: 'xiāo',  # 𩫳
    0x29AF4: 'jú',  # 𩫴
    # 0x29AF5: '',  # 𩫵
    # 0x29AF6: '',  # 𩫶
    # 0x29AF7: '',  # 𩫷
    # 0x29AF8: '',  # 𩫸
    0x29AF9: 'chéng',  # 𩫹
    0x29AFA: 'nǎo',  # 𩫺
    # 0x29AFB: '',  # 𩫻
    # 0x29AFC: '',  # 𩫼
    # 0x29AFD: '',  # 𩫽
    # 0x29AFE: '',  # 𩫾
    # 0x29AFF: '',  # 𩫿
    0x29B00: 'nèi',  # 𩬀
    # 0x29B01: '',  # 𩬁
    # 0x29B02: '',  # 𩬂
    # 0x29B03: '',  # 𩬃
    # 0x29B04: '',  # 𩬄
    # 0x29B05: '',  # 𩬅
    # 0x29B06: '',  # 𩬆
    # 0x29B07: '',  # 𩬇
    # 0x29B08: '',  # 𩬈
    # 0x29B09: '',  # 𩬉
    # 0x29B0A: '',  # 𩬊
    # 0x29B0B: '',  # 𩬋
    # 0x29B0C: '',  # 𩬌
    0x29B0D: 'mǔ',  # 𩬍
    # 0x29B0E: '',  # 𩬎
    0x29B0F: 'shāo',  # 𩬏
    # 0x29B10: '',  # 𩬐
    0x29B11: 'diān,chān',  # 𩬑
    # 0x29B12: '',  # 𩬒
    # 0x29B13: '',  # 𩬓
    0x29B14: 'líng',  # 𩬔
    # 0x29B15: '',  # 𩬕
    0x29B16: 'zhěn',  # 𩬖
    0x29B17: 'yǎo',  # 𩬗
    # 0x29B18: '',  # 𩬘
    0x29B19: 'fù,fū',  # 𩬙
    0x29B1A: 'qián,gàn',  # 𩬚
    0x29B1B: 'qióng',  # 𩬛
    0x29B1C: 'jú',  # 𩬜
    0x29B1D: 'bìng,fǎng',  # 𩬝
    0x29B1E: 'máo,mán,mián',  # 𩬞
    0x29B1F: 'zhà',  # 𩬟
    0x29B20: 'tāi',  # 𩬠
    # 0x29B21: '',  # 𩬡
    # 0x29B22: '',  # 𩬢
    # 0x29B23: '',  # 𩬣
    # 0x29B24: '',  # 𩬤
    # 0x29B25: '',  # 𩬥
    # 0x29B26: '',  # 𩬦
    # 0x29B27: '',  # 𩬧
    # 0x29B28: '',  # 𩬨
    # 0x29B29: '',  # 𩬩
    # 0x29B2A: '',  # 𩬪
    0x29B2B: 'zhǎi',  # 𩬫
    # 0x29B2C: '',  # 𩬬
    0x29B2D: 'shī',  # 𩬭
    0x29B2E: 'yòng',  # 𩬮
    # 0x29B2F: '',  # 𩬯
    0x29B30: 'qióng',  # 𩬰
    0x29B31: 'dào',  # 𩬱
    0x29B32: 'tì',  # 𩬲
    0x29B33: 'zhuǐ',  # 𩬳
    # 0x29B34: '',  # 𩬴
    0x29B35: 'yìn',  # 𩬵
    # 0x29B36: '',  # 𩬶
    0x29B37: 'nǎo',  # 𩬷
    0x29B38: 'bō',  # 𩬸
    0x29B39: 'kuāng',  # 𩬹
    0x29B3A: 'zhǐ',  # 𩬺
    0x29B3B: 'duǒ',  # 𩬻
    0x29B3C: 'cōng',  # 𩬼
    0x29B3D: 'bǎo',  # 𩬽
    # 0x29B3E: '',  # 𩬾
    # 0x29B3F: '',  # 𩬿
    # 0x29B40: '',  # 𩭀
    # 0x29B41: '',  # 𩭁
    # 0x29B42: '',  # 𩭂
    # 0x29B43: '',  # 𩭃
    # 0x29B44: '',  # 𩭄
    # 0x29B45: '',  # 𩭅
    # 0x29B46: '',  # 𩭆
    0x29B47: 'lí',  # 𩭇
    # 0x29B48: '',  # 𩭈
    # 0x29B49: '',  # 𩭉
    0x29B4A: 'jú',  # 𩭊
    0x29B4B: 'wén,kūn',  # 𩭋
    0x29B4C: 'liè',  # 𩭌
    # 0x29B4D: '',  # 𩭍
    # 0x29B4E: '',  # 𩭎
    0x29B4F: 'wǒ',  # 𩭏
    0x29B50: 'shǐ',  # 𩭐
    0x29B51: 'niǎo',  # 𩭑
    0x29B52: 'máng',  # 𩭒
    0x29B53: 'jiū',  # 𩭓
    # 0x29B54: '',  # 𩭔
    # 0x29B55: '',  # 𩭕
    # 0x29B56: '',  # 𩭖
    # 0x29B57: '',  # 𩭗
    0x29B58: 'xiū',  # 𩭘
    # 0x29B59: '',  # 𩭙
    # 0x29B5A: '',  # 𩭚
    0x29B5B: 'jiǎo',  # 𩭛
    # 0x29B5C: '',  # 𩭜
    0x29B5D: 'wō',  # 𩭝
    # 0x29B5E: '',  # 𩭞
    0x29B5F: 'dào',  # 𩭟
    # 0x29B60: '',  # 𩭠
    0x29B61: 'xī',  # 𩭡
    0x29B62: 'àn',  # 𩭢
    0x29B63: 'dá',  # 𩭣
    0x29B64: 'zǒng,zōng',  # 𩭤
    0x29B65: 'hàn',  # 𩭥
    0x29B66: 'chuí',  # 𩭦
    0x29B67: 'bī,bān',  # 𩭧
    # 0x29B68: '',  # 𩭨
    0x29B69: 'dòng',  # 𩭩
    # 0x29B6A: '',  # 𩭪
    0x29B6B: 'zhǎng',  # 𩭫
    # 0x29B6C: '',  # 𩭬
    # 0x29B6D: '',  # 𩭭
    # 0x29B6E: '',  # 𩭮
    0x29B6F: 'yā',  # 𩭯
    # 0x29B70: '',  # 𩭰
    # 0x29B71: '',  # 𩭱
    0x29B72: 'dí',  # 𩭲
    0x29B73: 'huō',  # 𩭳
    # 0x29B74: '',  # 𩭴
    # 0x29B75: '',  # 𩭵
    # 0x29B76: '',  # 𩭶
    0x29B77: 'mín',  # 𩭷
    # 0x29B78: '',  # 𩭸
    # 0x29B79: '',  # 𩭹
    0x29B7A: 'fù',  # 𩭺
    # 0x29B7B: '',  # 𩭻
    0x29B7C: 'bǎo',  # 𩭼
    0x29B7D: 'kè',  # 𩭽
    0x29B7E: 'máo',  # 𩭾
    0x29B7F: 'rè',  # 𩭿
    0x29B80: 'zōng,zǒng,sōng',  # 𩮀
    0x29B81: 'qià',  # 𩮁
    0x29B82: 'xiā',  # 𩮂
    0x29B83: 'sōu',  # 𩮃
    0x29B84: 'xiū',  # 𩮄
    0x29B85: 'nà',  # 𩮅
    # 0x29B86: '',  # 𩮆
    # 0x29B87: '',  # 𩮇
    # 0x29B88: '',  # 𩮈
    0x29B89: 'mán,mián',  # 𩮉
    # 0x29B8A: '',  # 𩮊
    # 0x29B8B: '',  # 𩮋
    # 0x29B8C: '',  # 𩮌
    # 0x29B8D: '',  # 𩮍
    0x29B8E: 'zhā',  # 𩮎
    0x29B8F: 'chán',  # 𩮏
    0x29B90: 'shè',  # 𩮐
    0x29B91: 'wǒ',  # 𩮑
    # 0x29B92: '',  # 𩮒
    # 0x29B93: '',  # 𩮓
    # 0x29B94: '',  # 𩮔
    # 0x29B95: '',  # 𩮕
    0x29B96: 'ái',  # 𩮖
    0x29B97: 'bàng,péng,fǎng',  # 𩮗
    0x29B98: 'hāo',  # 𩮘
    # 0x29B99: '',  # 𩮙
    0x29B9A: 'sāo',  # 𩮚
    0x29B9B: 'suǒ',  # 𩮛
    0x29B9C: 'tì',  # 𩮜
    0x29B9D: 'yà',  # 𩮝
    # 0x29B9E: '',  # 𩮞
    0x29B9F: 'bìng',  # 𩮟
    0x29BA0: 'róng',  # 𩮠
    # 0x29BA1: '',  # 𩮡
    # 0x29BA2: '',  # 𩮢
    # 0x29BA3: '',  # 𩮣
    # 0x29BA4: '',  # 𩮤
    # 0x29BA5: '',  # 𩮥
    # 0x29BA6: '',  # 𩮦
    # 0x29BA7: '',  # 𩮧
    # 0x29BA8: '',  # 𩮨
    # 0x29BA9: '',  # 𩮩
    # 0x29BAA: '',  # 𩮪
    0x29BAB: 'shā',  # 𩮫
    0x29BAC: 'wěng',  # 𩮬
    # 0x29BAD: '',  # 𩮭
    # 0x29BAE: '',  # 𩮮
    0x29BAF: 'áo',  # 𩮯
    # 0x29BB0: '',  # 𩮰
    0x29BB1: 'zhuāng',  # 𩮱
    # 0x29BB2: '',  # 𩮲
    0x29BB3: 'piào,piǎo,piē',  # 𩮳
    0x29BB4: 'suī,cuǐ',  # 𩮴
    0x29BB5: 'yī',  # 𩮵
    0x29BB6: 'sōu',  # 𩮶
    0x29BB7: 'dōu',  # 𩮷
    0x29BB8: 'sōu,nà',  # 𩮸
    0x29BB9: 'luó',  # 𩮹
    # 0x29BBA: '',  # 𩮺
    # 0x29BBB: '',  # 𩮻
    # 0x29BBC: '',  # 𩮼
    # 0x29BBD: '',  # 𩮽
    # 0x29BBE: '',  # 𩮾
    # 0x29BBF: '',  # 𩮿
    # 0x29BC0: '',  # 𩯀
    # 0x29BC1: '',  # 𩯁
    # 0x29BC2: '',  # 𩯂
    0x29BC3: 'fèi,bì',  # 𩯃
    0x29BC4: 'zùn',  # 𩯄
    # 0x29BC5: '',  # 𩯅
    0x29BC6: 'nào',  # 𩯆
    0x29BC7: 'dēng',  # 𩯇
    0x29BC8: 'zhí',  # 𩯈
    0x29BC9: 'cuō',  # 𩯉
    0x29BCA: 'liáo',  # 𩯊
    0x29BCB: 'jǐ',  # 𩯋
    0x29BCC: 'bō',  # 𩯌
    0x29BCD: 'cóng',  # 𩯍
    0x29BCE: 'chéng',  # 𩯎
    0x29BCF: 'bǔ',  # 𩯏
    # 0x29BD0: '',  # 𩯐
    0x29BD1: 'sān',  # 𩯑
    # 0x29BD2: '',  # 𩯒
    # 0x29BD3: '',  # 𩯓
    # 0x29BD4: '',  # 𩯔
    # 0x29BD5: '',  # 𩯕
    # 0x29BD6: '',  # 𩯖
    # 0x29BD7: '',  # 𩯗
    0x29BD8: 'jiào',  # 𩯘
    # 0x29BD9: '',  # 𩯙
    # 0x29BDA: '',  # 𩯚
    0x29BDB: 'yào',  # 𩯛
    0x29BDC: 'lǔ',  # 𩯜
    # 0x29BDD: '',  # 𩯝
    0x29BDE: 'càn',  # 𩯞
    # 0x29BDF: '',  # 𩯟
    # 0x29BE0: '',  # 𩯠
    # 0x29BE1: '',  # 𩯡
    # 0x29BE2: '',  # 𩯢
    # 0x29BE3: '',  # 𩯣
    # 0x29BE4: '',  # 𩯤
    # 0x29BE5: '',  # 𩯥
    # 0x29BE6: '',  # 𩯦
    # 0x29BE7: '',  # 𩯧
    0x29BE8: 'nǐ',  # 𩯨
    # 0x29BE9: '',  # 𩯩
    # 0x29BEA: '',  # 𩯪
    0x29BEB: 'bìn',  # 𩯫
    # 0x29BEC: '',  # 𩯬
    # 0x29BED: '',  # 𩯭
    # 0x29BEE: '',  # 𩯮
    # 0x29BEF: '',  # 𩯯
    0x29BF0: 'jié,jì',  # 𩯰
    0x29BF1: 'pú',  # 𩯱
    0x29BF2: 'zhuàng',  # 𩯲
    0x29BF3: 'zàn,zuǎn,zā',  # 𩯳
    # 0x29BF4: '',  # 𩯴
    # 0x29BF5: '',  # 𩯵
    # 0x29BF6: '',  # 𩯶
    # 0x29BF7: '',  # 𩯷
    # 0x29BF8: '',  # 𩯸
    # 0x29BF9: '',  # 𩯹
    0x29BFA: 'lì',  # 𩯺
    # 0x29BFB: '',  # 𩯻
    # 0x29BFC: '',  # 𩯼
    0x29BFD: 'là',  # 𩯽
    # 0x29BFE: '',  # 𩯾
    # 0x29BFF: '',  # 𩯿
    0x29C00: 'chōng',  # 𩰀
    # 0x29C01: '',  # 𩰁
    # 0x29C02: '',  # 𩰂
    0x29C03: 'zhàn',  # 𩰃
    # 0x29C04: '',  # 𩰄
    # 0x29C05: '',  # 𩰅
    # 0x29C06: '',  # 𩰆
    # 0x29C07: '',  # 𩰇
    # 0x29C08: '',  # 𩰈
    # 0x29C09: '',  # 𩰉
    # 0x29C0A: '',  # 𩰊
    # 0x29C0B: '',  # 𩰋
    # 0x29C0C: '',  # 𩰌
    0x29C0D: 'biàn',  # 𩰍
    0x29C0E: 'wēng',  # 𩰎
    # 0x29C0F: '',  # 𩰏
    # 0x29C10: '',  # 𩰐
    # 0x29C11: '',  # 𩰑
    # 0x29C12: '',  # 𩰒
    0x29C13: 'hòng',  # 𩰓
    # 0x29C14: '',  # 𩰔
    # 0x29C15: '',  # 𩰕
    # 0x29C16: '',  # 𩰖
    0x29C17: 'pīn',  # 𩰗
    # 0x29C18: '',  # 𩰘
    0x29C19: 'sè',  # 𩰙
    # 0x29C1A: '',  # 𩰚
    # 0x29C1B: '',  # 𩰛
    # 0x29C1C: '',  # 𩰜
    # 0x29C1D: '',  # 𩰝
    0x29C1E: 'nǐ',  # 𩰞
    0x29C1F: 'fēn',  # 𩰟
    0x29C20: 'xǔ',  # 𩰠
    # 0x29C21: '',  # 𩰡
    0x29C22: 'shǐ',  # 𩰢
    # 0x29C23: '',  # 𩰣
    0x29C24: 'jù',  # 𩰤
    # 0x29C25: '',  # 𩰥
    # 0x29C26: '',  # 𩰦
    # 0x29C27: '',  # 𩰧
    0x29C28: 'jué',  # 𩰨
    # 0x29C29: '',  # 𩰩
    0x29C2A: 'yù',  # 𩰪
    0x29C2B: 'guō',  # 𩰫
    0x29C2C: 'guō,wāi',  # 𩰬
    0x29C2D: 'guō',  # 𩰭
    # 0x29C2E: '',  # 𩰮
    0x29C2F: 'hú',  # 𩰯
    # 0x29C30: '',  # 𩰰
    0x29C31: 'shāng',  # 𩰱
    0x29C32: 'lì,fèi',  # 𩰲
    0x29C33: 'xié',  # 𩰳
    0x29C34: 'ér',  # 𩰴
    0x29C35: 'yuán',  # 𩰵
    0x29C36: 'hái,bèn',  # 𩰶
    # 0x29C37: '',  # 𩰷
    # 0x29C38: '',  # 𩰸
    0x29C39: 'jìng',  # 𩰹
    # 0x29C3A: '',  # 𩰺
    0x29C3B: 'kè',  # 𩰻
    # 0x29C3C: '',  # 𩰼
    0x29C3D: 'zōng',  # 𩰽
    0x29C3E: 'fèi',  # 𩰾
    # 0x29C3F: '',  # 𩰿
    0x29C40: 'pēng',  # 𩱀
    0x29C41: 'gēng',  # 𩱁
    # 0x29C42: '',  # 𩱂
    0x29C43: 'jiān',  # 𩱃
    0x29C44: 'ní',  # 𩱄
    # 0x29C45: '',  # 𩱅
    0x29C46: 'xián',  # 𩱆
    0x29C47: 'lì',  # 𩱇
    0x29C48: 'chǎo',  # 𩱈
    # 0x29C49: '',  # 𩱉
    0x29C4A: 'ér,xiàn',  # 𩱊
    0x29C4B: 'gēng,pēng',  # 𩱋
    0x29C4C: 'yù',  # 𩱌
    0x29C4D: 'hú',  # 𩱍
    0x29C4E: 'fèi',  # 𩱎
    0x29C4F: 'áo',  # 𩱏
    # 0x29C50: '',  # 𩱐
    # 0x29C51: '',  # 𩱑
    # 0x29C52: '',  # 𩱒
    0x29C53: 'ěr',  # 𩱓
    # 0x29C54: '',  # 𩱔
    # 0x29C55: '',  # 𩱕
    # 0x29C56: '',  # 𩱖
    # 0x29C57: '',  # 𩱗
    0x29C58: 'kè',  # 𩱘
    0x29C59: 'kù',  # 𩱙
    0x29C5A: 'bó',  # 𩱚
    # 0x29C5B: '',  # 𩱛
    # 0x29C5C: '',  # 𩱜
    0x29C5D: 'yè',  # 𩱝
    0x29C5E: 'jiào',  # 𩱞
    # 0x29C5F: '',  # 𩱟
    # 0x29C60: '',  # 𩱠
    0x29C61: 'zhān',  # 𩱡
    # 0x29C62: '',  # 𩱢
    # 0x29C63: '',  # 𩱣
    # 0x29C64: '',  # 𩱤
    # 0x29C65: '',  # 𩱥
    0x29C66: 'chǎo',  # 𩱦
    0x29C67: 'gēng',  # 𩱧
    0x29C68: 'rù',  # 𩱨
    # 0x29C69: '',  # 𩱩
    0x29C6A: 'yuè',  # 𩱪
    0x29C6B: 'sù',  # 𩱫
    0x29C6C: 'lín',  # 𩱬
    # 0x29C6D: '',  # 𩱭
    # 0x29C6E: '',  # 𩱮
    # 0x29C6F: '',  # 𩱯
    # 0x29C70: '',  # 𩱰
    0x29C71: 'yù',  # 𩱱
    0x29C72: 'yuè',  # 𩱲
    0x29C73: 'zhāi',  # 𩱳
    0x29C74: 'xiāo',  # 𩱴
    # 0x29C75: '',  # 𩱵
    # 0x29C76: '',  # 𩱶
    0x29C77: 'miè',  # 𩱷
    0x29C78: 'miè',  # 𩱸
    # 0x29C79: '',  # 𩱹
    # 0x29C7A: '',  # 𩱺
    0x29C7B: 'guǐ',  # 𩱻
    0x29C7C: 'jiū',  # 𩱼
    # 0x29C7D: '',  # 𩱽
    0x29C7E: 'tuò',  # 𩱾
    # 0x29C7F: '',  # 𩱿
    # 0x29C80: '',  # 𩲀
    0x29C81: 'xí',  # 𩲁
    0x29C82: 'wěi',  # 𩲂
    0x29C83: 'zhuó',  # 𩲃
    0x29C84: 'wèi',  # 𩲄
    0x29C85: 'kuí',  # 𩲅
    # 0x29C86: '',  # 𩲆
    # 0x29C87: '',  # 𩲇
    0x29C88: 'mèi,wéi',  # 𩲈
    0x29C89: 'mèi',  # 𩲉
    0x29C8A: 'hào',  # 𩲊
    0x29C8B: 'hāng',  # 𩲋
    0x29C8C: 'fāng',  # 𩲌
    0x29C8D: 'niú',  # 𩲍
    0x29C8E: 'yòu',  # 𩲎
    0x29C8F: 'huà',  # 𩲏
    # 0x29C90: '',  # 𩲐
    # 0x29C91: '',  # 𩲑
    # 0x29C92: '',  # 𩲒
    # 0x29C93: '',  # 𩲓
    # 0x29C94: '',  # 𩲔
    # 0x29C95: '',  # 𩲕
    # 0x29C96: '',  # 𩲖
    # 0x29C97: '',  # 𩲗
    # 0x29C98: '',  # 𩲘
    # 0x29C99: '',  # 𩲙
    # 0x29C9A: '',  # 𩲚
    # 0x29C9B: '',  # 𩲛
    # 0x29C9C: '',  # 𩲜
    # 0x29C9D: '',  # 𩲝
    # 0x29C9E: '',  # 𩲞
    # 0x29C9F: '',  # 𩲟
    0x29CA0: 'zhú',  # 𩲠
    0x29CA1: 'guǐ',  # 𩲡
    0x29CA2: 'bì,mèi',  # 𩲢
    0x29CA3: 'jiǎ',  # 𩲣
    0x29CA4: 'tiáo',  # 𩲤
    # 0x29CA5: '',  # 𩲥
    0x29CA6: 'lǜ',  # 𩲦
    0x29CA7: 'kǒng',  # 𩲧
    0x29CA8: 'zuǐ',  # 𩲨
    0x29CA9: 'líng',  # 𩲩
    0x29CAA: 'qí',  # 𩲪
    # 0x29CAB: '',  # 𩲫
    0x29CAC: 'zhú',  # 𩲬
    # 0x29CAD: '',  # 𩲭
    # 0x29CAE: '',  # 𩲮
    # 0x29CAF: '',  # 𩲯
    # 0x29CB0: '',  # 𩲰
    0x29CB1: 'gǔ',  # 𩲱
    0x29CB2: 'zù',  # 𩲲
    # 0x29CB3: '',  # 𩲳
    0x29CB4: 'yāng',  # 𩲴
    0x29CB5: 'sū',  # 𩲵
    # 0x29CB6: '',  # 𩲶
    0x29CB7: 'kuí',  # 𩲷
    # 0x29CB8: '',  # 𩲸
    0x29CB9: 'chāng',  # 𩲹
    # 0x29CBA: '',  # 𩲺
    0x29CBB: 'yáo',  # 𩲻
    # 0x29CBC: '',  # 𩲼
    # 0x29CBD: '',  # 𩲽
    0x29CBE: 'yù',  # 𩲾
    # 0x29CBF: '',  # 𩲿
    # 0x29CC0: '',  # 𩳀
    # 0x29CC1: '',  # 𩳁
    # 0x29CC2: '',  # 𩳂
    # 0x29CC3: '',  # 𩳃
    # 0x29CC4: '',  # 𩳄
    0x29CC5: 'shū',  # 𩳅
    0x29CC6: 'lài',  # 𩳆
    0x29CC7: 'yì',  # 𩳇
    0x29CC8: 'dōu',  # 𩳈
    # 0x29CC9: '',  # 𩳉
    # 0x29CCA: '',  # 𩳊
    0x29CCB: 'hū',  # 𩳋
    0x29CCC: 'wú',  # 𩳌
    0x29CCD: 'yǐng',  # 𩳍
    0x29CCE: 'fú',  # 𩳎
    0x29CCF: 'zhuàn',  # 𩳏
    0x29CD0: 'fǔ',  # 𩳐
    0x29CD1: 'yòu',  # 𩳑
    0x29CD2: 'sù',  # 𩳒
    0x29CD3: 'lǐ',  # 𩳓
    0x29CD4: 'yào',  # 𩳔
    0x29CD5: 'tuì,tì',  # 𩳕
    # 0x29CD6: '',  # 𩳖
    # 0x29CD7: '',  # 𩳗
    # 0x29CD8: '',  # 𩳘
    # 0x29CD9: '',  # 𩳙
    # 0x29CDA: '',  # 𩳚
    # 0x29CDB: '',  # 𩳛
    # 0x29CDC: '',  # 𩳜
    0x29CDD: 'guì',  # 𩳝
    # 0x29CDE: '',  # 𩳞
    # 0x29CDF: '',  # 𩳟
    # 0x29CE0: '',  # 𩳠
    0x29CE1: 'lǜ',  # 𩳡
    0x29CE2: 'yàn',  # 𩳢
    0x29CE3: 'qí',  # 𩳣
    0x29CE4: 'làng,chāng',  # 𩳤
    0x29CE5: 'zhú',  # 𩳥
    # 0x29CE6: '',  # 𩳦
    0x29CE7: 'guǐ',  # 𩳧
    0x29CE8: 'hū',  # 𩳨
    0x29CE9: 'chī',  # 𩳩
    # 0x29CEA: '',  # 𩳪
    # 0x29CEB: '',  # 𩳫
    # 0x29CEC: '',  # 𩳬
    # 0x29CED: '',  # 𩳭
    # 0x29CEE: '',  # 𩳮
    0x29CEF: 'jīng',  # 𩳯
    # 0x29CF0: '',  # 𩳰
    # 0x29CF1: '',  # 𩳱
    0x29CF2: 'chǐ',  # 𩳲
    # 0x29CF3: '',  # 𩳳
    # 0x29CF4: '',  # 𩳴
    0x29CF5: 'jú',  # 𩳵
    0x29CF6: 'zhá',  # 𩳶
    # 0x29CF7: '',  # 𩳷
    0x29CF8: 'miáo',  # 𩳸
    # 0x29CF9: '',  # 𩳹
    # 0x29CFA: '',  # 𩳺
    # 0x29CFB: '',  # 𩳻
    # 0x29CFC: '',  # 𩳼
    # 0x29CFD: '',  # 𩳽
    # 0x29CFE: '',  # 𩳾
    # 0x29CFF: '',  # 𩳿
    0x29D00: 'zhū',  # 𩴀
    0x29D01: 'gān',  # 𩴁
    0x29D02: 'xiōng',  # 𩴂
    0x29D03: 'jí',  # 𩴃
    # 0x29D04: '',  # 𩴄
    # 0x29D05: '',  # 𩴅
    # 0x29D06: '',  # 𩴆
    0x29D07: 'shài',  # 𩴇
    0x29D08: 'mèi',  # 𩴈
    0x29D09: 'yùn',  # 𩴉
    # 0x29D0A: '',  # 𩴊
    # 0x29D0B: '',  # 𩴋
    # 0x29D0C: '',  # 𩴌
    0x29D0D: 'shòu',  # 𩴍
    # 0x29D0E: '',  # 𩴎
    # 0x29D0F: '',  # 𩴏
    0x29D10: 'lǜ',  # 𩴐
    0x29D11: 'yòu',  # 𩴑
    0x29D12: 'jiàng',  # 𩴒
    0x29D13: 'nuó',  # 𩴓
    # 0x29D14: '',  # 𩴔
    # 0x29D15: '',  # 𩴕
    # 0x29D16: '',  # 𩴖
    # 0x29D17: '',  # 𩴗
    0x29D18: 'jù',  # 𩴘
    0x29D19: 'yòu',  # 𩴙
    # 0x29D1A: '',  # 𩴚
    # 0x29D1B: '',  # 𩴛
    0x29D1C: 'yì',  # 𩴜
    0x29D1D: 'téng',  # 𩴝
    0x29D1E: 'wéi',  # 𩴞
    0x29D1F: 'chě',  # 𩴟
    0x29D20: 'lìn',  # 𩴠
    0x29D21: 'gù',  # 𩴡
    # 0x29D22: '',  # 𩴢
    0x29D23: 'lì',  # 𩴣
    0x29D24: 'liào',  # 𩴤
    # 0x29D25: '',  # 𩴥
    # 0x29D26: '',  # 𩴦
    0x29D27: 'jiāo',  # 𩴧
    0x29D28: 'yáng',  # 𩴨
    0x29D29: 'biāo',  # 𩴩
    0x29D2A: 'qí',  # 𩴪
    # 0x29D2B: '',  # 𩴫
    # 0x29D2C: '',  # 𩴬
    # 0x29D2D: '',  # 𩴭
    0x29D2E: 'yì',  # 𩴮
    # 0x29D2F: '',  # 𩴯
    # 0x29D30: '',  # 𩴰
    0x29D31: 'bīn',  # 𩴱
    0x29D32: 'méng',  # 𩴲
    0x29D33: 'chà',  # 𩴳
    0x29D34: 'nuó',  # 𩴴
    0x29D35: 'gān',  # 𩴵
    # 0x29D36: '',  # 𩴶
    # 0x29D37: '',  # 𩴷
    # 0x29D38: '',  # 𩴸
    0x29D39: 'qú',  # 𩴹
    0x29D3A: 'dí',  # 𩴺
    0x29D3B: 'léi',  # 𩴻
    # 0x29D3C: '',  # 𩴼
    # 0x29D3D: '',  # 𩴽
    # 0x29D3E: '',  # 𩴾
    # 0x29D3F: '',  # 𩴿
    0x29D40: 'líng',  # 𩵀
    # 0x29D41: '',  # 𩵁
    # 0x29D42: '',  # 𩵂
    # 0x29D43: '',  # 𩵃
    0x29D44: 'huān',  # 𩵄
    0x29D45: 'qú',  # 𩵅
    # 0x29D46: '',  # 𩵆
    0x29D47: 'luó',  # 𩵇
    # 0x29D48: '',  # 𩵈
    0x29D49: 'kuí',  # 𩵉
    # 0x29D4A: '',  # 𩵊
    0x29D4B: 'yú',  # 𩵋
    # 0x29D4C: '',  # 𩵌
    0x29D4D: 'qiú',  # 𩵍
    0x29D4E: 'yǔ,yú',  # 𩵎
    0x29D4F: 'huà',  # 𩵏
    # 0x29D50: '',  # 𩵐
    # 0x29D51: '',  # 𩵑
    # 0x29D52: '',  # 𩵒
    0x29D53: 'lèi',  # 𩵓
    # 0x29D54: '',  # 𩵔
    0x29D55: 'rèn,dāo',  # 𩵕
    0x29D56: 'xiǎo',  # 𩵖
    0x29D57: 'sì',  # 𩵗
    # 0x29D58: '',  # 𩵘
    # 0x29D59: '',  # 𩵙
    0x29D5A: 'dù',  # 𩵚
    0x29D5B: 'biē',  # 𩵛
    # 0x29D5C: '',  # 𩵜
    # 0x29D5D: '',  # 𩵝
    # 0x29D5E: '',  # 𩵞
    # 0x29D5F: '',  # 𩵟
    0x29D60: 'niú,wěi',  # 𩵠
    # 0x29D61: '',  # 𩵡
    0x29D62: 'hè,zā',  # 𩵢
    0x29D63: 'pēi',  # 𩵣
    # 0x29D64: '',  # 𩵤
    0x29D65: 'fèi',  # 𩵥
    0x29D66: 'mù',  # 𩵦
    # 0x29D67: '',  # 𩵧
    # 0x29D68: '',  # 𩵨
    0x29D69: 'fū',  # 𩵩
    # 0x29D6A: '',  # 𩵪
    # 0x29D6B: '',  # 𩵫
    0x29D6C: 'hú',  # 𩵬
    0x29D6D: 'wáng',  # 𩵭
    0x29D6E: 'shā,xiǎo',  # 𩵮
    # 0x29D6F: '',  # 𩵯
    0x29D70: 'jiāo,qiū',  # 𩵰
    0x29D71: 'wǔ',  # 𩵱
    # 0x29D72: '',  # 𩵲
    # 0x29D73: '',  # 𩵳
    # 0x29D74: '',  # 𩵴
    # 0x29D75: '',  # 𩵵
    # 0x29D76: '',  # 𩵶
    # 0x29D77: '',  # 𩵷
    # 0x29D78: '',  # 𩵸
    0x29D79: 'fù',  # 𩵹
    # 0x29D7A: '',  # 𩵺
    # 0x29D7B: '',  # 𩵻
    # 0x29D7C: '',  # 𩵼
    # 0x29D7D: '',  # 𩵽
    # 0x29D7E: '',  # 𩵾
    # 0x29D7F: '',  # 𩵿
    # 0x29D80: '',  # 𩶀
    0x29D81: 'bǐng',  # 𩶁
    0x29D82: 'zhù',  # 𩶂
    # 0x29D83: '',  # 𩶃
    0x29D84: 'zhú',  # 𩶄
    0x29D85: 'chī',  # 𩶅
    # 0x29D86: '',  # 𩶆
    0x29D87: 'shěn',  # 𩶇
    0x29D88: 'hū',  # 𩶈
    0x29D89: 'bū',  # 𩶉
    # 0x29D8A: '',  # 𩶊
    # 0x29D8B: '',  # 𩶋
    # 0x29D8C: '',  # 𩶌
    # 0x29D8D: '',  # 𩶍
    0x29D8E: 'rǎn',  # 𩶎
    # 0x29D8F: '',  # 𩶏
    # 0x29D90: '',  # 𩶐
    0x29D91: 'lǔ',  # 𩶑
    # 0x29D92: '',  # 𩶒
    # 0x29D93: '',  # 𩶓
    # 0x29D94: '',  # 𩶔
    # 0x29D95: '',  # 𩶕
    0x29D96: 'mù',  # 𩶖
    # 0x29D97: '',  # 𩶗
    0x29D98: 'lì',  # 𩶘
    # 0x29D99: '',  # 𩶙
    # 0x29D9A: '',  # 𩶚
    0x29D9B: 'jiā',  # 𩶛
    # 0x29D9C: '',  # 𩶜
    # 0x29D9D: '',  # 𩶝
    0x29D9E: 'mà,háng',  # 𩶞
    # 0x29D9F: '',  # 𩶟
    # 0x29DA0: '',  # 𩶠
    0x29DA1: 'méng',  # 𩶡
    0x29DA2: 'móu',  # 𩶢
    0x29DA3: 'zhōu',  # 𩶣
    0x29DA4: 'xiǎn',  # 𩶤
    0x29DA5: 'huǐ,hóng',  # 𩶥
    0x29DA6: 'guài',  # 𩶦
    0x29DA7: 'jiù',  # 𩶧
    # 0x29DA8: '',  # 𩶨
    0x29DA9: 'mù',  # 𩶩
    0x29DAA: 'chī',  # 𩶪
    0x29DAB: 'rù,xuè',  # 𩶫
    # 0x29DAC: '',  # 𩶬
    0x29DAD: 'wú',  # 𩶭
    # 0x29DAE: '',  # 𩶮
    0x29DAF: 'rú',  # 𩶯
    # 0x29DB0: '',  # 𩶰
    0x29DB1: 'zhà',  # 𩶱
    # 0x29DB2: '',  # 𩶲
    # 0x29DB3: '',  # 𩶳
    # 0x29DB4: '',  # 𩶴
    # 0x29DB5: '',  # 𩶵
    # 0x29DB6: '',  # 𩶶
    # 0x29DB7: '',  # 𩶷
    # 0x29DB8: '',  # 𩶸
    # 0x29DB9: '',  # 𩶹
    # 0x29DBA: '',  # 𩶺
    # 0x29DBB: '',  # 𩶻
    # 0x29DBC: '',  # 𩶼
    # 0x29DBD: '',  # 𩶽
    # 0x29DBE: '',  # 𩶾
    # 0x29DBF: '',  # 𩶿
    # 0x29DC0: '',  # 𩷀
    0x29DC1: 'nuǒ',  # 𩷁
    0x29DC2: 'xié',  # 𩷂
    # 0x29DC3: '',  # 𩷃
    0x29DC4: 'jiàng',  # 𩷄
    # 0x29DC5: '',  # 𩷅
    # 0x29DC6: '',  # 𩷆
    # 0x29DC7: '',  # 𩷇
    # 0x29DC8: '',  # 𩷈
    # 0x29DC9: '',  # 𩷉
    # 0x29DCA: '',  # 𩷊
    0x29DCB: 'lǐ',  # 𩷋
    0x29DCC: 'shū',  # 𩷌
    0x29DCD: 'yì',  # 𩷍
    0x29DCE: 'dí',  # 𩷎
    0x29DCF: 'qíng',  # 𩷏
    0x29DD0: 'jú',  # 𩷐
    0x29DD1: 'yǎn',  # 𩷑
    # 0x29DD2: '',  # 𩷒
    0x29DD3: 'zhì',  # 𩷓
    # 0x29DD4: '',  # 𩷔
    0x29DD5: 'láng',  # 𩷕
    0x29DD6: 'bù',  # 𩷖
    0x29DD7: 'kuáng',  # 𩷗
    0x29DD8: 'yì',  # 𩷘
    # 0x29DD9: '',  # 𩷙
    0x29DDA: 'bó',  # 𩷚
    # 0x29DDB: '',  # 𩷛
    # 0x29DDC: '',  # 𩷜
    # 0x29DDD: '',  # 𩷝
    # 0x29DDE: '',  # 𩷞
    # 0x29DDF: '',  # 𩷟
    # 0x29DE0: '',  # 𩷠
    # 0x29DE1: '',  # 𩷡
    # 0x29DE2: '',  # 𩷢
    # 0x29DE3: '',  # 𩷣
    # 0x29DE4: '',  # 𩷤
    # 0x29DE5: '',  # 𩷥
    # 0x29DE6: '',  # 𩷦
    0x29DE7: 'chì',  # 𩷧
    # 0x29DE8: '',  # 𩷨
    # 0x29DE9: '',  # 𩷩
    # 0x29DEA: '',  # 𩷪
    # 0x29DEB: '',  # 𩷫
    # 0x29DEC: '',  # 𩷬
    0x29DED: 'jiàng',  # 𩷭
    # 0x29DEE: '',  # 𩷮
    0x29DEF: 'wò',  # 𩷯
    0x29DF0: 'xùn',  # 𩷰
    # 0x29DF1: '',  # 𩷱
    # 0x29DF2: '',  # 𩷲
    # 0x29DF3: '',  # 𩷳
    # 0x29DF4: '',  # 𩷴
    0x29DF5: 'tūn',  # 𩷵
    0x29DF6: 'máng',  # 𩷶
    # 0x29DF7: '',  # 𩷷
    0x29DF8: 'fáng',  # 𩷸
    0x29DF9: 'zhuó',  # 𩷹
    # 0x29DFA: '',  # 𩷺
    0x29DFB: 'qià',  # 𩷻
    0x29DFC: 'shèng',  # 𩷼
    0x29DFD: 'tǎ',  # 𩷽
    0x29DFE: 'qí',  # 𩷾
    # 0x29DFF: '',  # 𩷿
    0x29E00: 'pèng',  # 𩸀
    0x29E01: 'biē',  # 𩸁
    0x29E02: 'fèn,pèn',  # 𩸂
    0x29E03: 'tù',  # 𩸃
    0x29E04: 'huà',  # 𩸄
    # 0x29E05: '',  # 𩸅
    # 0x29E06: '',  # 𩸆
    0x29E07: 'è',  # 𩸇
    # 0x29E08: '',  # 𩸈
    # 0x29E09: '',  # 𩸉
    # 0x29E0A: '',  # 𩸊
    0x29E0B: 'è,yā',  # 𩸋
    # 0x29E0C: '',  # 𩸌
    # 0x29E0D: '',  # 𩸍
    0x29E0E: 'dìng',  # 𩸎
    # 0x29E0F: '',  # 𩸏
    0x29E10: 'rú',  # 𩸐
    # 0x29E11: '',  # 𩸑
    # 0x29E12: '',  # 𩸒
    # 0x29E13: '',  # 𩸓
    # 0x29E14: '',  # 𩸔
    # 0x29E15: '',  # 𩸕
    0x29E16: 'è',  # 𩸖
    # 0x29E17: '',  # 𩸗
    # 0x29E18: '',  # 𩸘
    # 0x29E19: '',  # 𩸙
    # 0x29E1A: '',  # 𩸚
    # 0x29E1B: '',  # 𩸛
    # 0x29E1C: '',  # 𩸜
    # 0x29E1D: '',  # 𩸝
    0x29E1E: 'yàn,qí',  # 𩸞
    0x29E1F: 'sì',  # 𩸟
    # 0x29E20: '',  # 𩸠
    # 0x29E21: '',  # 𩸡
    0x29E22: 'lí',  # 𩸢
    # 0x29E23: '',  # 𩸣
    # 0x29E24: '',  # 𩸤
    0x29E25: 'yíng',  # 𩸥
    0x29E26: 'ní',  # 𩸦
    0x29E27: 'ní',  # 𩸧
    0x29E28: 'yí',  # 𩸨
    0x29E29: 'huàn',  # 𩸩
    # 0x29E2A: '',  # 𩸪
    # 0x29E2B: '',  # 𩸫
    # 0x29E2C: '',  # 𩸬
    # 0x29E2D: '',  # 𩸭
    # 0x29E2E: '',  # 𩸮
    # 0x29E2F: '',  # 𩸯
    # 0x29E30: '',  # 𩸰
    # 0x29E31: '',  # 𩸱
    # 0x29E32: '',  # 𩸲
    # 0x29E33: '',  # 𩸳
    # 0x29E34: '',  # 𩸴
    # 0x29E35: '',  # 𩸵
    # 0x29E36: '',  # 𩸶
    # 0x29E37: '',  # 𩸷
    0x29E38: 'qī',  # 𩸸
    0x29E39: 'mí',  # 𩸹
    # 0x29E3A: '',  # 𩸺
    # 0x29E3B: '',  # 𩸻
    # 0x29E3C: '',  # 𩸼
    # 0x29E3D: '',  # 𩸽
    0x29E3E: 'yé',  # 𩸾
    0x29E3F: 'pō',  # 𩸿
    0x29E40: 'còu',  # 𩹀
    # 0x29E41: '',  # 𩹁
    0x29E42: 'wèi',  # 𩹂
    # 0x29E43: '',  # 𩹃
    0x29E44: 'hài',  # 𩹄
    0x29E45: 'yīng',  # 𩹅
    # 0x29E46: '',  # 𩹆
    0x29E47: 'tíng',  # 𩹇
    0x29E48: 'zhì',  # 𩹈
    0x29E49: 'fēi',  # 𩹉
    0x29E4A: 'yóu',  # 𩹊
    # 0x29E4B: '',  # 𩹋
    # 0x29E4C: '',  # 𩹌
    0x29E4D: 'kuí',  # 𩹍
    0x29E4E: 'àn',  # 𩹎
    0x29E4F: 'bà',  # 𩹏
    # 0x29E50: '',  # 𩹐
    0x29E51: 'hàn',  # 𩹑
    # 0x29E52: '',  # 𩹒
    # 0x29E53: '',  # 𩹓
    # 0x29E54: '',  # 𩹔
    # 0x29E55: '',  # 𩹕
    # 0x29E56: '',  # 𩹖
    # 0x29E57: '',  # 𩹗
    # 0x29E58: '',  # 𩹘
    # 0x29E59: '',  # 𩹙
    # 0x29E5A: '',  # 𩹚
    # 0x29E5B: '',  # 𩹛
    # 0x29E5C: '',  # 𩹜
    0x29E5D: 'dú',  # 𩹝
    0x29E5E: 'nán',  # 𩹞
    0x29E5F: 'nài',  # 𩹟
    # 0x29E60: '',  # 𩹠
    # 0x29E61: '',  # 𩹡
    0x29E62: 'jīng',  # 𩹢
    # 0x29E63: '',  # 𩹣
    # 0x29E64: '',  # 𩹤
    0x29E65: 'wēi',  # 𩹥
    # 0x29E66: '',  # 𩹦
    # 0x29E67: '',  # 𩹧
    # 0x29E68: '',  # 𩹨
    # 0x29E69: '',  # 𩹩
    # 0x29E6A: '',  # 𩹪
    # 0x29E6B: '',  # 𩹫
    # 0x29E6C: '',  # 𩹬
    # 0x29E6D: '',  # 𩹭
    # 0x29E6E: '',  # 𩹮
    # 0x29E6F: '',  # 𩹯
    # 0x29E70: '',  # 𩹰
    0x29E71: 'chù',  # 𩹱
    # 0x29E72: '',  # 𩹲
    0x29E73: 'suǒ',  # 𩹳
    0x29E74: 'tāo',  # 𩹴
    0x29E75: 'qí',  # 𩹵
    0x29E76: 'táng',  # 𩹶
    0x29E77: 'wěi',  # 𩹷
    0x29E78: 'gǎn',  # 𩹸
    # 0x29E79: '',  # 𩹹
    0x29E7A: 'gé',  # 𩹺
    # 0x29E7B: '',  # 𩹻
    0x29E7C: 'hàn',  # 𩹼
    # 0x29E7D: '',  # 𩹽
    0x29E7E: 'nà',  # 𩹾
    0x29E7F: 'gé',  # 𩹿
    0x29E80: 'jì',  # 𩺀
    # 0x29E81: '',  # 𩺁
    # 0x29E82: '',  # 𩺂
    # 0x29E83: '',  # 𩺃
    0x29E84: 'zhēng',  # 𩺄
    # 0x29E85: '',  # 𩺅
    # 0x29E86: '',  # 𩺆
    # 0x29E87: '',  # 𩺇
    # 0x29E88: '',  # 𩺈
    # 0x29E89: '',  # 𩺉
    # 0x29E8A: '',  # 𩺊
    # 0x29E8B: '',  # 𩺋
    # 0x29E8C: '',  # 𩺌
    # 0x29E8D: '',  # 𩺍
    # 0x29E8E: '',  # 𩺎
    # 0x29E8F: '',  # 𩺏
    # 0x29E90: '',  # 𩺐
    # 0x29E91: '',  # 𩺑
    # 0x29E92: '',  # 𩺒
    # 0x29E93: '',  # 𩺓
    # 0x29E94: '',  # 𩺔
    # 0x29E95: '',  # 𩺕
    # 0x29E96: '',  # 𩺖
    0x29E97: 'tǎ,dá',  # 𩺗
    # 0x29E98: '',  # 𩺘
    # 0x29E99: '',  # 𩺙
    # 0x29E9A: '',  # 𩺚
    0x29E9B: 'sī',  # 𩺛
    # 0x29E9C: '',  # 𩺜
    0x29E9D: 'nì',  # 𩺝
    0x29E9E: 'sǎng',  # 𩺞
    # 0x29E9F: '',  # 𩺟
    # 0x29EA0: '',  # 𩺠
    # 0x29EA1: '',  # 𩺡
    # 0x29EA2: '',  # 𩺢
    # 0x29EA3: '',  # 𩺣
    # 0x29EA4: '',  # 𩺤
    # 0x29EA5: '',  # 𩺥
    # 0x29EA6: '',  # 𩺦
    # 0x29EA7: '',  # 𩺧
    # 0x29EA8: '',  # 𩺨
    # 0x29EA9: '',  # 𩺩
    # 0x29EAA: '',  # 𩺪
    0x29EAB: 'xié',  # 𩺫
    # 0x29EAC: '',  # 𩺬
    # 0x29EAD: '',  # 𩺭
    # 0x29EAE: '',  # 𩺮
    0x29EAF: 'zú',  # 𩺯
    0x29EB0: 'yú,wú',  # 𩺰
    0x29EB1: 'nì',  # 𩺱
    0x29EB2: 'qī',  # 𩺲
    # 0x29EB3: '',  # 𩺳
    # 0x29EB4: '',  # 𩺴
    0x29EB5: 'shēn',  # 𩺵
    # 0x29EB6: '',  # 𩺶
    # 0x29EB7: '',  # 𩺷
    # 0x29EB8: '',  # 𩺸
    # 0x29EB9: '',  # 𩺹
    # 0x29EBA: '',  # 𩺺
    # 0x29EBB: '',  # 𩺻
    0x29EBC: 'bū',  # 𩺼
    # 0x29EBD: '',  # 𩺽
    # 0x29EBE: '',  # 𩺾
    # 0x29EBF: '',  # 𩺿
    # 0x29EC0: '',  # 𩻀
    # 0x29EC1: '',  # 𩻁
    # 0x29EC2: '',  # 𩻂
    # 0x29EC3: '',  # 𩻃
    # 0x29EC4: '',  # 𩻄
    # 0x29EC5: '',  # 𩻅
    # 0x29EC6: '',  # 𩻆
    # 0x29EC7: '',  # 𩻇
    # 0x29EC8: '',  # 𩻈
    0x29EC9: 'zhì',  # 𩻉
    # 0x29ECA: '',  # 𩻊
    0x29ECB: 'kūn',  # 𩻋
    0x29ECC: 'lí',  # 𩻌
    # 0x29ECD: '',  # 𩻍
    0x29ECE: 'guā',  # 𩻎
    # 0x29ECF: '',  # 𩻏
    # 0x29ED0: '',  # 𩻐
    # 0x29ED1: '',  # 𩻑
    # 0x29ED2: '',  # 𩻒
    # 0x29ED3: '',  # 𩻓
    # 0x29ED4: '',  # 𩻔
    # 0x29ED5: '',  # 𩻕
    0x29ED6: 'yǎn',  # 𩻖
    0x29ED7: 'bù',  # 𩻗
    0x29ED8: 'jiàn',  # 𩻘
    # 0x29ED9: '',  # 𩻙
    0x29EDA: 'wú',  # 𩻚
    0x29EDB: 'cén,jīn',  # 𩻛
    0x29EDC: 'lín',  # 𩻜
    0x29EDD: 'zhuàn',  # 𩻝
    # 0x29EDE: '',  # 𩻞
    0x29EDF: 'huī',  # 𩻟
    # 0x29EE0: '',  # 𩻠
    0x29EE1: 'tóng',  # 𩻡
    0x29EE2: 'zhǎ',  # 𩻢
    # 0x29EE3: '',  # 𩻣
    0x29EE4: 'hēi',  # 𩻤
    # 0x29EE5: '',  # 𩻥
    # 0x29EE6: '',  # 𩻦
    0x29EE7: 'guǒ',  # 𩻧
    # 0x29EE8: '',  # 𩻨
    # 0x29EE9: '',  # 𩻩
    # 0x29EEA: '',  # 𩻪
    # 0x29EEB: '',  # 𩻫
    # 0x29EEC: '',  # 𩻬
    # 0x29EED: '',  # 𩻭
    # 0x29EEE: '',  # 𩻮
    # 0x29EEF: '',  # 𩻯
    # 0x29EF0: '',  # 𩻰
    0x29EF1: 'jǐng',  # 𩻱
    # 0x29EF2: '',  # 𩻲
    0x29EF3: 'lí',  # 𩻳
    # 0x29EF4: '',  # 𩻴
    0x29EF5: 'dié',  # 𩻵
    # 0x29EF6: '',  # 𩻶
    0x29EF7: 'yíng',  # 𩻷
    # 0x29EF8: '',  # 𩻸
    # 0x29EF9: '',  # 𩻹
    # 0x29EFA: '',  # 𩻺
    # 0x29EFB: '',  # 𩻻
    0x29EFC: 'zhì',  # 𩻼
    # 0x29EFD: '',  # 𩻽
    # 0x29EFE: '',  # 𩻾
    # 0x29EFF: '',  # 𩻿
    # 0x29F00: '',  # 𩼀
    # 0x29F01: '',  # 𩼁
    0x29F02: 'wěi',  # 𩼂
    # 0x29F03: '',  # 𩼃
    0x29F04: 'jì',  # 𩼄
    0x29F05: 'rǒng',  # 𩼅
    # 0x29F06: '',  # 𩼆
    # 0x29F07: '',  # 𩼇
    0x29F08: 'ào,yǒu',  # 𩼈
    0x29F09: 'dāng,hān',  # 𩼉
    0x29F0A: 'luó',  # 𩼊
    0x29F0B: 'yè',  # 𩼋
    0x29F0C: 'wēi',  # 𩼌
    # 0x29F0D: '',  # 𩼍
    # 0x29F0E: '',  # 𩼎
    # 0x29F0F: '',  # 𩼏
    # 0x29F10: '',  # 𩼐
    # 0x29F11: '',  # 𩼑
    0x29F12: 'qiáng',  # 𩼒
    # 0x29F13: '',  # 𩼓
    0x29F14: 'nián',  # 𩼔
    # 0x29F15: '',  # 𩼕
    # 0x29F16: '',  # 𩼖
    # 0x29F17: '',  # 𩼗
    # 0x29F18: '',  # 𩼘
    0x29F19: 'gé',  # 𩼙
    0x29F1A: 'jì',  # 𩼚
    # 0x29F1B: '',  # 𩼛
    # 0x29F1C: '',  # 𩼜
    # 0x29F1D: '',  # 𩼝
    # 0x29F1E: '',  # 𩼞
    # 0x29F1F: '',  # 𩼟
    # 0x29F20: '',  # 𩼠
    # 0x29F21: '',  # 𩼡
    # 0x29F22: '',  # 𩼢
    # 0x29F23: '',  # 𩼣
    # 0x29F24: '',  # 𩼤
    # 0x29F25: '',  # 𩼥
    0x29F26: 'zòu',  # 𩼦
    # 0x29F27: '',  # 𩼧
    0x29F28: 'yí',  # 𩼨
    # 0x29F29: '',  # 𩼩
    0x29F2A: 'yú',  # 𩼪
    0x29F2B: 'zhǎ',  # 𩼫
    # 0x29F2C: '',  # 𩼬
    0x29F2D: 'liè',  # 𩼭
    # 0x29F2E: '',  # 𩼮
    # 0x29F2F: '',  # 𩼯
    # 0x29F30: '',  # 𩼰
    # 0x29F31: '',  # 𩼱
    # 0x29F32: '',  # 𩼲
    # 0x29F33: '',  # 𩼳
    0x29F34: 'yè',  # 𩼴
    # 0x29F35: '',  # 𩼵
    # 0x29F36: '',  # 𩼶
    # 0x29F37: '',  # 𩼷
    # 0x29F38: '',  # 𩼸
    # 0x29F39: '',  # 𩼹
    # 0x29F3A: '',  # 𩼺
    # 0x29F3B: '',  # 𩼻
    0x29F3C: 'zhān',  # 𩼼
    # 0x29F3D: '',  # 𩼽
    # 0x29F3E: '',  # 𩼾
    # 0x29F3F: '',  # 𩼿
    0x29F40: 'chóu',  # 𩽀
    0x29F41: 'biāo',  # 𩽁
    # 0x29F42: '',  # 𩽂
    # 0x29F43: '',  # 𩽃
    # 0x29F44: '',  # 𩽄
    # 0x29F45: '',  # 𩽅
    0x29F46: 'xù',  # 𩽆
    0x29F47: 'yōu',  # 𩽇
    # 0x29F48: '',  # 𩽈
    # 0x29F49: '',  # 𩽉
    # 0x29F4A: '',  # 𩽊
    # 0x29F4B: '',  # 𩽋
    # 0x29F4C: '',  # 𩽌
    0x29F4D: 'xiè',  # 𩽍
    0x29F4E: 'wéi',  # 𩽎
    0x29F4F: 'lì',  # 𩽏
    # 0x29F50: '',  # 𩽐
    # 0x29F51: '',  # 𩽑
    # 0x29F52: '',  # 𩽒
    # 0x29F53: '',  # 𩽓
    # 0x29F54: '',  # 𩽔
    # 0x29F55: '',  # 𩽕
    # 0x29F56: '',  # 𩽖
    # 0x29F57: '',  # 𩽗
    # 0x29F58: '',  # 𩽘
    # 0x29F59: '',  # 𩽙
    # 0x29F5A: '',  # 𩽚
    0x29F5B: 'bó',  # 𩽛
    0x29F5C: 'jiǎn',  # 𩽜
    0x29F5D: 'chán',  # 𩽝
    0x29F5E: 'kūn',  # 𩽞
    # 0x29F5F: '',  # 𩽟
    # 0x29F60: '',  # 𩽠
    0x29F61: 'qíng',  # 𩽡
    # 0x29F62: '',  # 𩽢
    # 0x29F63: '',  # 𩽣
    # 0x29F64: '',  # 𩽤
    # 0x29F65: '',  # 𩽥
    # 0x29F66: '',  # 𩽦
    0x29F67: 'shuāng',  # 𩽧
    0x29F68: 'xī',  # 𩽨
    0x29F69: 'qú',  # 𩽩
    # 0x29F6A: '',  # 𩽪
    # 0x29F6B: '',  # 𩽫
    # 0x29F6C: '',  # 𩽬
    # 0x29F6D: '',  # 𩽭
    # 0x29F6E: '',  # 𩽮
    # 0x29F6F: '',  # 𩽯
    0x29F70: 'luó',  # 𩽰
    # 0x29F71: '',  # 𩽱
    # 0x29F72: '',  # 𩽲
    0x29F73: 'dǎng',  # 𩽳
    0x29F74: 'nián',  # 𩽴
    0x29F75: 'lǐ',  # 𩽵
    # 0x29F76: '',  # 𩽶
    0x29F77: 'bà',  # 𩽷
    # 0x29F78: '',  # 𩽸
    # 0x29F79: '',  # 𩽹
    # 0x29F7A: '',  # 𩽺
    # 0x29F7B: '',  # 𩽻
    # 0x29F7C: '',  # 𩽼
    # 0x29F7D: '',  # 𩽽
    # 0x29F7E: '',  # 𩽾
    # 0x29F7F: '',  # 𩽿
    # 0x29F80: '',  # 𩾀
    # 0x29F81: '',  # 𩾁
    # 0x29F82: '',  # 𩾂
    # 0x29F83: '',  # 𩾃
    # 0x29F84: '',  # 𩾄
    # 0x29F85: '',  # 𩾅
    # 0x29F86: '',  # 𩾆
    # 0x29F87: '',  # 𩾇
    # 0x29F88: '',  # 𩾈
    # 0x29F89: '',  # 𩾉
    # 0x29F8A: '',  # 𩾊
    # 0x29F8B: '',  # 𩾋
    # 0x29F8C: '',  # 𩾌
    # 0x29F8D: '',  # 𩾍
    # 0x29F8E: '',  # 𩾎
    # 0x29F8F: '',  # 𩾏
    # 0x29F90: '',  # 𩾐
    # 0x29F91: '',  # 𩾑
    0x29F92: 'xiāo',  # 𩾒
    0x29F93: 'xiāo',  # 𩾓
    0x29F94: 'cì',  # 𩾔
    0x29F95: 'chì',  # 𩾕
    # 0x29F96: '',  # 𩾖
    0x29F97: 'diāo,jiāo',  # 𩾗
    0x29F98: 'yì',  # 𩾘
    # 0x29F99: '',  # 𩾙
    0x29F9A: 'dīng',  # 𩾚
    # 0x29F9B: '',  # 𩾛
    # 0x29F9C: '',  # 𩾜
    0x29F9D: 'hàn,yàn',  # 𩾝
    0x29F9E: 'wán',  # 𩾞
    # 0x29F9F: '',  # 𩾟
    0x29FA0: 'yǐ',  # 𩾠
    0x29FA1: 'bào',  # 𩾡
    0x29FA2: 'yì,yuān',  # 𩾢
    # 0x29FA3: '',  # 𩾣
    # 0x29FA4: '',  # 𩾤
    # 0x29FA5: '',  # 𩾥
    # 0x29FA6: '',  # 𩾦
    0x29FA7: 'xùn',  # 𩾧
    # 0x29FA8: '',  # 𩾨
    # 0x29FA9: '',  # 𩾩
    # 0x29FAA: '',  # 𩾪
    # 0x29FAB: '',  # 𩾫
    0x29FAC: 'xiáng',  # 𩾬
    # 0x29FAD: '',  # 𩾭
    # 0x29FAE: '',  # 𩾮
    # 0x29FAF: '',  # 𩾯
    # 0x29FB0: '',  # 𩾰
    # 0x29FB1: '',  # 𩾱
    # 0x29FB2: '',  # 𩾲
    0x29FB3: 'bí',  # 𩾳
    0x29FB4: 'jiè',  # 𩾴
    # 0x29FB5: '',  # 𩾵
    0x29FB6: 'jié',  # 𩾶
    0x29FB7: 'gē',  # 𩾷
    0x29FB8: 'zè,yàn',  # 𩾸
    # 0x29FB9: '',  # 𩾹
    0x29FBA: 'zhèn',  # 𩾺
    0x29FBB: 'hú',  # 𩾻
    0x29FBC: 'xī',  # 𩾼
    0x29FBD: 'xīn',  # 𩾽
    0x29FBE: 'xiāo,jiāo',  # 𩾾
    0x29FBF: 'fù',  # 𩾿
    0x29FC0: 'zhòng',  # 𩿀
    # 0x29FC1: '',  # 𩿁
    0x29FC2: 'mào',  # 𩿂
    0x29FC3: 'xīn',  # 𩿃
    0x29FC4: 'qiāng',  # 𩿄
    0x29FC5: 'xióng',  # 𩿅
    # 0x29FC6: '',  # 𩿆
    # 0x29FC7: '',  # 𩿇
    0x29FC8: 'fén,fēn',  # 𩿈
    0x29FC9: 'bān',  # 𩿉
    0x29FCA: 'huān',  # 𩿊
    # 0x29FCB: '',  # 𩿋
    # 0x29FCC: '',  # 𩿌
    # 0x29FCD: '',  # 𩿍
    # 0x29FCE: '',  # 𩿎
    # 0x29FCF: '',  # 𩿏
    # 0x29FD0: '',  # 𩿐
    0x29FD1: 'jiāo',  # 𩿑
    # 0x29FD2: '',  # 𩿒
    0x29FD3: 'bào',  # 𩿓
    0x29FD4: 'yā',  # 𩿔
    0x29FD5: 'yáo',  # 𩿕
    # 0x29FD6: '',  # 𩿖
    # 0x29FD7: '',  # 𩿗
    # 0x29FD8: '',  # 𩿘
    # 0x29FD9: '',  # 𩿙
    # 0x29FDA: '',  # 𩿚
    0x29FDB: 'xì',  # 𩿛
    # 0x29FDC: '',  # 𩿜
    0x29FDD: 'jù',  # 𩿝
    # 0x29FDE: '',  # 𩿞
    0x29FDF: 'qù',  # 𩿟
    0x29FE0: 'yuè',  # 𩿠
    0x29FE1: 'tái',  # 𩿡
    0x29FE2: 'tǒu',  # 𩿢
    0x29FE3: 'mò',  # 𩿣
    0x29FE4: 'zhá',  # 𩿤
    0x29FE5: 'qú',  # 𩿥
    # 0x29FE6: '',  # 𩿦
    0x29FE7: 'fū',  # 𩿧
    # 0x29FE8: '',  # 𩿨
    0x29FE9: 'qú,duó',  # 𩿩
    0x29FEA: 'chì',  # 𩿪
    # 0x29FEB: '',  # 𩿫
    0x29FEC: 'yóu',  # 𩿬
    # 0x29FED: '',  # 𩿭
    # 0x29FEE: '',  # 𩿮
    # 0x29FEF: '',  # 𩿯
    # 0x29FF0: '',  # 𩿰
    # 0x29FF1: '',  # 𩿱
    # 0x29FF2: '',  # 𩿲
    # 0x29FF3: '',  # 𩿳
    # 0x29FF4: '',  # 𩿴
    # 0x29FF5: '',  # 𩿵
    # 0x29FF6: '',  # 𩿶
    0x29FF7: 'tí',  # 𩿷
    # 0x29FF8: '',  # 𩿸
    # 0x29FF9: '',  # 𩿹
    0x29FFA: 'wā',  # 𩿺
    # 0x29FFB: '',  # 𩿻
    # 0x29FFC: '',  # 𩿼
    0x29FFD: 'tuó',  # 𩿽
    # 0x29FFE: '',  # 𩿾
    # 0x29FFF: '',  # 𩿿
    # 0x2A000: '',  # 𪀀
    0x2A001: 'gē',  # 𪀁
    # 0x2A002: '',  # 𪀂
    # 0x2A003: '',  # 𪀃
    # 0x2A004: '',  # 𪀄
    # 0x2A005: '',  # 𪀅
    # 0x2A006: '',  # 𪀆
    # 0x2A007: '',  # 𪀇
    0x2A008: 'yuān',  # 𪀈
    0x2A009: 'gē,kě',  # 𪀉
    0x2A00A: 'qú,gōu,gòu',  # 𪀊
    # 0x2A00B: '',  # 𪀋
    # 0x2A00C: '',  # 𪀌
    # 0x2A00D: '',  # 𪀍
    # 0x2A00E: '',  # 𪀎
    0x2A00F: 'jù,jiū',  # 𪀏
    0x2A010: 'fú',  # 𪀐
    # 0x2A011: '',  # 𪀑
    0x2A012: 'dié',  # 𪀒
    0x2A013: 'yí',  # 𪀓
    0x2A014: 'shī',  # 𪀔
    0x2A015: 'yì',  # 𪀕
    0x2A016: 'qiū',  # 𪀖
    0x2A017: 'guǐ',  # 𪀗
    0x2A018: 'jiàng',  # 𪀘
    # 0x2A019: '',  # 𪀙
    0x2A01A: 'sōng',  # 𪀚
    0x2A01B: 'qióng',  # 𪀛
    # 0x2A01C: '',  # 𪀜
    0x2A01D: 'è,yuān',  # 𪀝
    0x2A01E: 'huāng',  # 𪀞
    0x2A01F: 'huí',  # 𪀟
    0x2A020: 'xún',  # 𪀠
    # 0x2A021: '',  # 𪀡
    # 0x2A022: '',  # 𪀢
    0x2A023: 'jú',  # 𪀣
    # 0x2A024: '',  # 𪀤
    0x2A025: 'zhái',  # 𪀥
    0x2A026: 'chì',  # 𪀦
    0x2A027: 'lǎo',  # 𪀧
    # 0x2A028: '',  # 𪀨
    0x2A029: 'qí,dàn,chú',  # 𪀩
    0x2A02A: 'xiū',  # 𪀪
    # 0x2A02B: '',  # 𪀫
    0x2A02C: 'huī',  # 𪀬
    0x2A02D: 'tóng',  # 𪀭
    # 0x2A02E: '',  # 𪀮
    # 0x2A02F: '',  # 𪀯
    # 0x2A030: '',  # 𪀰
    # 0x2A031: '',  # 𪀱
    # 0x2A032: '',  # 𪀲
    # 0x2A033: '',  # 𪀳
    # 0x2A034: '',  # 𪀴
    # 0x2A035: '',  # 𪀵
    # 0x2A036: '',  # 𪀶
    # 0x2A037: '',  # 𪀷
    # 0x2A038: '',  # 𪀸
    # 0x2A039: '',  # 𪀹
    0x2A03A: 'fù',  # 𪀺
    # 0x2A03B: '',  # 𪀻
    # 0x2A03C: '',  # 𪀼
    0x2A03D: 'xún,xīn',  # 𪀽
    0x2A03E: 'jié',  # 𪀾
    0x2A03F: 'mǐ',  # 𪀿
    0x2A040: 'yù',  # 𪁀
    # 0x2A041: '',  # 𪁁
    # 0x2A042: '',  # 𪁂
    # 0x2A043: '',  # 𪁃
    # 0x2A044: '',  # 𪁄
    # 0x2A045: '',  # 𪁅
    # 0x2A046: '',  # 𪁆
    # 0x2A047: '',  # 𪁇
    0x2A048: 'zhuàng',  # 𪁈
    0x2A049: 'jiāo',  # 𪁉
    0x2A04A: 'zhì,zhé',  # 𪁊
    0x2A04B: 'chéng',  # 𪁋
    # 0x2A04C: '',  # 𪁌
    0x2A04D: 'jié',  # 𪁍
    0x2A04E: 'xiāo',  # 𪁎
    0x2A04F: 'chén',  # 𪁏
    0x2A050: 'lí',  # 𪁐
    0x2A051: 'yuè',  # 𪁑
    # 0x2A052: '',  # 𪁒
    0x2A053: 'zhì',  # 𪁓
    0x2A054: 'láo',  # 𪁔
    0x2A055: 'wò',  # 𪁕
    0x2A056: 'qú',  # 𪁖
    # 0x2A057: '',  # 𪁗
    0x2A058: 'wāng',  # 𪁘
    # 0x2A059: '',  # 𪁙
    0x2A05A: 'yī',  # 𪁚
    0x2A05B: 'yì',  # 𪁛
    0x2A05C: 'láng',  # 𪁜
    # 0x2A05D: '',  # 𪁝
    0x2A05E: 'tóu',  # 𪁞
    0x2A05F: 'ān,hàn',  # 𪁟
    0x2A060: 'jué',  # 𪁠
    0x2A061: 'yàn',  # 𪁡
    # 0x2A062: '',  # 𪁢
    # 0x2A063: '',  # 𪁣
    # 0x2A064: '',  # 𪁤
    0x2A065: 'jù',  # 𪁥
    # 0x2A066: '',  # 𪁦
    0x2A067: 'zhèn,chén',  # 𪁧
    # 0x2A068: '',  # 𪁨
    0x2A069: 'zhì,tí',  # 𪁩
    0x2A06A: 'mǎng',  # 𪁪
    # 0x2A06B: '',  # 𪁫
    # 0x2A06C: '',  # 𪁬
    # 0x2A06D: '',  # 𪁭
    0x2A06E: 'xiù',  # 𪁮
    # 0x2A06F: '',  # 𪁯
    # 0x2A070: '',  # 𪁰
    0x2A071: 'chuáng',  # 𪁱
    0x2A072: 'chū',  # 𪁲
    # 0x2A073: '',  # 𪁳
    # 0x2A074: '',  # 𪁴
    # 0x2A075: '',  # 𪁵
    # 0x2A076: '',  # 𪁶
    # 0x2A077: '',  # 𪁷
    0x2A078: 'qiāng',  # 𪁸
    0x2A079: 'fēi',  # 𪁹
    0x2A07A: 'cháng,chǎng',  # 𪁺
    # 0x2A07B: '',  # 𪁻
    0x2A07C: 'mián',  # 𪁼
    0x2A07D: 'sù',  # 𪁽
    0x2A07E: 'ǎo,wò',  # 𪁾
    # 0x2A07F: '',  # 𪁿
    0x2A080: 'fǔ',  # 𪂀
    # 0x2A081: '',  # 𪂁
    # 0x2A082: '',  # 𪂂
    0x2A083: 'bēi',  # 𪂃
    0x2A084: 'wèi',  # 𪂄
    0x2A085: 'zhī',  # 𪂅
    0x2A086: 'mín',  # 𪂆
    0x2A087: 'chāng',  # 𪂇
    0x2A088: 'yán',  # 𪂈
    0x2A089: 'yù',  # 𪂉
    # 0x2A08A: '',  # 𪂊
    0x2A08B: 'fù',  # 𪂋
    0x2A08C: 'tà',  # 𪂌
    0x2A08D: 'jǐ',  # 𪂍
    # 0x2A08E: '',  # 𪂎
    0x2A08F: 'fèi',  # 𪂏
    # 0x2A090: '',  # 𪂐
    # 0x2A091: '',  # 𪂑
    0x2A092: 'hú',  # 𪂒
    0x2A093: 'jū',  # 𪂓
    # 0x2A094: '',  # 𪂔
    0x2A095: 'yǔ',  # 𪂕
    # 0x2A096: '',  # 𪂖
    # 0x2A097: '',  # 𪂗
    # 0x2A098: '',  # 𪂘
    # 0x2A099: '',  # 𪂙
    0x2A09A: 'lù',  # 𪂚
    0x2A09B: 'qí',  # 𪂛
    0x2A09C: 'méi',  # 𪂜
    # 0x2A09D: '',  # 𪂝
    # 0x2A09E: '',  # 𪂞
    0x2A09F: 'biē',  # 𪂟
    0x2A0A0: 'guǒ',  # 𪂠
    # 0x2A0A1: '',  # 𪂡
    # 0x2A0A2: '',  # 𪂢
    # 0x2A0A3: '',  # 𪂣
    0x2A0A4: 'mìng',  # 𪂤
    # 0x2A0A5: '',  # 𪂥
    0x2A0A6: 'wǎn,yuān',  # 𪂦
    0x2A0A7: 'wǎn',  # 𪂧
    # 0x2A0A8: '',  # 𪂨
    # 0x2A0A9: '',  # 𪂩
    # 0x2A0AA: '',  # 𪂪
    # 0x2A0AB: '',  # 𪂫
    # 0x2A0AC: '',  # 𪂬
    # 0x2A0AD: '',  # 𪂭
    # 0x2A0AE: '',  # 𪂮
    # 0x2A0AF: '',  # 𪂯
    # 0x2A0B0: '',  # 𪂰
    # 0x2A0B1: '',  # 𪂱
    # 0x2A0B2: '',  # 𪂲
    # 0x2A0B3: '',  # 𪂳
    0x2A0B4: 'jīng',  # 𪂴
    0x2A0B5: 'yù',  # 𪂵
    0x2A0B6: 'xián',  # 𪂶
    # 0x2A0B7: '',  # 𪂷
    # 0x2A0B8: '',  # 𪂸
    0x2A0B9: 'chūn',  # 𪂹
    0x2A0BA: 'jí',  # 𪂺
    # 0x2A0BB: '',  # 𪂻
    0x2A0BC: 'xiāng',  # 𪂼
    0x2A0BD: 'pén',  # 𪂽
    0x2A0BE: 'fù',  # 𪂾
    0x2A0BF: 'tí',  # 𪂿
    # 0x2A0C0: '',  # 𪃀
    # 0x2A0C1: '',  # 𪃁
    0x2A0C2: 'liú',  # 𪃂
    # 0x2A0C3: '',  # 𪃃
    0x2A0C4: 'sāi',  # 𪃄
    0x2A0C5: 'xuē',  # 𪃅
    0x2A0C6: 'zòu',  # 𪃆
    # 0x2A0C7: '',  # 𪃇
    0x2A0C8: 'jié',  # 𪃈
    # 0x2A0C9: '',  # 𪃉
    # 0x2A0CA: '',  # 𪃊
    0x2A0CB: 'zhān,jiān',  # 𪃋
    # 0x2A0CC: '',  # 𪃌
    0x2A0CD: 'yú',  # 𪃍
    0x2A0CE: 'yú',  # 𪃎
    0x2A0CF: 'méi',  # 𪃏
    0x2A0D0: 'miǎo',  # 𪃐
    0x2A0D1: 'mào',  # 𪃑
    0x2A0D2: 'duó',  # 𪃒
    0x2A0D3: 'fù',  # 𪃓
    # 0x2A0D4: '',  # 𪃔
    # 0x2A0D5: '',  # 𪃕
    # 0x2A0D6: '',  # 𪃖
    # 0x2A0D7: '',  # 𪃗
    # 0x2A0D8: '',  # 𪃘
    # 0x2A0D9: '',  # 𪃙
    # 0x2A0DA: '',  # 𪃚
    0x2A0DB: 'jiàn',  # 𪃛
    # 0x2A0DC: '',  # 𪃜
    # 0x2A0DD: '',  # 𪃝
    # 0x2A0DE: '',  # 𪃞
    # 0x2A0DF: '',  # 𪃟
    # 0x2A0E0: '',  # 𪃠
    # 0x2A0E1: '',  # 𪃡
    # 0x2A0E2: '',  # 𪃢
    # 0x2A0E3: '',  # 𪃣
    # 0x2A0E4: '',  # 𪃤
    # 0x2A0E5: '',  # 𪃥
    0x2A0E6: 'miáo',  # 𪃦
    0x2A0E7: 'miǎo',  # 𪃧
    0x2A0E8: 'āo',  # 𪃨
    # 0x2A0E9: '',  # 𪃩
    # 0x2A0EA: '',  # 𪃪
    # 0x2A0EB: '',  # 𪃫
    # 0x2A0EC: '',  # 𪃬
    0x2A0ED: 'kè',  # 𪃭
    # 0x2A0EE: '',  # 𪃮
    # 0x2A0EF: '',  # 𪃯
    # 0x2A0F0: '',  # 𪃰
    # 0x2A0F1: '',  # 𪃱
    # 0x2A0F2: '',  # 𪃲
    # 0x2A0F3: '',  # 𪃳
    # 0x2A0F4: '',  # 𪃴
    # 0x2A0F5: '',  # 𪃵
    0x2A0F6: 'hóu',  # 𪃶
    # 0x2A0F7: '',  # 𪃷
    # 0x2A0F8: '',  # 𪃸
    # 0x2A0F9: '',  # 𪃹
    0x2A0FA: 'gòu',  # 𪃺
    # 0x2A0FB: '',  # 𪃻
    0x2A0FC: 'xī',  # 𪃼
    # 0x2A0FD: '',  # 𪃽
    0x2A0FE: 'róng',  # 𪃾
    0x2A0FF: 'gē',  # 𪃿
    0x2A100: 'pán',  # 𪄀
    0x2A101: 'yuán',  # 𪄁
    0x2A102: 'xià',  # 𪄂
    # 0x2A103: '',  # 𪄃
    # 0x2A104: '',  # 𪄄
    0x2A105: 'shā',  # 𪄅
    0x2A106: 'pī,pí',  # 𪄆
    # 0x2A107: '',  # 𪄇
    0x2A108: 'qíng',  # 𪄈
    0x2A109: 'yōng',  # 𪄉
    0x2A10A: 'qú',  # 𪄊
    # 0x2A10B: '',  # 𪄋
    0x2A10C: 'gòng',  # 𪄌
    # 0x2A10D: '',  # 𪄍
    0x2A10E: 'gé',  # 𪄎
    0x2A10F: 'xiān',  # 𪄏
    # 0x2A110: '',  # 𪄐
    0x2A111: 'sù',  # 𪄑
    # 0x2A112: '',  # 𪄒
    # 0x2A113: '',  # 𪄓
    # 0x2A114: '',  # 𪄔
    0x2A115: 'bān',  # 𪄕
    0x2A116: 'qí',  # 𪄖
    0x2A117: 'hòu',  # 𪄗
    # 0x2A118: '',  # 𪄘
    # 0x2A119: '',  # 𪄙
    # 0x2A11A: '',  # 𪄚
    0x2A11B: 'xī',  # 𪄛
    # 0x2A11C: '',  # 𪄜
    0x2A11D: 'wū',  # 𪄝
    # 0x2A11E: '',  # 𪄞
    # 0x2A11F: '',  # 𪄟
    0x2A120: 'chì',  # 𪄠
    # 0x2A121: '',  # 𪄡
    # 0x2A122: '',  # 𪄢
    # 0x2A123: '',  # 𪄣
    # 0x2A124: '',  # 𪄤
    # 0x2A125: '',  # 𪄥
    # 0x2A126: '',  # 𪄦
    # 0x2A127: '',  # 𪄧
    # 0x2A128: '',  # 𪄨
    # 0x2A129: '',  # 𪄩
    # 0x2A12A: '',  # 𪄪
    # 0x2A12B: '',  # 𪄫
    # 0x2A12C: '',  # 𪄬
    0x2A12D: 'qī',  # 𪄭
    0x2A12E: 'hù,gù',  # 𪄮
    0x2A12F: 'guī',  # 𪄯
    # 0x2A130: '',  # 𪄰
    0x2A131: 'dí',  # 𪄱
    0x2A132: 'shāng',  # 𪄲
    0x2A133: 'mài',  # 𪄳
    0x2A134: 'mǐn',  # 𪄴
    0x2A135: 'jì',  # 𪄵
    0x2A136: 'xí',  # 𪄶
    0x2A137: 'xiān',  # 𪄷
    0x2A138: 'jí',  # 𪄸
    0x2A139: 'cháng',  # 𪄹
    0x2A13A: 'kòu',  # 𪄺
    0x2A13B: 'chōng,zhuāng',  # 𪄻
    0x2A13C: 'yǎo',  # 𪄼
    # 0x2A13D: '',  # 𪄽
    # 0x2A13E: '',  # 𪄾
    # 0x2A13F: '',  # 𪄿
    0x2A140: 'nán',  # 𪅀
    # 0x2A141: '',  # 𪅁
    0x2A142: 'zhāng',  # 𪅂
    0x2A143: 'piǎo,piāo',  # 𪅃
    0x2A144: 'sù',  # 𪅄
    0x2A145: 'lüè',  # 𪅅
    0x2A146: 'lí',  # 𪅆
    0x2A147: 'mèng',  # 𪅇
    0x2A148: 'chōng',  # 𪅈
    0x2A149: 'tiān',  # 𪅉
    # 0x2A14A: '',  # 𪅊
    0x2A14B: 'líng',  # 𪅋
    # 0x2A14C: '',  # 𪅌
    0x2A14D: 'chì',  # 𪅍
    # 0x2A14E: '',  # 𪅎
    # 0x2A14F: '',  # 𪅏
    # 0x2A150: '',  # 𪅐
    # 0x2A151: '',  # 𪅑
    # 0x2A152: '',  # 𪅒
    # 0x2A153: '',  # 𪅓
    # 0x2A154: '',  # 𪅔
    # 0x2A155: '',  # 𪅕
    0x2A156: 'chōng,zhuāng',  # 𪅖
    # 0x2A157: '',  # 𪅗
    # 0x2A158: '',  # 𪅘
    0x2A159: 'chì',  # 𪅙
    # 0x2A15A: '',  # 𪅚
    # 0x2A15B: '',  # 𪅛
    # 0x2A15C: '',  # 𪅜
    0x2A15D: 'niǎo',  # 𪅝
    # 0x2A15E: '',  # 𪅞
    0x2A15F: 'yóng',  # 𪅟
    # 0x2A160: '',  # 𪅠
    0x2A161: 'liù',  # 𪅡
    # 0x2A162: '',  # 𪅢
    # 0x2A163: '',  # 𪅣
    # 0x2A164: '',  # 𪅤
    # 0x2A165: '',  # 𪅥
    # 0x2A166: '',  # 𪅦
    # 0x2A167: '',  # 𪅧
    # 0x2A168: '',  # 𪅨
    # 0x2A169: '',  # 𪅩
    # 0x2A16A: '',  # 𪅪
    # 0x2A16B: '',  # 𪅫
    # 0x2A16C: '',  # 𪅬
    # 0x2A16D: '',  # 𪅭
    0x2A16E: 'mì',  # 𪅮
    # 0x2A16F: '',  # 𪅯
    0x2A170: 'shū',  # 𪅰
    # 0x2A171: '',  # 𪅱
    0x2A172: 'xì',  # 𪅲
    0x2A173: 'liú',  # 𪅳
    0x2A174: 'è',  # 𪅴
    0x2A175: 'zī',  # 𪅵
    # 0x2A176: '',  # 𪅶
    # 0x2A177: '',  # 𪅷
    0x2A178: 'jié',  # 𪅸
    0x2A179: 'jī',  # 𪅹
    0x2A17A: 'hōu',  # 𪅺
    0x2A17B: 'shèng',  # 𪅻
    0x2A17C: 'lì',  # 𪅼
    # 0x2A17D: '',  # 𪅽
    0x2A17E: 'qī',  # 𪅾
    # 0x2A17F: '',  # 𪅿
    0x2A180: 'zhōu',  # 𪆀
    0x2A181: 'sī',  # 𪆁
    0x2A182: 'qú',  # 𪆂
    # 0x2A183: '',  # 𪆃
    0x2A184: 'jiāo',  # 𪆄
    # 0x2A185: '',  # 𪆅
    # 0x2A186: '',  # 𪆆
    # 0x2A187: '',  # 𪆇
    # 0x2A188: '',  # 𪆈
    # 0x2A189: '',  # 𪆉
    # 0x2A18A: '',  # 𪆊
    0x2A18B: 'xié',  # 𪆋
    # 0x2A18C: '',  # 𪆌
    # 0x2A18D: '',  # 𪆍
    # 0x2A18E: '',  # 𪆎
    # 0x2A18F: '',  # 𪆏
    # 0x2A190: '',  # 𪆐
    # 0x2A191: '',  # 𪆑
    # 0x2A192: '',  # 𪆒
    0x2A193: 'sī',  # 𪆓
    # 0x2A194: '',  # 𪆔
    # 0x2A195: '',  # 𪆕
    0x2A196: 'yì',  # 𪆖
    0x2A197: 'sī',  # 𪆗
    # 0x2A198: '',  # 𪆘
    # 0x2A199: '',  # 𪆙
    # 0x2A19A: '',  # 𪆚
    0x2A19B: 'xū',  # 𪆛
    # 0x2A19C: '',  # 𪆜
    # 0x2A19D: '',  # 𪆝
    # 0x2A19E: '',  # 𪆞
    # 0x2A19F: '',  # 𪆟
    0x2A1A0: 'fù',  # 𪆠
    # 0x2A1A1: '',  # 𪆡
    # 0x2A1A2: '',  # 𪆢
    # 0x2A1A3: '',  # 𪆣
    # 0x2A1A4: '',  # 𪆤
    # 0x2A1A5: '',  # 𪆥
    # 0x2A1A6: '',  # 𪆦
    # 0x2A1A7: '',  # 𪆧
    # 0x2A1A8: '',  # 𪆨
    0x2A1A9: 'jiù',  # 𪆩
    # 0x2A1AA: '',  # 𪆪
    0x2A1AB: 'qú',  # 𪆫
    # 0x2A1AC: '',  # 𪆬
    # 0x2A1AD: '',  # 𪆭
    # 0x2A1AE: '',  # 𪆮
    0x2A1AF: 'nóng',  # 𪆯
    0x2A1B0: 'yà',  # 𪆰
    0x2A1B1: 'liú',  # 𪆱
    0x2A1B2: 'jiǎ,zhān',  # 𪆲
    0x2A1B3: 'guī',  # 𪆳
    0x2A1B4: 'kuí',  # 𪆴
    0x2A1B5: 'chì',  # 𪆵
    0x2A1B6: 'càn',  # 𪆶
    0x2A1B7: 'chú',  # 𪆷
    # 0x2A1B8: '',  # 𪆸
    0x2A1B9: 'guō',  # 𪆹
    # 0x2A1BA: '',  # 𪆺
    0x2A1BB: 'dǎn',  # 𪆻
    # 0x2A1BC: '',  # 𪆼
    # 0x2A1BD: '',  # 𪆽
    # 0x2A1BE: '',  # 𪆾
    0x2A1BF: 'jiàn',  # 𪆿
    # 0x2A1C0: '',  # 𪇀
    0x2A1C1: 'dāng',  # 𪇁
    0x2A1C2: 'hòu',  # 𪇂
    # 0x2A1C3: '',  # 𪇃
    0x2A1C4: 'kòu,kū',  # 𪇄
    # 0x2A1C5: '',  # 𪇅
    0x2A1C6: 'chù,dú',  # 𪇆
    0x2A1C7: 'qiān',  # 𪇇
    0x2A1C8: 'ài',  # 𪇈
    # 0x2A1C9: '',  # 𪇉
    0x2A1CA: 'pì',  # 𪇊
    # 0x2A1CB: '',  # 𪇋
    # 0x2A1CC: '',  # 𪇌
    # 0x2A1CD: '',  # 𪇍
    # 0x2A1CE: '',  # 𪇎
    # 0x2A1CF: '',  # 𪇏
    # 0x2A1D0: '',  # 𪇐
    0x2A1D1: 'xùn',  # 𪇑
    0x2A1D2: 'jīng',  # 𪇒
    0x2A1D3: 'mèng',  # 𪇓
    # 0x2A1D4: '',  # 𪇔
    0x2A1D5: 'bīn',  # 𪇕
    0x2A1D6: 'lán',  # 𪇖
    0x2A1D7: 'gǔ',  # 𪇗
    0x2A1D8: 'chóu,táo',  # 𪇘
    # 0x2A1D9: '',  # 𪇙
    # 0x2A1DA: '',  # 𪇚
    0x2A1DB: 'yōng',  # 𪇛
    0x2A1DC: 'guá',  # 𪇜
    0x2A1DD: 'yú',  # 𪇝
    0x2A1DE: 'zhòu',  # 𪇞
    # 0x2A1DF: '',  # 𪇟
    # 0x2A1E0: '',  # 𪇠
    # 0x2A1E1: '',  # 𪇡
    # 0x2A1E2: '',  # 𪇢
    # 0x2A1E3: '',  # 𪇣
    # 0x2A1E4: '',  # 𪇤
    # 0x2A1E5: '',  # 𪇥
    # 0x2A1E6: '',  # 𪇦
    # 0x2A1E7: '',  # 𪇧
    # 0x2A1E8: '',  # 𪇨
    # 0x2A1E9: '',  # 𪇩
    # 0x2A1EA: '',  # 𪇪
    # 0x2A1EB: '',  # 𪇫
    0x2A1EC: 'yù',  # 𪇬
    0x2A1ED: 'cài',  # 𪇭
    # 0x2A1EE: '',  # 𪇮
    0x2A1EF: 'liú',  # 𪇯
    0x2A1F0: 'bǔ',  # 𪇰
    0x2A1F1: 'luò',  # 𪇱
    0x2A1F2: 'jié',  # 𪇲
    0x2A1F3: 'zhēn',  # 𪇳
    0x2A1F4: 'miè',  # 𪇴
    0x2A1F5: 'guǎng',  # 𪇵
    # 0x2A1F6: '',  # 𪇶
    0x2A1F7: 'jiá',  # 𪇷
    # 0x2A1F8: '',  # 𪇸
    0x2A1F9: 'là',  # 𪇹
    # 0x2A1FA: '',  # 𪇺
    # 0x2A1FB: '',  # 𪇻
    # 0x2A1FC: '',  # 𪇼
    # 0x2A1FD: '',  # 𪇽
    # 0x2A1FE: '',  # 𪇾
    # 0x2A1FF: '',  # 𪇿
    0x2A200: 'shòu',  # 𪈀
    0x2A201: 'zhēn',  # 𪈁
    # 0x2A202: '',  # 𪈂
    0x2A203: 'guō',  # 𪈃
    # 0x2A204: '',  # 𪈄
    0x2A205: 'jú',  # 𪈅
    0x2A206: 'mèng',  # 𪈆
    0x2A207: 'qián',  # 𪈇
    0x2A208: 'lài',  # 𪈈
    # 0x2A209: '',  # 𪈉
    0x2A20A: 'hé',  # 𪈊
    0x2A20B: 'tuán',  # 𪈋
    # 0x2A20C: '',  # 𪈌
    # 0x2A20D: '',  # 𪈍
    # 0x2A20E: '',  # 𪈎
    # 0x2A20F: '',  # 𪈏
    # 0x2A210: '',  # 𪈐
    0x2A211: 'huī',  # 𪈑
    0x2A212: 'lú',  # 𪈒
    # 0x2A213: '',  # 𪈓
    # 0x2A214: '',  # 𪈔
    # 0x2A215: '',  # 𪈕
    # 0x2A216: '',  # 𪈖
    # 0x2A217: '',  # 𪈗
    0x2A218: 'hōng',  # 𪈘
    # 0x2A219: '',  # 𪈙
    # 0x2A21A: '',  # 𪈚
    # 0x2A21B: '',  # 𪈛
    0x2A21C: 'lǚ',  # 𪈜
    # 0x2A21D: '',  # 𪈝
    # 0x2A21E: '',  # 𪈞
    0x2A21F: 'jiá',  # 𪈟
    # 0x2A220: '',  # 𪈠
    # 0x2A221: '',  # 𪈡
    # 0x2A222: '',  # 𪈢
    # 0x2A223: '',  # 𪈣
    # 0x2A224: '',  # 𪈤
    0x2A225: 'guī',  # 𪈥
    # 0x2A226: '',  # 𪈦
    # 0x2A227: '',  # 𪈧
    0x2A228: 'yī',  # 𪈨
    0x2A229: 'huān',  # 𪈩
    # 0x2A22A: '',  # 𪈪
    # 0x2A22B: '',  # 𪈫
    # 0x2A22C: '',  # 𪈬
    # 0x2A22D: '',  # 𪈭
    # 0x2A22E: '',  # 𪈮
    # 0x2A22F: '',  # 𪈯
    0x2A230: 'luó',  # 𪈰
    # 0x2A231: '',  # 𪈱
    # 0x2A232: '',  # 𪈲
    # 0x2A233: '',  # 𪈳
    0x2A234: 'jué',  # 𪈴
    # 0x2A235: '',  # 𪈵
    # 0x2A236: '',  # 𪈶
    # 0x2A237: '',  # 𪈷
    0x2A238: 'guàn',  # 𪈸
    # 0x2A239: '',  # 𪈹
    # 0x2A23A: '',  # 𪈺
    0x2A23B: 'quán',  # 𪈻
    0x2A23C: 'niǎo',  # 𪈼
    # 0x2A23D: '',  # 𪈽
    # 0x2A23E: '',  # 𪈾
    0x2A23F: 'mán',  # 𪈿
    # 0x2A240: '',  # 𪉀
    # 0x2A241: '',  # 𪉁
    # 0x2A242: '',  # 𪉂
    # 0x2A243: '',  # 𪉃
    # 0x2A244: '',  # 𪉄
    # 0x2A245: '',  # 𪉅
    # 0x2A246: '',  # 𪉆
    # 0x2A247: '',  # 𪉇
    # 0x2A248: '',  # 𪉈
    # 0x2A249: '',  # 𪉉
    # 0x2A24A: '',  # 𪉊
    # 0x2A24B: '',  # 𪉋
    # 0x2A24C: '',  # 𪉌
    # 0x2A24D: '',  # 𪉍
    # 0x2A24E: '',  # 𪉎
    # 0x2A24F: '',  # 𪉏
    # 0x2A250: '',  # 𪉐
    # 0x2A251: '',  # 𪉑
    # 0x2A252: '',  # 𪉒
    0x2A253: 'niǎo',  # 𪉓
    # 0x2A254: '',  # 𪉔
    # 0x2A255: '',  # 𪉕
    0x2A256: 'lǔ',  # 𪉖
    0x2A257: 'chì',  # 𪉗
    0x2A258: 'tóu',  # 𪉘
    # 0x2A259: '',  # 𪉙
    0x2A25A: 'jiē',  # 𪉚
    # 0x2A25B: '',  # 𪉛
    0x2A25C: 'zhān',  # 𪉜
    # 0x2A25D: '',  # 𪉝
    # 0x2A25E: '',  # 𪉞
    # 0x2A25F: '',  # 𪉟
    # 0x2A260: '',  # 𪉠
    # 0x2A261: '',  # 𪉡
    0x2A262: 'jīn',  # 𪉢
    0x2A263: 'lǔ',  # 𪉣
    0x2A264: 'cuó',  # 𪉤
    # 0x2A265: '',  # 𪉥
    0x2A266: 'jiàn,jiǎn,gàn',  # 𪉦
    0x2A267: 'tàn',  # 𪉧
    0x2A268: 'chāng',  # 𪉨
    # 0x2A269: '',  # 𪉩
    0x2A26A: 'cì',  # 𪉪
    # 0x2A26B: '',  # 𪉫
    # 0x2A26C: '',  # 𪉬
    0x2A26D: 'wāi',  # 𪉭
    0x2A26E: 'còu',  # 𪉮
    0x2A26F: 'kàn',  # 𪉯
    # 0x2A270: '',  # 𪉰
    0x2A271: 'biàn',  # 𪉱
    # 0x2A272: '',  # 𪉲
    # 0x2A273: '',  # 𪉳
    # 0x2A274: '',  # 𪉴
    # 0x2A275: '',  # 𪉵
    # 0x2A276: '',  # 𪉶
    0x2A277: 'tán',  # 𪉷
    0x2A278: 'wēn',  # 𪉸
    # 0x2A279: '',  # 𪉹
    # 0x2A27A: '',  # 𪉺
    0x2A27B: 'qiān',  # 𪉻
    # 0x2A27C: '',  # 𪉼
    # 0x2A27D: '',  # 𪉽
    # 0x2A27E: '',  # 𪉾
    0x2A27F: 'gàn',  # 𪉿
    # 0x2A280: '',  # 𪊀
    # 0x2A281: '',  # 𪊁
    0x2A282: 'huì',  # 𪊂
    # 0x2A283: '',  # 𪊃
    0x2A284: 'gǎn,gàn',  # 𪊄
    # 0x2A285: '',  # 𪊅
    0x2A286: 'jì',  # 𪊆
    0x2A287: 'gàn,tàn',  # 𪊇
    # 0x2A288: '',  # 𪊈
    0x2A289: 'huái',  # 𪊉
    # 0x2A28A: '',  # 𪊊
    0x2A28B: 'jǐ',  # 𪊋
    # 0x2A28C: '',  # 𪊌
    0x2A28D: 'sì',  # 𪊍
    # 0x2A28E: '',  # 𪊎
    # 0x2A28F: '',  # 𪊏
    0x2A290: 'fū',  # 𪊐
    # 0x2A291: '',  # 𪊑
    # 0x2A292: '',  # 𪊒
    # 0x2A293: '',  # 𪊓
    # 0x2A294: '',  # 𪊔
    0x2A295: 'pí',  # 𪊕
    # 0x2A296: '',  # 𪊖
    0x2A297: 'cā',  # 𪊗
    # 0x2A298: '',  # 𪊘
    # 0x2A299: '',  # 𪊙
    # 0x2A29A: '',  # 𪊚
    # 0x2A29B: '',  # 𪊛
    0x2A29C: 'bèn',  # 𪊜
    # 0x2A29D: '',  # 𪊝
    # 0x2A29E: '',  # 𪊞
    # 0x2A29F: '',  # 𪊟
    # 0x2A2A0: '',  # 𪊠
    # 0x2A2A1: '',  # 𪊡
    0x2A2A2: 'shǐ',  # 𪊢
    # 0x2A2A3: '',  # 𪊣
    # 0x2A2A4: '',  # 𪊤
    0x2A2A5: 'huán',  # 𪊥
    # 0x2A2A6: '',  # 𪊦
    0x2A2A7: 'guī',  # 𪊧
    0x2A2A8: 'jǐ',  # 𪊨
    # 0x2A2A9: '',  # 𪊩
    0x2A2AA: 'ǒu',  # 𪊪
    # 0x2A2AB: '',  # 𪊫
    # 0x2A2AC: '',  # 𪊬
    # 0x2A2AD: '',  # 𪊭
    # 0x2A2AE: '',  # 𪊮
    # 0x2A2AF: '',  # 𪊯
    # 0x2A2B0: '',  # 𪊰
    # 0x2A2B1: '',  # 𪊱
    # 0x2A2B2: '',  # 𪊲
    0x2A2B3: 'páo',  # 𪊳
    # 0x2A2B4: '',  # 𪊴
    0x2A2B5: 'yǐng',  # 𪊵
    0x2A2B6: 'tǐng',  # 𪊶
    0x2A2B7: 'xiào',  # 𪊷
    # 0x2A2B8: '',  # 𪊸
    0x2A2B9: 'zhù',  # 𪊹
    # 0x2A2BA: '',  # 𪊺
    0x2A2BB: 'yú',  # 𪊻
    # 0x2A2BC: '',  # 𪊼
    # 0x2A2BD: '',  # 𪊽
    # 0x2A2BE: '',  # 𪊾
    # 0x2A2BF: '',  # 𪊿
    # 0x2A2C0: '',  # 𪋀
    0x2A2C1: 'jiàn',  # 𪋁
    # 0x2A2C2: '',  # 𪋂
    # 0x2A2C3: '',  # 𪋃
    0x2A2C4: 'qǔ',  # 𪋄
    0x2A2C5: 'wǎn',  # 𪋅
    0x2A2C6: 'kūn',  # 𪋆
    0x2A2C7: 'zhuī',  # 𪋇
    # 0x2A2C8: '',  # 𪋈
    0x2A2C9: 'yù',  # 𪋉
    0x2A2CA: 'guǒ',  # 𪋊
    0x2A2CB: 'píng',  # 𪋋
    0x2A2CC: 'zuǐ',  # 𪋌
    0x2A2CD: 'zú',  # 𪋍
    # 0x2A2CE: '',  # 𪋎
    0x2A2CF: 'zhū',  # 𪋏
    0x2A2D0: 'nuàn',  # 𪋐
    0x2A2D1: 'zhū',  # 𪋑
    # 0x2A2D2: '',  # 𪋒
    # 0x2A2D3: '',  # 𪋓
    # 0x2A2D4: '',  # 𪋔
    # 0x2A2D5: '',  # 𪋕
    0x2A2D6: 'piāo',  # 𪋖
    0x2A2D7: 'mí',  # 𪋗
    # 0x2A2D8: '',  # 𪋘
    # 0x2A2D9: '',  # 𪋙
    # 0x2A2DA: '',  # 𪋚
    # 0x2A2DB: '',  # 𪋛
    0x2A2DC: 'bì',  # 𪋜
    0x2A2DD: 'sù',  # 𪋝
    # 0x2A2DE: '',  # 𪋞
    # 0x2A2DF: '',  # 𪋟
    # 0x2A2E0: '',  # 𪋠
    0x2A2E1: 'pú',  # 𪋡
    0x2A2E2: 'mí',  # 𪋢
    # 0x2A2E3: '',  # 𪋣
    # 0x2A2E4: '',  # 𪋤
    # 0x2A2E5: '',  # 𪋥
    # 0x2A2E6: '',  # 𪋦
    0x2A2E7: 'shè',  # 𪋧
    # 0x2A2E8: '',  # 𪋨
    # 0x2A2E9: '',  # 𪋩
    # 0x2A2EA: '',  # 𪋪
    0x2A2EB: 'yè',  # 𪋫
    0x2A2EC: 'yǔ',  # 𪋬
    # 0x2A2ED: '',  # 𪋭
    0x2A2EE: 'yù',  # 𪋮
    # 0x2A2EF: '',  # 𪋯
    0x2A2F0: 'zhǔ',  # 𪋰
    # 0x2A2F1: '',  # 𪋱
    # 0x2A2F2: '',  # 𪋲
    0x2A2F3: 'líng',  # 𪋳
    # 0x2A2F4: '',  # 𪋴
    # 0x2A2F5: '',  # 𪋵
    # 0x2A2F6: '',  # 𪋶
    # 0x2A2F7: '',  # 𪋷
    # 0x2A2F8: '',  # 𪋸
    # 0x2A2F9: '',  # 𪋹
    0x2A2FA: 'nòu',  # 𪋺
    0x2A2FB: 'chén',  # 𪋻
    # 0x2A2FC: '',  # 𪋼
    # 0x2A2FD: '',  # 𪋽
    0x2A2FE: 'líng',  # 𪋾
    # 0x2A2FF: '',  # 𪋿
    0x2A300: 'liǎo',  # 𪌀
    # 0x2A301: '',  # 𪌁
    0x2A302: 'tuō',  # 𪌂
    # 0x2A303: '',  # 𪌃
    0x2A304: 'bǐ',  # 𪌄
    0x2A305: 'nà',  # 𪌅
    0x2A306: 'qú',  # 𪌆
    # 0x2A307: '',  # 𪌇
    0x2A308: 'pí',  # 𪌈
    0x2A309: 'dǒu',  # 𪌉
    0x2A30A: 'niè',  # 𪌊
    0x2A30B: 'tún',  # 𪌋
    # 0x2A30C: '',  # 𪌌
    0x2A30D: 'jī',  # 𪌍
    # 0x2A30E: '',  # 𪌎
    0x2A30F: 'líng',  # 𪌏
    # 0x2A310: '',  # 𪌐
    # 0x2A311: '',  # 𪌑
    # 0x2A312: '',  # 𪌒
    0x2A313: 'kù',  # 𪌓
    0x2A314: 'sù',  # 𪌔
    # 0x2A315: '',  # 𪌕
    # 0x2A316: '',  # 𪌖
    # 0x2A317: '',  # 𪌗
    0x2A318: 'tǒu',  # 𪌘
    # 0x2A319: '',  # 𪌙
    # 0x2A31A: '',  # 𪌚
    # 0x2A31B: '',  # 𪌛
    # 0x2A31C: '',  # 𪌜
    # 0x2A31D: '',  # 𪌝
    0x2A31E: 'nái',  # 𪌞
    0x2A31F: 'zé',  # 𪌟
    # 0x2A320: '',  # 𪌠
    # 0x2A321: '',  # 𪌡
    0x2A322: 'tǒng',  # 𪌢
    0x2A323: 'gé',  # 𪌣
    0x2A324: 'duī',  # 𪌤
    # 0x2A325: '',  # 𪌥
    # 0x2A326: '',  # 𪌦
    0x2A327: 'jié',  # 𪌧
    # 0x2A328: '',  # 𪌨
    0x2A329: 'tián',  # 𪌩
    0x2A32A: 'tiào',  # 𪌪
    0x2A32B: 'chí',  # 𪌫
    0x2A32C: 'qū,chǎo',  # 𪌬
    # 0x2A32D: '',  # 𪌭
    0x2A32E: 'shā,suō',  # 𪌮
    # 0x2A32F: '',  # 𪌯
    0x2A330: 'bó',  # 𪌰
    0x2A331: 'lí',  # 𪌱
    # 0x2A332: '',  # 𪌲
    0x2A333: 'luò',  # 𪌳
    # 0x2A334: '',  # 𪌴
    0x2A335: 'liáo',  # 𪌵
    0x2A336: 'shù',  # 𪌶
    0x2A337: 'děng',  # 𪌷
    # 0x2A338: '',  # 𪌸
    0x2A339: 'chī',  # 𪌹
    0x2A33A: 'miè',  # 𪌺
    # 0x2A33B: '',  # 𪌻
    0x2A33C: 'táo',  # 𪌼
    0x2A33D: 'hún',  # 𪌽
    # 0x2A33E: '',  # 𪌾
    0x2A33F: 'nié',  # 𪌿
    # 0x2A340: '',  # 𪍀
    0x2A341: 'jùn',  # 𪍁
    0x2A342: 'hù',  # 𪍂
    # 0x2A343: '',  # 𪍃
    0x2A344: 'lù',  # 𪍄
    0x2A345: 'yè',  # 𪍅
    # 0x2A346: '',  # 𪍆
    0x2A347: 'mò,chǎo',  # 𪍇
    0x2A348: 'chào',  # 𪍈
    # 0x2A349: '',  # 𪍉
    # 0x2A34A: '',  # 𪍊
    # 0x2A34B: '',  # 𪍋
    0x2A34C: 'suò',  # 𪍌
    # 0x2A34D: '',  # 𪍍
    0x2A34E: 'kē',  # 𪍎
    0x2A34F: 'fù',  # 𪍏
    # 0x2A350: '',  # 𪍐
    0x2A351: 'chǎo',  # 𪍑
    # 0x2A352: '',  # 𪍒
    # 0x2A353: '',  # 𪍓
    0x2A354: 'suǒ',  # 𪍔
    # 0x2A355: '',  # 𪍕
    # 0x2A356: '',  # 𪍖
    0x2A357: 'qiū',  # 𪍗
    # 0x2A358: '',  # 𪍘
    # 0x2A359: '',  # 𪍙
    # 0x2A35A: '',  # 𪍚
    0x2A35B: 'sù,xiè',  # 𪍛
    # 0x2A35C: '',  # 𪍜
    0x2A35D: 'yùn',  # 𪍝
    # 0x2A35E: '',  # 𪍞
    0x2A35F: 'suǒ',  # 𪍟
    0x2A360: 'kū',  # 𪍠
    0x2A361: 'bó',  # 𪍡
    # 0x2A362: '',  # 𪍢
    0x2A363: 'lǒu',  # 𪍣
    0x2A364: 'mò',  # 𪍤
    # 0x2A365: '',  # 𪍥
    0x2A366: 'liǎn',  # 𪍦
    0x2A367: 'xuàn',  # 𪍧
    0x2A368: 'suǒ',  # 𪍨
    0x2A369: 'mán',  # 𪍩
    0x2A36A: 'bì',  # 𪍪
    # 0x2A36B: '',  # 𪍫
    # 0x2A36C: '',  # 𪍬
    # 0x2A36D: '',  # 𪍭
    # 0x2A36E: '',  # 𪍮
    # 0x2A36F: '',  # 𪍯
    # 0x2A370: '',  # 𪍰
    # 0x2A371: '',  # 𪍱
    0x2A372: 'tì',  # 𪍲
    # 0x2A373: '',  # 𪍳
    0x2A374: 'lián',  # 𪍴
    0x2A375: 'tán',  # 𪍵
    0x2A376: 'shàn',  # 𪍶
    # 0x2A377: '',  # 𪍷
    0x2A378: 'qú',  # 𪍸
    0x2A379: 'dú',  # 𪍹
    0x2A37A: 'huán,huàn',  # 𪍺
    0x2A37B: 'sào',  # 𪍻
    # 0x2A37C: '',  # 𪍼
    # 0x2A37D: '',  # 𪍽
    # 0x2A37E: '',  # 𪍾
    0x2A37F: 'kuàng',  # 𪍿
    # 0x2A380: '',  # 𪎀
    # 0x2A381: '',  # 𪎁
    # 0x2A382: '',  # 𪎂
    0x2A383: 'niè',  # 𪎃
    # 0x2A384: '',  # 𪎄
    0x2A385: 'niè',  # 𪎅
    0x2A386: 'luó',  # 𪎆
    0x2A387: 'zuó',  # 𪎇
    # 0x2A388: '',  # 𪎈
    # 0x2A389: '',  # 𪎉
    0x2A38A: 'chǎo',  # 𪎊
    0x2A38B: 'tiè',  # 𪎋
    # 0x2A38C: '',  # 𪎌
    # 0x2A38D: '',  # 𪎍
    # 0x2A38E: '',  # 𪎎
    # 0x2A38F: '',  # 𪎏
    # 0x2A390: '',  # 𪎐
    # 0x2A391: '',  # 𪎑
    0x2A392: 'shuò',  # 𪎒
    # 0x2A393: '',  # 𪎓
    0x2A394: 'mǐ',  # 𪎔
    # 0x2A395: '',  # 𪎕
    # 0x2A396: '',  # 𪎖
    0x2A397: 'mí',  # 𪎗
    # 0x2A398: '',  # 𪎘
    # 0x2A399: '',  # 𪎙
    # 0x2A39A: '',  # 𪎚
    0x2A39B: 'wǎn',  # 𪎛
    # 0x2A39C: '',  # 𪎜
    0x2A39D: 'bèn',  # 𪎝
    0x2A39E: 'qiāng',  # 𪎞
    # 0x2A39F: '',  # 𪎟
    0x2A3A0: 'mǒ',  # 𪎠
    # 0x2A3A1: '',  # 𪎡
    # 0x2A3A2: '',  # 𪎢
    0x2A3A3: 'liú',  # 𪎣
    0x2A3A4: 'wò',  # 𪎤
    # 0x2A3A5: '',  # 𪎥
    0x2A3A6: 'měi',  # 𪎦
    # 0x2A3A7: '',  # 𪎧
    0x2A3A8: 'tóu',  # 𪎨
    # 0x2A3A9: '',  # 𪎩
    # 0x2A3AA: '',  # 𪎪
    0x2A3AB: 'mǔ',  # 𪎫
    # 0x2A3AC: '',  # 𪎬
    0x2A3AD: 'méi',  # 𪎭
    0x2A3AE: 'huī',  # 𪎮
    # 0x2A3AF: '',  # 𪎯
    # 0x2A3B0: '',  # 𪎰
    # 0x2A3B1: '',  # 𪎱
    0x2A3B2: 'zuò',  # 𪎲
    # 0x2A3B3: '',  # 𪎳
    0x2A3B4: 'tún',  # 𪎴
    0x2A3B5: 'kàng',  # 𪎵
    0x2A3B6: 'tún',  # 𪎶
    # 0x2A3B7: '',  # 𪎷
    # 0x2A3B8: '',  # 𪎸
    # 0x2A3B9: '',  # 𪎹
    0x2A3BA: 'chè',  # 𪎺
    0x2A3BB: 'zhèng',  # 𪎻
    # 0x2A3BC: '',  # 𪎼
    0x2A3BD: 'chōng',  # 𪎽
    0x2A3BE: 'tiān',  # 𪎾
    # 0x2A3BF: '',  # 𪎿
    0x2A3C0: 'zhì',  # 𪏀
    0x2A3C1: 'chán',  # 𪏁
    0x2A3C2: 'chán',  # 𪏂
    # 0x2A3C3: '',  # 𪏃
    # 0x2A3C4: '',  # 𪏄
    0x2A3C5: 'qīng',  # 𪏅
    0x2A3C6: 'tūn',  # 𪏆
    0x2A3C7: 'huǐ',  # 𪏇
    0x2A3C8: 'què',  # 𪏈
    0x2A3C9: 'zhān',  # 𪏉
    0x2A3CA: 'jiān,miǎn',  # 𪏊
    0x2A3CB: 'chán',  # 𪏋
    # 0x2A3CC: '',  # 𪏌
    0x2A3CD: 'huáng',  # 𪏍
    # 0x2A3CE: '',  # 𪏎
    0x2A3CF: 'huī',  # 𪏏
    0x2A3D0: 'chí',  # 𪏐
    # 0x2A3D1: '',  # 𪏑
    0x2A3D2: 'huáng',  # 𪏒
    0x2A3D3: 'héng',  # 𪏓
    0x2A3D4: 'yǔn',  # 𪏔
    # 0x2A3D5: '',  # 𪏕
    0x2A3D6: 'tuān',  # 𪏖
    0x2A3D7: 'biān',  # 𪏗
    # 0x2A3D8: '',  # 𪏘
    0x2A3D9: 'huáng',  # 𪏙
    0x2A3DA: 'yǔn',  # 𪏚
    # 0x2A3DB: '',  # 𪏛
    # 0x2A3DC: '',  # 𪏜
    # 0x2A3DD: '',  # 𪏝
    # 0x2A3DE: '',  # 𪏞
    0x2A3DF: 'mò',  # 𪏟
    0x2A3E0: 'gōng',  # 𪏠
    # 0x2A3E1: '',  # 𪏡
    0x2A3E2: 'gōng',  # 𪏢
    # 0x2A3E3: '',  # 𪏣
    0x2A3E4: 'guì',  # 𪏤
    # 0x2A3E5: '',  # 𪏥
    0x2A3E6: 'chán',  # 𪏦
    # 0x2A3E7: '',  # 𪏧
    0x2A3E8: 'què',  # 𪏨
    0x2A3E9: 'ruì',  # 𪏩
    0x2A3EA: 'kuàng',  # 𪏪
    0x2A3EB: 'piào',  # 𪏫
    # 0x2A3EC: '',  # 𪏬
    # 0x2A3ED: '',  # 𪏭
    0x2A3EE: 'rǔ',  # 𪏮
    # 0x2A3EF: '',  # 𪏯
    # 0x2A3F0: '',  # 𪏰
    # 0x2A3F1: '',  # 𪏱
    0x2A3F2: 'niǔ',  # 𪏲
    0x2A3F3: 'hù',  # 𪏳
    0x2A3F4: 'jǐn',  # 𪏴
    0x2A3F5: 'nì,lí',  # 𪏵
    0x2A3F6: 'bào',  # 𪏶
    # 0x2A3F7: '',  # 𪏷
    0x2A3F8: 'nǐ,chī',  # 𪏸
    # 0x2A3F9: '',  # 𪏹
    0x2A3FA: 'bì',  # 𪏺
    0x2A3FB: 'hú',  # 𪏻
    0x2A3FC: 'lí',  # 𪏼
    # 0x2A3FD: '',  # 𪏽
    # 0x2A3FE: '',  # 𪏾
    0x2A3FF: 'zhū',  # 𪏿
    0x2A400: 'nǎ',  # 𪐀
    # 0x2A401: '',  # 𪐁
    0x2A402: 'quǎn',  # 𪐂
    0x2A403: 'fěng',  # 𪐃
    0x2A404: 'bǐ',  # 𪐄
    0x2A405: 'lí',  # 𪐅
    0x2A406: 'bié',  # 𪐆
    0x2A407: 'nián',  # 𪐇
    0x2A408: 'dǒng',  # 𪐈
    # 0x2A409: '',  # 𪐉
    # 0x2A40A: '',  # 𪐊
    0x2A40B: 'lián',  # 𪐋
    0x2A40C: 'nì',  # 𪐌
    0x2A40D: 'lián',  # 𪐍
    0x2A40E: 'má',  # 𪐎
    0x2A40F: 'zhé,zhí',  # 𪐏
    # 0x2A410: '',  # 𪐐
    # 0x2A411: '',  # 𪐑
    # 0x2A412: '',  # 𪐒
    0x2A413: 'jiā',  # 𪐓
    0x2A414: 'yí',  # 𪐔
    # 0x2A415: '',  # 𪐕
    0x2A416: 'lǒng',  # 𪐖
    # 0x2A417: '',  # 𪐗
    0x2A418: 'yì,yān',  # 𪐘
    # 0x2A419: '',  # 𪐙
    # 0x2A41A: '',  # 𪐚
    # 0x2A41B: '',  # 𪐛
    # 0x2A41C: '',  # 𪐜
    0x2A41D: 'dài,tài',  # 𪐝
    0x2A41E: 'dù',  # 𪐞
    # 0x2A41F: '',  # 𪐟
    # 0x2A420: '',  # 𪐠
    # 0x2A421: '',  # 𪐡
    # 0x2A422: '',  # 𪐢
    0x2A423: 'yǐ',  # 𪐣
    # 0x2A424: '',  # 𪐤
    0x2A425: 'tài',  # 𪐥
    0x2A426: 'hāng',  # 𪐦
    0x2A427: 'shù',  # 𪐧
    # 0x2A428: '',  # 𪐨
    # 0x2A429: '',  # 𪐩
    # 0x2A42A: '',  # 𪐪
    # 0x2A42B: '',  # 𪐫
    0x2A42C: 'wán',  # 𪐬
    # 0x2A42D: '',  # 𪐭
    0x2A42E: 'sù',  # 𪐮
    0x2A42F: 'yǎo',  # 𪐯
    0x2A430: 'èr',  # 𪐰
    # 0x2A431: '',  # 𪐱
    0x2A432: 'zhèn',  # 𪐲
    # 0x2A433: '',  # 𪐳
    # 0x2A434: '',  # 𪐴
    # 0x2A435: '',  # 𪐵
    # 0x2A436: '',  # 𪐶
    # 0x2A437: '',  # 𪐷
    # 0x2A438: '',  # 𪐸
    # 0x2A439: '',  # 𪐹
    0x2A43A: 'dòu',  # 𪐺
    0x2A43B: 'jiān',  # 𪐻
    # 0x2A43C: '',  # 𪐼
    # 0x2A43D: '',  # 𪐽
    # 0x2A43E: '',  # 𪐾
    0x2A43F: 'pāng',  # 𪐿
    0x2A440: 'huī',  # 𪑀
    # 0x2A441: '',  # 𪑁
    0x2A442: 'chà',  # 𪑂
    0x2A443: 'shān',  # 𪑃
    0x2A444: 'lú',  # 𪑄
    # 0x2A445: '',  # 𪑅
    0x2A446: 'yù',  # 𪑆
    # 0x2A447: '',  # 𪑇
    0x2A448: 'yàn',  # 𪑈
    0x2A449: 'wǎn',  # 𪑉
    0x2A44A: 'qiào',  # 𪑊
    0x2A44B: 'luō',  # 𪑋
    0x2A44C: 'yù',  # 𪑌
    # 0x2A44D: '',  # 𪑍
    # 0x2A44E: '',  # 𪑎
    0x2A44F: 'tú',  # 𪑏
    0x2A450: 'wèi',  # 𪑐
    # 0x2A451: '',  # 𪑑
    0x2A452: 'tùn',  # 𪑒
    # 0x2A453: '',  # 𪑓
    # 0x2A454: '',  # 𪑔
    0x2A455: 'hǔn',  # 𪑕
    0x2A456: 'bēn',  # 𪑖
    0x2A457: 'qiè',  # 𪑗
    # 0x2A458: '',  # 𪑘
    0x2A459: 'jīn,qián',  # 𪑙
    0x2A45A: 'lái,lí',  # 𪑚
    # 0x2A45B: '',  # 𪑛
    0x2A45C: 'zhǐ',  # 𪑜
    0x2A45D: 'yú',  # 𪑝
    # 0x2A45E: '',  # 𪑞
    0x2A45F: 'cì',  # 𪑟
    # 0x2A460: '',  # 𪑠
    # 0x2A461: '',  # 𪑡
    # 0x2A462: '',  # 𪑢
    # 0x2A463: '',  # 𪑣
    # 0x2A464: '',  # 𪑤
    # 0x2A465: '',  # 𪑥
    0x2A466: 'yè',  # 𪑦
    0x2A467: 'dié',  # 𪑧
    0x2A468: 'chà',  # 𪑨
    0x2A469: 'diàn',  # 𪑩
    0x2A46A: 'mán',  # 𪑪
    # 0x2A46B: '',  # 𪑫
    0x2A46C: 'dèng',  # 𪑬
    0x2A46D: 'wēi',  # 𪑭
    0x2A46E: 'niǎn',  # 𪑮
    0x2A46F: 'lèi',  # 𪑯
    0x2A470: 'bīng',  # 𪑰
    0x2A471: 'wū,wò',  # 𪑱
    0x2A472: 'yuè',  # 𪑲
    0x2A473: 'zhěn',  # 𪑳
    # 0x2A474: '',  # 𪑴
    # 0x2A475: '',  # 𪑵
    0x2A476: 'róu',  # 𪑶
    0x2A477: 'wài',  # 𪑷
    0x2A478: 'mì,yān',  # 𪑸
    0x2A479: 'jiè',  # 𪑹
    # 0x2A47A: '',  # 𪑺
    0x2A47B: 'hóu',  # 𪑻
    # 0x2A47C: '',  # 𪑼
    0x2A47D: 'zhài',  # 𪑽
    0x2A47E: 'rǔ',  # 𪑾
    0x2A47F: 'zī',  # 𪑿
    0x2A480: 'pán',  # 𪒀
    # 0x2A481: '',  # 𪒁
    0x2A482: 'mò',  # 𪒂
    # 0x2A483: '',  # 𪒃
    0x2A484: 'mì',  # 𪒄
    # 0x2A485: '',  # 𪒅
    0x2A486: 'qī',  # 𪒆
    0x2A487: 'mò',  # 𪒇
    # 0x2A488: '',  # 𪒈
    0x2A489: 'dì',  # 𪒉
    0x2A48A: 'zhī',  # 𪒊
    0x2A48B: 'bān,pán',  # 𪒋
    # 0x2A48C: '',  # 𪒌
    0x2A48D: 'miè',  # 𪒍
    # 0x2A48E: '',  # 𪒎
    0x2A48F: 'lù',  # 𪒏
    # 0x2A490: '',  # 𪒐
    0x2A491: 'qī',  # 𪒑
    0x2A492: 'chōng',  # 𪒒
    # 0x2A493: '',  # 𪒓
    0x2A494: 'lí',  # 𪒔
    0x2A495: 'yì',  # 𪒕
    # 0x2A496: '',  # 𪒖
    # 0x2A497: '',  # 𪒗
    0x2A498: 'dèng',  # 𪒘
    0x2A499: 'cuō',  # 𪒙
    # 0x2A49A: '',  # 𪒚
    0x2A49B: 'duì',  # 𪒛
    0x2A49C: 'mà',  # 𪒜
    0x2A49D: 'yǎn',  # 𪒝
    # 0x2A49E: '',  # 𪒞
    0x2A49F: 'zèng',  # 𪒟
    0x2A4A0: 'yǎn,ǎn,àn',  # 𪒠
    0x2A4A1: 'duì,dài',  # 𪒡
    0x2A4A2: 'pū',  # 𪒢
    # 0x2A4A3: '',  # 𪒣
    # 0x2A4A4: '',  # 𪒤
    0x2A4A5: 'yuè',  # 𪒥
    # 0x2A4A6: '',  # 𪒦
    # 0x2A4A7: '',  # 𪒧
    # 0x2A4A8: '',  # 𪒨
    0x2A4A9: 'huò',  # 𪒩
    0x2A4AA: 'mài',  # 𪒪
    0x2A4AB: 'jiǎn',  # 𪒫
    0x2A4AC: 'nóng',  # 𪒬
    0x2A4AD: 'qín',  # 𪒭
    # 0x2A4AE: '',  # 𪒮
    0x2A4AF: 'qín',  # 𪒯
    # 0x2A4B0: '',  # 𪒰
    # 0x2A4B1: '',  # 𪒱
    0x2A4B2: 'yè',  # 𪒲
    # 0x2A4B3: '',  # 𪒳
    0x2A4B4: 'tái',  # 𪒴
    # 0x2A4B5: '',  # 𪒵
    # 0x2A4B6: '',  # 𪒶
    # 0x2A4B7: '',  # 𪒷
    # 0x2A4B8: '',  # 𪒸
    0x2A4B9: 'jiān',  # 𪒹
    # 0x2A4BA: '',  # 𪒺
    # 0x2A4BB: '',  # 𪒻
    0x2A4BC: 'chá',  # 𪒼
    # 0x2A4BD: '',  # 𪒽
    0x2A4BE: 'dàn',  # 𪒾
    0x2A4BF: 'téng',  # 𪒿
    0x2A4C0: 'lì',  # 𪓀
    # 0x2A4C1: '',  # 𪓁
    # 0x2A4C2: '',  # 𪓂
    0x2A4C3: 'niǎng',  # 𪓃
    0x2A4C4: 'chán',  # 𪓄
    0x2A4C5: 'zāng',  # 𪓅
    # 0x2A4C6: '',  # 𪓆
    # 0x2A4C7: '',  # 𪓇
    # 0x2A4C8: '',  # 𪓈
    # 0x2A4C9: '',  # 𪓉
    0x2A4CA: 'yù',  # 𪓊
    0x2A4CB: 'mǐ',  # 𪓋
    0x2A4CC: 'zuì',  # 𪓌
    0x2A4CD: 'biān',  # 𪓍
    # 0x2A4CE: '',  # 𪓎
    # 0x2A4CF: '',  # 𪓏
    0x2A4D0: 'chǔ',  # 𪓐
    # 0x2A4D1: '',  # 𪓑
    # 0x2A4D2: '',  # 𪓒
    # 0x2A4D3: '',  # 𪓓
    # 0x2A4D4: '',  # 𪓔
    # 0x2A4D5: '',  # 𪓕
    # 0x2A4D6: '',  # 𪓖
    # 0x2A4D7: '',  # 𪓗
    0x2A4D8: 'rán',  # 𪓘
    # 0x2A4D9: '',  # 𪓙
    0x2A4DA: 'rán',  # 𪓚
    0x2A4DB: 'yāng',  # 𪓛
    0x2A4DC: 'bǒ',  # 𪓜
    # 0x2A4DD: '',  # 𪓝
    # 0x2A4DE: '',  # 𪓞
    # 0x2A4DF: '',  # 𪓟
    # 0x2A4E0: '',  # 𪓠
    0x2A4E1: 'cù',  # 𪓡
    # 0x2A4E2: '',  # 𪓢
    # 0x2A4E3: '',  # 𪓣
    # 0x2A4E4: '',  # 𪓤
    # 0x2A4E5: '',  # 𪓥
    # 0x2A4E6: '',  # 𪓦
    # 0x2A4E7: '',  # 𪓧
    # 0x2A4E8: '',  # 𪓨
    # 0x2A4E9: '',  # 𪓩
    # 0x2A4EA: '',  # 𪓪
    # 0x2A4EB: '',  # 𪓫
    0x2A4EC: 'mí',  # 𪓬
    # 0x2A4ED: '',  # 𪓭
    0x2A4EE: 'kě',  # 𪓮
    # 0x2A4EF: '',  # 𪓯
    0x2A4F0: 'cù',  # 𪓰
    # 0x2A4F1: '',  # 𪓱
    # 0x2A4F2: '',  # 𪓲
    # 0x2A4F3: '',  # 𪓳
    # 0x2A4F4: '',  # 𪓴
    # 0x2A4F5: '',  # 𪓵
    # 0x2A4F6: '',  # 𪓶
    0x2A4F7: 'xí',  # 𪓷
    # 0x2A4F8: '',  # 𪓸
    0x2A4F9: 'má',  # 𪓹
    # 0x2A4FA: '',  # 𪓺
    0x2A4FB: 'shī',  # 𪓻
    0x2A4FC: 'diān',  # 𪓼
    # 0x2A4FD: '',  # 𪓽
    # 0x2A4FE: '',  # 𪓾
    0x2A4FF: 'shī',  # 𪓿
    # 0x2A500: '',  # 𪔀
    # 0x2A501: '',  # 𪔁
    0x2A502: 'dǐng',  # 𪔂
    0x2A503: 'jiōng',  # 𪔃
    # 0x2A504: '',  # 𪔄
    0x2A505: 'yuán',  # 𪔅
    0x2A506: 'gān',  # 𪔆
    # 0x2A507: '',  # 𪔇
    # 0x2A508: '',  # 𪔈
    # 0x2A509: '',  # 𪔉
    0x2A50A: 'huì',  # 𪔊
    0x2A50B: 'jī',  # 𪔋
    # 0x2A50C: '',  # 𪔌
    0x2A50D: 'péng',  # 𪔍
    # 0x2A50E: '',  # 𪔎
    0x2A50F: 'dēng',  # 𪔏
    # 0x2A510: '',  # 𪔐
    0x2A511: 'bèng',  # 𪔑
    # 0x2A512: '',  # 𪔒
    # 0x2A513: '',  # 𪔓
    0x2A514: 'pāng,péng',  # 𪔔
    0x2A515: 'tà,lóng',  # 𪔕
    # 0x2A516: '',  # 𪔖
    0x2A517: 'yuān',  # 𪔗
    0x2A518: 'gāo',  # 𪔘
    0x2A519: 'yuān',  # 𪔙
    # 0x2A51A: '',  # 𪔚
    # 0x2A51B: '',  # 𪔛
    # 0x2A51C: '',  # 𪔜
    # 0x2A51D: '',  # 𪔝
    # 0x2A51E: '',  # 𪔞
    0x2A51F: 'jiā',  # 𪔟
    # 0x2A520: '',  # 𪔠
    # 0x2A521: '',  # 𪔡
    # 0x2A522: '',  # 𪔢
    0x2A523: 'kōng',  # 𪔣
    # 0x2A524: '',  # 𪔤
    # 0x2A525: '',  # 𪔥
    0x2A526: 'dòng',  # 𪔦
    # 0x2A527: '',  # 𪔧
    # 0x2A528: '',  # 𪔨
    0x2A529: 'xián',  # 𪔩
    0x2A52A: 'qì',  # 𪔪
    # 0x2A52B: '',  # 𪔫
    0x2A52C: 'sāng',  # 𪔬
    # 0x2A52D: '',  # 𪔭
    # 0x2A52E: '',  # 𪔮
    # 0x2A52F: '',  # 𪔯
    0x2A530: 'yìn',  # 𪔰
    # 0x2A531: '',  # 𪔱
    # 0x2A532: '',  # 𪔲
    0x2A533: 'lóng',  # 𪔳
    # 0x2A534: '',  # 𪔴
    # 0x2A535: '',  # 𪔵
    0x2A536: 'tēng',  # 𪔶
    0x2A537: 'lóng',  # 𪔷
    # 0x2A538: '',  # 𪔸
    # 0x2A539: '',  # 𪔹
    0x2A53A: 'rèn',  # 𪔺
    # 0x2A53B: '',  # 𪔻
    # 0x2A53C: '',  # 𪔼
    0x2A53D: 'yìn',  # 𪔽
    0x2A53E: 'píng',  # 𪔾
    0x2A53F: 'pū',  # 𪔿
    0x2A540: 'yuán',  # 𪕀
    0x2A541: 'rǒng,chén',  # 𪕁
    # 0x2A542: '',  # 𪕂
    0x2A543: 'fāng',  # 𪕃
    # 0x2A544: '',  # 𪕄
    # 0x2A545: '',  # 𪕅
    # 0x2A546: '',  # 𪕆
    0x2A547: 'hāng',  # 𪕇
    0x2A548: 'mí',  # 𪕈
    0x2A549: 'hú',  # 𪕉
    0x2A54A: 'zī',  # 𪕊
    # 0x2A54B: '',  # 𪕋
    0x2A54C: 'líng',  # 𪕌
    0x2A54D: 'jiōng',  # 𪕍
    0x2A54E: 'rǒng',  # 𪕎
    # 0x2A54F: '',  # 𪕏
    # 0x2A550: '',  # 𪕐
    # 0x2A551: '',  # 𪕑
    0x2A552: 'píng',  # 𪕒
    0x2A553: 'guāng',  # 𪕓
    0x2A554: 'ěr',  # 𪕔
    # 0x2A555: '',  # 𪕕
    # 0x2A556: '',  # 𪕖
    # 0x2A557: '',  # 𪕗
    # 0x2A558: '',  # 𪕘
    # 0x2A559: '',  # 𪕙
    0x2A55A: 'liú',  # 𪕚
    # 0x2A55B: '',  # 𪕛
    # 0x2A55C: '',  # 𪕜
    0x2A55D: 'cù',  # 𪕝
    0x2A55E: 'jùn',  # 𪕞
    # 0x2A55F: '',  # 𪕟
    # 0x2A560: '',  # 𪕠
    # 0x2A561: '',  # 𪕡
    # 0x2A562: '',  # 𪕢
    # 0x2A563: '',  # 𪕣
    # 0x2A564: '',  # 𪕤
    # 0x2A565: '',  # 𪕥
    0x2A566: 'xiǔ',  # 𪕦
    # 0x2A567: '',  # 𪕧
    0x2A568: 'ér',  # 𪕨
    0x2A569: 'tì',  # 𪕩
    # 0x2A56A: '',  # 𪕪
    0x2A56B: 'yáng',  # 𪕫
    # 0x2A56C: '',  # 𪕬
    0x2A56D: 'ài',  # 𪕭
    0x2A56E: 'hú',  # 𪕮
    0x2A56F: 'xí,xié',  # 𪕯
    # 0x2A570: '',  # 𪕰
    0x2A571: 'hú',  # 𪕱
    # 0x2A572: '',  # 𪕲
    0x2A573: 'sī',  # 𪕳
    0x2A574: 'lǐ',  # 𪕴
    # 0x2A575: '',  # 𪕵
    0x2A576: 'yì',  # 𪕶
    0x2A577: 'gǔ',  # 𪕷
    # 0x2A578: '',  # 𪕸
    0x2A579: 'táng',  # 𪕹
    # 0x2A57A: '',  # 𪕺
    # 0x2A57B: '',  # 𪕻
    # 0x2A57C: '',  # 𪕼
    # 0x2A57D: '',  # 𪕽
    # 0x2A57E: '',  # 𪕾
    # 0x2A57F: '',  # 𪕿
    0x2A580: 'què',  # 𪖀
    0x2A581: 'zōng',  # 𪖁
    0x2A582: 'lí',  # 𪖂
    # 0x2A583: '',  # 𪖃
    0x2A584: 'jiào',  # 𪖄
    # 0x2A585: '',  # 𪖅
    # 0x2A586: '',  # 𪖆
    0x2A587: 'fán',  # 𪖇
    0x2A588: 'pú',  # 𪖈
    0x2A589: 'sī',  # 𪖉
    # 0x2A58A: '',  # 𪖊
    0x2A58B: 'jié',  # 𪖋
    0x2A58C: 'lú',  # 𪖌
    0x2A58D: 'lì',  # 𪖍
    0x2A58E: 'chán',  # 𪖎
    # 0x2A58F: '',  # 𪖏
    0x2A590: 'yào,yà',  # 𪖐
    # 0x2A591: '',  # 𪖑
    # 0x2A592: '',  # 𪖒
    # 0x2A593: '',  # 𪖓
    # 0x2A594: '',  # 𪖔
    0x2A595: 'huī',  # 𪖕
    # 0x2A596: '',  # 𪖖
    # 0x2A597: '',  # 𪖗
    # 0x2A598: '',  # 𪖘
    0x2A599: 'hōu',  # 𪖙
    0x2A59A: 'diān',  # 𪖚
    0x2A59B: 'qiù',  # 𪖛
    0x2A59C: 'jué',  # 𪖜
    # 0x2A59D: '',  # 𪖝
    0x2A59E: 'pì',  # 𪖞
    # 0x2A59F: '',  # 𪖟
    # 0x2A5A0: '',  # 𪖠
    # 0x2A5A1: '',  # 𪖡
    0x2A5A2: 'kuī',  # 𪖢
    # 0x2A5A3: '',  # 𪖣
    # 0x2A5A4: '',  # 𪖤
    0x2A5A5: 'xǐ',  # 𪖥
    0x2A5A6: 'tī',  # 𪖦
    # 0x2A5A7: '',  # 𪖧
    # 0x2A5A8: '',  # 𪖨
    0x2A5A9: 'xù',  # 𪖩
    # 0x2A5AA: '',  # 𪖪
    # 0x2A5AB: '',  # 𪖫
    # 0x2A5AC: '',  # 𪖬
    # 0x2A5AD: '',  # 𪖭
    # 0x2A5AE: '',  # 𪖮
    0x2A5AF: 'biǎn',  # 𪖯
    # 0x2A5B0: '',  # 𪖰
    # 0x2A5B1: '',  # 𪖱
    0x2A5B2: 'hē',  # 𪖲
    0x2A5B3: 'lián',  # 𪖳
    # 0x2A5B4: '',  # 𪖴
    # 0x2A5B5: '',  # 𪖵
    0x2A5B6: 'sù',  # 𪖶
    0x2A5B7: 'liào',  # 𪖷
    # 0x2A5B8: '',  # 𪖸
    # 0x2A5B9: '',  # 𪖹
    # 0x2A5BA: '',  # 𪖺
    # 0x2A5BB: '',  # 𪖻
    0x2A5BC: 'jīn',  # 𪖼
    # 0x2A5BD: '',  # 𪖽
    # 0x2A5BE: '',  # 𪖾
    # 0x2A5BF: '',  # 𪖿
    # 0x2A5C0: '',  # 𪗀
    0x2A5C1: 'lì',  # 𪗁
    0x2A5C2: 'chán',  # 𪗂
    # 0x2A5C3: '',  # 𪗃
    # 0x2A5C4: '',  # 𪗄
    0x2A5C5: 'qí',  # 𪗅
    0x2A5C6: 'qí',  # 𪗆
    0x2A5C7: 'qí',  # 𪗇
    # 0x2A5C8: '',  # 𪗈
    0x2A5C9: 'zī',  # 𪗉
    # 0x2A5CA: '',  # 𪗊
    0x2A5CB: 'zī',  # 𪗋
    # 0x2A5CC: '',  # 𪗌
    0x2A5CD: 'qí',  # 𪗍
    # 0x2A5CE: '',  # 𪗎
    0x2A5CF: 'qí',  # 𪗏
    0x2A5D0: 'zī',  # 𪗐
    # 0x2A5D1: '',  # 𪗑
    0x2A5D2: 'zhāi',  # 𪗒
    0x2A5D3: 'zhāi',  # 𪗓
    0x2A5D4: 'pà',  # 𪗔
    # 0x2A5D5: '',  # 𪗕
    0x2A5D6: 'jū',  # 𪗖
    # 0x2A5D7: '',  # 𪗗
    # 0x2A5D8: '',  # 𪗘
    0x2A5D9: 'yǎn',  # 𪗙
    # 0x2A5DA: '',  # 𪗚
    # 0x2A5DB: '',  # 𪗛
    0x2A5DC: 'háng',  # 𪗜
    0x2A5DD: 'nà',  # 𪗝
    # 0x2A5DE: '',  # 𪗞
    # 0x2A5DF: '',  # 𪗟
    # 0x2A5E0: '',  # 𪗠
    # 0x2A5E1: '',  # 𪗡
    # 0x2A5E2: '',  # 𪗢
    # 0x2A5E3: '',  # 𪗣
    0x2A5E4: 'yǎn',  # 𪗤
    # 0x2A5E5: '',  # 𪗥
    0x2A5E6: 'zhàn',  # 𪗦
    0x2A5E7: 'shǐ',  # 𪗧
    0x2A5E8: 'zhí',  # 𪗨
    # 0x2A5E9: '',  # 𪗩
    0x2A5EA: 'chī',  # 𪗪
    # 0x2A5EB: '',  # 𪗫
    # 0x2A5EC: '',  # 𪗬
    0x2A5ED: 'zhā',  # 𪗭
    # 0x2A5EE: '',  # 𪗮
    # 0x2A5EF: '',  # 𪗯
    # 0x2A5F0: '',  # 𪗰
    # 0x2A5F1: '',  # 𪗱
    # 0x2A5F2: '',  # 𪗲
    # 0x2A5F3: '',  # 𪗳
    0x2A5F4: 'rǒng',  # 𪗴
    0x2A5F5: 'zhā',  # 𪗵
    # 0x2A5F6: '',  # 𪗶
    0x2A5F7: 'yì',  # 𪗷
    0x2A5F8: 'míng',  # 𪗸
    0x2A5F9: 'yá',  # 𪗹
    # 0x2A5FA: '',  # 𪗺
    0x2A5FB: 'zhì',  # 𪗻
    # 0x2A5FC: '',  # 𪗼
    0x2A5FD: 'kuò,huá',  # 𪗽
    0x2A5FE: 'xiá',  # 𪗾
    0x2A5FF: 'là',  # 𪗿
    0x2A600: 'pián',  # 𪘀
    0x2A601: 'tà,xiá',  # 𪘁
    # 0x2A602: '',  # 𪘂
    0x2A603: 'yǐ',  # 𪘃
    # 0x2A604: '',  # 𪘄
    # 0x2A605: '',  # 𪘅
    0x2A606: 'xiū',  # 𪘆
    0x2A607: 'zhāi',  # 𪘇
    # 0x2A608: '',  # 𪘈
    0x2A609: 'duǒ',  # 𪘉
    0x2A60A: 'è',  # 𪘊
    # 0x2A60B: '',  # 𪘋
    # 0x2A60C: '',  # 𪘌
    # 0x2A60D: '',  # 𪘍
    0x2A60E: 'yín,niè',  # 𪘎
    # 0x2A60F: '',  # 𪘏
    0x2A610: 'è',  # 𪘐
    0x2A611: 'suān',  # 𪘑
    0x2A612: 'ān',  # 𪘒
    0x2A613: 'cuó',  # 𪘓
    # 0x2A614: '',  # 𪘔
    0x2A615: 'tuó',  # 𪘕
    # 0x2A616: '',  # 𪘖
    0x2A617: 'tuó',  # 𪘗
    0x2A618: 'xiá',  # 𪘘
    # 0x2A619: '',  # 𪘙
    # 0x2A61A: '',  # 𪘚
    0x2A61B: 'chuò',  # 𪘛
    # 0x2A61C: '',  # 𪘜
    0x2A61D: 'suān',  # 𪘝
    # 0x2A61E: '',  # 𪘞
    # 0x2A61F: '',  # 𪘟
    # 0x2A620: '',  # 𪘠
    # 0x2A621: '',  # 𪘡
    # 0x2A622: '',  # 𪘢
    # 0x2A623: '',  # 𪘣
    # 0x2A624: '',  # 𪘤
    0x2A625: 'jì',  # 𪘥
    0x2A626: 'qiǎn',  # 𪘦
    0x2A627: 'zú',  # 𪘧
    0x2A628: 'zhāi',  # 𪘨
    0x2A629: 'yǔn,kǔn',  # 𪘩
    0x2A62A: 'zhàn',  # 𪘪
    # 0x2A62B: '',  # 𪘫
    0x2A62C: 'yí,yà,yá',  # 𪘬
    # 0x2A62D: '',  # 𪘭
    # 0x2A62E: '',  # 𪘮
    # 0x2A62F: '',  # 𪘯
    # 0x2A630: '',  # 𪘰
    # 0x2A631: '',  # 𪘱
    0x2A632: 'yá,yí,yà,cī',  # 𪘲
    0x2A633: 'yuē',  # 𪘳
    # 0x2A634: '',  # 𪘴
    # 0x2A635: '',  # 𪘵
    # 0x2A636: '',  # 𪘶
    # 0x2A637: '',  # 𪘷
    # 0x2A638: '',  # 𪘸
    0x2A639: 'hé',  # 𪘹
    0x2A63A: 'qià',  # 𪘺
    # 0x2A63B: '',  # 𪘻
    # 0x2A63C: '',  # 𪘼
    # 0x2A63D: '',  # 𪘽
    0x2A63E: 'chā',  # 𪘾
    # 0x2A63F: '',  # 𪘿
    # 0x2A640: '',  # 𪙀
    # 0x2A641: '',  # 𪙁
    # 0x2A642: '',  # 𪙂
    0x2A643: 'óu',  # 𪙃
    # 0x2A644: '',  # 𪙄
    # 0x2A645: '',  # 𪙅
    # 0x2A646: '',  # 𪙆
    # 0x2A647: '',  # 𪙇
    0x2A648: 'hú',  # 𪙈
    0x2A649: 'cī',  # 𪙉
    0x2A64A: 'yàn',  # 𪙊
    # 0x2A64B: '',  # 𪙋
    0x2A64C: 'qiè',  # 𪙌
    0x2A64D: 'bó',  # 𪙍
    0x2A64E: 'qiāng',  # 𪙎
    0x2A64F: 'jiè,jiá',  # 𪙏
    # 0x2A650: '',  # 𪙐
    0x2A651: 'lián',  # 𪙑
    # 0x2A652: '',  # 𪙒
    # 0x2A653: '',  # 𪙓
    # 0x2A654: '',  # 𪙔
    # 0x2A655: '',  # 𪙕
    # 0x2A656: '',  # 𪙖
    # 0x2A657: '',  # 𪙗
    # 0x2A658: '',  # 𪙘
    # 0x2A659: '',  # 𪙙
    # 0x2A65A: '',  # 𪙚
    0x2A65B: 'nì',  # 𪙛
    # 0x2A65C: '',  # 𪙜
    # 0x2A65D: '',  # 𪙝
    0x2A65E: 'chǎn',  # 𪙞
    0x2A65F: 'qǐn',  # 𪙟
    # 0x2A660: '',  # 𪙠
    0x2A661: 'zāo',  # 𪙡
    # 0x2A662: '',  # 𪙢
    # 0x2A663: '',  # 𪙣
    0x2A664: 'yǐn',  # 𪙤
    0x2A665: 'xiè',  # 𪙥
    # 0x2A666: '',  # 𪙦
    0x2A667: 'qí',  # 𪙧
    0x2A668: 'jiàn,jiān',  # 𪙨
    # 0x2A669: '',  # 𪙩
    # 0x2A66A: '',  # 𪙪
    0x2A66B: 'xū',  # 𪙫
    # 0x2A66C: '',  # 𪙬
    0x2A66D: 'zèng',  # 𪙭
    # 0x2A66E: '',  # 𪙮
    0x2A66F: 'è',  # 𪙯
    # 0x2A670: '',  # 𪙰
    # 0x2A671: '',  # 𪙱
    # 0x2A672: '',  # 𪙲
    0x2A673: 'zū',  # 𪙳
    0x2A674: 'yǐ',  # 𪙴
    # 0x2A675: '',  # 𪙵
    # 0x2A676: '',  # 𪙶
    # 0x2A677: '',  # 𪙷
    # 0x2A678: '',  # 𪙸
    0x2A679: 'zhí',  # 𪙹
    0x2A67A: 'lì',  # 𪙺
    # 0x2A67B: '',  # 𪙻
    # 0x2A67C: '',  # 𪙼
    0x2A67D: 'lì',  # 𪙽
    0x2A67E: 'yín',  # 𪙾
    # 0x2A67F: '',  # 𪙿
    # 0x2A680: '',  # 𪚀
    0x2A681: 'lián',  # 𪚁
    # 0x2A682: '',  # 𪚂
    0x2A683: 'chán',  # 𪚃
    # 0x2A684: '',  # 𪚄
    0x2A685: 'jué',  # 𪚅
    # 0x2A686: '',  # 𪚆
    0x2A687: 'zá',  # 𪚇
    # 0x2A688: '',  # 𪚈
    # 0x2A689: '',  # 𪚉
    # 0x2A68A: '',  # 𪚊
    # 0x2A68B: '',  # 𪚋
    # 0x2A68C: '',  # 𪚌
    # 0x2A68D: '',  # 𪚍
    0x2A68E: 'zhāi',  # 𪚎
    # 0x2A68F: '',  # 𪚏
    # 0x2A690: '',  # 𪚐
    0x2A691: 'lóng',  # 𪚑
    # 0x2A692: '',  # 𪚒
    0x2A693: 'lóng',  # 𪚓
    # 0x2A694: '',  # 𪚔
    # 0x2A695: '',  # 𪚕
    # 0x2A696: '',  # 𪚖
    # 0x2A697: '',  # 𪚗
    0x2A698: 'lóng',  # 𪚘
    # 0x2A699: '',  # 𪚙
    # 0x2A69A: '',  # 𪚚
    # 0x2A69B: '',  # 𪚛
    # 0x2A69C: '',  # 𪚜
    0x2A69D: 'lóng',  # 𪚝
    # 0x2A69E: '',  # 𪚞
    # 0x2A69F: '',  # 𪚟
    0x2A6A0: 'lóng',  # 𪚠
    # 0x2A6A1: '',  # 𪚡
    0x2A6A2: 'mǎng',  # 𪚢
    # 0x2A6A3: '',  # 𪚣
    # 0x2A6A4: '',  # 𪚤
    0x2A6A5: 'zhé',  # 𪚥
    # 0x2A6A6: '',  # 𪚦
    # 0x2A6A7: '',  # 𪚧
    # 0x2A6A8: '',  # 𪚨
    # 0x2A6A9: '',  # 𪚩
    # 0x2A6AA: '',  # 𪚪
    # 0x2A6AB: '',  # 𪚫
    0x2A6AC: 'gàn',  # 𪚬
    0x2A6AD: 'gōu',  # 𪚭
    0x2A6AE: 'rán',  # 𪚮
    0x2A6AF: 'cù',  # 𪚯
    0x2A6B0: 'jiāo',  # 𪚰
    # 0x2A6B1: '',  # 𪚱
    # 0x2A6B2: '',  # 𪚲
    # 0x2A6B3: '',  # 𪚳
    # 0x2A6B4: '',  # 𪚴
    # 0x2A6B5: '',  # 𪚵
    # 0x2A6B6: '',  # 𪚶
    0x2A6B7: 'bǒ',  # 𪚷
    # 0x2A6B8: '',  # 𪚸
    0x2A6B9: 'zhù',  # 𪚹
    0x2A6BA: 'qiū',  # 𪚺
    0x2A6BB: 'yāng',  # 𪚻
    # 0x2A6BC: '',  # 𪚼
    # 0x2A6BD: '',  # 𪚽
    # 0x2A6BE: '',  # 𪚾
    # 0x2A6BF: '',  # 𪚿
    0x2A6C0: 'xiào',  # 𪛀
    # 0x2A6C1: '',  # 𪛁
    0x2A6C2: 'huí',  # 𪛂
    0x2A6C3: 'qū',  # 𪛃
    # 0x2A6C4: '',  # 𪛄
    # 0x2A6C5: '',  # 𪛅
    # 0x2A6C6: '',  # 𪛆
    # 0x2A6C7: '',  # 𪛇
    0x2A6C8: 'líng',  # 𪛈
    # 0x2A6C9: '',  # 𪛉
    0x2A6CA: 'yín',  # 𪛊
    # 0x2A6CB: '',  # 𪛋
    # 0x2A6CC: '',  # 𪛌
    # 0x2A6CD: '',  # 𪛍
    0x2A6CE: 'pì',  # 𪛎
    # 0x2A6CF: '',  # 𪛏
    # 0x2A6D0: '',  # 𪛐
    # 0x2A6D1: '',  # 𪛑
    0x2A6D2: 'lián',  # 𪛒
    # 0x2A6D3: '',  # 𪛓
    # 0x2A6D4: '',  # 𪛔
    # 0x2A6D5: '',  # 𪛕
    # 0x2A6D6: '',  # 𪛖
    # 0x2A6D7: '',  #
    # 0x2A6D8: '',  #
    # 0x2A6D9: '',  #
    # 0x2A6DA: '',  #
    # 0x2A6DB: '',  #
    # 0x2A6DC: '',  #
    # 0x2A6DD: '',  #
    # 0x2A6DE: '',  #
    # 0x2A6DF: '',  #

    # CJK 扩展 C:[2A700-2B73F]
    # 0x2A700: '',  # 𪜀
    # 0x2A701: '',  # 𪜁
    # 0x2A702: '',  # 𪜂
    0x2A703: 'gā',  # 𪜃
    # 0x2A704: '',  # 𪜄
    0x2A705: 'shēn',  # 𪜅
    0x2A706: 'liǎn',  # 𪜆
    # 0x2A707: '',  # 𪜇
    # 0x2A708: '',  # 𪜈
    # 0x2A709: '',  # 𪜉
    # 0x2A70A: '',  # 𪜊
    # 0x2A70B: '',  # 𪜋
    # 0x2A70C: '',  # 𪜌
    # 0x2A70D: '',  # 𪜍
    # 0x2A70E: '',  # 𪜎
    # 0x2A70F: '',  # 𪜏
    # 0x2A710: '',  # 𪜐
    # 0x2A711: '',  # 𪜑
    # 0x2A712: '',  # 𪜒
    # 0x2A713: '',  # 𪜓
    # 0x2A714: '',  # 𪜔
    # 0x2A715: '',  # 𪜕
    # 0x2A716: '',  # 𪜖
    # 0x2A717: '',  # 𪜗
    # 0x2A718: '',  # 𪜘
    # 0x2A719: '',  # 𪜙
    # 0x2A71A: '',  # 𪜚
    # 0x2A71B: '',  # 𪜛
    # 0x2A71C: '',  # 𪜜
    # 0x2A71D: '',  # 𪜝
    # 0x2A71E: '',  # 𪜞
    # 0x2A71F: '',  # 𪜟
    # 0x2A720: '',  # 𪜠
    # 0x2A721: '',  # 𪜡
    # 0x2A722: '',  # 𪜢
    # 0x2A723: '',  # 𪜣
    # 0x2A724: '',  # 𪜤
    0x2A725: 'lǐn',  # 𪜥
    # 0x2A726: '',  # 𪜦
    # 0x2A727: '',  # 𪜧
    # 0x2A728: '',  # 𪜨
    0x2A729: 'gōu',  # 𪜩
    # 0x2A72A: '',  # 𪜪
    # 0x2A72B: '',  # 𪜫
    # 0x2A72C: '',  # 𪜬
    # 0x2A72D: '',  # 𪜭
    # 0x2A72E: '',  # 𪜮
    # 0x2A72F: '',  # 𪜯
    # 0x2A730: '',  # 𪜰
    # 0x2A731: '',  # 𪜱
    # 0x2A732: '',  # 𪜲
    # 0x2A733: '',  # 𪜳
    # 0x2A734: '',  # 𪜴
    0x2A735: 'qǐ',  # 𪜵
    0x2A736: 'yīn',  # 𪜶
    # 0x2A737: '',  # 𪜷
    # 0x2A738: '',  # 𪜸
    # 0x2A739: '',  # 𪜹
    0x2A73A: 'zhōu',  # 𪜺
    # 0x2A73B: '',  # 𪜻
    # 0x2A73C: '',  # 𪜼
    # 0x2A73D: '',  # 𪜽
    # 0x2A73E: '',  # 𪜾
    0x2A73F: 'yǎn',  # 𪜿
    # 0x2A740: '',  # 𪝀
    # 0x2A741: '',  # 𪝁
    # 0x2A742: '',  # 𪝂
    # 0x2A743: '',  # 𪝃
    # 0x2A744: '',  # 𪝄
    # 0x2A745: '',  # 𪝅
    # 0x2A746: '',  # 𪝆
    # 0x2A747: '',  # 𪝇
    # 0x2A748: '',  # 𪝈
    # 0x2A749: '',  # 𪝉
    # 0x2A74A: '',  # 𪝊
    # 0x2A74B: '',  # 𪝋
    # 0x2A74C: '',  # 𪝌
    # 0x2A74D: '',  # 𪝍
    # 0x2A74E: '',  # 𪝎
    # 0x2A74F: '',  # 𪝏
    # 0x2A750: '',  # 𪝐
    # 0x2A751: '',  # 𪝑
    # 0x2A752: '',  # 𪝒
    # 0x2A753: '',  # 𪝓
    # 0x2A754: '',  # 𪝔
    # 0x2A755: '',  # 𪝕
    # 0x2A756: '',  # 𪝖
    # 0x2A757: '',  # 𪝗
    # 0x2A758: '',  # 𪝘
    0x2A759: 'kē',  # 𪝙
    # 0x2A75A: '',  # 𪝚
    # 0x2A75B: '',  # 𪝛
    # 0x2A75C: '',  # 𪝜
    # 0x2A75D: '',  # 𪝝
    # 0x2A75E: '',  # 𪝞
    # 0x2A75F: '',  # 𪝟
    # 0x2A760: '',  # 𪝠
    # 0x2A761: '',  # 𪝡
    # 0x2A762: '',  # 𪝢
    # 0x2A763: '',  # 𪝣
    # 0x2A764: '',  # 𪝤
    # 0x2A765: '',  # 𪝥
    # 0x2A766: '',  # 𪝦
    # 0x2A767: '',  # 𪝧
    # 0x2A768: '',  # 𪝨
    # 0x2A769: '',  # 𪝩
    # 0x2A76A: '',  # 𪝪
    # 0x2A76B: '',  # 𪝫
    # 0x2A76C: '',  # 𪝬
    # 0x2A76D: '',  # 𪝭
    # 0x2A76E: '',  # 𪝮
    # 0x2A76F: '',  # 𪝯
    # 0x2A770: '',  # 𪝰
    # 0x2A771: '',  # 𪝱
    # 0x2A772: '',  # 𪝲
    # 0x2A773: '',  # 𪝳
    # 0x2A774: '',  # 𪝴
    # 0x2A775: '',  # 𪝵
    # 0x2A776: '',  # 𪝶
    # 0x2A777: '',  # 𪝷
    # 0x2A778: '',  # 𪝸
    # 0x2A779: '',  # 𪝹
    # 0x2A77A: '',  # 𪝺
    # 0x2A77B: '',  # 𪝻
    # 0x2A77C: '',  # 𪝼
    # 0x2A77D: '',  # 𪝽
    # 0x2A77E: '',  # 𪝾
    # 0x2A77F: '',  # 𪝿
    # 0x2A780: '',  # 𪞀
    # 0x2A781: '',  # 𪞁
    # 0x2A782: '',  # 𪞂
    # 0x2A783: '',  # 𪞃
    # 0x2A784: '',  # 𪞄
    # 0x2A785: '',  # 𪞅
    # 0x2A786: '',  # 𪞆
    # 0x2A787: '',  # 𪞇
    # 0x2A788: '',  # 𪞈
    # 0x2A789: '',  # 𪞉
    # 0x2A78A: '',  # 𪞊
    # 0x2A78B: '',  # 𪞋
    # 0x2A78C: '',  # 𪞌
    # 0x2A78D: '',  # 𪞍
    # 0x2A78E: '',  # 𪞎
    # 0x2A78F: '',  # 𪞏
    # 0x2A790: '',  # 𪞐
    # 0x2A791: '',  # 𪞑
    # 0x2A792: '',  # 𪞒
    0x2A793: 'shì',  # 𪞓
    # 0x2A794: '',  # 𪞔
    # 0x2A795: '',  # 𪞕
    # 0x2A796: '',  # 𪞖
    # 0x2A797: '',  # 𪞗
    # 0x2A798: '',  # 𪞘
    # 0x2A799: '',  # 𪞙
    # 0x2A79A: '',  # 𪞚
    # 0x2A79B: '',  # 𪞛
    # 0x2A79C: '',  # 𪞜
    # 0x2A79D: '',  # 𪞝
    # 0x2A79E: '',  # 𪞞
    # 0x2A79F: '',  # 𪞟
    # 0x2A7A0: '',  # 𪞠
    # 0x2A7A1: '',  # 𪞡
    # 0x2A7A2: '',  # 𪞢
    # 0x2A7A3: '',  # 𪞣
    # 0x2A7A4: '',  # 𪞤
    # 0x2A7A5: '',  # 𪞥
    # 0x2A7A6: '',  # 𪞦
    # 0x2A7A7: '',  # 𪞧
    # 0x2A7A8: '',  # 𪞨
    # 0x2A7A9: '',  # 𪞩
    # 0x2A7AA: '',  # 𪞪
    0x2A7AB: 'sōu',  # 𪞫
    # 0x2A7AC: '',  # 𪞬
    # 0x2A7AD: '',  # 𪞭
    # 0x2A7AE: '',  # 𪞮
    # 0x2A7AF: '',  # 𪞯
    # 0x2A7B0: '',  # 𪞰
    # 0x2A7B1: '',  # 𪞱
    # 0x2A7B2: '',  # 𪞲
    # 0x2A7B3: '',  # 𪞳
    # 0x2A7B4: '',  # 𪞴
    # 0x2A7B5: '',  # 𪞵
    # 0x2A7B6: '',  # 𪞶
    # 0x2A7B7: '',  # 𪞷
    # 0x2A7B8: '',  # 𪞸
    # 0x2A7B9: '',  # 𪞹
    # 0x2A7BA: '',  # 𪞺
    # 0x2A7BB: '',  # 𪞻
    # 0x2A7BC: '',  # 𪞼
    # 0x2A7BD: '',  # 𪞽
    # 0x2A7BE: '',  # 𪞾
    0x2A7BF: 'dùn',  # 𪞿
    # 0x2A7C0: '',  # 𪟀
    0x2A7C1: 'sūn',  # 𪟁
    # 0x2A7C2: '',  # 𪟂
    # 0x2A7C3: '',  # 𪟃
    # 0x2A7C4: '',  # 𪟄
    # 0x2A7C5: '',  # 𪟅
    # 0x2A7C6: '',  # 𪟆
    # 0x2A7C7: '',  # 𪟇
    # 0x2A7C8: '',  # 𪟈
    # 0x2A7C9: '',  # 𪟉
    # 0x2A7CA: '',  # 𪟊
    0x2A7CB: 'gè',  # 𪟋
    # 0x2A7CC: '',  # 𪟌
    0x2A7CD: 'tǒng',  # 𪟍
    # 0x2A7CE: '',  # 𪟎
    # 0x2A7CF: '',  # 𪟏
    # 0x2A7D0: '',  # 𪟐
    # 0x2A7D1: '',  # 𪟑
    # 0x2A7D2: '',  # 𪟒
    # 0x2A7D3: '',  # 𪟓
    # 0x2A7D4: '',  # 𪟔
    # 0x2A7D5: '',  # 𪟕
    # 0x2A7D6: '',  # 𪟖
    # 0x2A7D7: '',  # 𪟗
    # 0x2A7D8: '',  # 𪟘
    # 0x2A7D9: '',  # 𪟙
    # 0x2A7DA: '',  # 𪟚
    # 0x2A7DB: '',  # 𪟛
    # 0x2A7DC: '',  # 𪟜
    # 0x2A7DD: '',  # 𪟝
    # 0x2A7DE: '',  # 𪟞
    # 0x2A7DF: '',  # 𪟟
    # 0x2A7E0: '',  # 𪟠
    # 0x2A7E1: '',  # 𪟡
    # 0x2A7E2: '',  # 𪟢
    0x2A7E3: 'zhuó',  # 𪟣
    # 0x2A7E4: '',  # 𪟤
    # 0x2A7E5: '',  # 𪟥
    # 0x2A7E6: '',  # 𪟦
    # 0x2A7E7: '',  # 𪟧
    # 0x2A7E8: '',  # 𪟨
    # 0x2A7E9: '',  # 𪟩
    0x2A7EA: 'bèi',  # 𪟪
    # 0x2A7EB: '',  # 𪟫
    # 0x2A7EC: '',  # 𪟬
    # 0x2A7ED: '',  # 𪟭
    # 0x2A7EE: '',  # 𪟮
    # 0x2A7EF: '',  # 𪟯
    # 0x2A7F0: '',  # 𪟰
    # 0x2A7F1: '',  # 𪟱
    0x2A7F2: 'gǎn',  # 𪟲
    # 0x2A7F3: '',  # 𪟳
    # 0x2A7F4: '',  # 𪟴
    # 0x2A7F5: '',  # 𪟵
    # 0x2A7F6: '',  # 𪟶
    # 0x2A7F7: '',  # 𪟷
    # 0x2A7F8: '',  # 𪟸
    # 0x2A7F9: '',  # 𪟹
    # 0x2A7FA: '',  # 𪟺
    # 0x2A7FB: '',  # 𪟻
    # 0x2A7FC: '',  # 𪟼
    # 0x2A7FD: '',  # 𪟽
    # 0x2A7FE: '',  # 𪟾
    # 0x2A7FF: '',  # 𪟿
    0x2A800: 'kū',  # 𪠀
    0x2A801: 'hé',  # 𪠁
    # 0x2A802: '',  # 𪠂
    # 0x2A803: '',  # 𪠃
    # 0x2A804: '',  # 𪠄
    # 0x2A805: '',  # 𪠅
    # 0x2A806: '',  # 𪠆
    # 0x2A807: '',  # 𪠇
    # 0x2A808: '',  # 𪠈
    # 0x2A809: '',  # 𪠉
    # 0x2A80A: '',  # 𪠊
    # 0x2A80B: '',  # 𪠋
    # 0x2A80C: '',  # 𪠌
    # 0x2A80D: '',  # 𪠍
    # 0x2A80E: '',  # 𪠎
    0x2A80F: 'yǎn',  # 𪠏
    # 0x2A810: '',  # 𪠐
    0x2A811: 'bó',  # 𪠑
    # 0x2A812: '',  # 𪠒
    # 0x2A813: '',  # 𪠓
    # 0x2A814: '',  # 𪠔
    # 0x2A815: '',  # 𪠕
    # 0x2A816: '',  # 𪠖
    # 0x2A817: '',  # 𪠗
    # 0x2A818: '',  # 𪠘
    # 0x2A819: '',  # 𪠙
    0x2A81A: 'lì',  # 𪠚
    # 0x2A81B: '',  # 𪠛
    # 0x2A81C: '',  # 𪠜
    # 0x2A81D: '',  # 𪠝
    # 0x2A81E: '',  # 𪠞
    # 0x2A81F: '',  # 𪠟
    # 0x2A820: '',  # 𪠠
    # 0x2A821: '',  # 𪠡
    # 0x2A822: '',  # 𪠢
    # 0x2A823: '',  # 𪠣
    0x2A824: 'dāo',  # 𪠤
    0x2A825: 'yǒu,yòu',  # 𪠥
    0x2A826: 'bǎn',  # 𪠦
    0x2A827: 'qiān',  # 𪠧
    # 0x2A828: '',  # 𪠨
    # 0x2A829: '',  # 𪠩
    # 0x2A82A: '',  # 𪠪
    # 0x2A82B: '',  # 𪠫
    # 0x2A82C: '',  # 𪠬
    # 0x2A82D: '',  # 𪠭
    0x2A82E: 'róng',  # 𪠮
    # 0x2A82F: '',  # 𪠯
    0x2A830: 'zhuì',  # 𪠰
    # 0x2A831: '',  # 𪠱
    # 0x2A832: '',  # 𪠲
    0x2A833: 'chē',  # 𪠳
    # 0x2A834: '',  # 𪠴
    # 0x2A835: '',  # 𪠵
    # 0x2A836: '',  # 𪠶
    # 0x2A837: '',  # 𪠷
    0x2A838: 'hù',  # 𪠸
    # 0x2A839: '',  # 𪠹
    # 0x2A83A: '',  # 𪠺
    # 0x2A83B: '',  # 𪠻
    # 0x2A83C: '',  # 𪠼
    # 0x2A83D: '',  # 𪠽
    # 0x2A83E: '',  # 𪠾
    # 0x2A83F: '',  # 𪠿
    0x2A840: 'qiáo',  # 𪡀
    0x2A841: 'chòng',  # 𪡁
    # 0x2A842: '',  # 𪡂
    0x2A843: 'mǎi',  # 𪡃
    # 0x2A844: '',  # 𪡄
    # 0x2A845: '',  # 𪡅
    # 0x2A846: '',  # 𪡆
    0x2A847: 'nǐ',  # 𪡇
    # 0x2A848: '',  # 𪡈
    # 0x2A849: '',  # 𪡉
    # 0x2A84A: '',  # 𪡊
    # 0x2A84B: '',  # 𪡋
    # 0x2A84C: '',  # 𪡌
    # 0x2A84D: '',  # 𪡍
    # 0x2A84E: '',  # 𪡎
    # 0x2A84F: '',  # 𪡏
    # 0x2A850: '',  # 𪡐
    # 0x2A851: '',  # 𪡑
    # 0x2A852: '',  # 𪡒
    0x2A853: 'kūn',  # 𪡓
    # 0x2A854: '',  # 𪡔
    # 0x2A855: '',  # 𪡕
    # 0x2A856: '',  # 𪡖
    # 0x2A857: '',  # 𪡗
    # 0x2A858: '',  # 𪡘
    # 0x2A859: '',  # 𪡙
    # 0x2A85A: '',  # 𪡚
    0x2A85B: 'hé,xià,xiā',  # 𪡛
    # 0x2A85C: '',  # 𪡜
    # 0x2A85D: '',  # 𪡝
    # 0x2A85E: '',  # 𪡞
    # 0x2A85F: '',  # 𪡟
    # 0x2A860: '',  # 𪡠
    # 0x2A861: '',  # 𪡡
    # 0x2A862: '',  # 𪡢
    # 0x2A863: '',  # 𪡣
    # 0x2A864: '',  # 𪡤
    # 0x2A865: '',  # 𪡥
    # 0x2A866: '',  # 𪡦
    # 0x2A867: '',  # 𪡧
    # 0x2A868: '',  # 𪡨
    # 0x2A869: '',  # 𪡩
    # 0x2A86A: '',  # 𪡪
    # 0x2A86B: '',  # 𪡫
    # 0x2A86C: '',  # 𪡬
    # 0x2A86D: '',  # 𪡭
    # 0x2A86E: '',  # 𪡮
    # 0x2A86F: '',  # 𪡯
    # 0x2A870: '',  # 𪡰
    # 0x2A871: '',  # 𪡱
    # 0x2A872: '',  # 𪡲
    # 0x2A873: '',  # 𪡳
    # 0x2A874: '',  # 𪡴
    # 0x2A875: '',  # 𪡵
    0x2A876: 'yuān',  # 𪡶
    # 0x2A877: '',  # 𪡷
    # 0x2A878: '',  # 𪡸
    # 0x2A879: '',  # 𪡹
    # 0x2A87A: '',  # 𪡺
    # 0x2A87B: '',  # 𪡻
    # 0x2A87C: '',  # 𪡼
    # 0x2A87D: '',  # 𪡽
    # 0x2A87E: '',  # 𪡾
    # 0x2A87F: '',  # 𪡿
    # 0x2A880: '',  # 𪢀
    # 0x2A881: '',  # 𪢁
    # 0x2A882: '',  # 𪢂
    # 0x2A883: '',  # 𪢃
    0x2A884: 'yù',  # 𪢄
    # 0x2A885: '',  # 𪢅
    # 0x2A886: '',  # 𪢆
    # 0x2A887: '',  # 𪢇
    # 0x2A888: '',  # 𪢈
    # 0x2A889: '',  # 𪢉
    # 0x2A88A: '',  # 𪢊
    0x2A88B: 'jià',  # 𪢋
    # 0x2A88C: '',  # 𪢌
    # 0x2A88D: '',  # 𪢍
    # 0x2A88E: '',  # 𪢎
    # 0x2A88F: '',  # 𪢏
    0x2A890: 'lài',  # 𪢐
    # 0x2A891: '',  # 𪢑
    # 0x2A892: '',  # 𪢒
    # 0x2A893: '',  # 𪢓
    # 0x2A894: '',  # 𪢔
    # 0x2A895: '',  # 𪢕
    # 0x2A896: '',  # 𪢖
    # 0x2A897: '',  # 𪢗
    # 0x2A898: '',  # 𪢘
    # 0x2A899: '',  # 𪢙
    # 0x2A89A: '',  # 𪢚
    # 0x2A89B: '',  # 𪢛
    # 0x2A89C: '',  # 𪢜
    # 0x2A89D: '',  # 𪢝
    # 0x2A89E: '',  # 𪢞
    # 0x2A89F: '',  # 𪢟
    # 0x2A8A0: '',  # 𪢠
    # 0x2A8A1: '',  # 𪢡
    # 0x2A8A2: '',  # 𪢢
    # 0x2A8A3: '',  # 𪢣
    # 0x2A8A4: '',  # 𪢤
    0x2A8A5: 'biān',  # 𪢥
    # 0x2A8A6: '',  # 𪢦
    # 0x2A8A7: '',  # 𪢧
    # 0x2A8A8: '',  # 𪢨
    # 0x2A8A9: '',  # 𪢩
    # 0x2A8AA: '',  # 𪢪
    # 0x2A8AB: '',  # 𪢫
    0x2A8AC: 'kūn',  # 𪢬
    # 0x2A8AD: '',  # 𪢭
    # 0x2A8AE: '',  # 𪢮
    # 0x2A8AF: '',  # 𪢯
    # 0x2A8B0: '',  # 𪢰
    # 0x2A8B1: '',  # 𪢱
    # 0x2A8B2: '',  # 𪢲
    # 0x2A8B3: '',  # 𪢳
    # 0x2A8B4: '',  # 𪢴
    # 0x2A8B5: '',  # 𪢵
    # 0x2A8B6: '',  # 𪢶
    # 0x2A8B7: '',  # 𪢷
    0x2A8B8: 'wú',  # 𪢸
    # 0x2A8B9: '',  # 𪢹
    # 0x2A8BA: '',  # 𪢺
    # 0x2A8BB: '',  # 𪢻
    # 0x2A8BC: '',  # 𪢼
    0x2A8BD: 'fēng',  # 𪢽
    # 0x2A8BE: '',  # 𪢾
    # 0x2A8BF: '',  # 𪢿
    # 0x2A8C0: '',  # 𪣀
    # 0x2A8C1: '',  # 𪣁
    # 0x2A8C2: '',  # 𪣂
    # 0x2A8C3: '',  # 𪣃
    # 0x2A8C4: '',  # 𪣄
    # 0x2A8C5: '',  # 𪣅
    # 0x2A8C6: '',  # 𪣆
    # 0x2A8C7: '',  # 𪣇
    # 0x2A8C8: '',  # 𪣈
    # 0x2A8C9: '',  # 𪣉
    # 0x2A8CA: '',  # 𪣊
    # 0x2A8CB: '',  # 𪣋
    # 0x2A8CC: '',  # 𪣌
    # 0x2A8CD: '',  # 𪣍
    # 0x2A8CE: '',  # 𪣎
    # 0x2A8CF: '',  # 𪣏
    # 0x2A8D0: '',  # 𪣐
    # 0x2A8D1: '',  # 𪣑
    # 0x2A8D2: '',  # 𪣒
    # 0x2A8D3: '',  # 𪣓
    # 0x2A8D4: '',  # 𪣔
    # 0x2A8D5: '',  # 𪣕
    # 0x2A8D6: '',  # 𪣖
    0x2A8D7: 'zhèn',  # 𪣗
    # 0x2A8D8: '',  # 𪣘
    # 0x2A8D9: '',  # 𪣙
    0x2A8DA: 'yàn',  # 𪣚
    # 0x2A8DB: '',  # 𪣛
    # 0x2A8DC: '',  # 𪣜
    # 0x2A8DD: '',  # 𪣝
    # 0x2A8DE: '',  # 𪣞
    # 0x2A8DF: '',  # 𪣟
    # 0x2A8E0: '',  # 𪣠
    # 0x2A8E1: '',  # 𪣡
    # 0x2A8E2: '',  # 𪣢
    # 0x2A8E3: '',  # 𪣣
    # 0x2A8E4: '',  # 𪣤
    # 0x2A8E5: '',  # 𪣥
    # 0x2A8E6: '',  # 𪣦
    # 0x2A8E7: '',  # 𪣧
    # 0x2A8E8: '',  # 𪣨
    0x2A8E9: 'kěn',  # 𪣩
    # 0x2A8EA: '',  # 𪣪
    # 0x2A8EB: '',  # 𪣫
    # 0x2A8EC: '',  # 𪣬
    # 0x2A8ED: '',  # 𪣭
    # 0x2A8EE: '',  # 𪣮
    # 0x2A8EF: '',  # 𪣯
    # 0x2A8F0: '',  # 𪣰
    # 0x2A8F1: '',  # 𪣱
    # 0x2A8F2: '',  # 𪣲
    # 0x2A8F3: '',  # 𪣳
    # 0x2A8F4: '',  # 𪣴
    # 0x2A8F5: '',  # 𪣵
    # 0x2A8F6: '',  # 𪣶
    # 0x2A8F7: '',  # 𪣷
    # 0x2A8F8: '',  # 𪣸
    # 0x2A8F9: '',  # 𪣹
    # 0x2A8FA: '',  # 𪣺
    # 0x2A8FB: '',  # 𪣻
    # 0x2A8FC: '',  # 𪣼
    # 0x2A8FD: '',  # 𪣽
    # 0x2A8FE: '',  # 𪣾
    # 0x2A8FF: '',  # 𪣿
    # 0x2A900: '',  # 𪤀
    # 0x2A901: '',  # 𪤁
    # 0x2A902: '',  # 𪤂
    # 0x2A903: '',  # 𪤃
    # 0x2A904: '',  # 𪤄
    # 0x2A905: '',  # 𪤅
    # 0x2A906: '',  # 𪤆
    # 0x2A907: '',  # 𪤇
    # 0x2A908: '',  # 𪤈
    0x2A909: 'chéng',  # 𪤉
    # 0x2A90A: '',  # 𪤊
    # 0x2A90B: '',  # 𪤋
    # 0x2A90C: '',  # 𪤌
    # 0x2A90D: '',  # 𪤍
    # 0x2A90E: '',  # 𪤎
    # 0x2A90F: '',  # 𪤏
    # 0x2A910: '',  # 𪤐
    # 0x2A911: '',  # 𪤑
    # 0x2A912: '',  # 𪤒
    # 0x2A913: '',  # 𪤓
    # 0x2A914: '',  # 𪤔
    # 0x2A915: '',  # 𪤕
    # 0x2A916: '',  # 𪤖
    # 0x2A917: '',  # 𪤗
    # 0x2A918: '',  # 𪤘
    # 0x2A919: '',  # 𪤙
    # 0x2A91A: '',  # 𪤚
    # 0x2A91B: '',  # 𪤛
    # 0x2A91C: '',  # 𪤜
    0x2A91D: 'chǎng',  # 𪤝
    # 0x2A91E: '',  # 𪤞
    # 0x2A91F: '',  # 𪤟
    # 0x2A920: '',  # 𪤠
    # 0x2A921: '',  # 𪤡
    # 0x2A922: '',  # 𪤢
    # 0x2A923: '',  # 𪤣
    # 0x2A924: '',  # 𪤤
    # 0x2A925: '',  # 𪤥
    # 0x2A926: '',  # 𪤦
    # 0x2A927: '',  # 𪤧
    # 0x2A928: '',  # 𪤨
    # 0x2A929: '',  # 𪤩
    # 0x2A92A: '',  # 𪤪
    # 0x2A92B: '',  # 𪤫
    # 0x2A92C: '',  # 𪤬
    # 0x2A92D: '',  # 𪤭
    # 0x2A92E: '',  # 𪤮
    0x2A92F: 'dūn',  # 𪤯
    # 0x2A930: '',  # 𪤰
    # 0x2A931: '',  # 𪤱
    # 0x2A932: '',  # 𪤲
    # 0x2A933: '',  # 𪤳
    # 0x2A934: '',  # 𪤴
    # 0x2A935: '',  # 𪤵
    # 0x2A936: '',  # 𪤶
    # 0x2A937: '',  # 𪤷
    # 0x2A938: '',  # 𪤸
    # 0x2A939: '',  # 𪤹
    # 0x2A93A: '',  # 𪤺
    # 0x2A93B: '',  # 𪤻
    # 0x2A93C: '',  # 𪤼
    # 0x2A93D: '',  # 𪤽
    # 0x2A93E: '',  # 𪤾
    # 0x2A93F: '',  # 𪤿
    # 0x2A940: '',  # 𪥀
    # 0x2A941: '',  # 𪥁
    0x2A942: 'dāo',  # 𪥂
    # 0x2A943: '',  # 𪥃
    # 0x2A944: '',  # 𪥄
    0x2A945: 'jiè',  # 𪥅
    # 0x2A946: '',  # 𪥆
    # 0x2A947: '',  # 𪥇
    # 0x2A948: '',  # 𪥈
    # 0x2A949: '',  # 𪥉
    0x2A94A: 'mài',  # 𪥊
    # 0x2A94B: '',  # 𪥋
    # 0x2A94C: '',  # 𪥌
    # 0x2A94D: '',  # 𪥍
    # 0x2A94E: '',  # 𪥎
    # 0x2A94F: '',  # 𪥏
    # 0x2A950: '',  # 𪥐
    # 0x2A951: '',  # 𪥑
    # 0x2A952: '',  # 𪥒
    # 0x2A953: '',  # 𪥓
    # 0x2A954: '',  # 𪥔
    0x2A955: 'kū',  # 𪥕
    # 0x2A956: '',  # 𪥖
    # 0x2A957: '',  # 𪥗
    # 0x2A958: '',  # 𪥘
    # 0x2A959: '',  # 𪥙
    # 0x2A95A: '',  # 𪥚
    # 0x2A95B: '',  # 𪥛
    # 0x2A95C: '',  # 𪥜
    # 0x2A95D: '',  # 𪥝
    # 0x2A95E: '',  # 𪥞
    # 0x2A95F: '',  # 𪥟
    0x2A960: 'réng',  # 𪥠
    # 0x2A961: '',  # 𪥡
    # 0x2A962: '',  # 𪥢
    # 0x2A963: '',  # 𪥣
    # 0x2A964: '',  # 𪥤
    # 0x2A965: '',  # 𪥥
    # 0x2A966: '',  # 𪥦
    # 0x2A967: '',  # 𪥧
    # 0x2A968: '',  # 𪥨
    # 0x2A969: '',  # 𪥩
    0x2A96A: 'qí',  # 𪥪
    # 0x2A96B: '',  # 𪥫
    0x2A96C: 'xī',  # 𪥬
    # 0x2A96D: '',  # 𪥭
    # 0x2A96E: '',  # 𪥮
    # 0x2A96F: '',  # 𪥯
    0x2A970: 'níng',  # 𪥰
    # 0x2A971: '',  # 𪥱
    # 0x2A972: '',  # 𪥲
    # 0x2A973: '',  # 𪥳
    # 0x2A974: '',  # 𪥴
    # 0x2A975: '',  # 𪥵
    # 0x2A976: '',  # 𪥶
    # 0x2A977: '',  # 𪥷
    0x2A978: 'nāo',  # 𪥸
    # 0x2A979: '',  # 𪥹
    # 0x2A97A: '',  # 𪥺
    # 0x2A97B: '',  # 𪥻
    # 0x2A97C: '',  # 𪥼
    # 0x2A97D: '',  # 𪥽
    # 0x2A97E: '',  # 𪥾
    # 0x2A97F: '',  # 𪥿
    # 0x2A980: '',  # 𪦀
    # 0x2A981: '',  # 𪦁
    # 0x2A982: '',  # 𪦂
    # 0x2A983: '',  # 𪦃
    # 0x2A984: '',  # 𪦄
    # 0x2A985: '',  # 𪦅
    # 0x2A986: '',  # 𪦆
    # 0x2A987: '',  # 𪦇
    # 0x2A988: '',  # 𪦈
    # 0x2A989: '',  # 𪦉
    # 0x2A98A: '',  # 𪦊
    # 0x2A98B: '',  # 𪦋
    # 0x2A98C: '',  # 𪦌
    # 0x2A98D: '',  # 𪦍
    # 0x2A98E: '',  # 𪦎
    # 0x2A98F: '',  # 𪦏
    # 0x2A990: '',  # 𪦐
    # 0x2A991: '',  # 𪦑
    # 0x2A992: '',  # 𪦒
    # 0x2A993: '',  # 𪦓
    # 0x2A994: '',  # 𪦔
    0x2A995: 'diǎ',  # 𪦕
    # 0x2A996: '',  # 𪦖
    # 0x2A997: '',  # 𪦗
    # 0x2A998: '',  # 𪦘
    # 0x2A999: '',  # 𪦙
    # 0x2A99A: '',  # 𪦚
    # 0x2A99B: '',  # 𪦛
    # 0x2A99C: '',  # 𪦜
    # 0x2A99D: '',  # 𪦝
    # 0x2A99E: '',  # 𪦞
    # 0x2A99F: '',  # 𪦟
    # 0x2A9A0: '',  # 𪦠
    # 0x2A9A1: '',  # 𪦡
    # 0x2A9A2: '',  # 𪦢
    # 0x2A9A3: '',  # 𪦣
    # 0x2A9A4: '',  # 𪦤
    # 0x2A9A5: '',  # 𪦥
    # 0x2A9A6: '',  # 𪦦
    0x2A9A7: 'qí',  # 𪦧
    # 0x2A9A8: '',  # 𪦨
    # 0x2A9A9: '',  # 𪦩
    # 0x2A9AA: '',  # 𪦪
    # 0x2A9AB: '',  # 𪦫
    # 0x2A9AC: '',  # 𪦬
    # 0x2A9AD: '',  # 𪦭
    # 0x2A9AE: '',  # 𪦮
    # 0x2A9AF: '',  # 𪦯
    # 0x2A9B0: '',  # 𪦰
    # 0x2A9B1: '',  # 𪦱
    # 0x2A9B2: '',  # 𪦲
    0x2A9B3: 'yáng',  # 𪦳
    # 0x2A9B4: '',  # 𪦴
    # 0x2A9B5: '',  # 𪦵
    # 0x2A9B6: '',  # 𪦶
    # 0x2A9B7: '',  # 𪦷
    # 0x2A9B8: '',  # 𪦸
    # 0x2A9B9: '',  # 𪦹
    # 0x2A9BA: '',  # 𪦺
    # 0x2A9BB: '',  # 𪦻
    # 0x2A9BC: '',  # 𪦼
    # 0x2A9BD: '',  # 𪦽
    # 0x2A9BE: '',  # 𪦾
    # 0x2A9BF: '',  # 𪦿
    # 0x2A9C0: '',  # 𪧀
    # 0x2A9C1: '',  # 𪧁
    # 0x2A9C2: '',  # 𪧂
    # 0x2A9C3: '',  # 𪧃
    # 0x2A9C4: '',  # 𪧄
    # 0x2A9C5: '',  # 𪧅
    # 0x2A9C6: '',  # 𪧆
    0x2A9C7: 'chuáng',  # 𪧇
    # 0x2A9C8: '',  # 𪧈
    # 0x2A9C9: '',  # 𪧉
    # 0x2A9CA: '',  # 𪧊
    # 0x2A9CB: '',  # 𪧋
    # 0x2A9CC: '',  # 𪧌
    # 0x2A9CD: '',  # 𪧍
    # 0x2A9CE: '',  # 𪧎
    # 0x2A9CF: '',  # 𪧏
    # 0x2A9D0: '',  # 𪧐
    # 0x2A9D1: '',  # 𪧑
    0x2A9D2: 'kè',  # 𪧒
    # 0x2A9D3: '',  # 𪧓
    # 0x2A9D4: '',  # 𪧔
    0x2A9D5: 'bǎo',  # 𪧕
    # 0x2A9D6: '',  # 𪧖
    # 0x2A9D7: '',  # 𪧗
    0x2A9D8: 'jù,lóu',  # 𪧘
    # 0x2A9D9: '',  # 𪧙
    # 0x2A9DA: '',  # 𪧚
    # 0x2A9DB: '',  # 𪧛
    # 0x2A9DC: '',  # 𪧜
    0x2A9DD: 'mì',  # 𪧝
    # 0x2A9DE: '',  # 𪧞
    # 0x2A9DF: '',  # 𪧟
    # 0x2A9E0: '',  # 𪧠
    # 0x2A9E1: '',  # 𪧡
    # 0x2A9E2: '',  # 𪧢
    # 0x2A9E3: '',  # 𪧣
    # 0x2A9E4: '',  # 𪧤
    0x2A9E5: 'fú',  # 𪧥
    # 0x2A9E6: '',  # 𪧦
    0x2A9E7: 'shì',  # 𪧧
    # 0x2A9E8: '',  # 𪧨
    # 0x2A9E9: '',  # 𪧩
    # 0x2A9EA: '',  # 𪧪
    # 0x2A9EB: '',  # 𪧫
    0x2A9EC: 'táo',  # 𪧬
    0x2A9ED: 'qīn',  # 𪧭
    # 0x2A9EE: '',  # 𪧮
    # 0x2A9EF: '',  # 𪧯
    # 0x2A9F0: '',  # 𪧰
    # 0x2A9F1: '',  # 𪧱
    # 0x2A9F2: '',  # 𪧲
    0x2A9F3: 'lài',  # 𪧳
    # 0x2A9F4: '',  # 𪧴
    # 0x2A9F5: '',  # 𪧵
    0x2A9F6: 'lán',  # 𪧶
    # 0x2A9F7: '',  # 𪧷
    # 0x2A9F8: '',  # 𪧸
    # 0x2A9F9: '',  # 𪧹
    # 0x2A9FA: '',  # 𪧺
    # 0x2A9FB: '',  # 𪧻
    # 0x2A9FC: '',  # 𪧼
    # 0x2A9FD: '',  # 𪧽
    # 0x2A9FE: '',  # 𪧾
    # 0x2A9FF: '',  # 𪧿
    # 0x2AA00: '',  # 𪨀
    # 0x2AA01: '',  # 𪨁
    # 0x2AA02: '',  # 𪨂
    # 0x2AA03: '',  # 𪨃
    # 0x2AA04: '',  # 𪨄
    # 0x2AA05: '',  # 𪨅
    # 0x2AA06: '',  # 𪨆
    # 0x2AA07: '',  # 𪨇
    # 0x2AA08: '',  # 𪨈
    # 0x2AA09: '',  # 𪨉
    0x2AA0A: 'sóng',  # 𪨊
    0x2AA0B: 'tǐng',  # 𪨋
    # 0x2AA0C: '',  # 𪨌
    0x2AA0D: 'yī',  # 𪨍
    # 0x2AA0E: '',  # 𪨎
    # 0x2AA0F: '',  # 𪨏
    # 0x2AA10: '',  # 𪨐
    # 0x2AA11: '',  # 𪨑
    # 0x2AA12: '',  # 𪨒
    # 0x2AA13: '',  # 𪨓
    # 0x2AA14: '',  # 𪨔
    # 0x2AA15: '',  # 𪨕
    # 0x2AA16: '',  # 𪨖
    # 0x2AA17: '',  # 𪨗
    0x2AA18: 'zhēng',  # 𪨘
    # 0x2AA19: '',  # 𪨙
    # 0x2AA1A: '',  # 𪨚
    # 0x2AA1B: '',  # 𪨛
    # 0x2AA1C: '',  # 𪨜
    # 0x2AA1D: '',  # 𪨝
    # 0x2AA1E: '',  # 𪨞
    # 0x2AA1F: '',  # 𪨟
    # 0x2AA20: '',  # 𪨠
    # 0x2AA21: '',  # 𪨡
    # 0x2AA22: '',  # 𪨢
    # 0x2AA23: '',  # 𪨣
    # 0x2AA24: '',  # 𪨤
    # 0x2AA25: '',  # 𪨥
    # 0x2AA26: '',  # 𪨦
    # 0x2AA27: '',  # 𪨧
    # 0x2AA28: '',  # 𪨨
    # 0x2AA29: '',  # 𪨩
    # 0x2AA2A: '',  # 𪨪
    # 0x2AA2B: '',  # 𪨫
    # 0x2AA2C: '',  # 𪨬
    # 0x2AA2D: '',  # 𪨭
    # 0x2AA2E: '',  # 𪨮
    # 0x2AA2F: '',  # 𪨯
    # 0x2AA30: '',  # 𪨰
    # 0x2AA31: '',  # 𪨱
    # 0x2AA32: '',  # 𪨲
    # 0x2AA33: '',  # 𪨳
    # 0x2AA34: '',  # 𪨴
    # 0x2AA35: '',  # 𪨵
    # 0x2AA36: '',  # 𪨶
    # 0x2AA37: '',  # 𪨷
    # 0x2AA38: '',  # 𪨸
    # 0x2AA39: '',  # 𪨹
    # 0x2AA3A: '',  # 𪨺
    # 0x2AA3B: '',  # 𪨻
    # 0x2AA3C: '',  # 𪨼
    # 0x2AA3D: '',  # 𪨽
    # 0x2AA3E: '',  # 𪨾
    # 0x2AA3F: '',  # 𪨿
    # 0x2AA40: '',  # 𪩀
    # 0x2AA41: '',  # 𪩁
    # 0x2AA42: '',  # 𪩂
    # 0x2AA43: '',  # 𪩃
    # 0x2AA44: '',  # 𪩄
    # 0x2AA45: '',  # 𪩅
    # 0x2AA46: '',  # 𪩆
    # 0x2AA47: '',  # 𪩇
    # 0x2AA48: '',  # 𪩈
    # 0x2AA49: '',  # 𪩉
    # 0x2AA4A: '',  # 𪩊
    # 0x2AA4B: '',  # 𪩋
    # 0x2AA4C: '',  # 𪩌
    # 0x2AA4D: '',  # 𪩍
    # 0x2AA4E: '',  # 𪩎
    # 0x2AA4F: '',  # 𪩏
    # 0x2AA50: '',  # 𪩐
    # 0x2AA51: '',  # 𪩑
    # 0x2AA52: '',  # 𪩒
    # 0x2AA53: '',  # 𪩓
    # 0x2AA54: '',  # 𪩔
    # 0x2AA55: '',  # 𪩕
    # 0x2AA56: '',  # 𪩖
    # 0x2AA57: '',  # 𪩗
    # 0x2AA58: '',  # 𪩘
    # 0x2AA59: '',  # 𪩙
    # 0x2AA5A: '',  # 𪩚
    # 0x2AA5B: '',  # 𪩛
    # 0x2AA5C: '',  # 𪩜
    # 0x2AA5D: '',  # 𪩝
    # 0x2AA5E: '',  # 𪩞
    # 0x2AA5F: '',  # 𪩟
    # 0x2AA60: '',  # 𪩠
    # 0x2AA61: '',  # 𪩡
    # 0x2AA62: '',  # 𪩢
    # 0x2AA63: '',  # 𪩣
    # 0x2AA64: '',  # 𪩤
    # 0x2AA65: '',  # 𪩥
    # 0x2AA66: '',  # 𪩦
    # 0x2AA67: '',  # 𪩧
    # 0x2AA68: '',  # 𪩨
    # 0x2AA69: '',  # 𪩩
    # 0x2AA6A: '',  # 𪩪
    # 0x2AA6B: '',  # 𪩫
    # 0x2AA6C: '',  # 𪩬
    # 0x2AA6D: '',  # 𪩭
    # 0x2AA6E: '',  # 𪩮
    # 0x2AA6F: '',  # 𪩯
    # 0x2AA70: '',  # 𪩰
    # 0x2AA71: '',  # 𪩱
    # 0x2AA72: '',  # 𪩲
    # 0x2AA73: '',  # 𪩳
    # 0x2AA74: '',  # 𪩴
    # 0x2AA75: '',  # 𪩵
    # 0x2AA76: '',  # 𪩶
    # 0x2AA77: '',  # 𪩷
    # 0x2AA78: '',  # 𪩸
    # 0x2AA79: '',  # 𪩹
    # 0x2AA7A: '',  # 𪩺
    # 0x2AA7B: '',  # 𪩻
    # 0x2AA7C: '',  # 𪩼
    # 0x2AA7D: '',  # 𪩽
    # 0x2AA7E: '',  # 𪩾
    # 0x2AA7F: '',  # 𪩿
    # 0x2AA80: '',  # 𪪀
    # 0x2AA81: '',  # 𪪁
    # 0x2AA82: '',  # 𪪂
    # 0x2AA83: '',  # 𪪃
    # 0x2AA84: '',  # 𪪄
    # 0x2AA85: '',  # 𪪅
    # 0x2AA86: '',  # 𪪆
    # 0x2AA87: '',  # 𪪇
    # 0x2AA88: '',  # 𪪈
    # 0x2AA89: '',  # 𪪉
    # 0x2AA8A: '',  # 𪪊
    0x2AA8B: 'zāi',  # 𪪋
    # 0x2AA8C: '',  # 𪪌
    # 0x2AA8D: '',  # 𪪍
    # 0x2AA8E: '',  # 𪪎
    # 0x2AA8F: '',  # 𪪏
    # 0x2AA90: '',  # 𪪐
    # 0x2AA91: '',  # 𪪑
    # 0x2AA92: '',  # 𪪒
    # 0x2AA93: '',  # 𪪓
    # 0x2AA94: '',  # 𪪔
    0x2AA95: 'qū',  # 𪪕
    # 0x2AA96: '',  # 𪪖
    # 0x2AA97: '',  # 𪪗
    # 0x2AA98: '',  # 𪪘
    # 0x2AA99: '',  # 𪪙
    0x2AA9A: 'tīng',  # 𪪚
    # 0x2AA9B: '',  # 𪪛
    # 0x2AA9C: '',  # 𪪜
    # 0x2AA9D: '',  # 𪪝
    # 0x2AA9E: '',  # 𪪞
    # 0x2AA9F: '',  # 𪪟
    # 0x2AAA0: '',  # 𪪠
    # 0x2AAA1: '',  # 𪪡
    # 0x2AAA2: '',  # 𪪢
    # 0x2AAA3: '',  # 𪪣
    # 0x2AAA4: '',  # 𪪤
    # 0x2AAA5: '',  # 𪪥
    # 0x2AAA6: '',  # 𪪦
    # 0x2AAA7: '',  # 𪪧
    0x2AAA8: 'lǐn',  # 𪪨
    # 0x2AAA9: '',  # 𪪩
    # 0x2AAAA: '',  # 𪪪
    # 0x2AAAB: '',  # 𪪫
    # 0x2AAAC: '',  # 𪪬
    # 0x2AAAD: '',  # 𪪭
    # 0x2AAAE: '',  # 𪪮
    # 0x2AAAF: '',  # 𪪯
    # 0x2AAB0: '',  # 𪪰
    # 0x2AAB1: '',  # 𪪱
    # 0x2AAB2: '',  # 𪪲
    # 0x2AAB3: '',  # 𪪳
    # 0x2AAB4: '',  # 𪪴
    # 0x2AAB5: '',  # 𪪵
    0x2AAB6: 'dì',  # 𪪶
    # 0x2AAB7: '',  # 𪪷
    0x2AAB8: 'zhèn',  # 𪪸
    0x2AAB9: 'xūn',  # 𪪹
    0x2AABA: 'qiáng',  # 𪪺
    # 0x2AABB: '',  # 𪪻
    # 0x2AABC: '',  # 𪪼
    # 0x2AABD: '',  # 𪪽
    # 0x2AABE: '',  # 𪪾
    # 0x2AABF: '',  # 𪪿
    # 0x2AAC0: '',  # 𪫀
    # 0x2AAC1: '',  # 𪫁
    0x2AAC2: 'yín',  # 𪫂
    # 0x2AAC3: '',  # 𪫃
    # 0x2AAC4: '',  # 𪫄
    0x2AAC5: 'yú',  # 𪫅
    # 0x2AAC6: '',  # 𪫆
    # 0x2AAC7: '',  # 𪫇
    # 0x2AAC8: '',  # 𪫈
    # 0x2AAC9: '',  # 𪫉
    # 0x2AACA: '',  # 𪫊
    # 0x2AACB: '',  # 𪫋
    # 0x2AACC: '',  # 𪫌
    # 0x2AACD: '',  # 𪫍
    0x2AACE: 'kòu',  # 𪫎
    # 0x2AACF: '',  # 𪫏
    0x2AAD0: 'yì',  # 𪫐
    # 0x2AAD1: '',  # 𪫑
    # 0x2AAD2: '',  # 𪫒
    # 0x2AAD3: '',  # 𪫓
    # 0x2AAD4: '',  # 𪫔
    # 0x2AAD5: '',  # 𪫕
    0x2AAD6: 'chuán',  # 𪫖
    # 0x2AAD7: '',  # 𪫗
    0x2AAD8: 'yán',  # 𪫘
    # 0x2AAD9: '',  # 𪫙
    # 0x2AADA: '',  # 𪫚
    # 0x2AADB: '',  # 𪫛
    # 0x2AADC: '',  # 𪫜
    # 0x2AADD: '',  # 𪫝
    # 0x2AADE: '',  # 𪫞
    # 0x2AADF: '',  # 𪫟
    0x2AAE0: 'kǒng',  # 𪫠
    0x2AAE1: 'lì',  # 𪫡
    # 0x2AAE2: '',  # 𪫢
    # 0x2AAE3: '',  # 𪫣
    # 0x2AAE4: '',  # 𪫤
    0x2AAE5: 'shū',  # 𪫥
    # 0x2AAE6: '',  # 𪫦
    # 0x2AAE7: '',  # 𪫧
    # 0x2AAE8: '',  # 𪫨
    # 0x2AAE9: '',  # 𪫩
    # 0x2AAEA: '',  # 𪫪
    # 0x2AAEB: '',  # 𪫫
    # 0x2AAEC: '',  # 𪫬
    # 0x2AAED: '',  # 𪫭
    # 0x2AAEE: '',  # 𪫮
    # 0x2AAEF: '',  # 𪫯
    0x2AAF0: 'lǜ',  # 𪫰
    # 0x2AAF1: '',  # 𪫱
    # 0x2AAF2: '',  # 𪫲
    0x2AAF3: 'níng',  # 𪫳
    # 0x2AAF4: '',  # 𪫴
    # 0x2AAF5: '',  # 𪫵
    # 0x2AAF6: '',  # 𪫶
    # 0x2AAF7: '',  # 𪫷
    # 0x2AAF8: '',  # 𪫸
    # 0x2AAF9: '',  # 𪫹
    # 0x2AAFA: '',  # 𪫺
    # 0x2AAFB: '',  # 𪫻
    # 0x2AAFC: '',  # 𪫼
    # 0x2AAFD: '',  # 𪫽
    # 0x2AAFE: '',  # 𪫾
    # 0x2AAFF: '',  # 𪫿
    # 0x2AB00: '',  # 𪬀
    # 0x2AB01: '',  # 𪬁
    # 0x2AB02: '',  # 𪬂
    # 0x2AB03: '',  # 𪬃
    # 0x2AB04: '',  # 𪬄
    # 0x2AB05: '',  # 𪬅
    # 0x2AB06: '',  # 𪬆
    # 0x2AB07: '',  # 𪬇
    # 0x2AB08: '',  # 𪬈
    # 0x2AB09: '',  # 𪬉
    # 0x2AB0A: '',  # 𪬊
    # 0x2AB0B: '',  # 𪬋
    # 0x2AB0C: '',  # 𪬌
    # 0x2AB0D: '',  # 𪬍
    # 0x2AB0E: '',  # 𪬎
    # 0x2AB0F: '',  # 𪬏
    # 0x2AB10: '',  # 𪬐
    # 0x2AB11: '',  # 𪬑
    # 0x2AB12: '',  # 𪬒
    # 0x2AB13: '',  # 𪬓
    # 0x2AB14: '',  # 𪬔
    # 0x2AB15: '',  # 𪬕
    # 0x2AB16: '',  # 𪬖
    # 0x2AB17: '',  # 𪬗
    # 0x2AB18: '',  # 𪬘
    # 0x2AB19: '',  # 𪬙
    0x2AB1A: 'pīn',  # 𪬚
    # 0x2AB1B: '',  # 𪬛
    # 0x2AB1C: '',  # 𪬜
    # 0x2AB1D: '',  # 𪬝
    # 0x2AB1E: '',  # 𪬞
    # 0x2AB1F: '',  # 𪬟
    # 0x2AB20: '',  # 𪬠
    # 0x2AB21: '',  # 𪬡
    # 0x2AB22: '',  # 𪬢
    # 0x2AB23: '',  # 𪬣
    # 0x2AB24: '',  # 𪬤
    # 0x2AB25: '',  # 𪬥
    # 0x2AB26: '',  # 𪬦
    # 0x2AB27: '',  # 𪬧
    # 0x2AB28: '',  # 𪬨
    # 0x2AB29: '',  # 𪬩
    # 0x2AB2A: '',  # 𪬪
    # 0x2AB2B: '',  # 𪬫
    # 0x2AB2C: '',  # 𪬬
    # 0x2AB2D: '',  # 𪬭
    # 0x2AB2E: '',  # 𪬮
    # 0x2AB2F: '',  # 𪬯
    # 0x2AB30: '',  # 𪬰
    # 0x2AB31: '',  # 𪬱
    # 0x2AB32: '',  # 𪬲
    # 0x2AB33: '',  # 𪬳
    # 0x2AB34: '',  # 𪬴
    # 0x2AB35: '',  # 𪬵
    # 0x2AB36: '',  # 𪬶
    # 0x2AB37: '',  # 𪬷
    # 0x2AB38: '',  # 𪬸
    0x2AB39: 'tǎn',  # 𪬹
    # 0x2AB3A: '',  # 𪬺
    # 0x2AB3B: '',  # 𪬻
    # 0x2AB3C: '',  # 𪬼
    # 0x2AB3D: '',  # 𪬽
    # 0x2AB3E: '',  # 𪬾
    # 0x2AB3F: '',  # 𪬿
    # 0x2AB40: '',  # 𪭀
    # 0x2AB41: '',  # 𪭁
    # 0x2AB42: '',  # 𪭂
    # 0x2AB43: '',  # 𪭃
    # 0x2AB44: '',  # 𪭄
    # 0x2AB45: '',  # 𪭅
    # 0x2AB46: '',  # 𪭆
    # 0x2AB47: '',  # 𪭇
    # 0x2AB48: '',  # 𪭈
    # 0x2AB49: '',  # 𪭉
    0x2AB4A: 'lè',  # 𪭊
    0x2AB4B: 'zāi',  # 𪭋
    # 0x2AB4C: '',  # 𪭌
    0x2AB4D: 'gǒng',  # 𪭍
    0x2AB4E: 'guǐ',  # 𪭎
    # 0x2AB4F: '',  # 𪭏
    # 0x2AB50: '',  # 𪭐
    # 0x2AB51: '',  # 𪭑
    # 0x2AB52: '',  # 𪭒
    0x2AB53: 'méng',  # 𪭓
    # 0x2AB54: '',  # 𪭔
    # 0x2AB55: '',  # 𪭕
    # 0x2AB56: '',  # 𪭖
    # 0x2AB57: '',  # 𪭗
    # 0x2AB58: '',  # 𪭘
    # 0x2AB59: '',  # 𪭙
    # 0x2AB5A: '',  # 𪭚
    0x2AB5B: 'zhào',  # 𪭛
    # 0x2AB5C: '',  # 𪭜
    0x2AB5D: 'wěi',  # 𪭝
    # 0x2AB5E: '',  # 𪭞
    0x2AB5F: 'wǔ',  # 𪭟
    # 0x2AB60: '',  # 𪭠
    # 0x2AB61: '',  # 𪭡
    0x2AB62: 'chuāng',  # 𪭢
    # 0x2AB63: '',  # 𪭣
    # 0x2AB64: '',  # 𪭤
    0x2AB65: 'zuǒ',  # 𪭥
    # 0x2AB66: '',  # 𪭦
    0x2AB67: 'ér',  # 𪭧
    # 0x2AB68: '',  # 𪭨
    # 0x2AB69: '',  # 𪭩
    0x2AB6A: 'zhā',  # 𪭪
    # 0x2AB6B: '',  # 𪭫
    0x2AB6C: 'bù',  # 𪭬
    # 0x2AB6D: '',  # 𪭭
    # 0x2AB6E: '',  # 𪭮
    # 0x2AB6F: '',  # 𪭯
    0x2AB70: 'yáng',  # 𪭰
    # 0x2AB71: '',  # 𪭱
    # 0x2AB72: '',  # 𪭲
    # 0x2AB73: '',  # 𪭳
    # 0x2AB74: '',  # 𪭴
    0x2AB75: 'liǎng',  # 𪭵
    0x2AB76: 'chuàn',  # 𪭶
    # 0x2AB77: '',  # 𪭷
    # 0x2AB78: '',  # 𪭸
    # 0x2AB79: '',  # 𪭹
    # 0x2AB7A: '',  # 𪭺
    # 0x2AB7B: '',  # 𪭻
    # 0x2AB7C: '',  # 𪭼
    # 0x2AB7D: '',  # 𪭽
    # 0x2AB7E: '',  # 𪭾
    # 0x2AB7F: '',  # 𪭿
    # 0x2AB80: '',  # 𪮀
    # 0x2AB81: '',  # 𪮁
    # 0x2AB82: '',  # 𪮂
    0x2AB83: 'cán',  # 𪮃
    # 0x2AB84: '',  # 𪮄
    # 0x2AB85: '',  # 𪮅
    # 0x2AB86: '',  # 𪮆
    # 0x2AB87: '',  # 𪮇
    # 0x2AB88: '',  # 𪮈
    # 0x2AB89: '',  # 𪮉
    # 0x2AB8A: '',  # 𪮊
    # 0x2AB8B: '',  # 𪮋
    # 0x2AB8C: '',  # 𪮌
    # 0x2AB8D: '',  # 𪮍
    # 0x2AB8E: '',  # 𪮎
    # 0x2AB8F: '',  # 𪮏
    # 0x2AB90: '',  # 𪮐
    # 0x2AB91: '',  # 𪮑
    # 0x2AB92: '',  # 𪮒
    # 0x2AB93: '',  # 𪮓
    # 0x2AB94: '',  # 𪮔
    # 0x2AB95: '',  # 𪮕
    # 0x2AB96: '',  # 𪮖
    # 0x2AB97: '',  # 𪮗
    # 0x2AB98: '',  # 𪮘
    # 0x2AB99: '',  # 𪮙
    # 0x2AB9A: '',  # 𪮚
    # 0x2AB9B: '',  # 𪮛
    # 0x2AB9C: '',  # 𪮜
    # 0x2AB9D: '',  # 𪮝
    # 0x2AB9E: '',  # 𪮞
    0x2AB9F: 'diē',  # 𪮟
    # 0x2ABA0: '',  # 𪮠
    0x2ABA1: 'lǎng',  # 𪮡
    # 0x2ABA2: '',  # 𪮢
    # 0x2ABA3: '',  # 𪮣
    0x2ABA4: 'bīng',  # 𪮤
    # 0x2ABA5: '',  # 𪮥
    # 0x2ABA6: '',  # 𪮦
    # 0x2ABA7: '',  # 𪮧
    # 0x2ABA8: '',  # 𪮨
    # 0x2ABA9: '',  # 𪮩
    0x2ABAA: 'lòu',  # 𪮪
    # 0x2ABAB: '',  # 𪮫
    # 0x2ABAC: '',  # 𪮬
    # 0x2ABAD: '',  # 𪮭
    # 0x2ABAE: '',  # 𪮮
    # 0x2ABAF: '',  # 𪮯
    0x2ABB0: 'mèn',  # 𪮰
    # 0x2ABB1: '',  # 𪮱
    # 0x2ABB2: '',  # 𪮲
    0x2ABB3: 'mán',  # 𪮳
    # 0x2ABB4: '',  # 𪮴
    # 0x2ABB5: '',  # 𪮵
    # 0x2ABB6: '',  # 𪮶
    # 0x2ABB7: '',  # 𪮷
    # 0x2ABB8: '',  # 𪮸
    # 0x2ABB9: '',  # 𪮹
    # 0x2ABBA: '',  # 𪮺
    # 0x2ABBB: '',  # 𪮻
    # 0x2ABBC: '',  # 𪮼
    # 0x2ABBD: '',  # 𪮽
    # 0x2ABBE: '',  # 𪮾
    # 0x2ABBF: '',  # 𪮿
    # 0x2ABC0: '',  # 𪯀
    # 0x2ABC1: '',  # 𪯁
    # 0x2ABC2: '',  # 𪯂
    # 0x2ABC3: '',  # 𪯃
    # 0x2ABC4: '',  # 𪯄
    # 0x2ABC5: '',  # 𪯅
    # 0x2ABC6: '',  # 𪯆
    # 0x2ABC7: '',  # 𪯇
    0x2ABC8: 'fú',  # 𪯈
    # 0x2ABC9: '',  # 𪯉
    # 0x2ABCA: '',  # 𪯊
    # 0x2ABCB: '',  # 𪯋
    0x2ABCC: 'chuí',  # 𪯌
    0x2ABCD: 'gěng',  # 𪯍
    0x2ABCE: 'tà',  # 𪯎
    0x2ABCF: 'hū',  # 𪯏
    0x2ABD0: 'dì',  # 𪯐
    # 0x2ABD1: '',  # 𪯑
    # 0x2ABD2: '',  # 𪯒
    # 0x2ABD3: '',  # 𪯓
    # 0x2ABD4: '',  # 𪯔
    # 0x2ABD5: '',  # 𪯕
    0x2ABD6: 'lù',  # 𪯖
    # 0x2ABD7: '',  # 𪯗
    0x2ABD8: 'zēn',  # 𪯘
    0x2ABD9: 'dí',  # 𪯙
    # 0x2ABDA: '',  # 𪯚
    # 0x2ABDB: '',  # 𪯛
    0x2ABDC: 'lǐn',  # 𪯜
    # 0x2ABDD: '',  # 𪯝
    # 0x2ABDE: '',  # 𪯞
    # 0x2ABDF: '',  # 𪯟
    # 0x2ABE0: '',  # 𪯠
    # 0x2ABE1: '',  # 𪯡
    0x2ABE2: 'guàn',  # 𪯢
    # 0x2ABE3: '',  # 𪯣
    # 0x2ABE4: '',  # 𪯤
    # 0x2ABE5: '',  # 𪯥
    # 0x2ABE6: '',  # 𪯦
    # 0x2ABE7: '',  # 𪯧
    0x2ABE8: 'chǎn',  # 𪯨
    # 0x2ABE9: '',  # 𪯩
    # 0x2ABEA: '',  # 𪯪
    # 0x2ABEB: '',  # 𪯫
    # 0x2ABEC: '',  # 𪯬
    # 0x2ABED: '',  # 𪯭
    # 0x2ABEE: '',  # 𪯮
    # 0x2ABEF: '',  # 𪯯
    # 0x2ABF0: '',  # 𪯰
    0x2ABF1: 'xiān',  # 𪯱
    # 0x2ABF2: '',  # 𪯲
    # 0x2ABF3: '',  # 𪯳
    # 0x2ABF4: '',  # 𪯴
    # 0x2ABF5: '',  # 𪯵
    # 0x2ABF6: '',  # 𪯶
    # 0x2ABF7: '',  # 𪯷
    # 0x2ABF8: '',  # 𪯸
    # 0x2ABF9: '',  # 𪯹
    # 0x2ABFA: '',  # 𪯺
    # 0x2ABFB: '',  # 𪯻
    # 0x2ABFC: '',  # 𪯼
    # 0x2ABFD: '',  # 𪯽
    # 0x2ABFE: '',  # 𪯾
    # 0x2ABFF: '',  # 𪯿
    # 0x2AC00: '',  # 𪰀
    # 0x2AC01: '',  # 𪰁
    # 0x2AC02: '',  # 𪰂
    # 0x2AC03: '',  # 𪰃
    0x2AC04: 'gàng',  # 𪰄
    0x2AC05: 'xūn',  # 𪰅
    # 0x2AC06: '',  # 𪰆
    # 0x2AC07: '',  # 𪰇
    # 0x2AC08: '',  # 𪰈
    # 0x2AC09: '',  # 𪰉
    # 0x2AC0A: '',  # 𪰊
    # 0x2AC0B: '',  # 𪰋
    # 0x2AC0C: '',  # 𪰌
    0x2AC0D: 'dǒu',  # 𪰍
    # 0x2AC0E: '',  # 𪰎
    # 0x2AC0F: '',  # 𪰏
    # 0x2AC10: '',  # 𪰐
    # 0x2AC11: '',  # 𪰑
    # 0x2AC12: '',  # 𪰒
    # 0x2AC13: '',  # 𪰓
    # 0x2AC14: '',  # 𪰔
    # 0x2AC15: '',  # 𪰕
    0x2AC16: 'shùn',  # 𪰖
    # 0x2AC17: '',  # 𪰗
    # 0x2AC18: '',  # 𪰘
    # 0x2AC19: '',  # 𪰙
    # 0x2AC1A: '',  # 𪰚
    # 0x2AC1B: '',  # 𪰛
    # 0x2AC1C: '',  # 𪰜
    # 0x2AC1D: '',  # 𪰝
    # 0x2AC1E: '',  # 𪰞
    # 0x2AC1F: '',  # 𪰟
    # 0x2AC20: '',  # 𪰠
    # 0x2AC21: '',  # 𪰡
    # 0x2AC22: '',  # 𪰢
    # 0x2AC23: '',  # 𪰣
    # 0x2AC24: '',  # 𪰤
    # 0x2AC25: '',  # 𪰥
    # 0x2AC26: '',  # 𪰦
    # 0x2AC27: '',  # 𪰧
    # 0x2AC28: '',  # 𪰨
    # 0x2AC29: '',  # 𪰩
    # 0x2AC2A: '',  # 𪰪
    # 0x2AC2B: '',  # 𪰫
    # 0x2AC2C: '',  # 𪰬
    # 0x2AC2D: '',  # 𪰭
    # 0x2AC2E: '',  # 𪰮
    # 0x2AC2F: '',  # 𪰯
    # 0x2AC30: '',  # 𪰰
    # 0x2AC31: '',  # 𪰱
    # 0x2AC32: '',  # 𪰲
    # 0x2AC33: '',  # 𪰳
    # 0x2AC34: '',  # 𪰴
    # 0x2AC35: '',  # 𪰵
    # 0x2AC36: '',  # 𪰶
    # 0x2AC37: '',  # 𪰷
    0x2AC38: 'sù',  # 𪰸
    # 0x2AC39: '',  # 𪰹
    # 0x2AC3A: '',  # 𪰺
    # 0x2AC3B: '',  # 𪰻
    # 0x2AC3C: '',  # 𪰼
    # 0x2AC3D: '',  # 𪰽
    # 0x2AC3E: '',  # 𪰾
    # 0x2AC3F: '',  # 𪰿
    # 0x2AC40: '',  # 𪱀
    # 0x2AC41: '',  # 𪱁
    # 0x2AC42: '',  # 𪱂
    # 0x2AC43: '',  # 𪱃
    # 0x2AC44: '',  # 𪱄
    # 0x2AC45: '',  # 𪱅
    # 0x2AC46: '',  # 𪱆
    # 0x2AC47: '',  # 𪱇
    # 0x2AC48: '',  # 𪱈
    # 0x2AC49: '',  # 𪱉
    # 0x2AC4A: '',  # 𪱊
    # 0x2AC4B: '',  # 𪱋
    # 0x2AC4C: '',  # 𪱌
    # 0x2AC4D: '',  # 𪱍
    # 0x2AC4E: '',  # 𪱎
    # 0x2AC4F: '',  # 𪱏
    # 0x2AC50: '',  # 𪱐
    # 0x2AC51: '',  # 𪱑
    # 0x2AC52: '',  # 𪱒
    # 0x2AC53: '',  # 𪱓
    # 0x2AC54: '',  # 𪱔
    # 0x2AC55: '',  # 𪱕
    0x2AC56: 'jué',  # 𪱖
    # 0x2AC57: '',  # 𪱗
    # 0x2AC58: '',  # 𪱘
    # 0x2AC59: '',  # 𪱙
    # 0x2AC5A: '',  # 𪱚
    0x2AC5B: 'yǐn',  # 𪱛
    # 0x2AC5C: '',  # 𪱜
    # 0x2AC5D: '',  # 𪱝
    0x2AC5E: 'nì',  # 𪱞
    # 0x2AC5F: '',  # 𪱟
    0x2AC60: 'biǎn',  # 𪱠
    # 0x2AC61: '',  # 𪱡
    0x2AC62: 'zuò',  # 𪱢
    # 0x2AC63: '',  # 𪱣
    # 0x2AC64: '',  # 𪱤
    # 0x2AC65: '',  # 𪱥
    # 0x2AC66: '',  # 𪱦
    # 0x2AC67: '',  # 𪱧
    # 0x2AC68: '',  # 𪱨
    # 0x2AC69: '',  # 𪱩
    0x2AC6A: 'téng',  # 𪱪
    0x2AC6B: 'sì',  # 𪱫
    # 0x2AC6C: '',  # 𪱬
    # 0x2AC6D: '',  # 𪱭
    # 0x2AC6E: '',  # 𪱮
    # 0x2AC6F: '',  # 𪱯
    # 0x2AC70: '',  # 𪱰
    # 0x2AC71: '',  # 𪱱
    # 0x2AC72: '',  # 𪱲
    0x2AC73: 'hé',  # 𪱳
    # 0x2AC74: '',  # 𪱴
    # 0x2AC75: '',  # 𪱵
    # 0x2AC76: '',  # 𪱶
    # 0x2AC77: '',  # 𪱷
    # 0x2AC78: '',  # 𪱸
    # 0x2AC79: '',  # 𪱹
    # 0x2AC7A: '',  # 𪱺
    # 0x2AC7B: '',  # 𪱻
    # 0x2AC7C: '',  # 𪱼
    # 0x2AC7D: '',  # 𪱽
    # 0x2AC7E: '',  # 𪱾
    # 0x2AC7F: '',  # 𪱿
    # 0x2AC80: '',  # 𪲀
    # 0x2AC81: '',  # 𪲁
    # 0x2AC82: '',  # 𪲂
    # 0x2AC83: '',  # 𪲃
    # 0x2AC84: '',  # 𪲄
    # 0x2AC85: '',  # 𪲅
    # 0x2AC86: '',  # 𪲆
    # 0x2AC87: '',  # 𪲇
    # 0x2AC88: '',  # 𪲈
    0x2AC89: 'huò',  # 𪲉
    # 0x2AC8A: '',  # 𪲊
    # 0x2AC8B: '',  # 𪲋
    # 0x2AC8C: '',  # 𪲌
    # 0x2AC8D: '',  # 𪲍
    # 0x2AC8E: '',  # 𪲎
    # 0x2AC8F: '',  # 𪲏
    # 0x2AC90: '',  # 𪲐
    # 0x2AC91: '',  # 𪲑
    # 0x2AC92: '',  # 𪲒
    # 0x2AC93: '',  # 𪲓
    # 0x2AC94: '',  # 𪲔
    # 0x2AC95: '',  # 𪲕
    # 0x2AC96: '',  # 𪲖
    # 0x2AC97: '',  # 𪲗
    # 0x2AC98: '',  # 𪲘
    # 0x2AC99: '',  # 𪲙
    # 0x2AC9A: '',  # 𪲚
    # 0x2AC9B: '',  # 𪲛
    # 0x2AC9C: '',  # 𪲜
    # 0x2AC9D: '',  # 𪲝
    # 0x2AC9E: '',  # 𪲞
    # 0x2AC9F: '',  # 𪲟
    # 0x2ACA0: '',  # 𪲠
    # 0x2ACA1: '',  # 𪲡
    # 0x2ACA2: '',  # 𪲢
    # 0x2ACA3: '',  # 𪲣
    # 0x2ACA4: '',  # 𪲤
    # 0x2ACA5: '',  # 𪲥
    # 0x2ACA6: '',  # 𪲦
    # 0x2ACA7: '',  # 𪲧
    # 0x2ACA8: '',  # 𪲨
    # 0x2ACA9: '',  # 𪲩
    # 0x2ACAA: '',  # 𪲪
    # 0x2ACAB: '',  # 𪲫
    # 0x2ACAC: '',  # 𪲬
    # 0x2ACAD: '',  # 𪲭
    # 0x2ACAE: '',  # 𪲮
    # 0x2ACAF: '',  # 𪲯
    # 0x2ACB0: '',  # 𪲰
    # 0x2ACB1: '',  # 𪲱
    # 0x2ACB2: '',  # 𪲲
    # 0x2ACB3: '',  # 𪲳
    # 0x2ACB4: '',  # 𪲴
    0x2ACB5: 'duò',  # 𪲵
    # 0x2ACB6: '',  # 𪲶
    # 0x2ACB7: '',  # 𪲷
    # 0x2ACB8: '',  # 𪲸
    # 0x2ACB9: '',  # 𪲹
    # 0x2ACBA: '',  # 𪲺
    # 0x2ACBB: '',  # 𪲻
    # 0x2ACBC: '',  # 𪲼
    # 0x2ACBD: '',  # 𪲽
    # 0x2ACBE: '',  # 𪲾
    # 0x2ACBF: '',  # 𪲿
    # 0x2ACC0: '',  # 𪳀
    # 0x2ACC1: '',  # 𪳁
    # 0x2ACC2: '',  # 𪳂
    # 0x2ACC3: '',  # 𪳃
    0x2ACC4: 'liàng',  # 𪳄
    0x2ACC5: 'luò',  # 𪳅
    # 0x2ACC6: '',  # 𪳆
    # 0x2ACC7: '',  # 𪳇
    # 0x2ACC8: '',  # 𪳈
    # 0x2ACC9: '',  # 𪳉
    # 0x2ACCA: '',  # 𪳊
    # 0x2ACCB: '',  # 𪳋
    # 0x2ACCC: '',  # 𪳌
    # 0x2ACCD: '',  # 𪳍
    # 0x2ACCE: '',  # 𪳎
    # 0x2ACCF: '',  # 𪳏
    0x2ACD0: 'qú',  # 𪳐
    # 0x2ACD1: '',  # 𪳑
    # 0x2ACD2: '',  # 𪳒
    # 0x2ACD3: '',  # 𪳓
    # 0x2ACD4: '',  # 𪳔
    # 0x2ACD5: '',  # 𪳕
    # 0x2ACD6: '',  # 𪳖
    # 0x2ACD7: '',  # 𪳗
    # 0x2ACD8: '',  # 𪳘
    # 0x2ACD9: '',  # 𪳙
    0x2ACDA: 'sù',  # 𪳚
    # 0x2ACDB: '',  # 𪳛
    # 0x2ACDC: '',  # 𪳜
    # 0x2ACDD: '',  # 𪳝
    # 0x2ACDE: '',  # 𪳞
    # 0x2ACDF: '',  # 𪳟
    # 0x2ACE0: '',  # 𪳠
    # 0x2ACE1: '',  # 𪳡
    # 0x2ACE2: '',  # 𪳢
    # 0x2ACE3: '',  # 𪳣
    # 0x2ACE4: '',  # 𪳤
    # 0x2ACE5: '',  # 𪳥
    # 0x2ACE6: '',  # 𪳦
    # 0x2ACE7: '',  # 𪳧
    # 0x2ACE8: '',  # 𪳨
    # 0x2ACE9: '',  # 𪳩
    # 0x2ACEA: '',  # 𪳪
    # 0x2ACEB: '',  # 𪳫
    # 0x2ACEC: '',  # 𪳬
    # 0x2ACED: '',  # 𪳭
    # 0x2ACEE: '',  # 𪳮
    0x2ACEF: 'táng',  # 𪳯
    # 0x2ACF0: '',  # 𪳰
    # 0x2ACF1: '',  # 𪳱
    # 0x2ACF2: '',  # 𪳲
    # 0x2ACF3: '',  # 𪳳
    # 0x2ACF4: '',  # 𪳴
    # 0x2ACF5: '',  # 𪳵
    # 0x2ACF6: '',  # 𪳶
    0x2ACF7: 'dàng,yáng',  # 𪳷
    # 0x2ACF8: '',  # 𪳸
    # 0x2ACF9: '',  # 𪳹
    # 0x2ACFA: '',  # 𪳺
    # 0x2ACFB: '',  # 𪳻
    # 0x2ACFC: '',  # 𪳼
    # 0x2ACFD: '',  # 𪳽
    # 0x2ACFE: '',  # 𪳾
    # 0x2ACFF: '',  # 𪳿
    # 0x2AD00: '',  # 𪴀
    # 0x2AD01: '',  # 𪴁
    # 0x2AD02: '',  # 𪴂
    # 0x2AD03: '',  # 𪴃
    # 0x2AD04: '',  # 𪴄
    # 0x2AD05: '',  # 𪴅
    # 0x2AD06: '',  # 𪴆
    # 0x2AD07: '',  # 𪴇
    # 0x2AD08: '',  # 𪴈
    # 0x2AD09: '',  # 𪴉
    # 0x2AD0A: '',  # 𪴊
    # 0x2AD0B: '',  # 𪴋
    # 0x2AD0C: '',  # 𪴌
    # 0x2AD0D: '',  # 𪴍
    # 0x2AD0E: '',  # 𪴎
    # 0x2AD0F: '',  # 𪴏
    # 0x2AD10: '',  # 𪴐
    # 0x2AD11: '',  # 𪴑
    # 0x2AD12: '',  # 𪴒
    # 0x2AD13: '',  # 𪴓
    # 0x2AD14: '',  # 𪴔
    0x2AD15: 'chēng',  # 𪴕
    # 0x2AD16: '',  # 𪴖
    # 0x2AD17: '',  # 𪴗
    # 0x2AD18: '',  # 𪴘
    # 0x2AD19: '',  # 𪴙
    # 0x2AD1A: '',  # 𪴚
    # 0x2AD1B: '',  # 𪴛
    # 0x2AD1C: '',  # 𪴜
    # 0x2AD1D: '',  # 𪴝
    # 0x2AD1E: '',  # 𪴞
    # 0x2AD1F: '',  # 𪴟
    # 0x2AD20: '',  # 𪴠
    # 0x2AD21: '',  # 𪴡
    # 0x2AD22: '',  # 𪴢
    # 0x2AD23: '',  # 𪴣
    # 0x2AD24: '',  # 𪴤
    # 0x2AD25: '',  # 𪴥
    # 0x2AD26: '',  # 𪴦
    # 0x2AD27: '',  # 𪴧
    # 0x2AD28: '',  # 𪴨
    0x2AD29: 'fēng',  # 𪴩
    0x2AD2A: 'pǒ',  # 𪴪
    0x2AD2B: 'pā',  # 𪴫
    # 0x2AD2C: '',  # 𪴬
    0x2AD2D: 'pā',  # 𪴭
    # 0x2AD2E: '',  # 𪴮
    # 0x2AD2F: '',  # 𪴯
    # 0x2AD30: '',  # 𪴰
    # 0x2AD31: '',  # 𪴱
    # 0x2AD32: '',  # 𪴲
    # 0x2AD33: '',  # 𪴳
    0x2AD34: 'yáo',  # 𪴴
    0x2AD35: 'wù',  # 𪴵
    0x2AD36: 'yuán',  # 𪴶
    # 0x2AD37: '',  # 𪴷
    0x2AD38: 'wǎng',  # 𪴸
    # 0x2AD39: '',  # 𪴹
    # 0x2AD3A: '',  # 𪴺
    # 0x2AD3B: '',  # 𪴻
    # 0x2AD3C: '',  # 𪴼
    # 0x2AD3D: '',  # 𪴽
    # 0x2AD3E: '',  # 𪴾
    0x2AD3F: 'yǔ',  # 𪴿
    # 0x2AD40: '',  # 𪵀
    0x2AD41: 'tāo',  # 𪵁
    # 0x2AD42: '',  # 𪵂
    # 0x2AD43: '',  # 𪵃
    # 0x2AD44: '',  # 𪵄
    # 0x2AD45: '',  # 𪵅
    # 0x2AD46: '',  # 𪵆
    0x2AD47: 'ài',  # 𪵇
    # 0x2AD48: '',  # 𪵈
    0x2AD49: 'niē',  # 𪵉
    # 0x2AD4A: '',  # 𪵊
    # 0x2AD4B: '',  # 𪵋
    # 0x2AD4C: '',  # 𪵌
    0x2AD4D: 'lìng',  # 𪵍
    # 0x2AD4E: '',  # 𪵎
    # 0x2AD4F: '',  # 𪵏
    # 0x2AD50: '',  # 𪵐
    # 0x2AD51: '',  # 𪵑
    # 0x2AD52: '',  # 𪵒
    # 0x2AD53: '',  # 𪵓
    # 0x2AD54: '',  # 𪵔
    # 0x2AD55: '',  # 𪵕
    # 0x2AD56: '',  # 𪵖
    # 0x2AD57: '',  # 𪵗
    # 0x2AD58: '',  # 𪵘
    # 0x2AD59: '',  # 𪵙
    # 0x2AD5A: '',  # 𪵚
    # 0x2AD5B: '',  # 𪵛
    # 0x2AD5C: '',  # 𪵜
    # 0x2AD5D: '',  # 𪵝
    # 0x2AD5E: '',  # 𪵞
    # 0x2AD5F: '',  # 𪵟
    # 0x2AD60: '',  # 𪵠
    # 0x2AD61: '',  # 𪵡
    # 0x2AD62: '',  # 𪵢
    # 0x2AD63: '',  # 𪵣
    # 0x2AD64: '',  # 𪵤
    # 0x2AD65: '',  # 𪵥
    # 0x2AD66: '',  # 𪵦
    # 0x2AD67: '',  # 𪵧
    # 0x2AD68: '',  # 𪵨
    # 0x2AD69: '',  # 𪵩
    # 0x2AD6A: '',  # 𪵪
    # 0x2AD6B: '',  # 𪵫
    # 0x2AD6C: '',  # 𪵬
    # 0x2AD6D: '',  # 𪵭
    # 0x2AD6E: '',  # 𪵮
    # 0x2AD6F: '',  # 𪵯
    # 0x2AD70: '',  # 𪵰
    # 0x2AD71: '',  # 𪵱
    # 0x2AD72: '',  # 𪵲
    # 0x2AD73: '',  # 𪵳
    # 0x2AD74: '',  # 𪵴
    # 0x2AD75: '',  # 𪵵
    # 0x2AD76: '',  # 𪵶
    # 0x2AD77: '',  # 𪵷
    # 0x2AD78: '',  # 𪵸
    0x2AD79: 'jiāng',  # 𪵹
    # 0x2AD7A: '',  # 𪵺
    # 0x2AD7B: '',  # 𪵻
    # 0x2AD7C: '',  # 𪵼
    # 0x2AD7D: '',  # 𪵽
    # 0x2AD7E: '',  # 𪵾
    # 0x2AD7F: '',  # 𪵿
    # 0x2AD80: '',  # 𪶀
    # 0x2AD81: '',  # 𪶁
    # 0x2AD82: '',  # 𪶂
    # 0x2AD83: '',  # 𪶃
    0x2AD84: 'shí',  # 𪶄
    # 0x2AD85: '',  # 𪶅
    # 0x2AD86: '',  # 𪶆
    # 0x2AD87: '',  # 𪶇
    # 0x2AD88: '',  # 𪶈
    # 0x2AD89: '',  # 𪶉
    # 0x2AD8A: '',  # 𪶊
    # 0x2AD8B: '',  # 𪶋
    # 0x2AD8C: '',  # 𪶌
    # 0x2AD8D: '',  # 𪶍
    # 0x2AD8E: '',  # 𪶎
    # 0x2AD8F: '',  # 𪶏
    # 0x2AD90: '',  # 𪶐
    # 0x2AD91: '',  # 𪶑
    0x2AD92: 'luó',  # 𪶒
    # 0x2AD93: '',  # 𪶓
    # 0x2AD94: '',  # 𪶔
    # 0x2AD95: '',  # 𪶕
    # 0x2AD96: '',  # 𪶖
    # 0x2AD97: '',  # 𪶗
    # 0x2AD98: '',  # 𪶘
    # 0x2AD99: '',  # 𪶙
    # 0x2AD9A: '',  # 𪶚
    # 0x2AD9B: '',  # 𪶛
    0x2AD9C: 'pāng',  # 𪶜
    # 0x2AD9D: '',  # 𪶝
    # 0x2AD9E: '',  # 𪶞
    # 0x2AD9F: '',  # 𪶟
    # 0x2ADA0: '',  # 𪶠
    # 0x2ADA1: '',  # 𪶡
    # 0x2ADA2: '',  # 𪶢
    # 0x2ADA3: '',  # 𪶣
    # 0x2ADA4: '',  # 𪶤
    # 0x2ADA5: '',  # 𪶥
    # 0x2ADA6: '',  # 𪶦
    # 0x2ADA7: '',  # 𪶧
    # 0x2ADA8: '',  # 𪶨
    # 0x2ADA9: '',  # 𪶩
    # 0x2ADAA: '',  # 𪶪
    # 0x2ADAB: '',  # 𪶫
    # 0x2ADAC: '',  # 𪶬
    # 0x2ADAD: '',  # 𪶭
    0x2ADAE: 'wū',  # 𪶮
    # 0x2ADAF: '',  # 𪶯
    # 0x2ADB0: '',  # 𪶰
    # 0x2ADB1: '',  # 𪶱
    # 0x2ADB2: '',  # 𪶲
    # 0x2ADB3: '',  # 𪶳
    # 0x2ADB4: '',  # 𪶴
    # 0x2ADB5: '',  # 𪶵
    # 0x2ADB6: '',  # 𪶶
    # 0x2ADB7: '',  # 𪶷
    0x2ADB8: 'wěn',  # 𪶸
    # 0x2ADB9: '',  # 𪶹
    # 0x2ADBA: '',  # 𪶺
    0x2ADBB: 'zī',  # 𪶻
    # 0x2ADBC: '',  # 𪶼
    # 0x2ADBD: '',  # 𪶽
    # 0x2ADBE: '',  # 𪶾
    # 0x2ADBF: '',  # 𪶿
    # 0x2ADC0: '',  # 𪷀
    # 0x2ADC1: '',  # 𪷁
    # 0x2ADC2: '',  # 𪷂
    # 0x2ADC3: '',  # 𪷃
    # 0x2ADC4: '',  # 𪷄
    # 0x2ADC5: '',  # 𪷅
    # 0x2ADC6: '',  # 𪷆
    # 0x2ADC7: '',  # 𪷇
    # 0x2ADC8: '',  # 𪷈
    # 0x2ADC9: '',  # 𪷉
    # 0x2ADCA: '',  # 𪷊
    # 0x2ADCB: '',  # 𪷋
    # 0x2ADCC: '',  # 𪷌
    # 0x2ADCD: '',  # 𪷍
    # 0x2ADCE: '',  # 𪷎
    # 0x2ADCF: '',  # 𪷏
    # 0x2ADD0: '',  # 𪷐
    # 0x2ADD1: '',  # 𪷑
    # 0x2ADD2: '',  # 𪷒
    # 0x2ADD3: '',  # 𪷓
    # 0x2ADD4: '',  # 𪷔
    # 0x2ADD5: '',  # 𪷕
    # 0x2ADD6: '',  # 𪷖
    # 0x2ADD7: '',  # 𪷗
    # 0x2ADD8: '',  # 𪷘
    # 0x2ADD9: '',  # 𪷙
    0x2ADDA: 'cuān',  # 𪷚
    # 0x2ADDB: '',  # 𪷛
    # 0x2ADDC: '',  # 𪷜
    # 0x2ADDD: '',  # 𪷝
    # 0x2ADDE: '',  # 𪷞
    # 0x2ADDF: '',  # 𪷟
    # 0x2ADE0: '',  # 𪷠
    # 0x2ADE1: '',  # 𪷡
    # 0x2ADE2: '',  # 𪷢
    # 0x2ADE3: '',  # 𪷣
    # 0x2ADE4: '',  # 𪷤
    # 0x2ADE5: '',  # 𪷥
    # 0x2ADE6: '',  # 𪷦
    # 0x2ADE7: '',  # 𪷧
    # 0x2ADE8: '',  # 𪷨
    # 0x2ADE9: '',  # 𪷩
    # 0x2ADEA: '',  # 𪷪
    # 0x2ADEB: '',  # 𪷫
    # 0x2ADEC: '',  # 𪷬
    # 0x2ADED: '',  # 𪷭
    # 0x2ADEE: '',  # 𪷮
    # 0x2ADEF: '',  # 𪷯
    # 0x2ADF0: '',  # 𪷰
    # 0x2ADF1: '',  # 𪷱
    # 0x2ADF2: '',  # 𪷲
    # 0x2ADF3: '',  # 𪷳
    # 0x2ADF4: '',  # 𪷴
    # 0x2ADF5: '',  # 𪷵
    # 0x2ADF6: '',  # 𪷶
    # 0x2ADF7: '',  # 𪷷
    # 0x2ADF8: '',  # 𪷸
    # 0x2ADF9: '',  # 𪷹
    # 0x2ADFA: '',  # 𪷺
    # 0x2ADFB: '',  # 𪷻
    # 0x2ADFC: '',  # 𪷼
    # 0x2ADFD: '',  # 𪷽
    # 0x2ADFE: '',  # 𪷾
    # 0x2ADFF: '',  # 𪷿
    # 0x2AE00: '',  # 𪸀
    # 0x2AE01: '',  # 𪸁
    # 0x2AE02: '',  # 𪸂
    # 0x2AE03: '',  # 𪸃
    # 0x2AE04: '',  # 𪸄
    0x2AE05: 'yóu',  # 𪸅
    # 0x2AE06: '',  # 𪸆
    # 0x2AE07: '',  # 𪸇
    # 0x2AE08: '',  # 𪸈
    # 0x2AE09: '',  # 𪸉
    # 0x2AE0A: '',  # 𪸊
    # 0x2AE0B: '',  # 𪸋
    # 0x2AE0C: '',  # 𪸌
    0x2AE0D: 'yàn',  # 𪸍
    # 0x2AE0E: '',  # 𪸎
    # 0x2AE0F: '',  # 𪸏
    # 0x2AE10: '',  # 𪸐
    # 0x2AE11: '',  # 𪸑
    0x2AE12: 'hù',  # 𪸒
    # 0x2AE13: '',  # 𪸓
    # 0x2AE14: '',  # 𪸔
    # 0x2AE15: '',  # 𪸕
    # 0x2AE16: '',  # 𪸖
    # 0x2AE17: '',  # 𪸗
    # 0x2AE18: '',  # 𪸘
    # 0x2AE19: '',  # 𪸙
    # 0x2AE1A: '',  # 𪸚
    # 0x2AE1B: '',  # 𪸛
    # 0x2AE1C: '',  # 𪸜
    # 0x2AE1D: '',  # 𪸝
    # 0x2AE1E: '',  # 𪸞
    # 0x2AE1F: '',  # 𪸟
    # 0x2AE20: '',  # 𪸠
    # 0x2AE21: '',  # 𪸡
    # 0x2AE22: '',  # 𪸢
    # 0x2AE23: '',  # 𪸣
    # 0x2AE24: '',  # 𪸤
    # 0x2AE25: '',  # 𪸥
    # 0x2AE26: '',  # 𪸦
    # 0x2AE27: '',  # 𪸧
    # 0x2AE28: '',  # 𪸨
    # 0x2AE29: '',  # 𪸩
    # 0x2AE2A: '',  # 𪸪
    # 0x2AE2B: '',  # 𪸫
    0x2AE2C: 'kài',  # 𪸬
    # 0x2AE2D: '',  # 𪸭
    # 0x2AE2E: '',  # 𪸮
    # 0x2AE2F: '',  # 𪸯
    # 0x2AE30: '',  # 𪸰
    # 0x2AE31: '',  # 𪸱
    0x2AE32: 'zhào',  # 𪸲
    # 0x2AE33: '',  # 𪸳
    # 0x2AE34: '',  # 𪸴
    # 0x2AE35: '',  # 𪸵
    # 0x2AE36: '',  # 𪸶
    # 0x2AE37: '',  # 𪸷
    # 0x2AE38: '',  # 𪸸
    # 0x2AE39: '',  # 𪸹
    0x2AE3A: 'áng',  # 𪸺
    # 0x2AE3B: '',  # 𪸻
    # 0x2AE3C: '',  # 𪸼
    # 0x2AE3D: '',  # 𪸽
    # 0x2AE3E: '',  # 𪸾
    # 0x2AE3F: '',  # 𪸿
    # 0x2AE40: '',  # 𪹀
    # 0x2AE41: '',  # 𪹁
    # 0x2AE42: '',  # 𪹂
    # 0x2AE43: '',  # 𪹃
    # 0x2AE44: '',  # 𪹄
    0x2AE45: 'nài',  # 𪹅
    # 0x2AE46: '',  # 𪹆
    0x2AE47: 'tàn',  # 𪹇
    # 0x2AE48: '',  # 𪹈
    # 0x2AE49: '',  # 𪹉
    # 0x2AE4A: '',  # 𪹊
    # 0x2AE4B: '',  # 𪹋
    # 0x2AE4C: '',  # 𪹌
    # 0x2AE4D: '',  # 𪹍
    # 0x2AE4E: '',  # 𪹎
    # 0x2AE4F: '',  # 𪹏
    # 0x2AE50: '',  # 𪹐
    # 0x2AE51: '',  # 𪹑
    # 0x2AE52: '',  # 𪹒
    # 0x2AE53: '',  # 𪹓
    # 0x2AE54: '',  # 𪹔
    # 0x2AE55: '',  # 𪹕
    # 0x2AE56: '',  # 𪹖
    # 0x2AE57: '',  # 𪹗
    # 0x2AE58: '',  # 𪹘
    # 0x2AE59: '',  # 𪹙
    # 0x2AE5A: '',  # 𪹚
    # 0x2AE5B: '',  # 𪹛
    # 0x2AE5C: '',  # 𪹜
    # 0x2AE5D: '',  # 𪹝
    # 0x2AE5E: '',  # 𪹞
    # 0x2AE5F: '',  # 𪹟
    0x2AE60: 'rán',  # 𪹠
    # 0x2AE61: '',  # 𪹡
    # 0x2AE62: '',  # 𪹢
    # 0x2AE63: '',  # 𪹣
    # 0x2AE64: '',  # 𪹤
    # 0x2AE65: '',  # 𪹥
    # 0x2AE66: '',  # 𪹦
    # 0x2AE67: '',  # 𪹧
    # 0x2AE68: '',  # 𪹨
    # 0x2AE69: '',  # 𪹩
    # 0x2AE6A: '',  # 𪹪
    0x2AE6B: 'péng',  # 𪹫
    # 0x2AE6C: '',  # 𪹬
    # 0x2AE6D: '',  # 𪹭
    # 0x2AE6E: '',  # 𪹮
    # 0x2AE6F: '',  # 𪹯
    # 0x2AE70: '',  # 𪹰
    # 0x2AE71: '',  # 𪹱
    # 0x2AE72: '',  # 𪹲
    # 0x2AE73: '',  # 𪹳
    # 0x2AE74: '',  # 𪹴
    # 0x2AE75: '',  # 𪹵
    # 0x2AE76: '',  # 𪹶
    # 0x2AE77: '',  # 𪹷
    # 0x2AE78: '',  # 𪹸
    0x2AE79: 'tà',  # 𪹹
    # 0x2AE7A: '',  # 𪹺
    # 0x2AE7B: '',  # 𪹻
    # 0x2AE7C: '',  # 𪹼
    # 0x2AE7D: '',  # 𪹽
    # 0x2AE7E: '',  # 𪹾
    # 0x2AE7F: '',  # 𪹿
    # 0x2AE80: '',  # 𪺀
    # 0x2AE81: '',  # 𪺁
    # 0x2AE82: '',  # 𪺂
    # 0x2AE83: '',  # 𪺃
    # 0x2AE84: '',  # 𪺄
    # 0x2AE85: '',  # 𪺅
    # 0x2AE86: '',  # 𪺆
    # 0x2AE87: '',  # 𪺇
    # 0x2AE88: '',  # 𪺈
    # 0x2AE89: '',  # 𪺉
    # 0x2AE8A: '',  # 𪺊
    # 0x2AE8B: '',  # 𪺋
    # 0x2AE8C: '',  # 𪺌
    # 0x2AE8D: '',  # 𪺍
    # 0x2AE8E: '',  # 𪺎
    0x2AE8F: 'huàn',  # 𪺏
    # 0x2AE90: '',  # 𪺐
    # 0x2AE91: '',  # 𪺑
    # 0x2AE92: '',  # 𪺒
    # 0x2AE93: '',  # 𪺓
    # 0x2AE94: '',  # 𪺔
    0x2AE95: 'xì',  # 𪺕
    # 0x2AE96: '',  # 𪺖
    # 0x2AE97: '',  # 𪺗
    # 0x2AE98: '',  # 𪺘
    # 0x2AE99: '',  # 𪺙
    0x2AE9A: 'yú',  # 𪺚
    # 0x2AE9B: '',  # 𪺛
    # 0x2AE9C: '',  # 𪺜
    0x2AE9D: 'zhì',  # 𪺝
    0x2AE9E: 'fú',  # 𪺞
    0x2AE9F: 'zhuàng',  # 𪺟
    # 0x2AEA0: '',  # 𪺠
    # 0x2AEA1: '',  # 𪺡
    # 0x2AEA2: '',  # 𪺢
    0x2AEA3: 'shòu',  # 𪺣
    # 0x2AEA4: '',  # 𪺤
    # 0x2AEA5: '',  # 𪺥
    # 0x2AEA6: '',  # 𪺦
    # 0x2AEA7: '',  # 𪺧
    # 0x2AEA8: '',  # 𪺨
    # 0x2AEA9: '',  # 𪺩
    # 0x2AEAA: '',  # 𪺪
    0x2AEAB: 'nǎi',  # 𪺫
    # 0x2AEAC: '',  # 𪺬
    # 0x2AEAD: '',  # 𪺭
    # 0x2AEAE: '',  # 𪺮
    # 0x2AEAF: '',  # 𪺯
    # 0x2AEB0: '',  # 𪺰
    # 0x2AEB1: '',  # 𪺱
    # 0x2AEB2: '',  # 𪺲
    # 0x2AEB3: '',  # 𪺳
    # 0x2AEB4: '',  # 𪺴
    # 0x2AEB5: '',  # 𪺵
    # 0x2AEB6: '',  # 𪺶
    # 0x2AEB7: '',  # 𪺷
    # 0x2AEB8: '',  # 𪺸
    # 0x2AEB9: '',  # 𪺹
    # 0x2AEBA: '',  # 𪺺
    # 0x2AEBB: '',  # 𪺻
    # 0x2AEBC: '',  # 𪺼
    0x2AEBD: 'yìn',  # 𪺽
    0x2AEBE: 'ái',  # 𪺾
    # 0x2AEBF: '',  # 𪺿
    # 0x2AEC0: '',  # 𪻀
    # 0x2AEC1: '',  # 𪻁
    # 0x2AEC2: '',  # 𪻂
    # 0x2AEC3: '',  # 𪻃
    # 0x2AEC4: '',  # 𪻄
    # 0x2AEC5: '',  # 𪻅
    # 0x2AEC6: '',  # 𪻆
    # 0x2AEC7: '',  # 𪻇
    # 0x2AEC8: '',  # 𪻈
    # 0x2AEC9: '',  # 𪻉
    # 0x2AECA: '',  # 𪻊
    # 0x2AECB: '',  # 𪻋
    # 0x2AECC: '',  # 𪻌
    # 0x2AECD: '',  # 𪻍
    # 0x2AECE: '',  # 𪻎
    # 0x2AECF: '',  # 𪻏
    # 0x2AED0: '',  # 𪻐
    # 0x2AED1: '',  # 𪻑
    # 0x2AED2: '',  # 𪻒
    # 0x2AED3: '',  # 𪻓
    # 0x2AED4: '',  # 𪻔
    # 0x2AED5: '',  # 𪻕
    # 0x2AED6: '',  # 𪻖
    # 0x2AED7: '',  # 𪻗
    # 0x2AED8: '',  # 𪻘
    # 0x2AED9: '',  # 𪻙
    # 0x2AEDA: '',  # 𪻚
    # 0x2AEDB: '',  # 𪻛
    # 0x2AEDC: '',  # 𪻜
    # 0x2AEDD: '',  # 𪻝
    # 0x2AEDE: '',  # 𪻞
    # 0x2AEDF: '',  # 𪻟
    # 0x2AEE0: '',  # 𪻠
    # 0x2AEE1: '',  # 𪻡
    # 0x2AEE2: '',  # 𪻢
    # 0x2AEE3: '',  # 𪻣
    # 0x2AEE4: '',  # 𪻤
    # 0x2AEE5: '',  # 𪻥
    # 0x2AEE6: '',  # 𪻦
    # 0x2AEE7: '',  # 𪻧
    # 0x2AEE8: '',  # 𪻨
    # 0x2AEE9: '',  # 𪻩
    # 0x2AEEA: '',  # 𪻪
    # 0x2AEEB: '',  # 𪻫
    # 0x2AEEC: '',  # 𪻬
    # 0x2AEED: '',  # 𪻭
    # 0x2AEEE: '',  # 𪻮
    # 0x2AEEF: '',  # 𪻯
    # 0x2AEF0: '',  # 𪻰
    # 0x2AEF1: '',  # 𪻱
    # 0x2AEF2: '',  # 𪻲
    # 0x2AEF3: '',  # 𪻳
    # 0x2AEF4: '',  # 𪻴
    # 0x2AEF5: '',  # 𪻵
    # 0x2AEF6: '',  # 𪻶
    # 0x2AEF7: '',  # 𪻷
    # 0x2AEF8: '',  # 𪻸
    # 0x2AEF9: '',  # 𪻹
    # 0x2AEFA: '',  # 𪻺
    # 0x2AEFB: '',  # 𪻻
    # 0x2AEFC: '',  # 𪻼
    # 0x2AEFD: '',  # 𪻽
    # 0x2AEFE: '',  # 𪻾
    # 0x2AEFF: '',  # 𪻿
    # 0x2AF00: '',  # 𪼀
    # 0x2AF01: '',  # 𪼁
    # 0x2AF02: '',  # 𪼂
    # 0x2AF03: '',  # 𪼃
    0x2AF04: 'zhuàn',  # 𪼄
    # 0x2AF05: '',  # 𪼅
    # 0x2AF06: '',  # 𪼆
    # 0x2AF07: '',  # 𪼇
    # 0x2AF08: '',  # 𪼈
    # 0x2AF09: '',  # 𪼉
    # 0x2AF0A: '',  # 𪼊
    # 0x2AF0B: '',  # 𪼋
    # 0x2AF0C: '',  # 𪼌
    # 0x2AF0D: '',  # 𪼍
    # 0x2AF0E: '',  # 𪼎
    # 0x2AF0F: '',  # 𪼏
    # 0x2AF10: '',  # 𪼐
    # 0x2AF11: '',  # 𪼑
    # 0x2AF12: '',  # 𪼒
    # 0x2AF13: '',  # 𪼓
    # 0x2AF14: '',  # 𪼔
    # 0x2AF15: '',  # 𪼕
    # 0x2AF16: '',  # 𪼖
    # 0x2AF17: '',  # 𪼗
    # 0x2AF18: '',  # 𪼘
    # 0x2AF19: '',  # 𪼙
    # 0x2AF1A: '',  # 𪼚
    # 0x2AF1B: '',  # 𪼛
    # 0x2AF1C: '',  # 𪼜
    # 0x2AF1D: '',  # 𪼝
    # 0x2AF1E: '',  # 𪼞
    # 0x2AF1F: '',  # 𪼟
    # 0x2AF20: '',  # 𪼠
    # 0x2AF21: '',  # 𪼡
    # 0x2AF22: '',  # 𪼢
    # 0x2AF23: '',  # 𪼣
    # 0x2AF24: '',  # 𪼤
    # 0x2AF25: '',  # 𪼥
    # 0x2AF26: '',  # 𪼦
    # 0x2AF27: '',  # 𪼧
    # 0x2AF28: '',  # 𪼨
    # 0x2AF29: '',  # 𪼩
    # 0x2AF2A: '',  # 𪼪
    # 0x2AF2B: '',  # 𪼫
    # 0x2AF2C: '',  # 𪼬
    # 0x2AF2D: '',  # 𪼭
    # 0x2AF2E: '',  # 𪼮
    # 0x2AF2F: '',  # 𪼯
    # 0x2AF30: '',  # 𪼰
    # 0x2AF31: '',  # 𪼱
    # 0x2AF32: '',  # 𪼲
    # 0x2AF33: '',  # 𪼳
    # 0x2AF34: '',  # 𪼴
    # 0x2AF35: '',  # 𪼵
    # 0x2AF36: '',  # 𪼶
    # 0x2AF37: '',  # 𪼷
    # 0x2AF38: '',  # 𪼸
    # 0x2AF39: '',  # 𪼹
    # 0x2AF3A: '',  # 𪼺
    # 0x2AF3B: '',  # 𪼻
    # 0x2AF3C: '',  # 𪼼
    # 0x2AF3D: '',  # 𪼽
    # 0x2AF3E: '',  # 𪼾
    # 0x2AF3F: '',  # 𪼿
    # 0x2AF40: '',  # 𪽀
    # 0x2AF41: '',  # 𪽁
    # 0x2AF42: '',  # 𪽂
    # 0x2AF43: '',  # 𪽃
    # 0x2AF44: '',  # 𪽄
    # 0x2AF45: '',  # 𪽅
    # 0x2AF46: '',  # 𪽆
    0x2AF47: 'kē',  # 𪽇
    # 0x2AF48: '',  # 𪽈
    # 0x2AF49: '',  # 𪽉
    # 0x2AF4A: '',  # 𪽊
    # 0x2AF4B: '',  # 𪽋
    # 0x2AF4C: '',  # 𪽌
    # 0x2AF4D: '',  # 𪽍
    # 0x2AF4E: '',  # 𪽎
    # 0x2AF4F: '',  # 𪽏
    # 0x2AF50: '',  # 𪽐
    # 0x2AF51: '',  # 𪽑
    # 0x2AF52: '',  # 𪽒
    # 0x2AF53: '',  # 𪽓
    # 0x2AF54: '',  # 𪽔
    # 0x2AF55: '',  # 𪽕
    # 0x2AF56: '',  # 𪽖
    # 0x2AF57: '',  # 𪽗
    # 0x2AF58: '',  # 𪽘
    # 0x2AF59: '',  # 𪽙
    # 0x2AF5A: '',  # 𪽚
    # 0x2AF5B: '',  # 𪽛
    # 0x2AF5C: '',  # 𪽜
    # 0x2AF5D: '',  # 𪽝
    # 0x2AF5E: '',  # 𪽞
    # 0x2AF5F: '',  # 𪽟
    # 0x2AF60: '',  # 𪽠
    # 0x2AF61: '',  # 𪽡
    # 0x2AF62: '',  # 𪽢
    # 0x2AF63: '',  # 𪽣
    # 0x2AF64: '',  # 𪽤
    # 0x2AF65: '',  # 𪽥
    # 0x2AF66: '',  # 𪽦
    0x2AF67: 'chù',  # 𪽧
    # 0x2AF68: '',  # 𪽨
    # 0x2AF69: '',  # 𪽩
    0x2AF6A: 'zhàng',  # 𪽪
    # 0x2AF6B: '',  # 𪽫
    # 0x2AF6C: '',  # 𪽬
    # 0x2AF6D: '',  # 𪽭
    # 0x2AF6E: '',  # 𪽮
    # 0x2AF6F: '',  # 𪽯
    0x2AF70: 'xǔ',  # 𪽰
    # 0x2AF71: '',  # 𪽱
    # 0x2AF72: '',  # 𪽲
    # 0x2AF73: '',  # 𪽳
    0x2AF74: 'shè',  # 𪽴
    # 0x2AF75: '',  # 𪽵
    # 0x2AF76: '',  # 𪽶
    # 0x2AF77: '',  # 𪽷
    # 0x2AF78: '',  # 𪽸
    # 0x2AF79: '',  # 𪽹
    # 0x2AF7A: '',  # 𪽺
    # 0x2AF7B: '',  # 𪽻
    # 0x2AF7C: '',  # 𪽼
    # 0x2AF7D: '',  # 𪽽
    0x2AF7E: 'bó',  # 𪽾
    # 0x2AF7F: '',  # 𪽿
    # 0x2AF80: '',  # 𪾀
    # 0x2AF81: '',  # 𪾁
    # 0x2AF82: '',  # 𪾂
    # 0x2AF83: '',  # 𪾃
    # 0x2AF84: '',  # 𪾄
    # 0x2AF85: '',  # 𪾅
    # 0x2AF86: '',  # 𪾆
    0x2AF87: 'pī',  # 𪾇
    # 0x2AF88: '',  # 𪾈
    # 0x2AF89: '',  # 𪾉
    # 0x2AF8A: '',  # 𪾊
    # 0x2AF8B: '',  # 𪾋
    0x2AF8C: 'xiǎ',  # 𪾌
    # 0x2AF8D: '',  # 𪾍
    # 0x2AF8E: '',  # 𪾎
    0x2AF8F: 'yǒu',  # 𪾏
    # 0x2AF90: '',  # 𪾐
    # 0x2AF91: '',  # 𪾑
    # 0x2AF92: '',  # 𪾒
    # 0x2AF93: '',  # 𪾓
    # 0x2AF94: '',  # 𪾔
    0x2AF95: 'huàn',  # 𪾕
    # 0x2AF96: '',  # 𪾖
    # 0x2AF97: '',  # 𪾗
    0x2AF98: 'píng',  # 𪾘
    0x2AF99: 'nóng',  # 𪾙
    # 0x2AF9A: '',  # 𪾚
    0x2AF9B: 'mèi',  # 𪾛
    # 0x2AF9C: '',  # 𪾜
    # 0x2AF9D: '',  # 𪾝
    # 0x2AF9E: '',  # 𪾞
    # 0x2AF9F: '',  # 𪾟
    # 0x2AFA0: '',  # 𪾠
    # 0x2AFA1: '',  # 𪾡
    # 0x2AFA2: '',  # 𪾢
    # 0x2AFA3: '',  # 𪾣
    # 0x2AFA4: '',  # 𪾤
    # 0x2AFA5: '',  # 𪾥
    # 0x2AFA6: '',  # 𪾦
    # 0x2AFA7: '',  # 𪾧
    # 0x2AFA8: '',  # 𪾨
    # 0x2AFA9: '',  # 𪾩
    0x2AFAA: 'cì',  # 𪾪
    # 0x2AFAB: '',  # 𪾫
    # 0x2AFAC: '',  # 𪾬
    # 0x2AFAD: '',  # 𪾭
    # 0x2AFAE: '',  # 𪾮
    # 0x2AFAF: '',  # 𪾯
    # 0x2AFB0: '',  # 𪾰
    # 0x2AFB1: '',  # 𪾱
    # 0x2AFB2: '',  # 𪾲
    # 0x2AFB3: '',  # 𪾳
    # 0x2AFB4: '',  # 𪾴
    # 0x2AFB5: '',  # 𪾵
    # 0x2AFB6: '',  # 𪾶
    # 0x2AFB7: '',  # 𪾷
    # 0x2AFB8: '',  # 𪾸
    # 0x2AFB9: '',  # 𪾹
    # 0x2AFBA: '',  # 𪾺
    # 0x2AFBB: '',  # 𪾻
    # 0x2AFBC: '',  # 𪾼
    # 0x2AFBD: '',  # 𪾽
    0x2AFBE: 'dá',  # 𪾾
    # 0x2AFBF: '',  # 𪾿
    # 0x2AFC0: '',  # 𪿀
    # 0x2AFC1: '',  # 𪿁
    # 0x2AFC2: '',  # 𪿂
    # 0x2AFC3: '',  # 𪿃
    # 0x2AFC4: '',  # 𪿄
    # 0x2AFC5: '',  # 𪿅
    # 0x2AFC6: '',  # 𪿆
    # 0x2AFC7: '',  # 𪿇
    # 0x2AFC8: '',  # 𪿈
    # 0x2AFC9: '',  # 𪿉
    # 0x2AFCA: '',  # 𪿊
    # 0x2AFCB: '',  # 𪿋
    # 0x2AFCC: '',  # 𪿌
    # 0x2AFCD: '',  # 𪿍
    # 0x2AFCE: '',  # 𪿎
    # 0x2AFCF: '',  # 𪿏
    # 0x2AFD0: '',  # 𪿐
    # 0x2AFD1: '',  # 𪿑
    # 0x2AFD2: '',  # 𪿒
    # 0x2AFD3: '',  # 𪿓
    # 0x2AFD4: '',  # 𪿔
    # 0x2AFD5: '',  # 𪿕
    # 0x2AFD6: '',  # 𪿖
    # 0x2AFD7: '',  # 𪿗
    # 0x2AFD8: '',  # 𪿘
    # 0x2AFD9: '',  # 𪿙
    # 0x2AFDA: '',  # 𪿚
    # 0x2AFDB: '',  # 𪿛
    # 0x2AFDC: '',  # 𪿜
    # 0x2AFDD: '',  # 𪿝
    # 0x2AFDE: '',  # 𪿞
    # 0x2AFDF: '',  # 𪿟
    # 0x2AFE0: '',  # 𪿠
    # 0x2AFE1: '',  # 𪿡
    # 0x2AFE2: '',  # 𪿢
    # 0x2AFE3: '',  # 𪿣
    # 0x2AFE4: '',  # 𪿤
    # 0x2AFE5: '',  # 𪿥
    # 0x2AFE6: '',  # 𪿦
    # 0x2AFE7: '',  # 𪿧
    # 0x2AFE8: '',  # 𪿨
    # 0x2AFE9: '',  # 𪿩
    # 0x2AFEA: '',  # 𪿪
    # 0x2AFEB: '',  # 𪿫
    # 0x2AFEC: '',  # 𪿬
    # 0x2AFED: '',  # 𪿭
    # 0x2AFEE: '',  # 𪿮
    # 0x2AFEF: '',  # 𪿯
    # 0x2AFF0: '',  # 𪿰
    # 0x2AFF1: '',  # 𪿱
    # 0x2AFF2: '',  # 𪿲
    # 0x2AFF3: '',  # 𪿳
    # 0x2AFF4: '',  # 𪿴
    # 0x2AFF5: '',  # 𪿵
    # 0x2AFF6: '',  # 𪿶
    # 0x2AFF7: '',  # 𪿷
    # 0x2AFF8: '',  # 𪿸
    # 0x2AFF9: '',  # 𪿹
    # 0x2AFFA: '',  # 𪿺
    # 0x2AFFB: '',  # 𪿻
    # 0x2AFFC: '',  # 𪿼
    # 0x2AFFD: '',  # 𪿽
    # 0x2AFFE: '',  # 𪿾
    # 0x2AFFF: '',  # 𪿿
    # 0x2B000: '',  # 𫀀
    # 0x2B001: '',  # 𫀁
    0x2B002: 'zhāi',  # 𫀂
    # 0x2B003: '',  # 𫀃
    # 0x2B004: '',  # 𫀄
    # 0x2B005: '',  # 𫀅
    # 0x2B006: '',  # 𫀆
    # 0x2B007: '',  # 𫀇
    # 0x2B008: '',  # 𫀈
    0x2B009: 'xù',  # 𫀉
    # 0x2B00A: '',  # 𫀊
    # 0x2B00B: '',  # 𫀋
    # 0x2B00C: '',  # 𫀌
    # 0x2B00D: '',  # 𫀍
    # 0x2B00E: '',  # 𫀎
    # 0x2B00F: '',  # 𫀏
    # 0x2B010: '',  # 𫀐
    # 0x2B011: '',  # 𫀑
    # 0x2B012: '',  # 𫀒
    # 0x2B013: '',  # 𫀓
    # 0x2B014: '',  # 𫀔
    # 0x2B015: '',  # 𫀕
    # 0x2B016: '',  # 𫀖
    # 0x2B017: '',  # 𫀗
    # 0x2B018: '',  # 𫀘
    # 0x2B019: '',  # 𫀙
    # 0x2B01A: '',  # 𫀚
    # 0x2B01B: '',  # 𫀛
    # 0x2B01C: '',  # 𫀜
    # 0x2B01D: '',  # 𫀝
    # 0x2B01E: '',  # 𫀞
    # 0x2B01F: '',  # 𫀟
    # 0x2B020: '',  # 𫀠
    # 0x2B021: '',  # 𫀡
    # 0x2B022: '',  # 𫀢
    # 0x2B023: '',  # 𫀣
    # 0x2B024: '',  # 𫀤
    # 0x2B025: '',  # 𫀥
    # 0x2B026: '',  # 𫀦
    # 0x2B027: '',  # 𫀧
    # 0x2B028: '',  # 𫀨
    # 0x2B029: '',  # 𫀩
    # 0x2B02A: '',  # 𫀪
    # 0x2B02B: '',  # 𫀫
    # 0x2B02C: '',  # 𫀬
    # 0x2B02D: '',  # 𫀭
    # 0x2B02E: '',  # 𫀮
    # 0x2B02F: '',  # 𫀯
    # 0x2B030: '',  # 𫀰
    # 0x2B031: '',  # 𫀱
    0x2B032: 'pī',  # 𫀲
    # 0x2B033: '',  # 𫀳
    # 0x2B034: '',  # 𫀴
    # 0x2B035: '',  # 𫀵
    # 0x2B036: '',  # 𫀶
    # 0x2B037: '',  # 𫀷
    0x2B038: 'jú',  # 𫀸
    # 0x2B039: '',  # 𫀹
    # 0x2B03A: '',  # 𫀺
    # 0x2B03B: '',  # 𫀻
    # 0x2B03C: '',  # 𫀼
    # 0x2B03D: '',  # 𫀽
    # 0x2B03E: '',  # 𫀾
    # 0x2B03F: '',  # 𫀿
    # 0x2B040: '',  # 𫁀
    # 0x2B041: '',  # 𫁁
    # 0x2B042: '',  # 𫁂
    # 0x2B043: '',  # 𫁃
    0x2B044: 'xiāo',  # 𫁄
    # 0x2B045: '',  # 𫁅
    # 0x2B046: '',  # 𫁆
    # 0x2B047: '',  # 𫁇
    # 0x2B048: '',  # 𫁈
    # 0x2B049: '',  # 𫁉
    # 0x2B04A: '',  # 𫁊
    # 0x2B04B: '',  # 𫁋
    # 0x2B04C: '',  # 𫁌
    0x2B04D: 'zhū',  # 𫁍
    # 0x2B04E: '',  # 𫁎
    # 0x2B04F: '',  # 𫁏
    0x2B050: 'miào',  # 𫁐
    # 0x2B051: '',  # 𫁑
    # 0x2B052: '',  # 𫁒
    # 0x2B053: '',  # 𫁓
    # 0x2B054: '',  # 𫁔
    # 0x2B055: '',  # 𫁕
    # 0x2B056: '',  # 𫁖
    # 0x2B057: '',  # 𫁗
    0x2B058: 'zào',  # 𫁘
    # 0x2B059: '',  # 𫁙
    # 0x2B05A: '',  # 𫁚
    # 0x2B05B: '',  # 𫁛
    # 0x2B05C: '',  # 𫁜
    # 0x2B05D: '',  # 𫁝
    # 0x2B05E: '',  # 𫁞
    # 0x2B05F: '',  # 𫁟
    # 0x2B060: '',  # 𫁠
    # 0x2B061: '',  # 𫁡
    # 0x2B062: '',  # 𫁢
    # 0x2B063: '',  # 𫁣
    0x2B064: 'bān',  # 𫁤
    0x2B065: 'diàn',  # 𫁥
    # 0x2B066: '',  # 𫁦
    # 0x2B067: '',  # 𫁧
    # 0x2B068: '',  # 𫁨
    0x2B069: 'yù',  # 𫁩
    # 0x2B06A: '',  # 𫁪
    # 0x2B06B: '',  # 𫁫
    # 0x2B06C: '',  # 𫁬
    # 0x2B06D: '',  # 𫁭
    # 0x2B06E: '',  # 𫁮
    # 0x2B06F: '',  # 𫁯
    # 0x2B070: '',  # 𫁰
    # 0x2B071: '',  # 𫁱
    # 0x2B072: '',  # 𫁲
    0x2B073: 'wěi',  # 𫁳
    # 0x2B074: '',  # 𫁴
    # 0x2B075: '',  # 𫁵
    # 0x2B076: '',  # 𫁶
    # 0x2B077: '',  # 𫁷
    # 0x2B078: '',  # 𫁸
    # 0x2B079: '',  # 𫁹
    # 0x2B07A: '',  # 𫁺
    # 0x2B07B: '',  # 𫁻
    # 0x2B07C: '',  # 𫁼
    # 0x2B07D: '',  # 𫁽
    # 0x2B07E: '',  # 𫁾
    # 0x2B07F: '',  # 𫁿
    0x2B080: 'bō',  # 𫂀
    # 0x2B081: '',  # 𫂁
    # 0x2B082: '',  # 𫂂
    # 0x2B083: '',  # 𫂃
    # 0x2B084: '',  # 𫂄
    # 0x2B085: '',  # 𫂅
    # 0x2B086: '',  # 𫂆
    # 0x2B087: '',  # 𫂇
    # 0x2B088: '',  # 𫂈
    # 0x2B089: '',  # 𫂉
    # 0x2B08A: '',  # 𫂊
    # 0x2B08B: '',  # 𫂋
    # 0x2B08C: '',  # 𫂌
    # 0x2B08D: '',  # 𫂍
    # 0x2B08E: '',  # 𫂎
    # 0x2B08F: '',  # 𫂏
    # 0x2B090: '',  # 𫂐
    # 0x2B091: '',  # 𫂑
    # 0x2B092: '',  # 𫂒
    # 0x2B093: '',  # 𫂓
    # 0x2B094: '',  # 𫂔
    # 0x2B095: '',  # 𫂕
    # 0x2B096: '',  # 𫂖
    # 0x2B097: '',  # 𫂗
    # 0x2B098: '',  # 𫂘
    # 0x2B099: '',  # 𫂙
    # 0x2B09A: '',  # 𫂚
    # 0x2B09B: '',  # 𫂛
    0x2B09C: 'kuài',  # 𫂜
    # 0x2B09D: '',  # 𫂝
    # 0x2B09E: '',  # 𫂞
    # 0x2B09F: '',  # 𫂟
    # 0x2B0A0: '',  # 𫂠
    # 0x2B0A1: '',  # 𫂡
    # 0x2B0A2: '',  # 𫂢
    # 0x2B0A3: '',  # 𫂣
    # 0x2B0A4: '',  # 𫂤
    # 0x2B0A5: '',  # 𫂥
    # 0x2B0A6: '',  # 𫂦
    # 0x2B0A7: '',  # 𫂧
    # 0x2B0A8: '',  # 𫂨
    # 0x2B0A9: '',  # 𫂩
    # 0x2B0AA: '',  # 𫂪
    0x2B0AB: 'dìng',  # 𫂫
    # 0x2B0AC: '',  # 𫂬
    # 0x2B0AD: '',  # 𫂭
    # 0x2B0AE: '',  # 𫂮
    # 0x2B0AF: '',  # 𫂯
    # 0x2B0B0: '',  # 𫂰
    # 0x2B0B1: '',  # 𫂱
    # 0x2B0B2: '',  # 𫂲
    # 0x2B0B3: '',  # 𫂳
    # 0x2B0B4: '',  # 𫂴
    # 0x2B0B5: '',  # 𫂵
    # 0x2B0B6: '',  # 𫂶
    # 0x2B0B7: '',  # 𫂷
    # 0x2B0B8: '',  # 𫂸
    # 0x2B0B9: '',  # 𫂹
    # 0x2B0BA: '',  # 𫂺
    # 0x2B0BB: '',  # 𫂻
    # 0x2B0BC: '',  # 𫂼
    # 0x2B0BD: '',  # 𫂽
    0x2B0BE: 'yīn',  # 𫂾
    0x2B0BF: 'sà',  # 𫂿
    # 0x2B0C0: '',  # 𫃀
    # 0x2B0C1: '',  # 𫃁
    # 0x2B0C2: '',  # 𫃂
    # 0x2B0C3: '',  # 𫃃
    # 0x2B0C4: '',  # 𫃄
    0x2B0C5: 'lǐn',  # 𫃅
    # 0x2B0C6: '',  # 𫃆
    # 0x2B0C7: '',  # 𫃇
    # 0x2B0C8: '',  # 𫃈
    # 0x2B0C9: '',  # 𫃉
    # 0x2B0CA: '',  # 𫃊
    # 0x2B0CB: '',  # 𫃋
    # 0x2B0CC: '',  # 𫃌
    # 0x2B0CD: '',  # 𫃍
    # 0x2B0CE: '',  # 𫃎
    # 0x2B0CF: '',  # 𫃏
    0x2B0D0: 'mèn',  # 𫃐
    0x2B0D1: 'lào',  # 𫃑
    # 0x2B0D2: '',  # 𫃒
    # 0x2B0D3: '',  # 𫃓
    # 0x2B0D4: '',  # 𫃔
    0x2B0D5: 'cí',  # 𫃕
    # 0x2B0D6: '',  # 𫃖
    0x2B0D7: 'jiū',  # 𫃗
    # 0x2B0D8: '',  # 𫃘
    # 0x2B0D9: '',  # 𫃙
    # 0x2B0DA: '',  # 𫃚
    # 0x2B0DB: '',  # 𫃛
    # 0x2B0DC: '',  # 𫃜
    # 0x2B0DD: '',  # 𫃝
    # 0x2B0DE: '',  # 𫃞
    # 0x2B0DF: '',  # 𫃟
    # 0x2B0E0: '',  # 𫃠
    # 0x2B0E1: '',  # 𫃡
    # 0x2B0E2: '',  # 𫃢
    # 0x2B0E3: '',  # 𫃣
    # 0x2B0E4: '',  # 𫃤
    # 0x2B0E5: '',  # 𫃥
    0x2B0E6: 'zǔ',  # 𫃦
    # 0x2B0E7: '',  # 𫃧
    # 0x2B0E8: '',  # 𫃨
    # 0x2B0E9: '',  # 𫃩
    # 0x2B0EA: '',  # 𫃪
    # 0x2B0EB: '',  # 𫃫
    # 0x2B0EC: '',  # 𫃬
    # 0x2B0ED: '',  # 𫃭
    # 0x2B0EE: '',  # 𫃮
    # 0x2B0EF: '',  # 𫃯
    # 0x2B0F0: '',  # 𫃰
    # 0x2B0F1: '',  # 𫃱
    # 0x2B0F2: '',  # 𫃲
    # 0x2B0F3: '',  # 𫃳
    # 0x2B0F4: '',  # 𫃴
    # 0x2B0F5: '',  # 𫃵
    # 0x2B0F6: '',  # 𫃶
    # 0x2B0F7: '',  # 𫃷
    # 0x2B0F8: '',  # 𫃸
    # 0x2B0F9: '',  # 𫃹
    # 0x2B0FA: '',  # 𫃺
    # 0x2B0FB: '',  # 𫃻
    # 0x2B0FC: '',  # 𫃼
    # 0x2B0FD: '',  # 𫃽
    # 0x2B0FE: '',  # 𫃾
    # 0x2B0FF: '',  # 𫃿
    # 0x2B100: '',  # 𫄀
    # 0x2B101: '',  # 𫄁
    # 0x2B102: '',  # 𫄂
    # 0x2B103: '',  # 𫄃
    # 0x2B104: '',  # 𫄄
    # 0x2B105: '',  # 𫄅
    # 0x2B106: '',  # 𫄆
    0x2B107: 'zài',  # 𫄇
    # 0x2B108: '',  # 𫄈
    # 0x2B109: '',  # 𫄉
    # 0x2B10A: '',  # 𫄊
    # 0x2B10B: '',  # 𫄋
    # 0x2B10C: '',  # 𫄌
    # 0x2B10D: '',  # 𫄍
    # 0x2B10E: '',  # 𫄎
    # 0x2B10F: '',  # 𫄏
    # 0x2B110: '',  # 𫄐
    # 0x2B111: '',  # 𫄑
    # 0x2B112: '',  # 𫄒
    # 0x2B113: '',  # 𫄓
    # 0x2B114: '',  # 𫄔
    # 0x2B115: '',  # 𫄕
    # 0x2B116: '',  # 𫄖
    # 0x2B117: '',  # 𫄗
    # 0x2B118: '',  # 𫄘
    # 0x2B119: '',  # 𫄙
    # 0x2B11A: '',  # 𫄚
    # 0x2B11B: '',  # 𫄛
    # 0x2B11C: '',  # 𫄜
    0x2B11D: 'dào',  # 𫄝
    # 0x2B11E: '',  # 𫄞
    # 0x2B11F: '',  # 𫄟
    # 0x2B120: '',  # 𫄠
    # 0x2B121: '',  # 𫄡
    # 0x2B122: '',  # 𫄢
    # 0x2B123: '',  # 𫄣
    # 0x2B124: '',  # 𫄤
    # 0x2B125: '',  # 𫄥
    0x2B126: 'jié',  # 𫄦
    # 0x2B127: '',  # 𫄧
    # 0x2B128: '',  # 𫄨
    0x2B129: 'fán',  # 𫄩
    0x2B12A: 'sāng',  # 𫄪
    # 0x2B12B: '',  # 𫄫
    # 0x2B12C: '',  # 𫄬
    # 0x2B12D: '',  # 𫄭
    0x2B12E: 'tīng',  # 𫄮
    # 0x2B12F: '',  # 𫄯
    0x2B130: 'bāng',  # 𫄰
    0x2B131: 'sè',  # 𫄱
    # 0x2B132: '',  # 𫄲
    # 0x2B133: '',  # 𫄳
    # 0x2B134: '',  # 𫄴
    0x2B135: 'bēng',  # 𫄵
    # 0x2B136: '',  # 𫄶
    # 0x2B137: '',  # 𫄷
    # 0x2B138: '',  # 𫄸
    # 0x2B139: '',  # 𫄹
    0x2B13A: 'chéng',  # 𫄺
    # 0x2B13B: '',  # 𫄻
    # 0x2B13C: '',  # 𫄼
    # 0x2B13D: '',  # 𫄽
    # 0x2B13E: '',  # 𫄾
    # 0x2B13F: '',  # 𫄿
    # 0x2B140: '',  # 𫅀
    # 0x2B141: '',  # 𫅁
    # 0x2B142: '',  # 𫅂
    # 0x2B143: '',  # 𫅃
    # 0x2B144: '',  # 𫅄
    0x2B145: 'jǐ',  # 𫅅
    0x2B146: 'qī',  # 𫅆
    # 0x2B147: '',  # 𫅇
    0x2B148: 'xuán',  # 𫅈
    # 0x2B149: '',  # 𫅉
    # 0x2B14A: '',  # 𫅊
    # 0x2B14B: '',  # 𫅋
    # 0x2B14C: '',  # 𫅌
    # 0x2B14D: '',  # 𫅍
    # 0x2B14E: '',  # 𫅎
    # 0x2B14F: '',  # 𫅏
    0x2B150: 'yàng',  # 𫅐
    # 0x2B151: '',  # 𫅑
    # 0x2B152: '',  # 𫅒
    0x2B153: 'shān',  # 𫅓
    # 0x2B154: '',  # 𫅔
    # 0x2B155: '',  # 𫅕
    # 0x2B156: '',  # 𫅖
    # 0x2B157: '',  # 𫅗
    # 0x2B158: '',  # 𫅘
    0x2B159: 'gāng',  # 𫅙
    # 0x2B15A: '',  # 𫅚
    # 0x2B15B: '',  # 𫅛
    # 0x2B15C: '',  # 𫅜
    # 0x2B15D: '',  # 𫅝
    # 0x2B15E: '',  # 𫅞
    # 0x2B15F: '',  # 𫅟
    # 0x2B160: '',  # 𫅠
    # 0x2B161: '',  # 𫅡
    # 0x2B162: '',  # 𫅢
    # 0x2B163: '',  # 𫅣
    # 0x2B164: '',  # 𫅤
    # 0x2B165: '',  # 𫅥
    # 0x2B166: '',  # 𫅦
    # 0x2B167: '',  # 𫅧
    # 0x2B168: '',  # 𫅨
    # 0x2B169: '',  # 𫅩
    # 0x2B16A: '',  # 𫅪
    # 0x2B16B: '',  # 𫅫
    # 0x2B16C: '',  # 𫅬
    # 0x2B16D: '',  # 𫅭
    # 0x2B16E: '',  # 𫅮
    # 0x2B16F: '',  # 𫅯
    # 0x2B170: '',  # 𫅰
    # 0x2B171: '',  # 𫅱
    # 0x2B172: '',  # 𫅲
    # 0x2B173: '',  # 𫅳
    # 0x2B174: '',  # 𫅴
    # 0x2B175: '',  # 𫅵
    # 0x2B176: '',  # 𫅶
    # 0x2B177: '',  # 𫅷
    # 0x2B178: '',  # 𫅸
    # 0x2B179: '',  # 𫅹
    # 0x2B17A: '',  # 𫅺
    # 0x2B17B: '',  # 𫅻
    # 0x2B17C: '',  # 𫅼
    # 0x2B17D: '',  # 𫅽
    # 0x2B17E: '',  # 𫅾
    # 0x2B17F: '',  # 𫅿
    # 0x2B180: '',  # 𫆀
    # 0x2B181: '',  # 𫆁
    # 0x2B182: '',  # 𫆂
    # 0x2B183: '',  # 𫆃
    # 0x2B184: '',  # 𫆄
    # 0x2B185: '',  # 𫆅
    # 0x2B186: '',  # 𫆆
    # 0x2B187: '',  # 𫆇
    # 0x2B188: '',  # 𫆈
    # 0x2B189: '',  # 𫆉
    # 0x2B18A: '',  # 𫆊
    # 0x2B18B: '',  # 𫆋
    # 0x2B18C: '',  # 𫆌
    # 0x2B18D: '',  # 𫆍
    # 0x2B18E: '',  # 𫆎
    # 0x2B18F: '',  # 𫆏
    # 0x2B190: '',  # 𫆐
    # 0x2B191: '',  # 𫆑
    # 0x2B192: '',  # 𫆒
    # 0x2B193: '',  # 𫆓
    # 0x2B194: '',  # 𫆔
    # 0x2B195: '',  # 𫆕
    # 0x2B196: '',  # 𫆖
    # 0x2B197: '',  # 𫆗
    # 0x2B198: '',  # 𫆘
    # 0x2B199: '',  # 𫆙
    # 0x2B19A: '',  # 𫆚
    # 0x2B19B: '',  # 𫆛
    # 0x2B19C: '',  # 𫆜
    # 0x2B19D: '',  # 𫆝
    # 0x2B19E: '',  # 𫆞
    # 0x2B19F: '',  # 𫆟
    # 0x2B1A0: '',  # 𫆠
    # 0x2B1A1: '',  # 𫆡
    # 0x2B1A2: '',  # 𫆢
    # 0x2B1A3: '',  # 𫆣
    # 0x2B1A4: '',  # 𫆤
    # 0x2B1A5: '',  # 𫆥
    # 0x2B1A6: '',  # 𫆦
    # 0x2B1A7: '',  # 𫆧
    # 0x2B1A8: '',  # 𫆨
    # 0x2B1A9: '',  # 𫆩
    # 0x2B1AA: '',  # 𫆪
    # 0x2B1AB: '',  # 𫆫
    # 0x2B1AC: '',  # 𫆬
    # 0x2B1AD: '',  # 𫆭
    # 0x2B1AE: '',  # 𫆮
    # 0x2B1AF: '',  # 𫆯
    # 0x2B1B0: '',  # 𫆰
    # 0x2B1B1: '',  # 𫆱
    # 0x2B1B2: '',  # 𫆲
    # 0x2B1B3: '',  # 𫆳
    # 0x2B1B4: '',  # 𫆴
    # 0x2B1B5: '',  # 𫆵
    # 0x2B1B6: '',  # 𫆶
    # 0x2B1B7: '',  # 𫆷
    # 0x2B1B8: '',  # 𫆸
    # 0x2B1B9: '',  # 𫆹
    # 0x2B1BA: '',  # 𫆺
    # 0x2B1BB: '',  # 𫆻
    # 0x2B1BC: '',  # 𫆼
    # 0x2B1BD: '',  # 𫆽
    # 0x2B1BE: '',  # 𫆾
    # 0x2B1BF: '',  # 𫆿
    # 0x2B1C0: '',  # 𫇀
    # 0x2B1C1: '',  # 𫇁
    # 0x2B1C2: '',  # 𫇂
    # 0x2B1C3: '',  # 𫇃
    # 0x2B1C4: '',  # 𫇄
    # 0x2B1C5: '',  # 𫇅
    # 0x2B1C6: '',  # 𫇆
    # 0x2B1C7: '',  # 𫇇
    # 0x2B1C8: '',  # 𫇈
    # 0x2B1C9: '',  # 𫇉
    # 0x2B1CA: '',  # 𫇊
    # 0x2B1CB: '',  # 𫇋
    # 0x2B1CC: '',  # 𫇌
    # 0x2B1CD: '',  # 𫇍
    # 0x2B1CE: '',  # 𫇎
    0x2B1CF: 'zhī',  # 𫇏
    # 0x2B1D0: '',  # 𫇐
    # 0x2B1D1: '',  # 𫇑
    # 0x2B1D2: '',  # 𫇒
    0x2B1D3: 'líng',  # 𫇓
    # 0x2B1D4: '',  # 𫇔
    # 0x2B1D5: '',  # 𫇕
    # 0x2B1D6: '',  # 𫇖
    # 0x2B1D7: '',  # 𫇗
    0x2B1D8: 'lài',  # 𫇘
    # 0x2B1D9: '',  # 𫇙
    # 0x2B1DA: '',  # 𫇚
    # 0x2B1DB: '',  # 𫇛
    # 0x2B1DC: '',  # 𫇜
    # 0x2B1DD: '',  # 𫇝
    # 0x2B1DE: '',  # 𫇞
    # 0x2B1DF: '',  # 𫇟
    # 0x2B1E0: '',  # 𫇠
    # 0x2B1E1: '',  # 𫇡
    # 0x2B1E2: '',  # 𫇢
    # 0x2B1E3: '',  # 𫇣
    # 0x2B1E4: '',  # 𫇤
    # 0x2B1E5: '',  # 𫇥
    # 0x2B1E6: '',  # 𫇦
    # 0x2B1E7: '',  # 𫇧
    # 0x2B1E8: '',  # 𫇨
    # 0x2B1E9: '',  # 𫇩
    # 0x2B1EA: '',  # 𫇪
    # 0x2B1EB: '',  # 𫇫
    # 0x2B1EC: '',  # 𫇬
    # 0x2B1ED: '',  # 𫇭
    # 0x2B1EE: '',  # 𫇮
    # 0x2B1EF: '',  # 𫇯
    # 0x2B1F0: '',  # 𫇰
    # 0x2B1F1: '',  # 𫇱
    # 0x2B1F2: '',  # 𫇲
    # 0x2B1F3: '',  # 𫇳
    # 0x2B1F4: '',  # 𫇴
    # 0x2B1F5: '',  # 𫇵
    # 0x2B1F6: '',  # 𫇶
    # 0x2B1F7: '',  # 𫇷
    # 0x2B1F8: '',  # 𫇸
    # 0x2B1F9: '',  # 𫇹
    # 0x2B1FA: '',  # 𫇺
    # 0x2B1FB: '',  # 𫇻
    # 0x2B1FC: '',  # 𫇼
    # 0x2B1FD: '',  # 𫇽
    # 0x2B1FE: '',  # 𫇾
    # 0x2B1FF: '',  # 𫇿
    # 0x2B200: '',  # 𫈀
    # 0x2B201: '',  # 𫈁
    # 0x2B202: '',  # 𫈂
    # 0x2B203: '',  # 𫈃
    # 0x2B204: '',  # 𫈄
    # 0x2B205: '',  # 𫈅
    # 0x2B206: '',  # 𫈆
    0x2B207: 'jiāo',  # 𫈇
    # 0x2B208: '',  # 𫈈
    # 0x2B209: '',  # 𫈉
    # 0x2B20A: '',  # 𫈊
    # 0x2B20B: '',  # 𫈋
    # 0x2B20C: '',  # 𫈌
    # 0x2B20D: '',  # 𫈍
    # 0x2B20E: '',  # 𫈎
    # 0x2B20F: '',  # 𫈏
    0x2B210: 'zí',  # 𫈐
    # 0x2B211: '',  # 𫈑
    # 0x2B212: '',  # 𫈒
    # 0x2B213: '',  # 𫈓
    # 0x2B214: '',  # 𫈔
    # 0x2B215: '',  # 𫈕
    # 0x2B216: '',  # 𫈖
    # 0x2B217: '',  # 𫈗
    # 0x2B218: '',  # 𫈘
    # 0x2B219: '',  # 𫈙
    # 0x2B21A: '',  # 𫈚
    # 0x2B21B: '',  # 𫈛
    # 0x2B21C: '',  # 𫈜
    # 0x2B21D: '',  # 𫈝
    # 0x2B21E: '',  # 𫈞
    # 0x2B21F: '',  # 𫈟
    # 0x2B220: '',  # 𫈠
    # 0x2B221: '',  # 𫈡
    # 0x2B222: '',  # 𫈢
    # 0x2B223: '',  # 𫈣
    # 0x2B224: '',  # 𫈤
    # 0x2B225: '',  # 𫈥
    # 0x2B226: '',  # 𫈦
    # 0x2B227: '',  # 𫈧
    # 0x2B228: '',  # 𫈨
    # 0x2B229: '',  # 𫈩
    # 0x2B22A: '',  # 𫈪
    # 0x2B22B: '',  # 𫈫
    # 0x2B22C: '',  # 𫈬
    # 0x2B22D: '',  # 𫈭
    # 0x2B22E: '',  # 𫈮
    # 0x2B22F: '',  # 𫈯
    # 0x2B230: '',  # 𫈰
    # 0x2B231: '',  # 𫈱
    # 0x2B232: '',  # 𫈲
    # 0x2B233: '',  # 𫈳
    # 0x2B234: '',  # 𫈴
    # 0x2B235: '',  # 𫈵
    # 0x2B236: '',  # 𫈶
    # 0x2B237: '',  # 𫈷
    # 0x2B238: '',  # 𫈸
    0x2B239: 'jú',  # 𫈹
    # 0x2B23A: '',  # 𫈺
    # 0x2B23B: '',  # 𫈻
    # 0x2B23C: '',  # 𫈼
    # 0x2B23D: '',  # 𫈽
    # 0x2B23E: '',  # 𫈾
    # 0x2B23F: '',  # 𫈿
    # 0x2B240: '',  # 𫉀
    # 0x2B241: '',  # 𫉁
    # 0x2B242: '',  # 𫉂
    # 0x2B243: '',  # 𫉃
    # 0x2B244: '',  # 𫉄
    # 0x2B245: '',  # 𫉅
    # 0x2B246: '',  # 𫉆
    # 0x2B247: '',  # 𫉇
    # 0x2B248: '',  # 𫉈
    # 0x2B249: '',  # 𫉉
    # 0x2B24A: '',  # 𫉊
    # 0x2B24B: '',  # 𫉋
    # 0x2B24C: '',  # 𫉌
    # 0x2B24D: '',  # 𫉍
    # 0x2B24E: '',  # 𫉎
    0x2B24F: 'jié',  # 𫉏
    # 0x2B250: '',  # 𫉐
    # 0x2B251: '',  # 𫉑
    # 0x2B252: '',  # 𫉒
    # 0x2B253: '',  # 𫉓
    # 0x2B254: '',  # 𫉔
    # 0x2B255: '',  # 𫉕
    # 0x2B256: '',  # 𫉖
    # 0x2B257: '',  # 𫉗
    # 0x2B258: '',  # 𫉘
    # 0x2B259: '',  # 𫉙
    # 0x2B25A: '',  # 𫉚
    # 0x2B25B: '',  # 𫉛
    # 0x2B25C: '',  # 𫉜
    # 0x2B25D: '',  # 𫉝
    # 0x2B25E: '',  # 𫉞
    # 0x2B25F: '',  # 𫉟
    # 0x2B260: '',  # 𫉠
    # 0x2B261: '',  # 𫉡
    # 0x2B262: '',  # 𫉢
    # 0x2B263: '',  # 𫉣
    # 0x2B264: '',  # 𫉤
    # 0x2B265: '',  # 𫉥
    # 0x2B266: '',  # 𫉦
    # 0x2B267: '',  # 𫉧
    0x2B268: 'tà',  # 𫉨
    # 0x2B269: '',  # 𫉩
    # 0x2B26A: '',  # 𫉪
    # 0x2B26B: '',  # 𫉫
    0x2B26C: 'huò',  # 𫉬
    # 0x2B26D: '',  # 𫉭
    # 0x2B26E: '',  # 𫉮
    # 0x2B26F: '',  # 𫉯
    # 0x2B270: '',  # 𫉰
    # 0x2B271: '',  # 𫉱
    # 0x2B272: '',  # 𫉲
    # 0x2B273: '',  # 𫉳
    # 0x2B274: '',  # 𫉴
    # 0x2B275: '',  # 𫉵
    # 0x2B276: '',  # 𫉶
    # 0x2B277: '',  # 𫉷
    # 0x2B278: '',  # 𫉸
    # 0x2B279: '',  # 𫉹
    # 0x2B27A: '',  # 𫉺
    # 0x2B27B: '',  # 𫉻
    # 0x2B27C: '',  # 𫉼
    # 0x2B27D: '',  # 𫉽
    # 0x2B27E: '',  # 𫉾
    # 0x2B27F: '',  # 𫉿
    # 0x2B280: '',  # 𫊀
    # 0x2B281: '',  # 𫊁
    # 0x2B282: '',  # 𫊂
    # 0x2B283: '',  # 𫊃
    # 0x2B284: '',  # 𫊄
    # 0x2B285: '',  # 𫊅
    # 0x2B286: '',  # 𫊆
    # 0x2B287: '',  # 𫊇
    0x2B288: 'cā',  # 𫊈
    # 0x2B289: '',  # 𫊉
    # 0x2B28A: '',  # 𫊊
    # 0x2B28B: '',  # 𫊋
    # 0x2B28C: '',  # 𫊌
    # 0x2B28D: '',  # 𫊍
    # 0x2B28E: '',  # 𫊎
    # 0x2B28F: '',  # 𫊏
    # 0x2B290: '',  # 𫊐
    # 0x2B291: '',  # 𫊑
    # 0x2B292: '',  # 𫊒
    # 0x2B293: '',  # 𫊓
    # 0x2B294: '',  # 𫊔
    # 0x2B295: '',  # 𫊕
    # 0x2B296: '',  # 𫊖
    # 0x2B297: '',  # 𫊗
    # 0x2B298: '',  # 𫊘
    # 0x2B299: '',  # 𫊙
    # 0x2B29A: '',  # 𫊚
    # 0x2B29B: '',  # 𫊛
    # 0x2B29C: '',  # 𫊜
    0x2B29D: 'nüè',  # 𫊝
    # 0x2B29E: '',  # 𫊞
    # 0x2B29F: '',  # 𫊟
    # 0x2B2A0: '',  # 𫊠
    # 0x2B2A1: '',  # 𫊡
    # 0x2B2A2: '',  # 𫊢
    0x2B2A3: 'wú',  # 𫊣
    # 0x2B2A4: '',  # 𫊤
    # 0x2B2A5: '',  # 𫊥
    # 0x2B2A6: '',  # 𫊦
    # 0x2B2A7: '',  # 𫊧
    # 0x2B2A8: '',  # 𫊨
    # 0x2B2A9: '',  # 𫊩
    0x2B2AA: 'cháng',  # 𫊪
    # 0x2B2AB: '',  # 𫊫
    # 0x2B2AC: '',  # 𫊬
    # 0x2B2AD: '',  # 𫊭
    # 0x2B2AE: '',  # 𫊮
    # 0x2B2AF: '',  # 𫊯
    # 0x2B2B0: '',  # 𫊰
    # 0x2B2B1: '',  # 𫊱
    # 0x2B2B2: '',  # 𫊲
    # 0x2B2B3: '',  # 𫊳
    # 0x2B2B4: '',  # 𫊴
    # 0x2B2B5: '',  # 𫊵
    # 0x2B2B6: '',  # 𫊶
    # 0x2B2B7: '',  # 𫊷
    # 0x2B2B8: '',  # 𫊸
    # 0x2B2B9: '',  # 𫊹
    # 0x2B2BA: '',  # 𫊺
    # 0x2B2BB: '',  # 𫊻
    0x2B2BC: 'yì',  # 𫊼
    # 0x2B2BD: '',  # 𫊽
    # 0x2B2BE: '',  # 𫊾
    # 0x2B2BF: '',  # 𫊿
    # 0x2B2C0: '',  # 𫋀
    # 0x2B2C1: '',  # 𫋁
    # 0x2B2C2: '',  # 𫋂
    # 0x2B2C3: '',  # 𫋃
    # 0x2B2C4: '',  # 𫋄
    # 0x2B2C5: '',  # 𫋅
    # 0x2B2C6: '',  # 𫋆
    # 0x2B2C7: '',  # 𫋇
    # 0x2B2C8: '',  # 𫋈
    # 0x2B2C9: '',  # 𫋉
    # 0x2B2CA: '',  # 𫋊
    # 0x2B2CB: '',  # 𫋋
    # 0x2B2CC: '',  # 𫋌
    # 0x2B2CD: '',  # 𫋍
    # 0x2B2CE: '',  # 𫋎
    # 0x2B2CF: '',  # 𫋏
    # 0x2B2D0: '',  # 𫋐
    # 0x2B2D1: '',  # 𫋑
    0x2B2D2: 'huí',  # 𫋒
    # 0x2B2D3: '',  # 𫋓
    # 0x2B2D4: '',  # 𫋔
    # 0x2B2D5: '',  # 𫋕
    # 0x2B2D6: '',  # 𫋖
    # 0x2B2D7: '',  # 𫋗
    # 0x2B2D8: '',  # 𫋘
    # 0x2B2D9: '',  # 𫋙
    # 0x2B2DA: '',  # 𫋚
    # 0x2B2DB: '',  # 𫋛
    # 0x2B2DC: '',  # 𫋜
    # 0x2B2DD: '',  # 𫋝
    # 0x2B2DE: '',  # 𫋞
    # 0x2B2DF: '',  # 𫋟
    # 0x2B2E0: '',  # 𫋠
    # 0x2B2E1: '',  # 𫋡
    # 0x2B2E2: '',  # 𫋢
    # 0x2B2E3: '',  # 𫋣
    # 0x2B2E4: '',  # 𫋤
    # 0x2B2E5: '',  # 𫋥
    # 0x2B2E6: '',  # 𫋦
    # 0x2B2E7: '',  # 𫋧
    # 0x2B2E8: '',  # 𫋨
    # 0x2B2E9: '',  # 𫋩
    0x2B2EA: 'pǐ',  # 𫋪
    # 0x2B2EB: '',  # 𫋫
    # 0x2B2EC: '',  # 𫋬
    # 0x2B2ED: '',  # 𫋭
    # 0x2B2EE: '',  # 𫋮
    # 0x2B2EF: '',  # 𫋯
    # 0x2B2F0: '',  # 𫋰
    # 0x2B2F1: '',  # 𫋱
    # 0x2B2F2: '',  # 𫋲
    # 0x2B2F3: '',  # 𫋳
    # 0x2B2F4: '',  # 𫋴
    # 0x2B2F5: '',  # 𫋵
    # 0x2B2F6: '',  # 𫋶
    # 0x2B2F7: '',  # 𫋷
    # 0x2B2F8: '',  # 𫋸
    # 0x2B2F9: '',  # 𫋹
    # 0x2B2FA: '',  # 𫋺
    # 0x2B2FB: '',  # 𫋻
    # 0x2B2FC: '',  # 𫋼
    # 0x2B2FD: '',  # 𫋽
    # 0x2B2FE: '',  # 𫋾
    # 0x2B2FF: '',  # 𫋿
    # 0x2B300: '',  # 𫌀
    # 0x2B301: '',  # 𫌁
    # 0x2B302: '',  # 𫌂
    0x2B303: 'xuē',  # 𫌃
    # 0x2B304: '',  # 𫌄
    # 0x2B305: '',  # 𫌅
    # 0x2B306: '',  # 𫌆
    # 0x2B307: '',  # 𫌇
    # 0x2B308: '',  # 𫌈
    # 0x2B309: '',  # 𫌉
    # 0x2B30A: '',  # 𫌊
    0x2B30B: 'shù',  # 𫌋
    # 0x2B30C: '',  # 𫌌
    # 0x2B30D: '',  # 𫌍
    # 0x2B30E: '',  # 𫌎
    # 0x2B30F: '',  # 𫌏
    # 0x2B310: '',  # 𫌐
    # 0x2B311: '',  # 𫌑
    # 0x2B312: '',  # 𫌒
    # 0x2B313: '',  # 𫌓
    # 0x2B314: '',  # 𫌔
    # 0x2B315: '',  # 𫌕
    # 0x2B316: '',  # 𫌖
    # 0x2B317: '',  # 𫌗
    # 0x2B318: '',  # 𫌘
    0x2B319: 'jiǎn',  # 𫌙
    # 0x2B31A: '',  # 𫌚
    # 0x2B31B: '',  # 𫌛
    # 0x2B31C: '',  # 𫌜
    # 0x2B31D: '',  # 𫌝
    # 0x2B31E: '',  # 𫌞
    # 0x2B31F: '',  # 𫌟
    # 0x2B320: '',  # 𫌠
    # 0x2B321: '',  # 𫌡
    # 0x2B322: '',  # 𫌢
    0x2B323: 'shé',  # 𫌣
    # 0x2B324: '',  # 𫌤
    # 0x2B325: '',  # 𫌥
    # 0x2B326: '',  # 𫌦
    # 0x2B327: '',  # 𫌧
    # 0x2B328: '',  # 𫌨
    0x2B329: 'hǒu',  # 𫌩
    # 0x2B32A: '',  # 𫌪
    # 0x2B32B: '',  # 𫌫
    # 0x2B32C: '',  # 𫌬
    0x2B32D: 'wéi',  # 𫌭
    # 0x2B32E: '',  # 𫌮
    # 0x2B32F: '',  # 𫌯
    # 0x2B330: '',  # 𫌰
    # 0x2B331: '',  # 𫌱
    0x2B332: 'gào',  # 𫌲
    # 0x2B333: '',  # 𫌳
    # 0x2B334: '',  # 𫌴
    # 0x2B335: '',  # 𫌵
    # 0x2B336: '',  # 𫌶
    # 0x2B337: '',  # 𫌷
    0x2B338: 'jiàn',  # 𫌸
    # 0x2B339: '',  # 𫌹
    # 0x2B33A: '',  # 𫌺
    # 0x2B33B: '',  # 𫌻
    # 0x2B33C: '',  # 𫌼
    # 0x2B33D: '',  # 𫌽
    # 0x2B33E: '',  # 𫌾
    # 0x2B33F: '',  # 𫌿
    # 0x2B340: '',  # 𫍀
    # 0x2B341: '',  # 𫍁
    # 0x2B342: '',  # 𫍂
    # 0x2B343: '',  # 𫍃
    # 0x2B344: '',  # 𫍄
    # 0x2B345: '',  # 𫍅
    # 0x2B346: '',  # 𫍆
    # 0x2B347: '',  # 𫍇
    0x2B348: 'tāo',  # 𫍈
    # 0x2B349: '',  # 𫍉
    # 0x2B34A: '',  # 𫍊
    # 0x2B34B: '',  # 𫍋
    # 0x2B34C: '',  # 𫍌
    # 0x2B34D: '',  # 𫍍
    # 0x2B34E: '',  # 𫍎
    # 0x2B34F: '',  # 𫍏
    0x2B350: 'pín',  # 𫍐
    0x2B351: 'yīng',  # 𫍑
    # 0x2B352: '',  # 𫍒
    # 0x2B353: '',  # 𫍓
    # 0x2B354: '',  # 𫍔
    # 0x2B355: '',  # 𫍕
    # 0x2B356: '',  # 𫍖
    # 0x2B357: '',  # 𫍗
    # 0x2B358: '',  # 𫍘
    # 0x2B359: '',  # 𫍙
    # 0x2B35A: '',  # 𫍚
    0x2B35B: 'fēn',  # 𫍛
    # 0x2B35C: '',  # 𫍜
    # 0x2B35D: '',  # 𫍝
    # 0x2B35E: '',  # 𫍞
    # 0x2B35F: '',  # 𫍟
    0x2B360: 'yuǎn',  # 𫍠
    # 0x2B361: '',  # 𫍡
    # 0x2B362: '',  # 𫍢
    0x2B363: 'tóng',  # 𫍣
    # 0x2B364: '',  # 𫍤
    # 0x2B365: '',  # 𫍥
    # 0x2B366: '',  # 𫍦
    # 0x2B367: '',  # 𫍧
    # 0x2B368: '',  # 𫍨
    0x2B369: 'huà',  # 𫍩
    # 0x2B36A: '',  # 𫍪
    0x2B36B: 'yàn',  # 𫍫
    # 0x2B36C: '',  # 𫍬
    # 0x2B36D: '',  # 𫍭
    # 0x2B36E: '',  # 𫍮
    # 0x2B36F: '',  # 𫍯
    # 0x2B370: '',  # 𫍰
    0x2B371: 'zhuān',  # 𫍱
    # 0x2B372: '',  # 𫍲
    0x2B373: 'zhòng',  # 𫍳
    # 0x2B374: '',  # 𫍴
    # 0x2B375: '',  # 𫍵
    0x2B376: 'zhǐ',  # 𫍶
    0x2B377: 'kuì',  # 𫍷
    # 0x2B378: '',  # 𫍸
    # 0x2B379: '',  # 𫍹
    0x2B37A: 'shǎ',  # 𫍺
    # 0x2B37B: '',  # 𫍻
    0x2B37C: 'zhòng',  # 𫍼
    # 0x2B37D: '',  # 𫍽
    # 0x2B37E: '',  # 𫍾
    # 0x2B37F: '',  # 𫍿
    0x2B380: 'gé',  # 𫎀
    # 0x2B381: '',  # 𫎁
    # 0x2B382: '',  # 𫎂
    # 0x2B383: '',  # 𫎃
    # 0x2B384: '',  # 𫎄
    # 0x2B385: '',  # 𫎅
    # 0x2B386: '',  # 𫎆
    0x2B387: 'mēng',  # 𫎇
    # 0x2B388: '',  # 𫎈
    0x2B389: 'kuǎn',  # 𫎉
    # 0x2B38A: '',  # 𫎊
    # 0x2B38B: '',  # 𫎋
    # 0x2B38C: '',  # 𫎌
    # 0x2B38D: '',  # 𫎍
    0x2B38E: 'èr',  # 𫎎
    # 0x2B38F: '',  # 𫎏
    # 0x2B390: '',  # 𫎐
    # 0x2B391: '',  # 𫎑
    # 0x2B392: '',  # 𫎒
    # 0x2B393: '',  # 𫎓
    # 0x2B394: '',  # 𫎔
    # 0x2B395: '',  # 𫎕
    # 0x2B396: '',  # 𫎖
    # 0x2B397: '',  # 𫎗
    0x2B398: 'zhá',  # 𫎘
    # 0x2B399: '',  # 𫎙
    # 0x2B39A: '',  # 𫎚
    0x2B39B: 'chí',  # 𫎛
    # 0x2B39C: '',  # 𫎜
    # 0x2B39D: '',  # 𫎝
    # 0x2B39E: '',  # 𫎞
    # 0x2B39F: '',  # 𫎟
    0x2B3A0: 'xián',  # 𫎠
    # 0x2B3A1: '',  # 𫎡
    0x2B3A2: 'jiù',  # 𫎢
    # 0x2B3A3: '',  # 𫎣
    # 0x2B3A4: '',  # 𫎤
    # 0x2B3A5: '',  # 𫎥
    0x2B3A6: 'lǒng',  # 𫎦
    0x2B3A7: 'gòu',  # 𫎧
    # 0x2B3A8: '',  # 𫎨
    # 0x2B3A9: '',  # 𫎩
    # 0x2B3AA: '',  # 𫎪
    # 0x2B3AB: '',  # 𫎫
    # 0x2B3AC: '',  # 𫎬
    # 0x2B3AD: '',  # 𫎭
    # 0x2B3AE: '',  # 𫎮
    # 0x2B3AF: '',  # 𫎯
    # 0x2B3B0: '',  # 𫎰
    0x2B3B1: 'lì',  # 𫎱
    # 0x2B3B2: '',  # 𫎲
    # 0x2B3B3: '',  # 𫎳
    # 0x2B3B4: '',  # 𫎴
    # 0x2B3B5: '',  # 𫎵
    # 0x2B3B6: '',  # 𫎶
    # 0x2B3B7: '',  # 𫎷
    0x2B3B8: 'jiàn',  # 𫎸
    # 0x2B3B9: '',  # 𫎹
    # 0x2B3BA: '',  # 𫎺
    # 0x2B3BB: '',  # 𫎻
    # 0x2B3BC: '',  # 𫎼
    0x2B3BD: 'ǎi',  # 𫎽
    # 0x2B3BE: '',  # 𫎾
    0x2B3BF: 'shuǎng',  # 𫎿
    # 0x2B3C0: '',  # 𫏀
    0x2B3C1: 'kú',  # 𫏁
    # 0x2B3C2: '',  # 𫏂
    # 0x2B3C3: '',  # 𫏃
    # 0x2B3C4: '',  # 𫏄
    # 0x2B3C5: '',  # 𫏅
    # 0x2B3C6: '',  # 𫏆
    0x2B3C7: 'gòng',  # 𫏇
    # 0x2B3C8: '',  # 𫏈
    # 0x2B3C9: '',  # 𫏉
    # 0x2B3CA: '',  # 𫏊
    # 0x2B3CB: '',  # 𫏋
    0x2B3CC: 'lái',  # 𫏌
    # 0x2B3CD: '',  # 𫏍
    # 0x2B3CE: '',  # 𫏎
    # 0x2B3CF: '',  # 𫏏
    # 0x2B3D0: '',  # 𫏐
    0x2B3D1: 'luò',  # 𫏑
    # 0x2B3D2: '',  # 𫏒
    # 0x2B3D3: '',  # 𫏓
    # 0x2B3D4: '',  # 𫏔
    # 0x2B3D5: '',  # 𫏕
    # 0x2B3D6: '',  # 𫏖
    # 0x2B3D7: '',  # 𫏗
    # 0x2B3D8: '',  # 𫏘
    # 0x2B3D9: '',  # 𫏙
    # 0x2B3DA: '',  # 𫏚
    # 0x2B3DB: '',  # 𫏛
    # 0x2B3DC: '',  # 𫏜
    # 0x2B3DD: '',  # 𫏝
    # 0x2B3DE: '',  # 𫏞
    # 0x2B3DF: '',  # 𫏟
    0x2B3E0: 'làn',  # 𫏠
    # 0x2B3E1: '',  # 𫏡
    # 0x2B3E2: '',  # 𫏢
    # 0x2B3E3: '',  # 𫏣
    # 0x2B3E4: '',  # 𫏤
    # 0x2B3E5: '',  # 𫏥
    # 0x2B3E6: '',  # 𫏦
    # 0x2B3E7: '',  # 𫏧
    # 0x2B3E8: '',  # 𫏨
    # 0x2B3E9: '',  # 𫏩
    # 0x2B3EA: '',  # 𫏪
    # 0x2B3EB: '',  # 𫏫
    # 0x2B3EC: '',  # 𫏬
    # 0x2B3ED: '',  # 𫏭
    # 0x2B3EE: '',  # 𫏮
    0x2B3EF: 'guǐ',  # 𫏯
    # 0x2B3F0: '',  # 𫏰
    # 0x2B3F1: '',  # 𫏱
    # 0x2B3F2: '',  # 𫏲
    # 0x2B3F3: '',  # 𫏳
    # 0x2B3F4: '',  # 𫏴
    # 0x2B3F5: '',  # 𫏵
    # 0x2B3F6: '',  # 𫏶
    0x2B3F7: 'kuáng',  # 𫏷
    # 0x2B3F8: '',  # 𫏸
    # 0x2B3F9: '',  # 𫏹
    # 0x2B3FA: '',  # 𫏺
    # 0x2B3FB: '',  # 𫏻
    # 0x2B3FC: '',  # 𫏼
    # 0x2B3FD: '',  # 𫏽
    # 0x2B3FE: '',  # 𫏾
    # 0x2B3FF: '',  # 𫏿
    # 0x2B400: '',  # 𫐀
    # 0x2B401: '',  # 𫐁
    # 0x2B402: '',  # 𫐂
    0x2B403: 'shēn',  # 𫐃
    # 0x2B404: '',  # 𫐄
    # 0x2B405: '',  # 𫐅
    0x2B406: 'lì',  # 𫐆
    # 0x2B407: '',  # 𫐇
    # 0x2B408: '',  # 𫐈
    # 0x2B409: '',  # 𫐉
    # 0x2B40A: '',  # 𫐊
    # 0x2B40B: '',  # 𫐋
    # 0x2B40C: '',  # 𫐌
    # 0x2B40D: '',  # 𫐍
    # 0x2B40E: '',  # 𫐎
    # 0x2B40F: '',  # 𫐏
    # 0x2B410: '',  # 𫐐
    # 0x2B411: '',  # 𫐑
    # 0x2B412: '',  # 𫐒
    # 0x2B413: '',  # 𫐓
    # 0x2B414: '',  # 𫐔
    # 0x2B415: '',  # 𫐕
    # 0x2B416: '',  # 𫐖
    # 0x2B417: '',  # 𫐗
    # 0x2B418: '',  # 𫐘
    # 0x2B419: '',  # 𫐙
    # 0x2B41A: '',  # 𫐚
    # 0x2B41B: '',  # 𫐛
    # 0x2B41C: '',  # 𫐜
    # 0x2B41D: '',  # 𫐝
    # 0x2B41E: '',  # 𫐞
    # 0x2B41F: '',  # 𫐟
    # 0x2B420: '',  # 𫐠
    # 0x2B421: '',  # 𫐡
    # 0x2B422: '',  # 𫐢
    # 0x2B423: '',  # 𫐣
    # 0x2B424: '',  # 𫐤
    0x2B425: 'lǎo',  # 𫐥
    # 0x2B426: '',  # 𫐦
    # 0x2B427: '',  # 𫐧
    # 0x2B428: '',  # 𫐨
    # 0x2B429: '',  # 𫐩
    # 0x2B42A: '',  # 𫐪
    # 0x2B42B: '',  # 𫐫
    # 0x2B42C: '',  # 𫐬
    # 0x2B42D: '',  # 𫐭
    # 0x2B42E: '',  # 𫐮
    # 0x2B42F: '',  # 𫐯
    # 0x2B430: '',  # 𫐰
    # 0x2B431: '',  # 𫐱
    # 0x2B432: '',  # 𫐲
    # 0x2B433: '',  # 𫐳
    # 0x2B434: '',  # 𫐴
    # 0x2B435: '',  # 𫐵
    # 0x2B436: '',  # 𫐶
    # 0x2B437: '',  # 𫐷
    # 0x2B438: '',  # 𫐸
    # 0x2B439: '',  # 𫐹
    # 0x2B43A: '',  # 𫐺
    0x2B43B: 'qū',  # 𫐻
    # 0x2B43C: '',  # 𫐼
    # 0x2B43D: '',  # 𫐽
    # 0x2B43E: '',  # 𫐾
    # 0x2B43F: '',  # 𫐿
    # 0x2B440: '',  # 𫑀
    # 0x2B441: '',  # 𫑁
    # 0x2B442: '',  # 𫑂
    # 0x2B443: '',  # 𫑃
    # 0x2B444: '',  # 𫑄
    # 0x2B445: '',  # 𫑅
    # 0x2B446: '',  # 𫑆
    # 0x2B447: '',  # 𫑇
    0x2B448: 'yù',  # 𫑈
    # 0x2B449: '',  # 𫑉
    # 0x2B44A: '',  # 𫑊
    # 0x2B44B: '',  # 𫑋
    # 0x2B44C: '',  # 𫑌
    0x2B44D: 'qiǎn',  # 𫑍
    # 0x2B44E: '',  # 𫑎
    # 0x2B44F: '',  # 𫑏
    # 0x2B450: '',  # 𫑐
    # 0x2B451: '',  # 𫑑
    # 0x2B452: '',  # 𫑒
    # 0x2B453: '',  # 𫑓
    # 0x2B454: '',  # 𫑔
    0x2B455: 'dòng',  # 𫑕
    # 0x2B456: '',  # 𫑖
    # 0x2B457: '',  # 𫑗
    # 0x2B458: '',  # 𫑘
    # 0x2B459: '',  # 𫑙
    # 0x2B45A: '',  # 𫑚
    0x2B45B: 'yuè',  # 𫑛
    0x2B45C: 'táo',  # 𫑜
    # 0x2B45D: '',  # 𫑝
    # 0x2B45E: '',  # 𫑞
    # 0x2B45F: '',  # 𫑟
    # 0x2B460: '',  # 𫑠
    # 0x2B461: '',  # 𫑡
    # 0x2B462: '',  # 𫑢
    # 0x2B463: '',  # 𫑣
    # 0x2B464: '',  # 𫑤
    # 0x2B465: '',  # 𫑥
    # 0x2B466: '',  # 𫑦
    # 0x2B467: '',  # 𫑧
    # 0x2B468: '',  # 𫑨
    0x2B469: 'yǎng',  # 𫑩
    # 0x2B46A: '',  # 𫑪
    # 0x2B46B: '',  # 𫑫
    # 0x2B46C: '',  # 𫑬
    0x2B46D: 'qìng',  # 𫑭
    # 0x2B46E: '',  # 𫑮
    # 0x2B46F: '',  # 𫑯
    0x2B470: 'lóng',  # 𫑰
    # 0x2B471: '',  # 𫑱
    0x2B472: 'táng',  # 𫑲
    # 0x2B473: '',  # 𫑳
    0x2B474: 'cún',  # 𫑴
    # 0x2B475: '',  # 𫑵
    # 0x2B476: '',  # 𫑶
    # 0x2B477: '',  # 𫑷
    # 0x2B478: '',  # 𫑸
    # 0x2B479: '',  # 𫑹
    # 0x2B47A: '',  # 𫑺
    # 0x2B47B: '',  # 𫑻
    # 0x2B47C: '',  # 𫑼
    # 0x2B47D: '',  # 𫑽
    # 0x2B47E: '',  # 𫑾
    # 0x2B47F: '',  # 𫑿
    # 0x2B480: '',  # 𫒀
    # 0x2B481: '',  # 𫒁
    # 0x2B482: '',  # 𫒂
    # 0x2B483: '',  # 𫒃
    # 0x2B484: '',  # 𫒄
    # 0x2B485: '',  # 𫒅
    # 0x2B486: '',  # 𫒆
    # 0x2B487: '',  # 𫒇
    # 0x2B488: '',  # 𫒈
    # 0x2B489: '',  # 𫒉
    0x2B48A: 'jǐ',  # 𫒊
    # 0x2B48B: '',  # 𫒋
    0x2B48C: 'jiè',  # 𫒌
    # 0x2B48D: '',  # 𫒍
    # 0x2B48E: '',  # 𫒎
    0x2B48F: 'mǐn',  # 𫒏
    # 0x2B490: '',  # 𫒐
    # 0x2B491: '',  # 𫒑
    # 0x2B492: '',  # 𫒒
    # 0x2B493: '',  # 𫒓
    # 0x2B494: '',  # 𫒔
    # 0x2B495: '',  # 𫒕
    # 0x2B496: '',  # 𫒖
    0x2B497: 'yì',  # 𫒗
    0x2B498: 'fǒu',  # 𫒘
    # 0x2B499: '',  # 𫒙
    # 0x2B49A: '',  # 𫒚
    # 0x2B49B: '',  # 𫒛
    # 0x2B49C: '',  # 𫒜
    0x2B49D: 'xíng',  # 𫒝
    0x2B49E: 'jiè',  # 𫒞
    # 0x2B49F: '',  # 𫒟
    # 0x2B4A0: '',  # 𫒠
    0x2B4A1: 'xián',  # 𫒡
    # 0x2B4A2: '',  # 𫒢
    # 0x2B4A3: '',  # 𫒣
    # 0x2B4A4: '',  # 𫒤
    # 0x2B4A5: '',  # 𫒥
    # 0x2B4A6: '',  # 𫒦
    # 0x2B4A7: '',  # 𫒧
    # 0x2B4A8: '',  # 𫒨
    # 0x2B4A9: '',  # 𫒩
    # 0x2B4AA: '',  # 𫒪
    # 0x2B4AB: '',  # 𫒫
    # 0x2B4AC: '',  # 𫒬
    # 0x2B4AD: '',  # 𫒭
    # 0x2B4AE: '',  # 𫒮
    # 0x2B4AF: '',  # 𫒯
    # 0x2B4B0: '',  # 𫒰
    0x2B4B1: 'shè',  # 𫒱
    # 0x2B4B2: '',  # 𫒲
    # 0x2B4B3: '',  # 𫒳
    # 0x2B4B4: '',  # 𫒴
    # 0x2B4B5: '',  # 𫒵
    # 0x2B4B6: '',  # 𫒶
    0x2B4B7: 'duó',  # 𫒷
    # 0x2B4B8: '',  # 𫒸
    # 0x2B4B9: '',  # 𫒹
    # 0x2B4BA: '',  # 𫒺
    # 0x2B4BB: '',  # 𫒻
    # 0x2B4BC: '',  # 𫒼
    0x2B4BD: 'yíng',  # 𫒽
    # 0x2B4BE: '',  # 𫒾
    # 0x2B4BF: '',  # 𫒿
    # 0x2B4C0: '',  # 𫓀
    # 0x2B4C1: '',  # 𫓁
    # 0x2B4C2: '',  # 𫓂
    # 0x2B4C3: '',  # 𫓃
    # 0x2B4C4: '',  # 𫓄
    # 0x2B4C5: '',  # 𫓅
    # 0x2B4C6: '',  # 𫓆
    0x2B4C7: 'zào',  # 𫓇
    # 0x2B4C8: '',  # 𫓈
    # 0x2B4C9: '',  # 𫓉
    # 0x2B4CA: '',  # 𫓊
    # 0x2B4CB: '',  # 𫓋
    # 0x2B4CC: '',  # 𫓌
    # 0x2B4CD: '',  # 𫓍
    # 0x2B4CE: '',  # 𫓎
    # 0x2B4CF: '',  # 𫓏
    # 0x2B4D0: '',  # 𫓐
    # 0x2B4D1: '',  # 𫓑
    # 0x2B4D2: '',  # 𫓒
    # 0x2B4D3: '',  # 𫓓
    # 0x2B4D4: '',  # 𫓔
    0x2B4D5: 'dūn',  # 𫓕
    # 0x2B4D6: '',  # 𫓖
    # 0x2B4D7: '',  # 𫓗
    # 0x2B4D8: '',  # 𫓘
    # 0x2B4D9: '',  # 𫓙
    # 0x2B4DA: '',  # 𫓚
    # 0x2B4DB: '',  # 𫓛
    0x2B4DC: 'dūn',  # 𫓜
    # 0x2B4DD: '',  # 𫓝
    0x2B4DE: 'lín',  # 𫓞
    # 0x2B4DF: '',  # 𫓟
    # 0x2B4E0: '',  # 𫓠
    # 0x2B4E1: '',  # 𫓡
    # 0x2B4E2: '',  # 𫓢
    # 0x2B4E3: '',  # 𫓣
    # 0x2B4E4: '',  # 𫓤
    0x2B4E5: 'bā',  # 𫓥
    0x2B4E6: 'zǐ',  # 𫓦
    # 0x2B4E7: '',  # 𫓧
    # 0x2B4E8: '',  # 𫓨
    # 0x2B4E9: '',  # 𫓩
    # 0x2B4EA: '',  # 𫓪
    # 0x2B4EB: '',  # 𫓫
    # 0x2B4EC: '',  # 𫓬
    # 0x2B4ED: '',  # 𫓭
    # 0x2B4EE: '',  # 𫓮
    # 0x2B4EF: '',  # 𫓯
    # 0x2B4F0: '',  # 𫓰
    # 0x2B4F1: '',  # 𫓱
    # 0x2B4F2: '',  # 𫓲
    0x2B4F3: 'lǎi',  # 𫓳
    # 0x2B4F4: '',  # 𫓴
    # 0x2B4F5: '',  # 𫓵
    # 0x2B4F6: '',  # 𫓶
    0x2B4F7: 'xián',  # 𫓷
    # 0x2B4F8: '',  # 𫓸
    # 0x2B4F9: '',  # 𫓹
    # 0x2B4FA: '',  # 𫓺
    # 0x2B4FB: '',  # 𫓻
    # 0x2B4FC: '',  # 𫓼
    # 0x2B4FD: '',  # 𫓽
    # 0x2B4FE: '',  # 𫓾
    # 0x2B4FF: '',  # 𫓿
    # 0x2B500: '',  # 𫔀
    0x2B501: 'fén',  # 𫔁
    # 0x2B502: '',  # 𫔂
    0x2B503: 'fén',  # 𫔃
    # 0x2B504: '',  # 𫔄
    # 0x2B505: '',  # 𫔅
    # 0x2B506: '',  # 𫔆
    # 0x2B507: '',  # 𫔇
    0x2B508: 'shuò',  # 𫔈
    # 0x2B509: '',  # 𫔉
    0x2B50A: 'xiù',  # 𫔊
    # 0x2B50B: '',  # 𫔋
    # 0x2B50C: '',  # 𫔌
    # 0x2B50D: '',  # 𫔍
    # 0x2B50E: '',  # 𫔎
    0x2B50F: 'chán',  # 𫔏
    # 0x2B510: '',  # 𫔐
    0x2B511: 'zhǎn',  # 𫔑
    # 0x2B512: '',  # 𫔒
    0x2B513: 'huò',  # 𫔓
    # 0x2B514: '',  # 𫔔
    # 0x2B515: '',  # 𫔕
    # 0x2B516: '',  # 𫔖
    # 0x2B517: '',  # 𫔗
    0x2B518: 'chēng',  # 𫔘
    # 0x2B519: '',  # 𫔙
    # 0x2B51A: '',  # 𫔚
    # 0x2B51B: '',  # 𫔛
    # 0x2B51C: '',  # 𫔜
    # 0x2B51D: '',  # 𫔝
    # 0x2B51E: '',  # 𫔞
    # 0x2B51F: '',  # 𫔟
    # 0x2B520: '',  # 𫔠
    # 0x2B521: '',  # 𫔡
    0x2B522: 'guān',  # 𫔢
    # 0x2B523: '',  # 𫔣
    # 0x2B524: '',  # 𫔤
    # 0x2B525: '',  # 𫔥
    # 0x2B526: '',  # 𫔦
    # 0x2B527: '',  # 𫔧
    # 0x2B528: '',  # 𫔨
    # 0x2B529: '',  # 𫔩
    # 0x2B52A: '',  # 𫔪
    # 0x2B52B: '',  # 𫔫
    # 0x2B52C: '',  # 𫔬
    # 0x2B52D: '',  # 𫔭
    # 0x2B52E: '',  # 𫔮
    # 0x2B52F: '',  # 𫔯
    # 0x2B530: '',  # 𫔰
    0x2B531: 'lán',  # 𫔱
    # 0x2B532: '',  # 𫔲
    # 0x2B533: '',  # 𫔳
    # 0x2B534: '',  # 𫔴
    # 0x2B535: '',  # 𫔵
    # 0x2B536: '',  # 𫔶
    # 0x2B537: '',  # 𫔷
    # 0x2B538: '',  # 𫔸
    # 0x2B539: '',  # 𫔹
    # 0x2B53A: '',  # 𫔺
    # 0x2B53B: '',  # 𫔻
    # 0x2B53C: '',  # 𫔼
    0x2B53D: 'suí',  # 𫔽
    # 0x2B53E: '',  # 𫔾
    # 0x2B53F: '',  # 𫔿
    # 0x2B540: '',  # 𫕀
    # 0x2B541: '',  # 𫕁
    # 0x2B542: '',  # 𫕂
    0x2B543: 'xù',  # 𫕃
    # 0x2B544: '',  # 𫕄
    # 0x2B545: '',  # 𫕅
    # 0x2B546: '',  # 𫕆
    0x2B547: 'yí',  # 𫕇
    # 0x2B548: '',  # 𫕈
    # 0x2B549: '',  # 𫕉
    # 0x2B54A: '',  # 𫕊
    # 0x2B54B: '',  # 𫕋
    # 0x2B54C: '',  # 𫕌
    # 0x2B54D: '',  # 𫕍
    # 0x2B54E: '',  # 𫕎
    # 0x2B54F: '',  # 𫕏
    # 0x2B550: '',  # 𫕐
    # 0x2B551: '',  # 𫕑
    # 0x2B552: '',  # 𫕒
    # 0x2B553: '',  # 𫕓
    # 0x2B554: '',  # 𫕔
    # 0x2B555: '',  # 𫕕
    # 0x2B556: '',  # 𫕖
    # 0x2B557: '',  # 𫕗
    0x2B558: 'jiāng',  # 𫕘
    # 0x2B559: '',  # 𫕙
    # 0x2B55A: '',  # 𫕚
    # 0x2B55B: '',  # 𫕛
    # 0x2B55C: '',  # 𫕜
    0x2B55D: 'zhí',  # 𫕝
    # 0x2B55E: '',  # 𫕞
    # 0x2B55F: '',  # 𫕟
    # 0x2B560: '',  # 𫕠
    # 0x2B561: '',  # 𫕡
    # 0x2B562: '',  # 𫕢
    # 0x2B563: '',  # 𫕣
    # 0x2B564: '',  # 𫕤
    # 0x2B565: '',  # 𫕥
    # 0x2B566: '',  # 𫕦
    # 0x2B567: '',  # 𫕧
    # 0x2B568: '',  # 𫕨
    # 0x2B569: '',  # 𫕩
    # 0x2B56A: '',  # 𫕪
    # 0x2B56B: '',  # 𫕫
    # 0x2B56C: '',  # 𫕬
    # 0x2B56D: '',  # 𫕭
    # 0x2B56E: '',  # 𫕮
    # 0x2B56F: '',  # 𫕯
    # 0x2B570: '',  # 𫕰
    # 0x2B571: '',  # 𫕱
    # 0x2B572: '',  # 𫕲
    # 0x2B573: '',  # 𫕳
    # 0x2B574: '',  # 𫕴
    # 0x2B575: '',  # 𫕵
    # 0x2B576: '',  # 𫕶
    # 0x2B577: '',  # 𫕷
    # 0x2B578: '',  # 𫕸
    # 0x2B579: '',  # 𫕹
    # 0x2B57A: '',  # 𫕺
    # 0x2B57B: '',  # 𫕻
    # 0x2B57C: '',  # 𫕼
    # 0x2B57D: '',  # 𫕽
    # 0x2B57E: '',  # 𫕾
    0x2B57F: 'yáng',  # 𫕿
    # 0x2B580: '',  # 𫖀
    # 0x2B581: '',  # 𫖁
    # 0x2B582: '',  # 𫖂
    # 0x2B583: '',  # 𫖃
    # 0x2B584: '',  # 𫖄
    # 0x2B585: '',  # 𫖅
    # 0x2B586: '',  # 𫖆
    # 0x2B587: '',  # 𫖇
    # 0x2B588: '',  # 𫖈
    # 0x2B589: '',  # 𫖉
    # 0x2B58A: '',  # 𫖊
    # 0x2B58B: '',  # 𫖋
    # 0x2B58C: '',  # 𫖌
    0x2B58D: 'fú',  # 𫖍
    # 0x2B58E: '',  # 𫖎
    # 0x2B58F: '',  # 𫖏
    0x2B590: 'huī',  # 𫖐
    # 0x2B591: '',  # 𫖑
    # 0x2B592: '',  # 𫖒
    0x2B593: 'bǐng',  # 𫖓
    # 0x2B594: '',  # 𫖔
    # 0x2B595: '',  # 𫖕
    0x2B596: 'zhèng',  # 𫖖
    # 0x2B597: '',  # 𫖗
    # 0x2B598: '',  # 𫖘
    # 0x2B599: '',  # 𫖙
    # 0x2B59A: '',  # 𫖚
    # 0x2B59B: '',  # 𫖛
    0x2B59C: 'mù',  # 𫖜
    # 0x2B59D: '',  # 𫖝
    0x2B59E: 'chì',  # 𫖞
    # 0x2B59F: '',  # 𫖟
    # 0x2B5A0: '',  # 𫖠
    # 0x2B5A1: '',  # 𫖡
    # 0x2B5A2: '',  # 𫖢
    # 0x2B5A3: '',  # 𫖣
    # 0x2B5A4: '',  # 𫖤
    # 0x2B5A5: '',  # 𫖥
    # 0x2B5A6: '',  # 𫖦
    # 0x2B5A7: '',  # 𫖧
    # 0x2B5A8: '',  # 𫖨
    # 0x2B5A9: '',  # 𫖩
    0x2B5AA: 'kū',  # 𫖪
    # 0x2B5AB: '',  # 𫖫
    0x2B5AC: 'zhěn',  # 𫖬
    # 0x2B5AD: '',  # 𫖭
    # 0x2B5AE: '',  # 𫖮
    # 0x2B5AF: '',  # 𫖯
    0x2B5B0: 'duǒ',  # 𫖰
    # 0x2B5B1: '',  # 𫖱
    0x2B5B2: 'hùn',  # 𫖲
    # 0x2B5B3: '',  # 𫖳
    0x2B5B4: 'zé',  # 𫖴
    0x2B5B5: 'yuè',  # 𫖵
    0x2B5B6: 'qiān',  # 𫖶
    # 0x2B5B7: '',  # 𫖷
    # 0x2B5B8: '',  # 𫖸
    # 0x2B5B9: '',  # 𫖹
    0x2B5BA: 'fán',  # 𫖺
    # 0x2B5BB: '',  # 𫖻
    # 0x2B5BC: '',  # 𫖼
    # 0x2B5BD: '',  # 𫖽
    # 0x2B5BE: '',  # 𫖾
    # 0x2B5BF: '',  # 𫖿
    # 0x2B5C0: '',  # 𫗀
    # 0x2B5C1: '',  # 𫗁
    # 0x2B5C2: '',  # 𫗂
    # 0x2B5C3: '',  # 𫗃
    # 0x2B5C4: '',  # 𫗄
    # 0x2B5C5: '',  # 𫗅
    # 0x2B5C6: '',  # 𫗆
    # 0x2B5C7: '',  # 𫗇
    0x2B5C8: 'bó',  # 𫗈
    0x2B5C9: 'bèng',  # 𫗉
    # 0x2B5CA: '',  # 𫗊
    # 0x2B5CB: '',  # 𫗋
    # 0x2B5CC: '',  # 𫗌
    0x2B5CD: 'xiào',  # 𫗍
    # 0x2B5CE: '',  # 𫗎
    # 0x2B5CF: '',  # 𫗏
    # 0x2B5D0: '',  # 𫗐
    # 0x2B5D1: '',  # 𫗑
    # 0x2B5D2: '',  # 𫗒
    # 0x2B5D3: '',  # 𫗓
    # 0x2B5D4: '',  # 𫗔
    # 0x2B5D5: '',  # 𫗕
    # 0x2B5D6: '',  # 𫗖
    0x2B5D7: 'mì',  # 𫗗
    # 0x2B5D8: '',  # 𫗘
    # 0x2B5D9: '',  # 𫗙
    0x2B5DA: 'jiǎn',  # 𫗚
    # 0x2B5DB: '',  # 𫗛
    # 0x2B5DC: '',  # 𫗜
    # 0x2B5DD: '',  # 𫗝
    0x2B5DE: 'zhān',  # 𫗞
    0x2B5DF: 'yuán',  # 𫗟
    # 0x2B5E0: '',  # 𫗠
    0x2B5E1: 'hú',  # 𫗡
    # 0x2B5E2: '',  # 𫗢
    # 0x2B5E3: '',  # 𫗣
    0x2B5E4: 'shì',  # 𫗤
    # 0x2B5E5: '',  # 𫗥
    # 0x2B5E6: '',  # 𫗦
    # 0x2B5E7: '',  # 𫗧
    0x2B5E8: 'láng',  # 𫗨
    # 0x2B5E9: '',  # 𫗩
    0x2B5EA: 'wèi',  # 𫗪
    # 0x2B5EB: '',  # 𫗫
    # 0x2B5EC: '',  # 𫗬
    # 0x2B5ED: '',  # 𫗭
    # 0x2B5EE: '',  # 𫗮
    # 0x2B5EF: '',  # 𫗯
    # 0x2B5F0: '',  # 𫗰
    # 0x2B5F1: '',  # 𫗱
    0x2B5F2: 'sǎn',  # 𫗲
    0x2B5F3: 'qiǎng',  # 𫗳
    # 0x2B5F4: '',  # 𫗴
    # 0x2B5F5: '',  # 𫗵
    # 0x2B5F6: '',  # 𫗶
    # 0x2B5F7: '',  # 𫗷
    # 0x2B5F8: '',  # 𫗸
    # 0x2B5F9: '',  # 𫗹
    # 0x2B5FA: '',  # 𫗺
    # 0x2B5FB: '',  # 𫗻
    # 0x2B5FC: '',  # 𫗼
    # 0x2B5FD: '',  # 𫗽
    # 0x2B5FE: '',  # 𫗾
    # 0x2B5FF: '',  # 𫗿
    # 0x2B600: '',  # 𫘀
    # 0x2B601: '',  # 𫘁
    # 0x2B602: '',  # 𫘂
    # 0x2B603: '',  # 𫘃
    # 0x2B604: '',  # 𫘄
    # 0x2B605: '',  # 𫘅
    # 0x2B606: '',  # 𫘆
    0x2B607: 'pǐ',  # 𫘇
    # 0x2B608: '',  # 𫘈
    # 0x2B609: '',  # 𫘉
    # 0x2B60A: '',  # 𫘊
    # 0x2B60B: '',  # 𫘋
    # 0x2B60C: '',  # 𫘌
    # 0x2B60D: '',  # 𫘍
    # 0x2B60E: '',  # 𫘎
    # 0x2B60F: '',  # 𫘏
    # 0x2B610: '',  # 𫘐
    # 0x2B611: '',  # 𫘑
    # 0x2B612: '',  # 𫘒
    # 0x2B613: '',  # 𫘓
    # 0x2B614: '',  # 𫘔
    # 0x2B615: '',  # 𫘕
    # 0x2B616: '',  # 𫘖
    # 0x2B617: '',  # 𫘗
    # 0x2B618: '',  # 𫘘
    # 0x2B619: '',  # 𫘙
    # 0x2B61A: '',  # 𫘚
    # 0x2B61B: '',  # 𫘛
    # 0x2B61C: '',  # 𫘜
    # 0x2B61D: '',  # 𫘝
    # 0x2B61E: '',  # 𫘞
    # 0x2B61F: '',  # 𫘟
    # 0x2B620: '',  # 𫘠
    # 0x2B621: '',  # 𫘡
    # 0x2B622: '',  # 𫘢
    # 0x2B623: '',  # 𫘣
    # 0x2B624: '',  # 𫘤
    # 0x2B625: '',  # 𫘥
    # 0x2B626: '',  # 𫘦
    # 0x2B627: '',  # 𫘧
    # 0x2B628: '',  # 𫘨
    # 0x2B629: '',  # 𫘩
    # 0x2B62A: '',  # 𫘪
    # 0x2B62B: '',  # 𫘫
    # 0x2B62C: '',  # 𫘬
    # 0x2B62D: '',  # 𫘭
    # 0x2B62E: '',  # 𫘮
    # 0x2B62F: '',  # 𫘯
    # 0x2B630: '',  # 𫘰
    # 0x2B631: '',  # 𫘱
    # 0x2B632: '',  # 𫘲
    0x2B633: 'jiàn',  # 𫘳
    # 0x2B634: '',  # 𫘴
    # 0x2B635: '',  # 𫘵
    # 0x2B636: '',  # 𫘶
    # 0x2B637: '',  # 𫘷
    # 0x2B638: '',  # 𫘸
    # 0x2B639: '',  # 𫘹
    # 0x2B63A: '',  # 𫘺
    # 0x2B63B: '',  # 𫘻
    # 0x2B63C: '',  # 𫘼
    # 0x2B63D: '',  # 𫘽
    # 0x2B63E: '',  # 𫘾
    # 0x2B63F: '',  # 𫘿
    # 0x2B640: '',  # 𫙀
    # 0x2B641: '',  # 𫙁
    # 0x2B642: '',  # 𫙂
    # 0x2B643: '',  # 𫙃
    # 0x2B644: '',  # 𫙄
    # 0x2B645: '',  # 𫙅
    0x2B646: 'fǔ',  # 𫙆
    0x2B647: 'huò',  # 𫙇
    # 0x2B648: '',  # 𫙈
    0x2B649: 'fǔ',  # 𫙉
    # 0x2B64A: '',  # 𫙊
    # 0x2B64B: '',  # 𫙋
    # 0x2B64C: '',  # 𫙌
    # 0x2B64D: '',  # 𫙍
    # 0x2B64E: '',  # 𫙎
    # 0x2B64F: '',  # 𫙏
    0x2B650: 'yú',  # 𫙐
    # 0x2B651: '',  # 𫙑
    # 0x2B652: '',  # 𫙒
    # 0x2B653: '',  # 𫙓
    # 0x2B654: '',  # 𫙔
    # 0x2B655: '',  # 𫙕
    # 0x2B656: '',  # 𫙖
    # 0x2B657: '',  # 𫙗
    # 0x2B658: '',  # 𫙘
    # 0x2B659: '',  # 𫙙
    # 0x2B65A: '',  # 𫙚
    # 0x2B65B: '',  # 𫙛
    # 0x2B65C: '',  # 𫙜
    0x2B65D: 'shèng',  # 𫙝
    # 0x2B65E: '',  # 𫙞
    # 0x2B65F: '',  # 𫙟
    # 0x2B660: '',  # 𫙠
    # 0x2B661: '',  # 𫙡
    # 0x2B662: '',  # 𫙢
    # 0x2B663: '',  # 𫙣
    # 0x2B664: '',  # 𫙤
    # 0x2B665: '',  # 𫙥
    # 0x2B666: '',  # 𫙦
    # 0x2B667: '',  # 𫙧
    # 0x2B668: '',  # 𫙨
    # 0x2B669: '',  # 𫙩
    # 0x2B66A: '',  # 𫙪
    # 0x2B66B: '',  # 𫙫
    # 0x2B66C: '',  # 𫙬
    # 0x2B66D: '',  # 𫙭
    # 0x2B66E: '',  # 𫙮
    # 0x2B66F: '',  # 𫙯
    # 0x2B670: '',  # 𫙰
    # 0x2B671: '',  # 𫙱
    # 0x2B672: '',  # 𫙲
    # 0x2B673: '',  # 𫙳
    # 0x2B674: '',  # 𫙴
    # 0x2B675: '',  # 𫙵
    # 0x2B676: '',  # 𫙶
    # 0x2B677: '',  # 𫙷
    # 0x2B678: '',  # 𫙸
    # 0x2B679: '',  # 𫙹
    # 0x2B67A: '',  # 𫙺
    # 0x2B67B: '',  # 𫙻
    # 0x2B67C: '',  # 𫙼
    # 0x2B67D: '',  # 𫙽
    # 0x2B67E: '',  # 𫙾
    # 0x2B67F: '',  # 𫙿
    # 0x2B680: '',  # 𫚀
    # 0x2B681: '',  # 𫚁
    # 0x2B682: '',  # 𫚂
    # 0x2B683: '',  # 𫚃
    # 0x2B684: '',  # 𫚄
    # 0x2B685: '',  # 𫚅
    # 0x2B686: '',  # 𫚆
    # 0x2B687: '',  # 𫚇
    # 0x2B688: '',  # 𫚈
    # 0x2B689: '',  # 𫚉
    # 0x2B68A: '',  # 𫚊
    # 0x2B68B: '',  # 𫚋
    # 0x2B68C: '',  # 𫚌
    # 0x2B68D: '',  # 𫚍
    # 0x2B68E: '',  # 𫚎
    # 0x2B68F: '',  # 𫚏
    # 0x2B690: '',  # 𫚐
    # 0x2B691: '',  # 𫚑
    # 0x2B692: '',  # 𫚒
    # 0x2B693: '',  # 𫚓
    # 0x2B694: '',  # 𫚔
    # 0x2B695: '',  # 𫚕
    # 0x2B696: '',  # 𫚖
    # 0x2B697: '',  # 𫚗
    # 0x2B698: '',  # 𫚘
    # 0x2B699: '',  # 𫚙
    # 0x2B69A: '',  # 𫚚
    # 0x2B69B: '',  # 𫚛
    # 0x2B69C: '',  # 𫚜
    0x2B69D: 'huà',  # 𫚝
    # 0x2B69E: '',  # 𫚞
    # 0x2B69F: '',  # 𫚟
    # 0x2B6A0: '',  # 𫚠
    # 0x2B6A1: '',  # 𫚡
    # 0x2B6A2: '',  # 𫚢
    # 0x2B6A3: '',  # 𫚣
    # 0x2B6A4: '',  # 𫚤
    # 0x2B6A5: '',  # 𫚥
    # 0x2B6A6: '',  # 𫚦
    # 0x2B6A7: '',  # 𫚧
    # 0x2B6A8: '',  # 𫚨
    # 0x2B6A9: '',  # 𫚩
    # 0x2B6AA: '',  # 𫚪
    0x2B6AB: 'sāo',  # 𫚫
    # 0x2B6AC: '',  # 𫚬
    # 0x2B6AD: '',  # 𫚭
    # 0x2B6AE: '',  # 𫚮
    # 0x2B6AF: '',  # 𫚯
    # 0x2B6B0: '',  # 𫚰
    # 0x2B6B1: '',  # 𫚱
    # 0x2B6B2: '',  # 𫚲
    # 0x2B6B3: '',  # 𫚳
    # 0x2B6B4: '',  # 𫚴
    # 0x2B6B5: '',  # 𫚵
    # 0x2B6B6: '',  # 𫚶
    # 0x2B6B7: '',  # 𫚷
    0x2B6B8: 'yǒu',  # 𫚸
    # 0x2B6B9: '',  # 𫚹
    # 0x2B6BA: '',  # 𫚺
    # 0x2B6BB: '',  # 𫚻
    # 0x2B6BC: '',  # 𫚼
    # 0x2B6BD: '',  # 𫚽
    # 0x2B6BE: '',  # 𫚾
    # 0x2B6BF: '',  # 𫚿
    # 0x2B6C0: '',  # 𫛀
    # 0x2B6C1: '',  # 𫛁
    # 0x2B6C2: '',  # 𫛂
    # 0x2B6C3: '',  # 𫛃
    # 0x2B6C4: '',  # 𫛄
    # 0x2B6C5: '',  # 𫛅
    # 0x2B6C6: '',  # 𫛆
    # 0x2B6C7: '',  # 𫛇
    # 0x2B6C8: '',  # 𫛈
    # 0x2B6C9: '',  # 𫛉
    # 0x2B6CA: '',  # 𫛊
    # 0x2B6CB: '',  # 𫛋
    # 0x2B6CC: '',  # 𫛌
    # 0x2B6CD: '',  # 𫛍
    # 0x2B6CE: '',  # 𫛎
    # 0x2B6CF: '',  # 𫛏
    # 0x2B6D0: '',  # 𫛐
    # 0x2B6D1: '',  # 𫛑
    # 0x2B6D2: '',  # 𫛒
    # 0x2B6D3: '',  # 𫛓
    # 0x2B6D4: '',  # 𫛔
    # 0x2B6D5: '',  # 𫛕
    # 0x2B6D6: '',  # 𫛖
    # 0x2B6D7: '',  # 𫛗
    # 0x2B6D8: '',  # 𫛘
    # 0x2B6D9: '',  # 𫛙
    # 0x2B6DA: '',  # 𫛚
    # 0x2B6DB: '',  # 𫛛
    # 0x2B6DC: '',  # 𫛜
    # 0x2B6DD: '',  # 𫛝
    # 0x2B6DE: '',  # 𫛞
    # 0x2B6DF: '',  # 𫛟
    0x2B6E0: 'zhá',  # 𫛠
    # 0x2B6E1: '',  # 𫛡
    # 0x2B6E2: '',  # 𫛢
    # 0x2B6E3: '',  # 𫛣
    # 0x2B6E4: '',  # 𫛤
    # 0x2B6E5: '',  # 𫛥
    # 0x2B6E6: '',  # 𫛦
    # 0x2B6E7: '',  # 𫛧
    # 0x2B6E8: '',  # 𫛨
    # 0x2B6E9: '',  # 𫛩
    # 0x2B6EA: '',  # 𫛪
    # 0x2B6EB: '',  # 𫛫
    # 0x2B6EC: '',  # 𫛬
    # 0x2B6ED: '',  # 𫛭
    # 0x2B6EE: '',  # 𫛮
    # 0x2B6EF: '',  # 𫛯
    # 0x2B6F0: '',  # 𫛰
    # 0x2B6F1: '',  # 𫛱
    # 0x2B6F2: '',  # 𫛲
    # 0x2B6F3: '',  # 𫛳
    # 0x2B6F4: '',  # 𫛴
    # 0x2B6F5: '',  # 𫛵
    # 0x2B6F6: '',  # 𫛶
    # 0x2B6F7: '',  # 𫛷
    # 0x2B6F8: '',  # 𫛸
    0x2B6F9: 'miǎo',  # 𫛹
    # 0x2B6FA: '',  # 𫛺
    # 0x2B6FB: '',  # 𫛻
    # 0x2B6FC: '',  # 𫛼
    # 0x2B6FD: '',  # 𫛽
    # 0x2B6FE: '',  # 𫛾
    # 0x2B6FF: '',  # 𫛿
    # 0x2B700: '',  # 𫜀
    # 0x2B701: '',  # 𫜁
    0x2B702: 'zhāng',  # 𫜂
    # 0x2B703: '',  # 𫜃
    # 0x2B704: '',  # 𫜄
    # 0x2B705: '',  # 𫜅
    # 0x2B706: '',  # 𫜆
    # 0x2B707: '',  # 𫜇
    # 0x2B708: '',  # 𫜈
    # 0x2B709: '',  # 𫜉
    # 0x2B70A: '',  # 𫜊
    # 0x2B70B: '',  # 𫜋
    # 0x2B70C: '',  # 𫜌
    # 0x2B70D: '',  # 𫜍
    # 0x2B70E: '',  # 𫜎
    # 0x2B70F: '',  # 𫜏
    # 0x2B710: '',  # 𫜐
    # 0x2B711: '',  # 𫜑
    0x2B712: 'tuō',  # 𫜒
    # 0x2B713: '',  # 𫜓
    # 0x2B714: '',  # 𫜔
    0x2B715: 'kū',  # 𫜕
    # 0x2B716: '',  # 𫜖
    # 0x2B717: '',  # 𫜗
    # 0x2B718: '',  # 𫜘
    # 0x2B719: '',  # 𫜙
    # 0x2B71A: '',  # 𫜚
    # 0x2B71B: '',  # 𫜛
    # 0x2B71C: '',  # 𫜜
    # 0x2B71D: '',  # 𫜝
    0x2B71E: 'mò',  # 𫜞
    # 0x2B71F: '',  # 𫜟
    # 0x2B720: '',  # 𫜠
    # 0x2B721: '',  # 𫜡
    0x2B722: 'yī',  # 𫜢
    0x2B723: 'dēng',  # 𫜣
    # 0x2B724: '',  # 𫜤
    # 0x2B725: '',  # 𫜥
    0x2B726: 'bǔ',  # 𫜦
    # 0x2B727: '',  # 𫜧
    # 0x2B728: '',  # 𫜨
    # 0x2B729: '',  # 𫜩
    # 0x2B72A: '',  # 𫜪
    0x2B72B: 'bǔ',  # 𫜫
    # 0x2B72C: '',  # 𫜬
    0x2B72D: 'chǔ',  # 𫜭
    # 0x2B72E: '',  # 𫜮
    # 0x2B72F: '',  # 𫜯
    # 0x2B730: '',  # 𫜰
    # 0x2B731: '',  # 𫜱
    0x2B732: 'lóng',  # 𫜲
    # 0x2B733: '',  # 𫜳
    # 0x2B734: '',  # 𫜴
    # 0x2B735: '',  #
    # 0x2B736: '',  #
    # 0x2B737: '',  #
    # 0x2B738: '',  #
    # 0x2B739: '',  #
    # 0x2B73A: '',  #
    # 0x2B73B: '',  #
    # 0x2B73C: '',  #
    # 0x2B73D: '',  #
    # 0x2B73E: '',  #
    # 0x2B73F: '',  #

    # CJK 扩展 D:[2B740-2B81D]
    0x2B740: 'wǔ',  # 𫝀
    0x2B741: 'yǒu',  # 𫝁
    0x2B742: 'suǒ',  # 𫝂
    0x2B743: 'ěr',  # 𫝃
    0x2B744: 'jiǔ',  # 𫝄
    0x2B745: 'huāng',  # 𫝅
    0x2B746: 'jīn',  # 𫝆
    0x2B747: 'mìng',  # 𫝇
    0x2B748: 'hún',  # 𫝈
    0x2B749: 'cāng',  # 𫝉
    0x2B74A: 'fù',  # 𫝊
    0x2B74B: 'shù',  # 𫝋
    0x2B74C: 'yǔ',  # 𫝌
    0x2B74D: 'gāng',  # 𫝍
    # 0x2B74E: '',  # 𫝎
    # 0x2B74F: '',  # 𫝏
    0x2B750: 'qián',  # 𫝐
    0x2B751: 'shì',  # 𫝑
    # 0x2B752: '',  # 𫝒
    0x2B753: 'xié',  # 𫝓
    0x2B754: 'yáo',  # 𫝔
    0x2B755: 'chén',  # 𫝕
    0x2B756: 'cū',  # 𫝖
    0x2B757: 'hòu',  # 𫝗
    # 0x2B758: '',  # 𫝘
    # 0x2B759: '',  # 𫝙
    0x2B75A: 'zhuàn',  # 𫝚
    # 0x2B75B: '',  # 𫝛
    0x2B75C: 'zǎ',  # 𫝜
    0x2B75D: 'yán',  # 𫝝
    0x2B75E: 'bù',  # 𫝞
    0x2B75F: 'zhòng',  # 𫝟
    0x2B760: 'tán',  # 𫝠
    0x2B761: 'duò',  # 𫝡
    0x2B762: 'shēng',  # 𫝢
    0x2B763: 'shēng',  # 𫝣
    0x2B764: 'zòu',  # 𫝤
    0x2B765: 'yǎng',  # 𫝥
    0x2B766: 'bèi',  # 𫝦
    0x2B767: 'shù',  # 𫝧
    0x2B768: 'huī',  # 𫝨
    0x2B769: 'chóu',  # 𫝩
    0x2B76A: 'gòng',  # 𫝪
    0x2B76B: 'lái',  # 𫝫
    0x2B76C: 'kuì',  # 𫝬
    0x2B76D: 'yīng',  # 𫝭
    0x2B76E: 'lǎn',  # 𫝮
    0x2B76F: 'xué',  # 𫝯
    0x2B770: 'zào',  # 𫝰
    0x2B771: 'níng',  # 𫝱
    0x2B772: 'kāo',  # 𫝲
    0x2B773: 'hù',  # 𫝳
    # 0x2B774: '',  # 𫝴
    0x2B775: 'dǎo',  # 𫝵
    0x2B776: 'zuò',  # 𫝶
    0x2B777: 'zuò',  # 𫝷
    0x2B778: 'yàn',  # 𫝸
    0x2B779: 'niàn',  # 𫝹
    # 0x2B77A: '',  # 𫝺
    # 0x2B77B: '',  # 𫝻
    0x2B77C: 'bō',  # 𫝼
    # 0x2B77D: '',  # 𫝽
    # 0x2B77E: '',  # 𫝾
    # 0x2B77F: '',  # 𫝿
    0x2B780: 'zú',  # 𫞀
    # 0x2B781: '',  # 𫞁
    0x2B782: 'yào',  # 𫞂
    0x2B783: 'zhāo,zhào',  # 𫞃
    0x2B784: 'jìn',  # 𫞄
    0x2B785: 'xún',  # 𫞅
    0x2B786: 'gǔ',  # 𫞆
    0x2B787: 'là',  # 𫞇
    # 0x2B788: '',  # 𫞈
    0x2B789: 'liǔ',  # 𫞉
    0x2B78A: 'lì',  # 𫞊
    # 0x2B78B: '',  # 𫞋
    0x2B78C: 'duàn',  # 𫞌
    0x2B78D: 'tán',  # 𫞍
    0x2B78E: 'qiáo',  # 𫞎
    0x2B78F: 'qiáo',  # 𫞏
    0x2B790: 'quán',  # 𫞐
    # 0x2B791: '',  # 𫞑
    0x2B792: 'lì',  # 𫞒
    0x2B793: 'suì',  # 𫞓
    0x2B794: 'jiān',  # 𫞔
    0x2B795: 'shì',  # 𫞕
    0x2B796: 'mín',  # 𫞖
    0x2B797: 'mǐn',  # 𫞗
    0x2B798: 'yuān',  # 𫞘
    # 0x2B799: '',  # 𫞙
    0x2B79A: 'zī',  # 𫞚
    0x2B79B: 'zhū',  # 𫞛
    0x2B79C: 'mǎn',  # 𫞜
    0x2B79D: 'jué',  # 𫞝
    0x2B79E: 'guàn',  # 𫞞
    # 0x2B79F: '',  # 𫞟
    0x2B7A0: 'líng',  # 𫞠
    0x2B7A1: 'róng',  # 𫞡
    0x2B7A2: 'zhì',  # 𫞢
    0x2B7A3: 'chǎn',  # 𫞣
    0x2B7A4: 'yuán',  # 𫞤
    0x2B7A5: 'bèi',  # 𫞥
    0x2B7A6: 'jì',  # 𫞦
    0x2B7A7: 'láo',  # 𫞧
    0x2B7A8: 'lán',  # 𫞨
    0x2B7A9: 'mén',  # 𫞩
    0x2B7AA: 'shèn',  # 𫞪
    0x2B7AB: 'yī',  # 𫞫
    0x2B7AC: 'jìng',  # 𫞬
    # 0x2B7AD: '',  # 𫞭
    # 0x2B7AE: '',  # 𫞮
    0x2B7AF: 'yíng',  # 𫞯
    0x2B7B0: 'yíng',  # 𫞰
    0x2B7B1: 'yán',  # 𫞱
    0x2B7B2: 'zhēn',  # 𫞲
    # 0x2B7B3: '',  # 𫞳
    0x2B7B4: 'jì',  # 𫞴
    # 0x2B7B5: '',  # 𫞵
    0x2B7B6: 'fǔ',  # 𫞶
    0x2B7B7: 'kuài',  # 𫞷
    # 0x2B7B8: '',  # 𫞸
    0x2B7B9: 'kōng',  # 𫞹
    0x2B7BA: 'qiè',  # 𫞺
    # 0x2B7BB: '',  # 𫞻
    # 0x2B7BC: '',  # 𫞼
    0x2B7BD: 'suō',  # 𫞽
    0x2B7BE: 'bì',  # 𫞾
    0x2B7BF: 'liāng',  # 𫞿
    0x2B7C0: 'líng',  # 𫟀
    0x2B7C1: 'duàn',  # 𫟁
    # 0x2B7C2: '',  # 𫟂
    0x2B7C3: 'rén',  # 𫟃
    0x2B7C4: 'hóng',  # 𫟄
    0x2B7C5: 'liáng',  # 𫟅
    0x2B7C6: 'chóng,zhòng',  # 𫟆
    0x2B7C7: 'liào',  # 𫟇
    0x2B7C8: 'měi',  # 𫟈
    0x2B7C9: 'zhí',  # 𫟉
    # 0x2B7CA: '',  # 𫟊
    0x2B7CB: 'yǔ',  # 𫟋
    0x2B7CC: 'yì',  # 𫟌
    0x2B7CD: 'yuàn',  # 𫟍
    0x2B7CE: 'huāng',  # 𫟎
    0x2B7CF: 'tù',  # 𫟏
    0x2B7D0: 'páng,bàng',  # 𫟐
    0x2B7D1: 'líng',  # 𫟑
    0x2B7D2: 'yè',  # 𫟒
    0x2B7D3: 'hàn',  # 𫟓
    0x2B7D4: 'jué',  # 𫟔
    # 0x2B7D5: '',  # 𫟕
    # 0x2B7D6: '',  # 𫟖
    # 0x2B7D7: '',  # 𫟗
    0x2B7D8: 'wèi',  # 𫟘
    0x2B7D9: 'wèi',  # 𫟙
    0x2B7DA: 'lǐ',  # 𫟚
    0x2B7DB: 'tán',  # 𫟛
    0x2B7DC: 'guān,guàn',  # 𫟜
    0x2B7DD: 'ràng',  # 𫟝
    0x2B7DE: 'zhǐ',  # 𫟞
    0x2B7DF: 'pàn',  # 𫟟
    0x2B7E0: 'chǎn',  # 𫟠
    0x2B7E1: 'cóng',  # 𫟡
    0x2B7E2: 'tán',  # 𫟢
    # 0x2B7E3: '',  # 𫟣
    0x2B7E4: 'tuó',  # 𫟤
    0x2B7E5: 'kēng, zhěn',  # 𫟥
    0x2B7E6: 'suì',  # 𫟦
    # 0x2B7E7: '',  # 𫟧
    0x2B7E8: 'yuǎn',  # 𫟨
    # 0x2B7E9: '',  # 𫟩
    0x2B7EA: 'biān',  # 𫟪
    0x2B7EB: 'lì',  # 𫟫
    0x2B7EC: 'zhì',  # 𫟬
    0x2B7ED: 'kè',  # 𫟭
    # 0x2B7EE: '',  # 𫟮
    # 0x2B7EF: '',  # 𫟯
    0x2B7F0: 'dāng',  # 𫟰
    0x2B7F1: 'zhù',  # 𫟱
    0x2B7F2: 'qiú',  # 𫟲
    0x2B7F3: 'sì',  # 𫟳
    0x2B7F4: 'fēn',  # 𫟴
    0x2B7F5: 'yǔn',  # 𫟵
    0x2B7F6: 'shàn,shuò',  # 𫟶
    0x2B7F7: 'lì',  # 𫟷
    0x2B7F8: 'shì',  # 𫟸
    0x2B7F9: 'hóng',  # 𫟹
    0x2B7FA: 'kāi',  # 𫟺
    0x2B7FB: 'zhōu',  # 𫟻
    0x2B7FC: 'dá',  # 𫟼
    0x2B7FD: 'zú',  # 𫟽
    0x2B7FE: 'zú',  # 𫟾
    0x2B7FF: 'chā,suǒ',  # 𫟿
    0x2B800: 'cù',  # 𫠀
    0x2B801: 'hé',  # 𫠁
    0x2B802: 'líng',  # 𫠂
    0x2B803: 'xí',  # 𫠃
    # 0x2B804: '',  # 𫠄
    0x2B805: 'gé',  # 𫠅
    0x2B806: 'kuǐ',  # 𫠆
    0x2B807: 'xín',  # 𫠇
    0x2B808: 'bī,bì',  # 𫠈
    0x2B809: 'mǎ',  # 𫠉
    0x2B80A: 'xuán',  # 𫠊
    0x2B80B: 'lù',  # 𫠋
    0x2B80C: 'bàng',  # 𫠌
    # 0x2B80D: '',  # 𫠍
    # 0x2B80E: '',  # 𫠎
    0x2B80F: 'mù',  # 𫠏
    0x2B810: 'hān',  # 𫠐
    0x2B811: 'qiū,sōu',  # 𫠑
    0x2B812: 'zhāng',  # 𫠒
    0x2B813: 'niǎo,diǎo',  # 𫠓
    0x2B814: 'yuān',  # 𫠔
    0x2B815: 'yīng',  # 𫠕
    0x2B816: 'xióng',  # 𫠖
    0x2B817: 'jiǎn',  # 𫠗
    0x2B818: 'yòu',  # 𫠘
    # 0x2B819: '',  # 𫠙
    0x2B81A: 'chū',  # 𫠚
    # 0x2B81B: '',  # 𫠛
    0x2B81C: 'ní',  # 𫠜
    # 0x2B81D: '',  # 𫠝

    # CJK 兼容扩展:[2F800-2FA1F]
    # 0x2F800: '',  # 丽
    # 0x2F801: '',  # 丸
    # 0x2F802: '',  # 乁
    # 0x2F803: '',  # 𠄢
    # 0x2F804: '',  # 你
    # 0x2F805: '',  # 侮
    # 0x2F806: '',  # 侻
    # 0x2F807: '',  # 倂
    # 0x2F808: '',  # 偺
    # 0x2F809: '',  # 備
    0x2F80A: 'sēng',  # 僧
    # 0x2F80B: '',  # 像
    # 0x2F80C: '',  # 㒞
    # 0x2F80D: '',  # 𠘺
    # 0x2F80E: '',  # 免
    # 0x2F80F: '',  # 兔
    # 0x2F810: '',  # 兤
    # 0x2F811: '',  # 具
    # 0x2F812: '',  # 𠔜
    # 0x2F813: '',  # 㒹
    # 0x2F814: '',  # 內
    # 0x2F815: '',  # 再
    # 0x2F816: '',  # 𠕋
    # 0x2F817: '',  # 冗
    # 0x2F818: '',  # 冤
    # 0x2F819: '',  # 仌
    # 0x2F81A: '',  # 冬
    # 0x2F81B: '',  # 况
    # 0x2F81C: '',  # 𩇟
    # 0x2F81D: '',  # 凵
    # 0x2F81E: '',  # 刃
    # 0x2F81F: '',  # 㓟
    # 0x2F820: '',  # 刻
    # 0x2F821: '',  # 剆
    # 0x2F822: '',  # 割
    # 0x2F823: '',  # 剷
    # 0x2F824: '',  # 㔕
    # 0x2F825: '',  # 勇
    # 0x2F826: '',  # 勉
    # 0x2F827: '',  # 勤
    # 0x2F828: '',  # 勺
    # 0x2F829: '',  # 包
    # 0x2F82A: '',  # 匆
    # 0x2F82B: '',  # 北
    # 0x2F82C: '',  # 卉
    # 0x2F82D: '',  # 卑
    # 0x2F82E: '',  # 博
    # 0x2F82F: '',  # 即
    # 0x2F830: '',  # 卽
    # 0x2F831: '',  # 卿
    # 0x2F832: '',  # 卿
    # 0x2F833: '',  # 卿
    # 0x2F834: '',  # 𠨬
    # 0x2F835: '',  # 灰
    # 0x2F836: '',  # 及
    # 0x2F837: '',  # 叟
    # 0x2F838: '',  # 𠭣
    # 0x2F839: '',  # 叫
    # 0x2F83A: '',  # 叱
    # 0x2F83B: '',  # 吆
    # 0x2F83C: '',  # 咞
    # 0x2F83D: '',  # 吸
    # 0x2F83E: '',  # 呈
    # 0x2F83F: '',  # 周
    # 0x2F840: '',  # 咢
    # 0x2F841: '',  # 哶
    # 0x2F842: '',  # 唐
    # 0x2F843: '',  # 啓
    # 0x2F844: '',  # 啣
    # 0x2F845: '',  # 善
    # 0x2F846: '',  # 善
    # 0x2F847: '',  # 喙
    # 0x2F848: '',  # 喫
    # 0x2F849: '',  # 喳
    # 0x2F84A: '',  # 嗂
    # 0x2F84B: '',  # 圖
    # 0x2F84C: '',  # 嘆
    # 0x2F84D: '',  # 圗
    # 0x2F84E: '',  # 噑
    # 0x2F84F: '',  # 噴
    # 0x2F850: '',  # 切
    # 0x2F851: '',  # 壮
    # 0x2F852: '',  # 城
    # 0x2F853: '',  # 埴
    # 0x2F854: '',  # 堍
    # 0x2F855: '',  # 型
    # 0x2F856: '',  # 堲
    # 0x2F857: '',  # 報
    # 0x2F858: '',  # 墬
    # 0x2F859: '',  # 𡓤
    # 0x2F85A: '',  # 売
    # 0x2F85B: '',  # 壷
    # 0x2F85C: '',  # 夆
    # 0x2F85D: '',  # 多
    # 0x2F85E: '',  # 夢
    # 0x2F85F: '',  # 奢
    # 0x2F860: '',  # 𡚨
    # 0x2F861: '',  # 𡛪
    # 0x2F862: '',  # 姬
    # 0x2F863: '',  # 娛
    # 0x2F864: '',  # 娧
    # 0x2F865: '',  # 姘
    # 0x2F866: '',  # 婦
    # 0x2F867: '',  # 㛮
    # 0x2F868: '',  # 㛼
    # 0x2F869: '',  # 嬈
    # 0x2F86A: '',  # 嬾
    # 0x2F86B: '',  # 嬾
    # 0x2F86C: '',  # 𡧈
    # 0x2F86D: '',  # 寃
    # 0x2F86E: '',  # 寘
    # 0x2F86F: '',  # 寧
    # 0x2F870: '',  # 寳
    # 0x2F871: '',  # 𡬘
    # 0x2F872: '',  # 寿
    # 0x2F873: '',  # 将
    # 0x2F874: '',  # 当
    # 0x2F875: '',  # 尢
    # 0x2F876: '',  # 㞁
    # 0x2F877: '',  # 屠
    # 0x2F878: '',  # 屮
    # 0x2F879: '',  # 峀
    # 0x2F87A: '',  # 岍
    # 0x2F87B: '',  # 𡷤
    # 0x2F87C: '',  # 嵃
    # 0x2F87D: '',  # 𡷦
    # 0x2F87E: '',  # 嵮
    # 0x2F87F: '',  # 嵫
    # 0x2F880: '',  # 嵼
    # 0x2F881: '',  # 巡
    # 0x2F882: '',  # 巢
    # 0x2F883: '',  # 㠯
    # 0x2F884: '',  # 巽
    # 0x2F885: '',  # 帨
    # 0x2F886: '',  # 帽
    # 0x2F887: '',  # 幩
    # 0x2F888: '',  # 㡢
    # 0x2F889: '',  # 𢆃
    # 0x2F88A: '',  # 㡼
    # 0x2F88B: '',  # 庰
    # 0x2F88C: '',  # 庳
    # 0x2F88D: '',  # 庶
    # 0x2F88E: '',  # 廊
    # 0x2F88F: '',  # 𪎒
    # 0x2F890: '',  # 廾
    # 0x2F891: '',  # 𢌱
    # 0x2F892: '',  # 𢌱
    # 0x2F893: '',  # 舁
    # 0x2F894: '',  # 弢
    # 0x2F895: '',  # 弢
    # 0x2F896: '',  # 㣇
    # 0x2F897: '',  # 𣊸
    # 0x2F898: '',  # 𦇚
    # 0x2F899: '',  # 形
    # 0x2F89A: '',  # 彫
    # 0x2F89B: '',  # 㣣
    # 0x2F89C: '',  # 徚
    # 0x2F89D: '',  # 忍
    # 0x2F89E: '',  # 志
    # 0x2F89F: '',  # 忹
    # 0x2F8A0: '',  # 悁
    # 0x2F8A1: '',  # 㤺
    # 0x2F8A2: '',  # 㤜
    # 0x2F8A3: '',  # 悔
    # 0x2F8A4: '',  # 𢛔
    # 0x2F8A5: '',  # 惇
    # 0x2F8A6: '',  # 慈
    # 0x2F8A7: '',  # 慌
    # 0x2F8A8: '',  # 慎
    # 0x2F8A9: '',  # 慌
    # 0x2F8AA: '',  # 慺
    # 0x2F8AB: '',  # 憎
    # 0x2F8AC: '',  # 憲
    # 0x2F8AD: '',  # 憤
    # 0x2F8AE: '',  # 憯
    # 0x2F8AF: '',  # 懞
    # 0x2F8B0: '',  # 懲
    # 0x2F8B1: '',  # 懶
    # 0x2F8B2: '',  # 成
    # 0x2F8B3: '',  # 戛
    # 0x2F8B4: '',  # 扝
    # 0x2F8B5: '',  # 抱
    # 0x2F8B6: '',  # 拔
    0x2F8B7: 'juān',  # 捐
    # 0x2F8B8: '',  # 𢬌
    # 0x2F8B9: '',  # 挽
    # 0x2F8BA: '',  # 拼
    # 0x2F8BB: '',  # 捨
    # 0x2F8BC: '',  # 掃
    # 0x2F8BD: '',  # 揤
    # 0x2F8BE: '',  # 𢯱
    # 0x2F8BF: '',  # 搢
    # 0x2F8C0: '',  # 揅
    # 0x2F8C1: '',  # 掩
    # 0x2F8C2: '',  # 㨮
    # 0x2F8C3: '',  # 摩
    # 0x2F8C4: '',  # 摾
    # 0x2F8C5: '',  # 撝
    # 0x2F8C6: '',  # 摷
    # 0x2F8C7: '',  # 㩬
    # 0x2F8C8: '',  # 敏
    # 0x2F8C9: '',  # 敬
    # 0x2F8CA: '',  # 𣀊
    # 0x2F8CB: '',  # 旣
    # 0x2F8CC: '',  # 書
    # 0x2F8CD: '',  # 晉
    # 0x2F8CE: '',  # 㬙
    # 0x2F8CF: '',  # 暑
    # 0x2F8D0: '',  # 㬈
    # 0x2F8D1: '',  # 㫤
    # 0x2F8D2: '',  # 冒
    # 0x2F8D3: '',  # 冕
    # 0x2F8D4: '',  # 最
    # 0x2F8D5: '',  # 暜
    # 0x2F8D6: '',  # 肭
    # 0x2F8D7: '',  # 䏙
    # 0x2F8D8: '',  # 朗
    # 0x2F8D9: '',  # 望
    # 0x2F8DA: '',  # 朡
    # 0x2F8DB: '',  # 杞
    # 0x2F8DC: '',  # 杓
    # 0x2F8DD: '',  # 𣏃
    # 0x2F8DE: '',  # 㭉
    # 0x2F8DF: '',  # 柺
    # 0x2F8E0: '',  # 枅
    # 0x2F8E1: '',  # 桒
    # 0x2F8E2: '',  # 梅
    # 0x2F8E3: '',  # 𣑭
    # 0x2F8E4: '',  # 梎
    # 0x2F8E5: '',  # 栟
    # 0x2F8E6: '',  # 椔
    # 0x2F8E7: '',  # 㮝
    # 0x2F8E8: '',  # 楂
    # 0x2F8E9: '',  # 榣
    # 0x2F8EA: '',  # 槪
    # 0x2F8EB: '',  # 檨
    # 0x2F8EC: '',  # 𣚣
    # 0x2F8ED: '',  # 櫛
    # 0x2F8EE: '',  # 㰘
    # 0x2F8EF: '',  # 次
    # 0x2F8F0: '',  # 𣢧
    # 0x2F8F1: '',  # 歔
    # 0x2F8F2: '',  # 㱎
    # 0x2F8F3: '',  # 歲
    # 0x2F8F4: '',  # 殟
    # 0x2F8F5: '',  # 殺
    # 0x2F8F6: '',  # 殻
    # 0x2F8F7: '',  # 𣪍
    # 0x2F8F8: '',  # 𡴋
    # 0x2F8F9: '',  # 𣫺
    # 0x2F8FA: '',  # 汎
    # 0x2F8FB: '',  # 𣲼
    # 0x2F8FC: '',  # 沿
    # 0x2F8FD: '',  # 泍
    # 0x2F8FE: '',  # 汧
    # 0x2F8FF: '',  # 洖
    # 0x2F900: '',  # 派
    # 0x2F901: '',  # 海
    # 0x2F902: '',  # 流
    # 0x2F903: '',  # 浩
    # 0x2F904: '',  # 浸
    # 0x2F905: '',  # 涅
    # 0x2F906: '',  # 𣴞
    # 0x2F907: '',  # 洴
    # 0x2F908: '',  # 港
    # 0x2F909: '',  # 湮
    # 0x2F90A: '',  # 㴳
    # 0x2F90B: '',  # 滋
    # 0x2F90C: '',  # 滇
    # 0x2F90D: '',  # 𣻑
    # 0x2F90E: '',  # 淹
    # 0x2F90F: '',  # 潮
    # 0x2F910: '',  # 𣽞
    # 0x2F911: '',  # 𣾎
    # 0x2F912: '',  # 濆
    # 0x2F913: '',  # 瀹
    # 0x2F914: '',  # 瀞
    # 0x2F915: '',  # 瀛
    # 0x2F916: '',  # 㶖
    # 0x2F917: '',  # 灊
    # 0x2F918: '',  # 災
    # 0x2F919: '',  # 灷
    # 0x2F91A: '',  # 炭
    # 0x2F91B: '',  # 𠔥
    # 0x2F91C: '',  # 煅
    # 0x2F91D: '',  # 𤉣
    # 0x2F91E: '',  # 熜
    # 0x2F91F: '',  # 𤎫
    # 0x2F920: '',  # 爨
    # 0x2F921: '',  # 爵
    # 0x2F922: '',  # 牐
    # 0x2F923: '',  # 𤘈
    # 0x2F924: '',  # 犀
    # 0x2F925: '',  # 犕
    # 0x2F926: '',  # 𤜵
    # 0x2F927: '',  # 𤠔
    # 0x2F928: '',  # 獺
    # 0x2F929: '',  # 王
    # 0x2F92A: '',  # 㺬
    # 0x2F92B: '',  # 玥
    # 0x2F92C: '',  # 㺸
    # 0x2F92D: '',  # 㺸
    # 0x2F92E: '',  # 瑇
    # 0x2F92F: '',  # 瑜
    # 0x2F930: '',  # 瑱
    # 0x2F931: '',  # 璅
    # 0x2F932: '',  # 瓊
    # 0x2F933: '',  # 㼛
    # 0x2F934: '',  # 甤
    # 0x2F935: '',  # 𤰶
    # 0x2F936: '',  # 甾
    # 0x2F937: '',  # 𤲒
    # 0x2F938: '',  # 異
    # 0x2F939: '',  # 𢆟
    # 0x2F93A: '',  # 瘐
    # 0x2F93B: '',  # 𤾡
    # 0x2F93C: '',  # 𤾸
    # 0x2F93D: '',  # 𥁄
    # 0x2F93E: '',  # 㿼
    # 0x2F93F: '',  # 䀈
    # 0x2F940: '',  # 直
    # 0x2F941: '',  # 𥃳
    # 0x2F942: '',  # 𥃲
    # 0x2F943: '',  # 𥄙
    # 0x2F944: '',  # 𥄳
    # 0x2F945: '',  # 眞
    # 0x2F946: '',  # 真
    # 0x2F947: '',  # 真
    # 0x2F948: '',  # 睊
    # 0x2F949: '',  # 䀹
    # 0x2F94A: '',  # 瞋
    # 0x2F94B: '',  # 䁆
    # 0x2F94C: '',  # 䂖
    # 0x2F94D: '',  # 𥐝
    # 0x2F94E: '',  # 硎
    # 0x2F94F: '',  # 碌
    # 0x2F950: '',  # 磌
    # 0x2F951: '',  # 䃣
    # 0x2F952: '',  # 𥘦
    # 0x2F953: '',  # 祖
    # 0x2F954: '',  # 𥚚
    # 0x2F955: '',  # 𥛅
    # 0x2F956: '',  # 福
    # 0x2F957: '',  # 秫
    # 0x2F958: '',  # 䄯
    # 0x2F959: '',  # 穀
    # 0x2F95A: '',  # 穊
    # 0x2F95B: '',  # 穏
    # 0x2F95C: '',  # 𥥼
    # 0x2F95D: '',  # 𥪧
    # 0x2F95E: '',  # 𥪧
    # 0x2F95F: '',  # 竮
    # 0x2F960: '',  # 䈂
    # 0x2F961: '',  # 𥮫
    # 0x2F962: '',  # 篆
    # 0x2F963: '',  # 築
    # 0x2F964: '',  # 䈧
    # 0x2F965: '',  # 𥲀
    # 0x2F966: '',  # 糒
    # 0x2F967: '',  # 䊠
    # 0x2F968: '',  # 糨
    # 0x2F969: '',  # 糣
    # 0x2F96A: '',  # 紀
    # 0x2F96B: '',  # 𥾆
    # 0x2F96C: '',  # 絣
    # 0x2F96D: '',  # 䌁
    # 0x2F96E: '',  # 緇
    # 0x2F96F: '',  # 縂
    # 0x2F970: '',  # 繅
    # 0x2F971: '',  # 䌴
    # 0x2F972: '',  # 𦈨
    # 0x2F973: '',  # 𦉇
    # 0x2F974: '',  # 䍙
    # 0x2F975: '',  # 𦋙
    # 0x2F976: '',  # 罺
    # 0x2F977: '',  # 𦌾
    # 0x2F978: '',  # 羕
    # 0x2F979: '',  # 翺
    # 0x2F97A: '',  # 者
    # 0x2F97B: '',  # 𦓚
    # 0x2F97C: '',  # 𦔣
    # 0x2F97D: '',  # 聠
    # 0x2F97E: '',  # 𦖨
    # 0x2F97F: '',  # 聰
    # 0x2F980: '',  # 𣍟
    # 0x2F981: '',  # 䏕
    # 0x2F982: '',  # 育
    # 0x2F983: '',  # 脃
    # 0x2F984: '',  # 䐋
    # 0x2F985: '',  # 脾
    # 0x2F986: '',  # 媵
    # 0x2F987: '',  # 𦞧
    # 0x2F988: '',  # 𦞵
    # 0x2F989: '',  # 𣎓
    # 0x2F98A: '',  # 𣎜
    # 0x2F98B: '',  # 舁
    # 0x2F98C: '',  # 舄
    # 0x2F98D: '',  # 辞
    # 0x2F98E: '',  # 䑫
    # 0x2F98F: '',  # 芑
    # 0x2F990: '',  # 芋
    # 0x2F991: '',  # 芝
    # 0x2F992: '',  # 劳
    # 0x2F993: '',  # 花
    # 0x2F994: '',  # 芳
    # 0x2F995: '',  # 芽
    # 0x2F996: '',  # 苦
    # 0x2F997: '',  # 𦬼
    # 0x2F998: '',  # 若
    # 0x2F999: '',  # 茝
    # 0x2F99A: '',  # 荣
    # 0x2F99B: '',  # 莭
    # 0x2F99C: '',  # 茣
    # 0x2F99D: '',  # 莽
    # 0x2F99E: '',  # 菧
    # 0x2F99F: '',  # 著
    # 0x2F9A0: '',  # 荓
    # 0x2F9A1: '',  # 菊
    # 0x2F9A2: '',  # 菌
    # 0x2F9A3: '',  # 菜
    # 0x2F9A4: '',  # 𦰶
    # 0x2F9A5: '',  # 𦵫
    # 0x2F9A6: '',  # 𦳕
    # 0x2F9A7: '',  # 䔫
    # 0x2F9A8: '',  # 蓱
    # 0x2F9A9: '',  # 蓳
    # 0x2F9AA: '',  # 蔖
    # 0x2F9AB: '',  # 𧏊
    # 0x2F9AC: '',  # 蕤
    # 0x2F9AD: '',  # 𦼬
    # 0x2F9AE: '',  # 䕝
    # 0x2F9AF: '',  # 䕡
    # 0x2F9B0: '',  # 𦾱
    # 0x2F9B1: '',  # 𧃒
    # 0x2F9B2: '',  # 䕫
    # 0x2F9B3: '',  # 虐
    # 0x2F9B4: '',  # 虜
    # 0x2F9B5: '',  # 虧
    # 0x2F9B6: '',  # 虩
    # 0x2F9B7: '',  # 蚩
    # 0x2F9B8: '',  # 蚈
    # 0x2F9B9: '',  # 蜎
    # 0x2F9BA: '',  # 蛢
    # 0x2F9BB: '',  # 蝹
    # 0x2F9BC: '',  # 蜨
    # 0x2F9BD: '',  # 蝫
    # 0x2F9BE: '',  # 螆
    # 0x2F9BF: '',  # 䗗
    # 0x2F9C0: '',  # 蟡
    # 0x2F9C1: '',  # 蠁
    # 0x2F9C2: '',  # 䗹
    # 0x2F9C3: '',  # 衠
    # 0x2F9C4: '',  # 衣
    # 0x2F9C5: '',  # 𧙧
    # 0x2F9C6: '',  # 裗
    # 0x2F9C7: '',  # 裞
    # 0x2F9C8: '',  # 䘵
    # 0x2F9C9: '',  # 裺
    # 0x2F9CA: '',  # 㒻
    # 0x2F9CB: '',  # 𧢮
    # 0x2F9CC: '',  # 𧥦
    # 0x2F9CD: '',  # 䚾
    # 0x2F9CE: '',  # 䛇
    # 0x2F9CF: '',  # 誠
    # 0x2F9D0: '',  # 諭
    # 0x2F9D1: '',  # 變
    # 0x2F9D2: '',  # 豕
    # 0x2F9D3: '',  # 𧲨
    # 0x2F9D4: '',  # 貫
    # 0x2F9D5: '',  # 賁
    # 0x2F9D6: '',  # 贛
    # 0x2F9D7: '',  # 起
    # 0x2F9D8: '',  # 𧼯
    # 0x2F9D9: '',  # 𠠄
    # 0x2F9DA: '',  # 跋
    # 0x2F9DB: '',  # 趼
    # 0x2F9DC: '',  # 跰
    # 0x2F9DD: '',  # 𠣞
    # 0x2F9DE: '',  # 軔
    # 0x2F9DF: '',  # 輸
    # 0x2F9E0: '',  # 𨗒
    # 0x2F9E1: '',  # 𨗭
    # 0x2F9E2: '',  # 邔
    # 0x2F9E3: '',  # 郱
    # 0x2F9E4: '',  # 鄑
    # 0x2F9E5: '',  # 𨜮
    # 0x2F9E6: '',  # 鄛
    # 0x2F9E7: '',  # 鈸
    # 0x2F9E8: '',  # 鋗
    # 0x2F9E9: '',  # 鋘
    # 0x2F9EA: '',  # 鉼
    # 0x2F9EB: '',  # 鏹
    # 0x2F9EC: '',  # 鐕
    # 0x2F9ED: '',  # 𨯺
    # 0x2F9EE: '',  # 開
    # 0x2F9EF: '',  # 䦕
    # 0x2F9F0: '',  # 閷
    # 0x2F9F1: '',  # 𨵷
    # 0x2F9F2: '',  # 䧦
    # 0x2F9F3: '',  # 雃
    # 0x2F9F4: '',  # 嶲
    # 0x2F9F5: '',  # 霣
    # 0x2F9F6: '',  # 𩅅
    # 0x2F9F7: '',  # 𩈚
    # 0x2F9F8: '',  # 䩮
    # 0x2F9F9: '',  # 䩶
    # 0x2F9FA: '',  # 韠
    # 0x2F9FB: '',  # 𩐊
    # 0x2F9FC: '',  # 䪲
    # 0x2F9FD: '',  # 𩒖
    # 0x2F9FE: '',  # 頋
    # 0x2F9FF: '',  # 頋
    # 0x2FA00: '',  # 頩
    # 0x2FA01: '',  # 𩖶
    # 0x2FA02: '',  # 飢
    # 0x2FA03: '',  # 䬳
    # 0x2FA04: '',  # 餩
    # 0x2FA05: '',  # 馧
    # 0x2FA06: '',  # 駂
    # 0x2FA07: '',  # 駾
    # 0x2FA08: '',  # 䯎
    # 0x2FA09: '',  # 𩬰
    # 0x2FA0A: '',  # 鬒
    # 0x2FA0B: '',  # 鱀
    # 0x2FA0C: '',  # 鳽
    # 0x2FA0D: '',  # 䳎
    # 0x2FA0E: '',  # 䳭
    # 0x2FA0F: '',  # 鵧
    # 0x2FA10: '',  # 𪃎
    # 0x2FA11: '',  # 䳸
    # 0x2FA12: '',  # 𪄅
    # 0x2FA13: '',  # 𪈎
    # 0x2FA14: '',  # 𪊑
    # 0x2FA15: '',  # 麻
    # 0x2FA16: '',  # 䵖
    # 0x2FA17: '',  # 黹
    # 0x2FA18: '',  # 黾
    # 0x2FA19: '',  # 鼅
    # 0x2FA1A: '',  # 鼏
    # 0x2FA1B: '',  # 鼖
    # 0x2FA1C: '',  # 鼻
    # 0x2FA1D: '',  # 𪘀
    # 0x2FA1E: '',  #
    # 0x2FA1F: '',  #
'''
